@@ -65,6 +65,14 @@ DOCUMENTATION = """
         vars:
           - name: ansible_libssh_password_prompt
         version_added: 3.1.0
+      private_key_passphrase:
+        description:
+          - Passphrase used to unlock the private key specified by the C(ansible_private_key_file) attribute.
+          - This is required if the private key is encrypted with a passphrase.
+        type: string
+        vars:
+            - name: ansible_private_key_password
+            - name: ansible_private_key_passphrase
       host_key_auto_add:
         description: 'TODO: write it'
         env: [{name: ANSIBLE_LIBSSH_HOST_KEY_AUTO_ADD}]
@@ -100,6 +108,40 @@ DOCUMENTATION = """
           - section: libssh_connection
             key: pty
         type: boolean
+      publickey_accepted_algorithms:
+        default: ''
+        description:
+            - List of algorithms to forward to SSH_OPTIONS_PUBLICKEY_ACCEPTED_TYPES.
+        type: str
+        env:
+          - name: ANSIBLE_LIBSSH_PUBLICKEY_ALGORITHMS
+        ini:
+          - {key: publickey_algorithms, section: libssh_connection}
+        vars:
+          - name: ansible_libssh_publickey_algorithms
+      hostkeys:
+        default: ''
+        description: Set the preferred server host key types as a comma-separated list (e.g., ssh-rsa,ssh-dss,ecdh-sha2-nistp256).
+        type: str
+        env:
+          - name: ANSIBLE_LIBSSH_HOSTKEYS
+        ini:
+          - {key: hostkeys, section: libssh_connection}
+        vars:
+          - name: ansible_libssh_hostkeys
+      key_exchange_algorithms:
+        description:
+          - Set the key exchange method as a comma-separated list (e.g., "ecdh-sha2-nistp256,diffie-hellman-group14-sha1,diffie-hellman-group1-sha1").
+          - The list can be prepended by +,-,^ which will append, remove or move to the beginning (prioritizing) of the default list respectively.
+            Giving an empty list after + and ^ will cause error.
+        type: str
+        env:
+          - name: ANSIBLE_LIBSSH_KEY_EXCHANGE_ALGORITHMS
+        ini:
+          - key: key_exchange_algorithms
+            section: libssh_connection
+        vars:
+          - name: ansible_libssh_key_exchange_algorithms
       host_key_checking:
         description: 'Set this to "False" if you want to avoid host key checking by the underlying tools Ansible uses to connect to the host'
         type: boolean
@@ -195,14 +237,10 @@ import logging
 import os
 import re
 import socket
-import sys
-
-from termios import TCIFLUSH, tcflush
 
 from ansible.errors import AnsibleConnectionFailure, AnsibleError, AnsibleFileNotFound
-from ansible.module_utils._text import to_bytes, to_native, to_text
 from ansible.module_utils.basic import missing_required_lib
-from ansible.module_utils.six.moves import input
+from ansible.module_utils.common.text.converters import to_bytes, to_native, to_text
 from ansible.plugins.connection import ConnectionBase
 from ansible.utils.display import Display
 
@@ -241,8 +279,7 @@ class MyAddPolicy(object):
     local L{HostKeys} object, and saving it.  This is used by L{SSHClient}.
     """
 
-    def __init__(self, new_stdin, connection):
-        self._new_stdin = new_stdin
+    def __init__(self, connection):
         self.connection = connection
         self._options = connection._options
 
@@ -263,15 +300,12 @@ class MyAddPolicy(object):
                     AUTHENTICITY_MSG.rsplit("\n", 2)[0] % (hostname, message, key_type, fingerprint)
                 )
 
-            self.connection.connection_lock()
-            old_stdin = sys.stdin
-            sys.stdin = self._new_stdin
-
-            # clear out any premature input on sys.stdin
-            tcflush(sys.stdin, TCIFLUSH)
-
-            inp = input(AUTHENTICITY_MSG % (hostname, message, key_type, fingerprint))
-            sys.stdin = old_stdin
+            inp = to_text(
+                display.prompt_until(
+                    AUTHENTICITY_MSG % (hostname, message, key_type, fingerprint), private=False
+                ),
+                errors="surrogate_or_strict",
+            )
 
             self.connection.connection_unlock()
             if inp not in ["yes", "y", ""]:
@@ -375,8 +409,8 @@ class Connection(ConnectionBase):
 
         self.ssh = Session()
 
-        if self._play_context.verbosity > 3:
-            self.ssh.set_log_level(logging.INFO)
+        if display.verbosity > 3:
+            self.ssh.set_log_level(logging.DEBUG)
 
         self.keyfile = os.path.expanduser("~/.ssh/known_hosts")
 
@@ -401,7 +435,20 @@ class Connection(ConnectionBase):
                     "Please upgrade to ansible-pylibssh 1.0.0 or newer." % PYLIBSSH_VERSION
                 )
 
-            self.ssh.set_missing_host_key_policy(MyAddPolicy(self._new_stdin, self))
+            if self.get_option("publickey_accepted_algorithms"):
+                ssh_connect_kwargs["publickey_accepted_algorithms"] = self.get_option(
+                    "publickey_accepted_algorithms"
+                )
+
+            if self.get_option("hostkeys"):
+                ssh_connect_kwargs["hostkeys"] = self.get_option("hostkeys")
+
+            if self.get_option("key_exchange_algorithms"):
+                ssh_connect_kwargs["key_exchange_algorithms"] = self.get_option(
+                    "key_exchange_algorithms"
+                )
+
+            self.ssh.set_missing_host_key_policy(MyAddPolicy(self))
 
             self.ssh.connect(
                 host=remote_addr.lower(),
@@ -411,6 +458,7 @@ class Connection(ConnectionBase):
                 password=self.get_option("password"),
                 password_prompt=self.get_option("password_prompt"),
                 private_key=private_key,
+                private_key_password=self.get_option("private_key_passphrase"),
                 timeout=self._play_context.timeout,
                 port=port,
                 **ssh_connect_kwargs,
@@ -594,7 +642,10 @@ class Connection(ConnectionBase):
         elif proto == "scp":
             scp = self.ssh.scp()
             try:
-                scp.get(out_path, in_path)
+                # this abruptly closes the connection when
+                # scp.get fails only when the file is not there
+                # it works fine if the file is actually present
+                scp.get(in_path, out_path)
             except LibsshSCPException as exc:
                 raise AnsibleError("Error transferring file from %s: %s" % (out_path, to_text(exc)))
         else:
