@@ -11,13 +11,12 @@ __metaclass__ = type
 
 import json
 import sys
-import unittest
 
 from contextlib import contextmanager
 from io import BytesIO, StringIO
+from unittest import TestCase
 
 from ansible.module_utils._text import to_bytes
-from ansible.module_utils.six import PY3
 
 
 @contextmanager
@@ -28,11 +27,8 @@ def swap_stdin_and_argv(stdin_data="", argv_data=tuple()):
     real_stdin = sys.stdin
     real_argv = sys.argv
 
-    if PY3:
-        fake_stream = StringIO(stdin_data)
-        fake_stream.buffer = BytesIO(to_bytes(stdin_data))
-    else:
-        fake_stream = BytesIO(to_bytes(stdin_data))
+    fake_stream = StringIO(stdin_data)
+    fake_stream.buffer = BytesIO(to_bytes(stdin_data))
 
     try:
         sys.stdin = fake_stream
@@ -50,21 +46,16 @@ def swap_stdout():
     context manager that temporarily replaces stdout for tests that need to verify output
     """
     old_stdout = sys.stdout
-
-    if PY3:
-        fake_stream = StringIO()
-    else:
-        fake_stream = BytesIO()
+    fake_stream = StringIO()
 
     try:
         sys.stdout = fake_stream
-
         yield fake_stream
     finally:
         sys.stdout = old_stdout
 
 
-class ModuleTestCase(unittest.TestCase):
+class ModuleTestCase(TestCase):
     def setUp(self, module_args=None):
         if module_args is None:
             module_args = {
