@@ -21,16 +21,30 @@ class TestIpCut(TestCase):
     def setUp(self):
         pass
 
-    def test_get_last_X_bits(self):
+    def test_get_last_X_bits_ipv6(self):
         """Get last X bits of Ipv6 address"""
 
         args = ["", "1234:4321:abcd:dcba::17", -80]
         result = _ipcut(*args)
         self.assertEqual(result, "dcba:0:0:0:17")
 
-    def test_get_first_X_bits(self):
+    def test_get_first_X_bits_ipv6(self):
         """Get first X bits of Ipv6 address"""
 
         args = ["", "1234:4321:abcd:dcba::17", 64]
         result = _ipcut(*args)
         self.assertEqual(result, "1234:4321:abcd:dcba")
+
+    def test_get_last_X_bits_ipv4(self):
+        """Get last X bits of Ipv4 address"""
+
+        args = ["", "10.2.3.0", -16]
+        result = _ipcut(*args)
+        self.assertEqual(result, "3.0")
+
+    def test_get_first_X_bits_ipv4(self):
+        """Get first X bits of Ipv4 address"""
+
+        args = ["", "10.2.3.0", 24]
+        result = _ipcut(*args)
+        self.assertEqual(result, "10.2.3")
