@@ -12,12 +12,12 @@ from __future__ import absolute_import, division, print_function
 
 __metaclass__ = type
 
-import unittest
+from unittest import TestCase
 
 from ansible_collections.ansible.utils.plugins.filter.ipv6form import _ipv6form
 
 
-class TestIpv6Form(unittest.TestCase):
+class TestIpv6Form(TestCase):
     def setUp(self):
         pass
 
