@@ -12,12 +12,12 @@ from __future__ import absolute_import, division, print_function
 
 __metaclass__ = type
 
-import unittest
+from unittest import TestCase
 
 from ansible_collections.ansible.utils.plugins.test.ipv4 import _ipv4
 
 
-class TestIpV4(unittest.TestCase):
+class TestIpV4(TestCase):
     def setUp(self):
         pass
 
