@@ -12,12 +12,12 @@ from __future__ import absolute_import, division, print_function
 
 __metaclass__ = type
 
-import unittest
+from unittest import TestCase
 
 from ansible_collections.ansible.utils.plugins.test.ipv4_netmask import _ipv4_netmask
 
 
-class TestIpV4Netmask(unittest.TestCase):
+class TestIpV4Netmask(TestCase):
     def setUp(self):
         pass
 
