@@ -12,12 +12,12 @@ from __future__ import absolute_import, division, print_function
 
 __metaclass__ = type
 
-import unittest
+from unittest import TestCase
 
 from ansible_collections.ansible.utils.plugins.test.ipv6_ipv4_mapped import _ipv6_ipv4_mapped
 
 
-class TestIpV6IpV4Mapped(unittest.TestCase):
+class TestIpV6IpV4Mapped(TestCase):
     def setUp(self):
         pass
 
