@@ -12,12 +12,12 @@ from __future__ import absolute_import, division, print_function
 
 __metaclass__ = type
 
-import unittest
+from unittest import TestCase
 
 from ansible_collections.ansible.utils.plugins.test.ipv6_teredo import _ipv6_teredo
 
 
-class TestIpV6Teredo(unittest.TestCase):
+class TestIpV6Teredo(TestCase):
     def setUp(self):
         pass
 
