@@ -64,6 +64,23 @@ options:
     - Parameters to pass into the script as key value pairs.
     - The key corresponds to the parameter name and the value is the value for that parameter.
     type: dict
+  path:
+    description:
+    - The path to a PowerShell script to run.
+    - When O(remote_src=False), or unset, this path is searched on the Ansible host.
+    - When O(remote_src=True), or set, this path is searched on the target host.
+    - This option is mutually exclusive with O(script).
+    - Scripts are expected to be saved with UTF-8 encoding, using a different encoding will result in non-ASCII
+      characters being read as invalid characters.
+    type: str
+    version_added: 3.1.0
+  remote_src:
+    description:
+    - When V(false), the O(path) specified will be searched on the Ansible host.
+    - When V(true), the O(path) specified will be searched on the target host.
+    default: false
+    type: bool
+    version_added: 3.1.0
   removes:
     description:
     - A path or path filter pattern; when the referenced path B(does not) exist on the target host, the task will be
@@ -72,8 +89,41 @@ options:
   script:
     description:
     - The PowerShell script to run.
+    - This option is mutually exclusive with O(path).
     type: str
-    required: true
+  sensitive_parameters:
+    description:
+    - Parameters to pass into the script as a SecureString or PSCredential.
+    - Each sensitive value will be marked with C(no_log) to ensure they are
+      not exposed in the module invocation args logs.
+    - The I(value) suboption can be used to create a SecureString value while
+      I(username) and I(password) can be used to create a PSCredential value.
+    type: list
+    elements: dict
+    suboptions:
+      name:
+        description:
+        - The name of the parameter to pass this value to.
+        required: true
+        type: str
+      value:
+        description:
+        - The string to pass as a SecureString of the parameter specified by
+          I(name).
+        - This is mutually exclusive with I(username) and I(password).
+        type: str
+      username:
+        description:
+        - The C(UserName) for the PSCredential value.
+        - This is mutually exclusive with I(value).
+        - This value is B(NOT) added to the C(no_log) list.
+        type: str
+      password:
+        description:
+        - The C(Password) for the PSCredential value.
+        - This is mutually exclusive with I(value) and must be set when
+          I(username) is provided.
+        type: str
 seealso:
 - module: ansible.windows.win_command
 - module: ansible.windows.win_shell
@@ -116,6 +166,15 @@ EXAMPLES = r'''
     script: |
       echo "Hello World"
 
+- name: Run script located in the adjacent files directory
+  ansible.windows.win_powershell:
+    path: my-script.ps1
+
+- name: Run script located on the target Windows host
+  ansible.windows.win_powershell:
+    path: C:\temp\my-script.ps1
+    remote_src: true
+
 - name: Run PowerShell script with parameters
   ansible.windows.win_powershell:
     script: |
@@ -149,11 +208,11 @@ EXAMPLES = r'''
       $PSVersionTable.PSVersion.Major
     executable: pwsh.exe
     arguments:
-    - -ExecutionPolicy
-    - ByPass
+      - -ExecutionPolicy
+      - ByPass
   register: pwsh_output
   failed_when:
-  - pwsh_output.output[0] != 7
+    - pwsh_output.output[0] != 7
 
 - name: Run code in check mode
   ansible.windows.win_powershell:
@@ -176,7 +235,13 @@ EXAMPLES = r'''
       else {
           echo 'also running in check mode'
       }
-  check_mode: yes
+  check_mode: true
+
+- name: Create a file in a specific directory using chdir
+  ansible.windows.win_powershell:
+    script: |
+      New-Item -Path 'created_by_ansible.txt' -ItemType File -Force
+    chdir: 'C:\Temp'
 
 - name: Return a failure back to Ansible
   ansible.windows.win_powershell:
@@ -208,6 +273,36 @@ EXAMPLES = r'''
       Write-Verbose "Hello World!"
       Write-Debug "Hello World!"
 
+- name: Set sensitive parameter value as SecureString parameter
+  ansible.windows.win_powershell:
+    script: |
+      param(
+          [string]$Uri,
+          [SecureString]$Token
+      )
+
+      Invoke-WebRequest -Uri $Uri -Token $Token
+    parameters:
+      Uri: foo
+    sensitive_parameters:
+      - name: Token
+        value: '{{ sensitive_value }}'
+
+- name: Set credential parameter
+  ansible.windows.win_powershell:
+    script: |
+      param(
+          [string]$Uri,
+          [PSCredential]$Credential
+      )
+
+      Invoke-WebRequest -Uri $Uri -Credential $Credential
+    parameters:
+      Uri: foo
+    sensitive_parameters:
+      - name: Credential
+        username: CredUserName
+        password: '{{ sensitive_value }}'
 '''
 
 RETURN = r'''
