@@ -8,8 +8,9 @@ from __future__ import absolute_import, division, print_function
 
 __metaclass__ = type
 
+from unittest.mock import patch
+
 from ansible_collections.arista.eos.plugins.modules import eos_snmp_server
-from ansible_collections.arista.eos.tests.unit.compat.mock import patch
 from ansible_collections.arista.eos.tests.unit.modules.utils import set_module_args
 
 from .eos_module import TestEosModule, load_fixture
@@ -400,7 +401,7 @@ class TestEosSnmp_ServerModule(TestEosModule):
             "no snmp-server group group2 v3 priv write view2 notify view1",
             "no snmp-server host host01 version 3 priv user01 udp-port 23",
             "no snmp-server host host02 version 2c user01 udp-port 23",
-            "snmp-server user user01 grp01 remote 1.1.1.1 udp-port 100 v3 md5 password123 priv aes abcdef",
+            "snmp-server user user01 grp01 remote 1.1.1.1 udp-port 100 v3 auth md5 password123 priv aes abcdef",
             "no snmp-server vrf vrf01 local-interface Ethernet1",
             "snmp-server vrf replacevrf",
             "snmp-server chassis-id 123456",
@@ -450,7 +451,7 @@ class TestEosSnmp_ServerModule(TestEosModule):
             "no snmp-server group group2 v3 priv write view2 notify view1",
             "no snmp-server host host01 version 3 priv user01 udp-port 23",
             "no snmp-server host host02 version 2c user01 udp-port 23",
-            "snmp-server user user01 grp01 remote 1.1.1.1 udp-port 100 v3 localized abcdef md5 password123 priv aes abcdef",
+            "snmp-server user user01 grp01 remote 1.1.1.1 udp-port 100 v3 localized abcdef auth md5 password123 priv aes abcdef",
             "snmp-server view view1 mib1 excluded",
             "no snmp-server vrf vrf01 local-interface Ethernet1",
             "snmp-server transport tcp",
