@@ -259,6 +259,11 @@ options:
                 description:
                     - Configures a virtual machine's endpoint for the floating IP capability required to configure a SQL AlwaysOn Availability Group.
                 type: bool
+            enable_tcp_reset:
+                description:
+                    - Receive bidirectional TCP Reset on TCP flow idle timeout or unexpected connection termination.
+                    - This element is only used when the protocol is set to TCP.
+                type: bool
             disable_outbound_snat:
                 description:
                     - Configure outbound source network address translation (SNAT).
@@ -328,6 +333,50 @@ options:
                     - Receive bidirectional TCP Reset on TCP flow idle timeout or unexpected connection termination.
                     - This element is only used when I(protocol=Tcp).
                 type: bool
+    outbound_rules:
+        description:
+            - The outbound rules.
+        type: list
+        elements: dict
+        version_added: '3.5.0'
+        suboptions:
+            name:
+                description:
+                    - The name of the resource that is unique within the set of outbound rules used by the load balancer.
+                    - This name can be used to access the resource.
+                type: str
+                required: True
+            allocated_outbound_ports:
+                description:
+                    - The number of outbound ports to be used for NAT.
+                type: int
+            frontend_ip_configurations:
+                description:
+                    - The Frontend IP addresses of the load balancer.
+                type: list
+                elements: str
+            backend_address_pool:
+                description:
+                    - A reference to a pool of DIPs.
+                    - Outbound traffic is randomly load balanced across IPs in the backend IPs.
+                type: str
+            protocol:
+                description:
+                    - The protocol for the outbound rule in load balancer.
+                type: str
+                choices:
+                    - Tcp
+                    - Udp
+                    - All
+            enable_tcp_reset:
+                description:
+                    - Receive bidirectional TCP Reset on TCP flow idle timeout or unexpected connection termination.
+                    - This element is only used when the protocol is set to C(Tcp).
+                type: bool
+            idle_timeout_in_minutes:
+                description:
+                    - The timeout for the TCP idle connection.
+                type: int
 extends_documentation_fragment:
     - azure.azcollection.azure
     - azure.azcollection.azure_tags
@@ -345,8 +394,11 @@ EXAMPLES = '''
     frontend_ip_configurations:
       - name: frontendipconf0
         public_ip_address: testpip
+      - name: frontendipconf1
+        public_ip_address: testpip1
     backend_address_pools:
       - name: backendaddrpool0
+      - name: backendaddrpool1
     probes:
       - name: prob0
         port: 80
@@ -370,6 +422,15 @@ EXAMPLES = '''
         protocol: Tcp
         frontend_port: 8080
         frontend_ip_configuration: frontendipconf0
+    outbound_rules:
+      - name: outrule1
+        allocated_outbound_ports: 800
+        frontend_ip_configurations:
+          - frontendipconf1
+        backend_address_pool: backendaddrpool1
+        protocol: Tcp
+        enable_tcp_reset: true
+        idle_timeout_in_minutes: 4
 '''
 
 RETURN = '''
@@ -385,10 +446,12 @@ changed:
     type: bool
 '''
 
-from ansible_collections.azure.azcollection.plugins.module_utils.azure_rm_common import AzureRMModuleBase, format_resource_id
+from ansible_collections.azure.azcollection.plugins.module_utils.azure_rm_common import format_resource_id
+from ansible_collections.azure.azcollection.plugins.module_utils.azure_rm_common_ext import AzureRMModuleBaseExt
 from ansible.module_utils._text import to_native
 try:
     from azure.core.exceptions import ResourceNotFoundError
+    from azure.mgmt.core.tools import parse_resource_id
 except ImportError:
     # This is handled in azure_rm_common
     pass
@@ -560,10 +623,25 @@ load_balancing_rule_spec = dict(
         type='bool',
         default=False
     ),
+    enable_tcp_reset=dict(
+        type='bool'
+    )
 )
 
 
-class AzureRMLoadBalancer(AzureRMModuleBase):
+outbound_rule_spec = dict(
+    name=dict(type='str', required=True),
+    allocated_outbound_ports=dict(type='int'),
+    frontend_ip_configurations=dict(type='list', elements='str'),
+    backend_address_pool=dict(type='str'),
+    protocol=dict(type='str', choices=['Tcp', 'Udp', 'All']),
+    enable_tcp_reset=dict(type='bool'),
+    idle_timeout_in_minutes=dict(type='int')
+
+)
+
+
+class AzureRMLoadBalancer(AzureRMModuleBaseExt):
     """Configuration class for an Azure RM load balancer resource"""
 
     def __init__(self):
@@ -617,6 +695,11 @@ class AzureRMLoadBalancer(AzureRMModuleBase):
                 type='list',
                 elements='dict',
                 options=load_balancing_rule_spec
+            ),
+            outbound_rules=dict(
+                type='list',
+                elements='dict',
+                options=outbound_rule_spec
             )
         )
 
@@ -629,6 +712,7 @@ class AzureRMLoadBalancer(AzureRMModuleBase):
         self.probes = None
         self.inbound_nat_rules = None
         self.inbound_nat_pools = None
+        self.outbound_rules = None
         self.load_balancing_rules = None
         self.state = None
         self.tags = None
@@ -656,35 +740,31 @@ class AzureRMLoadBalancer(AzureRMModuleBase):
         if self.state == 'present':
             # create new load balancer structure early, so it can be easily compared
             if not load_balancer:
-                frontend_ip_configurations_param = [self.network_models.FrontendIPConfiguration(
-                    name=item.get('name'),
-                    public_ip_address=self.get_public_ip_address_instance(item.get('public_ip_address')) if item.get('public_ip_address') else None,
-                    private_ip_address=item.get('private_ip_address'),
-                    private_ip_allocation_method=item.get('private_ip_allocation_method'),
-                    zones=item.get('zones'),
-                    subnet=self.network_models.Subnet(
-                        id=item.get('subnet'),
-                        private_endpoint_network_policies=None,
-                        private_link_service_network_policies=None
-                    ) if item.get('subnet') else None
-                ) for item in self.frontend_ip_configurations] if self.frontend_ip_configurations else None
+                changed = True
             else:
-                old_front = load_balancer.frontend_ip_configurations
-                new_front = self.frontend_ip_configurations
-                frontend_ip_configurations_param = [self.network_models.FrontendIPConfiguration(
-                    name=new_front[index].get('name'),
-                    public_ip_address=self.get_public_ip_address_instance(
-                        new_front[index].get('public_ip_address')
-                    ) if new_front[index].get('public_ip_address') else None,
-                    private_ip_address=new_front[index].get('private_ip_address'),
-                    private_ip_allocation_method=new_front[index].get('private_ip_allocation_method'),
-                    zones=new_front[index].get('zones') if new_front[index].get('zones') else None,
-                    subnet=self.network_models.Subnet(
-                        id=new_front[index].get('subnet'),
-                        private_endpoint_network_policies=None,
-                        private_link_service_network_policies=None
-                    ) if new_front[index].get('subnet') else None
-                ) for index in range(len(new_front))] if new_front else None
+                response = self.format_item(load_balancer)
+                update1, self.frontend_ip_configurations = self.update_item(self.frontend_ip_configurations, response.get('frontend_ip_configurations'))
+                update2, self.backend_address_pools = self.update_item(self.backend_address_pools, response.get('backend_address_pools'))
+                update3, self.probes = self.update_item(self.probes, response.get('probes'))
+                update4, self.inbound_nat_rules = self.update_item(self.inbound_nat_rules, response.get('inbound_nat_rules'))
+                update5, self.inbound_nat_pools = self.update_item(self.inbound_nat_pools, response.get('inbound_nat_pools'))
+                update6, self.outbound_rules = self.update_item(self.outbound_rules, response.get('outbound_rules'))
+                update7, self.load_balancing_rules = self.update_item(self.load_balancing_rules, response.get('load_balancing_rules'))
+
+                changed = update1 or update2 or update3 or update4 or update5 or update6 or update7
+
+            frontend_ip_configurations_param = [self.network_models.FrontendIPConfiguration(
+                name=item.get('name'),
+                public_ip_address=self.get_public_ip_address_instance(item.get('public_ip_address')) if item.get('public_ip_address') else None,
+                private_ip_address=item.get('private_ip_address'),
+                private_ip_allocation_method=item.get('private_ip_allocation_method'),
+                zones=item.get('zones'),
+                subnet=self.network_models.Subnet(
+                    id=item.get('subnet'),
+                    private_endpoint_network_policies=None,
+                    private_link_service_network_policies=None
+                ) if item.get('subnet') else None
+            ) for item in self.frontend_ip_configurations] if self.frontend_ip_configurations else None
 
             backend_address_pools_param = [self.network_models.BackendAddressPool(
                 name=item.get('name')
@@ -745,6 +825,7 @@ class AzureRMLoadBalancer(AzureRMModuleBase):
                 backend_port=item.get('backend_port'),
                 idle_timeout_in_minutes=item.get('idle_timeout'),
                 enable_floating_ip=item.get('enable_floating_ip'),
+                enable_tcp_reset=item.get('enable_tcp_reset'),
                 disable_outbound_snat=item.get('disable_outbound_snat'),
             ) for item in self.load_balancing_rules] if self.load_balancing_rules else None
 
@@ -766,6 +847,30 @@ class AzureRMLoadBalancer(AzureRMModuleBase):
                 enable_floating_ip=item.get('enable_floating_ip')
             ) for item in self.inbound_nat_rules] if self.inbound_nat_rules else None
 
+            outbound_rules_param = [self.network_models.OutboundRule(
+                name=item.get('name'),
+                frontend_ip_configurations=[self.network_models.SubResource(
+                    id=frontend_ip_configuration_id(
+                        self.subscription_id,
+                        self.resource_group,
+                        self.name,
+                        value
+                    )
+                )for value in item['frontend_ip_configurations']] if item.get('frontend_ip_configurations') else None,
+                backend_address_pool=self.network_models.SubResource(
+                    id=backend_address_pool_id(
+                        self.subscription_id,
+                        self.resource_group,
+                        self.name,
+                        item.get('backend_address_pool')
+                    )
+                ),
+                allocated_outbound_ports=item.get('allocated_outbound_ports'),
+                protocol=item.get('protocol'),
+                enable_tcp_reset=item.get('enable_tcp_reset'),
+                idle_timeout_in_minutes=item.get('idle_timeout_in_minutes')
+            ) for item in self.outbound_rules] if self.outbound_rules else None
+
             # construct the new instance, if the parameter is none, keep remote one
             self.new_load_balancer = self.network_models.LoadBalancer(
                 sku=self.network_models.LoadBalancerSku(name=self.sku) if self.sku else None,
@@ -776,21 +881,14 @@ class AzureRMLoadBalancer(AzureRMModuleBase):
                 probes=probes_param,
                 inbound_nat_pools=inbound_nat_pools_param,
                 load_balancing_rules=load_balancing_rules_param,
-                inbound_nat_rules=inbound_nat_rules_param
+                inbound_nat_rules=inbound_nat_rules_param,
+                outbound_rules=outbound_rules_param,
             )
 
             self.new_load_balancer = self.assign_protocol(self.new_load_balancer, load_balancer)
 
             if load_balancer:
                 self.new_load_balancer = self.object_assign(self.new_load_balancer, load_balancer)
-                load_balancer_dict = load_balancer.as_dict()
-                new_dict = self.new_load_balancer.as_dict()
-                if not default_compare(new_dict, load_balancer_dict, ''):
-                    changed = True
-                else:
-                    changed = False
-            else:
-                changed = True
         elif self.state == 'absent' and load_balancer:
             changed = True
 
@@ -815,6 +913,135 @@ class AzureRMLoadBalancer(AzureRMModuleBase):
 
         return self.results
 
+    def update_item(self, new, old):
+        changed = False
+        if new is not None:
+            if old is not None:
+                if not self.default_compare({}, new, old, '', dict(compare=[])):
+                    changed = True
+
+                keys = [item['name'] for item in new]
+                for item in old:
+                    if item['name'] not in keys:
+                        new.append(item)
+            else:
+                changed = True
+        else:
+            new = old
+        return changed, new
+
+    def format_item(self, item):
+        results = dict()
+        if item.frontend_ip_configurations is not None:
+            results['frontend_ip_configurations'] = []
+            for value in item.frontend_ip_configurations:
+                new_item = dict(name=value.name,
+                                public_ip_address=None,
+                                private_ip_address=value.private_ip_address,
+                                private_ip_allocation_method=value.private_ip_allocation_method,
+                                subnet=None,
+                                zones=value.zones)
+                if value.public_ip_address is not None:
+                    new_item['public_ip_address'] = parse_resource_id(value.public_ip_address.id)['name']
+                if value.subnet is not None:
+                    new_item['subnet'] = value.subnet.id
+                results['frontend_ip_configurations'].append(new_item)
+        else:
+            results['frontend_ip_configurations'] = None
+        if item.backend_address_pools is not None:
+            results['backend_address_pools'] = []
+            for value in item.backend_address_pools:
+                results['backend_address_pools'].append(dict(name=value.name))
+        else:
+            results['backend_address_pools'] = None
+        if item.probes is not None:
+            results['probes'] = []
+            for value in item.probes:
+                results['probes'].append(dict(name=value.name,
+                                              port=value.port,
+                                              protocol=value.protocol,
+                                              interval=value.interval_in_seconds,
+                                              fail_count=value.number_of_probes,
+                                              request_path=value.request_path))
+        else:
+            results['probes'] = None
+        if item.inbound_nat_pools is not None:
+            results['inbound_nat_pools'] = []
+            for value in item.inbound_nat_pools:
+                new_item = dict(name=value.name,
+                                frontend_ip_configuration_name=None,
+                                protocol=value.protocol,
+                                frontend_port_range_start=value.frontend_port_range_start,
+                                frontend_port_range_end=value.frontend_port_range_end,
+                                backend_port=value.backend_port)
+                if value.frontend_ip_configuration is not None:
+                    new_item['frontend_ip_configuration_name'] = parse_resource_id(value.frontend_ip_configuration.id)['resource_name']
+                results['inbound_nat_pools'].append(new_item)
+        else:
+            results['inbound_nat_pools'] = None
+        if item.inbound_nat_rules is not None:
+            results['inbound_nat_rules'] = []
+            for value in item.inbound_nat_rules:
+                new_item = dict(name=value.name,
+                                frontend_ip_configuration=None,
+                                protocol=value.protocol,
+                                frontend_port=value.frontend_port,
+                                idle_timeout=value.idle_timeout_in_minutes,
+                                backend_port=value.backend_port,
+                                enable_floating_ip=value.enable_floating_ip,
+                                enable_tcp_reset=value.enable_tcp_reset)
+                if value.frontend_ip_configuration is not None:
+                    new_item['frontend_ip_configuration'] = parse_resource_id(value.frontend_ip_configuration.id)['resource_name']
+                results['inbound_nat_rules'].append(new_item)
+        else:
+            results['inbound_nat_rules'] = None
+        if item.load_balancing_rules is not None:
+            results['load_balancing_rules'] = []
+            for value in item.load_balancing_rules:
+                new_item = dict(name=value.name,
+                                frontend_ip_configuration=None,
+                                backend_address_pool=None,
+                                probe=None,
+                                protocol=value.protocol,
+                                load_distribution=value.load_distribution,
+                                frontend_port=value.frontend_port,
+                                backend_port=value.backend_port,
+                                idle_timeout=value.idle_timeout_in_minutes,
+                                enable_floating_ip=value.enable_floating_ip,
+                                disable_outbound_snat=value.disable_outbound_snat,
+                                enable_tcp_reset=value.enable_tcp_reset)
+                if value.frontend_ip_configuration is not None:
+                    new_item['frontend_ip_configuration'] = parse_resource_id(value.frontend_ip_configuration.id)['resource_name']
+                if value.backend_address_pool is not None:
+                    new_item['backend_address_pool'] = parse_resource_id(value.backend_address_pool.id)['resource_name']
+                if value.probe is not None:
+                    new_item['probe'] = parse_resource_id(value.probe.id)['resource_name']
+                results['load_balancing_rules'].append(new_item)
+        else:
+            results['load_balancing_rules'] = None
+        if item.outbound_rules is not None:
+            results['outbound_rules'] = []
+            for value in item.outbound_rules:
+                new_item = dict(name=value.name,
+                                allocated_outbound_ports=value.allocated_outbound_ports,
+                                frontend_ip_configurations=[],
+                                backend_address_pool=None,
+                                protocol=value.protocol,
+                                enable_tcp_reset=value.enable_tcp_reset,
+                                idle_timeout_in_minutes=value.idle_timeout_in_minutes)
+                if value.frontend_ip_configurations is not None:
+                    for key in value.frontend_ip_configurations:
+                        new_item['frontend_ip_configurations'].append(parse_resource_id(key.id)['resource_name'])
+                else:
+                    new_item['frontend_ip_configurations'] = None
+                if value.backend_address_pool is not None:
+                    new_item['backend_address_pool'] = parse_resource_id(value.backend_address_pool.id)['resource_name']
+                results['outbound_rules'].append(new_item)
+        else:
+            results['outbound_rules'] = None
+
+        return results
+
     def get_public_ip_address_instance(self, id):
         """Get a reference to the public ip address resource"""
         self.log('Fetching public ip address {0}'.format(id))
@@ -869,40 +1096,6 @@ class AzureRMLoadBalancer(AzureRMModuleBase):
         return patch
 
 
-def default_compare(new, old, path):
-    if isinstance(new, dict):
-        if not isinstance(old, dict):
-            return False
-        for k in new.keys():
-            if k == 'disable_outbound_snat':
-                return True
-            if not default_compare(new.get(k), old.get(k, None), path + '/' + k):
-                return False
-        return True
-    elif isinstance(new, list):
-        if not isinstance(old, list) or len(new) != len(old):
-            return False
-        if len(old) == 0:
-            return True
-        if isinstance(old[0], dict):
-            key = None
-            if 'id' in old[0] and 'id' in new[0]:
-                key = 'id'
-            elif 'name' in old[0] and 'name' in new[0]:
-                key = 'name'
-            new = sorted(new, key=lambda x: x.get(key, None))
-            old = sorted(old, key=lambda x: x.get(key, None))
-        else:
-            new = sorted(new)
-            old = sorted(old)
-        for i in range(len(new)):
-            if not default_compare(new[i], old[i], path + '/*'):
-                return False
-        return True
-    else:
-        return new == old
-
-
 def frontend_ip_configuration_id(subscription_id, resource_group_name, load_balancer_name, name):
     """Generate the id for a frontend ip configuration"""
     return '/subscriptions/{0}/resourceGroups/{1}/providers/Microsoft.Network/loadBalancers/{2}/frontendIPConfigurations/{3}'.format(
