@@ -57,6 +57,16 @@ options:
             - Name of the Public IP.
         type: str
         required: true
+    public_ip_prefix:
+        description:
+            - The Public IP Prefix this Public IP Address should be allocated from.
+            - Once set, it cannot be updated.
+        type: dict
+        suboptions:
+            id:
+                description:
+                    - The Public IP Prefix ID.
+                type: str
     state:
         description:
             - Assert the state of the Public IP. Use C(present) to create or update a and C(absent) to delete.
@@ -74,11 +84,11 @@ options:
             - The public IP address SKU.
             - When I(version=ipv6), if I(sku=standard) then set I(allocation_method=static).
             - When I(version=ipv4), if I(sku=standard) then set I(allocation_method=static).
+            - The I(sku=basic) will be retired on September 30, 2025.
+            - New I(sku=basic) SKU resource cannot be deployed after March 31, 2025.
         type: str
         choices:
-            - basic
             - standard
-            - Basic
             - Standard
     ip_tags:
         description:
@@ -150,6 +160,12 @@ state:
     returned: always
     type: complex
     contains:
+        id:
+            description:
+                - The resource's ID.
+            type: str
+            returned: always
+            sample: /subscriptions/xxx-xxx/resourceGroups/testRG/providers/Microsoft.Network/publicIPAddresses/pip01
         dns_settings:
             description:
                 - The FQDN of the DNS record associated with the public IP address.
@@ -208,12 +224,18 @@ state:
              returned: always
              type: str
              sample: ipv4
+        public_ip_prefix:
+            description:
+                - The Public IP Prefix this Public IP Address should be allocated from.
+            type: dict
+            returned: when-used
+            sample: {"id": "/subscriptions/xxx-xxx/resourceGroups/testRG/providers/Microsoft.Network/publicIPPrefixes/prefix01"}
         sku:
             description:
                 - The public IP address SKU.
             returned: always
             type: str
-            sample: Basic
+            sample: Standard
         tags:
             description:
                 - The resource tags.
@@ -250,6 +272,7 @@ except ImportError:
 def pip_to_dict(pip):
     result = dict(
         name=pip.name,
+        id=pip.id,
         type=pip.type,
         location=pip.location,
         tags=pip.tags,
@@ -261,7 +284,8 @@ def pip_to_dict(pip):
         provisioning_state=pip.provisioning_state,
         etag=pip.etag,
         sku=pip.sku.name,
-        zones=pip.zones
+        zones=pip.zones,
+        public_ip_prefix=None
     )
     if pip.dns_settings:
         result['dns_settings']['domain_name_label'] = pip.dns_settings.domain_name_label
@@ -269,6 +293,9 @@ def pip_to_dict(pip):
         result['dns_settings']['reverse_fqdn'] = pip.dns_settings.reverse_fqdn
     if pip.ip_tags:
         result['ip_tags'] = [dict(type=to_native(x.ip_tag_type), value=to_native(x.tag)) for x in pip.ip_tags]
+    if pip.public_ip_prefix:
+        result['public_ip_prefix'] = dict(id=pip.public_ip_prefix.id)
+
     return result
 
 
@@ -291,9 +318,10 @@ class AzureRMPublicIPAddress(AzureRMModuleBase):
             allocation_method=dict(type='str', default='dynamic', choices=['Dynamic', 'Static', 'dynamic', 'static']),
             domain_name=dict(type='str', aliases=['domain_name_label']),
             reverse_fqdn=dict(type='str'),
-            sku=dict(type='str', choices=['Basic', 'Standard', 'basic', 'standard']),
+            sku=dict(type='str', choices=['Standard', 'standard']),
             ip_tags=dict(type='list', elements='dict', options=ip_tag_spec),
             idle_timeout=dict(type='int'),
+            public_ip_prefix=dict(type='dict', options=dict(id=dict(type='str'))),
             zones=dict(type='list', elements='str', choices=['1', '2', '3'])
         )
 
@@ -310,6 +338,7 @@ class AzureRMPublicIPAddress(AzureRMModuleBase):
         self.version = None
         self.ip_tags = None
         self.idle_timeout = None
+        self.public_ip_prefix = None
 
         self.results = dict(
             changed=False,
@@ -328,7 +357,7 @@ class AzureRMPublicIPAddress(AzureRMModuleBase):
         changed = False
         pip = None
 
-        # capitalize the sku and allocation_method. basic => Basic, Basic => Basic.
+        # capitalize the sku and allocation_method. standard => Standard, Standard => Standard.
         self.allocation_method = self.allocation_method.capitalize() if self.allocation_method else None
         self.sku = self.sku.capitalize() if self.sku else None
         self.version = 'IPv4' if self.version == 'ipv4' else 'IPv6'
@@ -404,7 +433,7 @@ class AzureRMPublicIPAddress(AzureRMModuleBase):
         self.results['changed'] = changed
 
         if self.check_mode:
-            return results
+            return dict(state=results)
 
         if changed:
             if self.state == 'present':
@@ -413,6 +442,7 @@ class AzureRMPublicIPAddress(AzureRMModuleBase):
                     pip = self.network_models.PublicIPAddress(
                         location=self.location,
                         public_ip_address_version=self.version,
+                        public_ip_prefix=self.public_ip_prefix,
                         public_ip_allocation_method=self.allocation_method,
                         sku=self.network_models.PublicIPAddressSku(name=self.sku) if self.sku else None,
                         idle_timeout_in_minutes=self.idle_timeout if self.idle_timeout and self.idle_timeout > 0 else None,
@@ -434,6 +464,7 @@ class AzureRMPublicIPAddress(AzureRMModuleBase):
                         public_ip_allocation_method=results['public_ip_allocation_method'],
                         sku=self.network_models.PublicIPAddressSku(name=self.sku) if self.sku else None,
                         tags=results['tags'],
+                        public_ip_prefix=self.public_ip_prefix,
                         zones=results['zones']
                     )
                     if self.domain_name or self.reverse_fqdn:
