@@ -22,10 +22,22 @@ description:
     - the module can work exclusively in three modes, when C(batch_upload_src) is set, it is working in batch upload mode;
       when C(src) is set, it is working in upload mode and when C(dst) is set, it is working in dowload mode.
 options:
+    auth_mode:
+        description:
+            - The mode in which to run the command. C(login) mode will directly use your login credentials for the authentication.
+            - The legacy C(key) mode will attempt to query for an account key if no authentication parameters for the account are provided.
+            - Can also be set via the environment variable C(AZURE_STORAGE_AUTH_MODE).
+        default: key
+        type: str
+        choices:
+            - key
+            - login
+        version_added: "1.19.0"
     storage_account_name:
         description:
             - Name of the storage account to use.
         required: true
+        type: str
         aliases:
             - account_name
             - storage_account
@@ -34,10 +46,12 @@ options:
             - Name of a blob object within the container.
         aliases:
             - blob_name
+        type: str
     blob_type:
         description:
             - Type of blob object.
         default: block
+        type: str
         choices:
             - block
             - page
@@ -46,31 +60,39 @@ options:
         description:
             - Name of a blob container within the storage account.
         required: true
+        type: str
         aliases:
             - container_name
     content_type:
         description:
             - Set the blob content-type header. For example C(image/png).
+        type: str
     cache_control:
         description:
             - Set the blob cache-control header.
+        type: str
     content_disposition:
         description:
             - Set the blob content-disposition header.
+        type: str
     content_encoding:
         description:
             - Set the blob encoding header.
+        type: str
     content_language:
         description:
             - Set the blob content-language header.
+        type: str
     content_md5:
         description:
             - Set the blob md5 hash value.
+        type: str
     dest:
         description:
             - Destination file path. Use with state C(present) to download a blob.
         aliases:
             - destination
+        type: path
     force:
         description:
             - Overwrite existing blob or file when uploading or downloading. Force deletion of a container that contains blobs.
@@ -80,19 +102,33 @@ options:
         description:
             - Name of the resource group to use.
         required: true
+        type: str
         aliases:
             - resource_group_name
     src:
         description:
             - Source file path. Use with state C(present) to upload a blob.
+        type: str
         aliases:
             - source
     batch_upload_src:
         description:
             - Batch upload source directory. Use with state C(present) to upload batch of files under the directory.
+        type: path
     batch_upload_dst:
         description:
             - Base directory in container when upload batch of files.
+        type: path
+    standard_blob_tier:
+        description:
+            - Specifies the blob tier to set the blob to.
+            - This is only applicable for block blobs on standard storage accounts.
+        type: str
+        choices:
+            - Archive
+            - Cool
+            - Cold
+            - Hot
     state:
         description:
             - State of a container or blob.
@@ -105,6 +141,7 @@ options:
               to download. If a blob (uploading) or a file (downloading) already exists, it will not be overwritten
               unless I(force=true).
         default: present
+        type: str
         choices:
             - absent
             - present
@@ -112,6 +149,9 @@ options:
         description:
             - A container's level of public access. By default containers are private.
             - Can only be set at time of container creation.
+            - The I(public_access) parameter should not be set for private access.
+            - If I(public_access) is not configured, access level is by default private. It can not be set explicitely to private.
+        type: str
         choices:
             - container
             - blob
@@ -172,7 +212,8 @@ blob:
         "last_modified": "09-Mar-2016 22:08:25 +0000",
         "name": "graylog.png",
         "tags": {},
-        "type": "BlockBlob"
+        "type": "BlockBlob",
+        'standard_blob_tier': 'Hot'
     }
 container:
     description:
@@ -190,13 +231,14 @@ import os
 import mimetypes
 
 try:
-    from azure.storage.blob._models import BlobType, ContentSettings
+    from azure.storage.blob._models import BlobType, ContentSettings, StandardBlobTier
     from azure.core.exceptions import ResourceNotFoundError
 except ImportError:
     # This is handled in azure_rm_common
     pass
 
 from ansible_collections.azure.azcollection.plugins.module_utils.azure_rm_common import AzureRMModuleBase
+from ansible.module_utils.basic import env_fallback
 
 
 class AzureRMStorageBlob(AzureRMModuleBase):
@@ -204,9 +246,16 @@ class AzureRMStorageBlob(AzureRMModuleBase):
     def __init__(self):
 
         self.module_arg_spec = dict(
+            auth_mode=dict(
+                type='str',
+                choices=['key', 'login'],
+                fallback=(env_fallback, ['AZURE_STORAGE_AUTH_MODE']),
+                default="key"
+            ),
             storage_account_name=dict(required=True, type='str', aliases=['account_name', 'storage_account']),
             blob=dict(type='str', aliases=['blob_name']),
             blob_type=dict(type='str', default='block', choices=['block', 'page']),
+            standard_blob_tier=dict(type='str', choices=['Archive', 'Cool', 'Cold', 'Hot']),
             container=dict(required=True, type='str', aliases=['container_name']),
             dest=dict(type='path', aliases=['destination']),
             force=dict(type='bool', default=False),
@@ -232,6 +281,7 @@ class AzureRMStorageBlob(AzureRMModuleBase):
         self.blob = None
         self.blob_obj = None
         self.blob_type = None
+        self.standard_blob_tier = None
         self.container = None
         self.container_obj = None
         self.dest = None
@@ -264,7 +314,7 @@ class AzureRMStorageBlob(AzureRMModuleBase):
 
         # add file path validation
 
-        self.blob_service_client = self.get_blob_service_client(self.resource_group, self.storage_account_name)
+        self.blob_service_client = self.get_blob_service_client(self.resource_group, self.storage_account_name, self.auth_mode)
         self.container_obj = self.get_container()
         if self.blob:
             self.blob_obj = self.get_blob()
@@ -300,6 +350,10 @@ class AzureRMStorageBlob(AzureRMModuleBase):
                 if self.blob_content_settings_differ():
                     self.update_blob_content_settings()
 
+                if self.standard_blob_tier is not None and self.blob_obj.get('standard_blob_tier') is not None and \
+                   self.blob_obj['standard_blob_tier'] != self.standard_blob_tier:
+                    self.update_blob_tier()
+
         elif self.state == 'absent':
             if self.container_obj and not self.blob:
                 # Delete container
@@ -378,7 +432,9 @@ class AzureRMStorageBlob(AzureRMModuleBase):
                         client.upload_blob(data=data,
                                            blob_type=self.get_blob_type(self.blob_type),
                                            metadata=self.tags,
-                                           content_settings=_guess_content_type(src, content_settings))
+                                           content_settings=_guess_content_type(src, content_settings),
+                                           standard_blob_tier=self.get_blob_tier(self.standard_blob_tier),
+                                           overwrite=self.force)
                 except Exception as exc:
                     self.fail("Error creating blob {0} - {1}".format(src, str(exc)))
             self.results['actions'].append('created blob from {0}'.format(src))
@@ -386,6 +442,18 @@ class AzureRMStorageBlob(AzureRMModuleBase):
         self.results['changed'] = True
         self.results['container'] = self.container_obj
 
+    def get_blob_tier(self, blob_tier):
+        if blob_tier == "archive":
+            return StandardBlobTier.Archive
+        elif blob_tier == "cool":
+            return StandardBlobTier.Cool
+        elif blob_tier == "hot":
+            return StandardBlobTier.Hot
+        elif blob_tier == "cold":
+            return StandardBlobTier.Cold
+        else:
+            return None
+
     def get_blob_type(self, blob_type):
         if blob_type == "block":
             return BlobType.BlockBlob
@@ -424,6 +492,7 @@ class AzureRMStorageBlob(AzureRMModuleBase):
                 tags=blob["metadata"],
                 last_modified=blob["last_modified"].strftime('%d-%b-%Y %H:%M:%S %z'),
                 type=blob["blob_type"],
+                standard_blob_tier=blob.get('blob_tier'),
                 content_length=blob["size"],
                 content_settings=dict(
                     content_type=blob["content_settings"]["content_type"],
@@ -431,7 +500,7 @@ class AzureRMStorageBlob(AzureRMModuleBase):
                     content_language=blob["content_settings"]["content_language"],
                     content_disposition=blob["content_settings"]["content_disposition"],
                     cache_control=blob["content_settings"]["cache_control"],
-                    content_md5=blob["content_settings"]["content_md5"],
+                    content_md5=blob["content_settings"]["content_md5"].hex() if blob["content_settings"]["content_md5"] else None,
                 )
             )
         return result
@@ -471,11 +540,19 @@ class AzureRMStorageBlob(AzureRMModuleBase):
             try:
                 client = self.blob_service_client.get_blob_client(container=self.container, blob=self.blob)
                 with open(self.src, "rb") as data:
-                    client.upload_blob(data=data,
-                                       blob_type=self.get_blob_type(self.blob_type),
-                                       metadata=self.tags,
-                                       content_settings=content_settings,
-                                       overwrite=self.force)
+                    if self.blob_type == 'page':
+                        client.upload_blob(data=data,
+                                           blob_type=self.get_blob_type(self.blob_type),
+                                           metadata=self.tags,
+                                           content_settings=content_settings,
+                                           overwrite=self.force)
+                    else:
+                        client.upload_blob(data=data,
+                                           blob_type=self.get_blob_type(self.blob_type),
+                                           metadata=self.tags,
+                                           content_settings=content_settings,
+                                           standard_blob_tier=self.get_blob_tier(self.standard_blob_tier),
+                                           overwrite=self.force)
             except Exception as exc:
                 self.fail("Error creating blob {0} - {1}".format(self.blob, str(exc)))
 
@@ -598,6 +675,11 @@ class AzureRMStorageBlob(AzureRMModuleBase):
         self.results['container'] = self.container_obj
         self.results['blob'] = self.blob_obj
 
+    def update_blob_tier(self):
+        client = self.blob_service_client.get_blob_client(container=self.container, blob=self.blob)
+        client.set_standard_blob_tier(standard_blob_tier=self.standard_blob_tier)
+        self.results['changed'] = True
+
     def blob_content_settings_differ(self):
         if self.content_type or self.content_encoding or self.content_language or self.content_disposition or \
                 self.cache_control or self.content_md5:
