@@ -2,6 +2,7 @@
 # -*- coding: utf-8 -*-
 
 # Copyright: (c) 2017, Bruno Calogero <brunocalogero@hotmail.com>
+# Copyright: (c) 2025, Eric Girard @netgirard
 # GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)
 
 from __future__ import absolute_import, division, print_function
@@ -40,6 +41,12 @@ options:
     description:
     - The ID of the Second Leaf Switch for the Explicit vPC Protection Group.
     type: int
+  pod_id:
+    description:
+    - The pod id of the VPC member nodes.
+    - Accepted values range between C(1) and C(255).
+    - The APIC defaults to C(1) when unset during creation.
+    type: int
   state:
     description:
     - Use C(present) or C(absent) for adding or removing.
@@ -62,6 +69,7 @@ seealso:
   link: https://developer.cisco.com/docs/apic-mim-ref/
 author:
 - Bruno Calogero (@brunocalogero)
+- Eric Girard (@netgirard)
 """
 
 EXAMPLES = r"""
@@ -224,6 +232,7 @@ def main():
         vpc_domain_policy=dict(type="str", aliases=["vpc_domain_policy_name"]),
         switch_1_id=dict(type="int"),
         switch_2_id=dict(type="int"),
+        pod_id=dict(type="int"),
         state=dict(type="str", default="present", choices=["absent", "present", "query"]),
         name_alias=dict(type="str"),
     )
@@ -242,6 +251,7 @@ def main():
     vpc_domain_policy = module.params.get("vpc_domain_policy")
     switch_1_id = module.params.get("switch_1_id")
     switch_2_id = module.params.get("switch_2_id")
+    pod_id = module.params.get("pod_id")
     state = module.params.get("state")
     name_alias = module.params.get("name_alias")
 
@@ -271,6 +281,7 @@ def main():
                     fabricNodePEp=dict(
                         attributes=dict(
                             id="{0}".format(switch_1_id),
+                            podId=pod_id,
                         ),
                     ),
                 ),
@@ -278,6 +289,7 @@ def main():
                     fabricNodePEp=dict(
                         attributes=dict(
                             id="{0}".format(switch_2_id),
+                            podId=pod_id,
                         ),
                     ),
                 ),
