@@ -7,39 +7,44 @@
 DOCUMENTATION = r"""
 ---
 module: business_sda_wireless_controller_delete
-short_description: Resource module for Business Sda Wireless Controller Delete
+short_description: Resource module for Business Sda
+  Wireless Controller Delete
 description:
-- Manage operation delete of the resource Business Sda Wireless Controller Delete.
-- Remove WLC from Fabric Domain.
+  - Manage operation delete of the resource Business
+    Sda Wireless Controller Delete.
+  - Remove WLC from Fabric Domain.
 version_added: '4.0.0'
 extends_documentation_fragment:
   - cisco.dnac.module
 author: Rafael Campos (@racampos)
 options:
   deviceIPAddress:
-    description: DeviceIPAddress query parameter. Device Management IP Address.
+    description: DeviceIPAddress query parameter. Device
+      Management IP Address.
     type: str
   headers:
     description: Additional headers.
     type: dict
 requirements:
-- dnacentersdk >= 2.5.5
-- python >= 3.5
+  - dnacentersdk >= 2.10.1
+  - python >= 3.5
 seealso:
-- name: Cisco DNA Center documentation for Fabric Wireless RemoveWLCFromFabricDomain
-  description: Complete reference of the RemoveWLCFromFabricDomain API.
-  link: https://developer.cisco.com/docs/dna-center/#!remove-wlc-from-fabric-domain
+  - name: Cisco DNA Center documentation for Fabric
+      Wireless RemoveWLCFromFabricDomain
+    description: Complete reference of the RemoveWLCFromFabricDomain
+      API.
+    link: https://developer.cisco.com/docs/dna-center/#!remove-wlc-from-fabric-domain
 notes:
   - SDK Method used are
     fabric_wireless.FabricWireless.remove_w_l_c_from_fabric_domain,
-
   - Paths used are
     delete /dna/intent/api/v1/business/sda/wireless-controller,
-
-  - Removed 'deviceName' and 'siteNameHierarchy' options in v4.3.0.
+    - Removed 'deviceName' and 'siteNameHierarchy' options
+    in v4.3.0.
 """
 
 EXAMPLES = r"""
+---
 - name: Delete all
   cisco.dnac.business_sda_wireless_controller_delete:
     dnac_host: "{{dnac_host}}"
@@ -51,7 +56,6 @@ EXAMPLES = r"""
     dnac_debug: "{{dnac_debug}}"
     deviceIPAddress: string
     headers: '{{my_headers | from_json}}'
-
 """
 RETURN = r"""
 dnac_response:
