@@ -4,26 +4,33 @@
 # Copyright (c) 2021, Cisco Systems
 # GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)
 
-
 DOCUMENTATION = r"""
 ---
 module: configuration_template_import_template
-short_description: Resource module for Configuration Template Import Template
+short_description: Resource module for Configuration
+  Template Import Template
 description:
-- This module represents an alias of the module configuration_template_import_template_v1
+  - Manage operation create of the resource Configuration
+    Template Import Template.
+  - Imports the templates provided in the DTO by project
+    Name.
 version_added: '3.1.0'
 extends_documentation_fragment:
   - cisco.dnac.module
 author: Rafael Campos (@racampos)
 options:
   doVersion:
-    description: DoVersion query parameter. If this flag is true then it creates a new
-      version of the template with the imported contents in case if the templates already
-      exists. " If this flag is false and if template already exists, then operation
-      fails with 'Template already exists' error.
+    description: DoVersion query parameter. If this
+      flag is true then it creates a new version of
+      the template with the imported contents in case
+      if the templates already exists. " If this flag
+      is false and if template already exists, then
+      operation fails with 'Template already exists'
+      error.
     type: bool
   payload:
-    description: Configuration Template Import Template's payload.
+    description: Configuration Template Import Template's
+      payload.
     elements: dict
     suboptions:
       author:
@@ -33,7 +40,8 @@ options:
         description: Is it composite template.
         type: bool
       containingTemplates:
-        description: Configuration Template Import Template's containingTemplates.
+        description: Configuration Template Import Template's
+          containingTemplates.
         elements: dict
         suboptions:
           composite:
@@ -43,7 +51,8 @@ options:
             description: Description of template.
             type: str
           deviceTypes:
-            description: Configuration Template Import Template's deviceTypes.
+            description: Configuration Template Import
+              Template's deviceTypes.
             elements: dict
             suboptions:
               productFamily:
@@ -60,7 +69,8 @@ options:
             description: UUID of template.
             type: str
           language:
-            description: Template language (JINJA or VELOCITY).
+            description: Template language (JINJA or
+              VELOCITY).
             type: str
           name:
             description: Name of template.
@@ -69,23 +79,27 @@ options:
             description: Project name.
             type: str
           rollbackTemplateParams:
-            description: Configuration Template Import Template's rollbackTemplateParams.
+            description: Configuration Template Import
+              Template's rollbackTemplateParams.
             elements: dict
             suboptions:
               binding:
                 description: Bind to source.
                 type: str
               customOrder:
-                description: CustomOrder of template param.
+                description: CustomOrder of template
+                  param.
                 type: int
               dataType:
                 description: Datatype of template param.
                 type: str
               defaultValue:
-                description: Default value of template param.
+                description: Default value of template
+                  param.
                 type: str
               description:
-                description: Description of template param.
+                description: Description of template
+                  param.
                 type: str
               displayName:
                 description: Display name of param.
@@ -118,7 +132,8 @@ options:
                 description: Provider.
                 type: str
               range:
-                description: Configuration Template Import Template's range.
+                description: Configuration Template
+                  Import Template's range.
                 elements: dict
                 suboptions:
                   id:
@@ -135,7 +150,8 @@ options:
                 description: Is param required.
                 type: bool
               selection:
-                description: Configuration Template Import Template's selection.
+                description: Configuration Template
+                  Import Template's selection.
                 suboptions:
                   defaultSelectedValues:
                     description: Default selection values.
@@ -145,7 +161,8 @@ options:
                     description: UUID of selection.
                     type: str
                   selectionType:
-                    description: Type of selection(SINGLE_SELECT or MULTI_SELECT).
+                    description: Type of selection(SINGLE_SELECT
+                      or MULTI_SELECT).
                     type: str
                   selectionValues:
                     description: Selection values.
@@ -153,7 +170,8 @@ options:
                 type: dict
             type: list
           tags:
-            description: Configuration Template Import Template's tags.
+            description: Configuration Template Import
+              Template's tags.
             elements: dict
             suboptions:
               id:
@@ -167,23 +185,27 @@ options:
             description: Template content.
             type: str
           templateParams:
-            description: Configuration Template Import Template's templateParams.
+            description: Configuration Template Import
+              Template's templateParams.
             elements: dict
             suboptions:
               binding:
                 description: Bind to source.
                 type: str
               customOrder:
-                description: CustomOrder of template param.
+                description: CustomOrder of template
+                  param.
                 type: int
               dataType:
                 description: Datatype of template param.
                 type: str
               defaultValue:
-                description: Default value of template param.
+                description: Default value of template
+                  param.
                 type: str
               description:
-                description: Description of template param.
+                description: Description of template
+                  param.
                 type: str
               displayName:
                 description: Display name of param.
@@ -216,7 +238,8 @@ options:
                 description: Provider.
                 type: str
               range:
-                description: Configuration Template Import Template's range.
+                description: Configuration Template
+                  Import Template's range.
                 elements: dict
                 suboptions:
                   id:
@@ -233,7 +256,8 @@ options:
                 description: Is param required.
                 type: bool
               selection:
-                description: Configuration Template Import Template's selection.
+                description: Configuration Template
+                  Import Template's selection.
                 suboptions:
                   defaultSelectedValues:
                     description: Default selection values.
@@ -243,7 +267,8 @@ options:
                     description: UUID of selection.
                     type: str
                   selectionType:
-                    description: Type of selection(SINGLE_SELECT or MULTI_SELECT).
+                    description: Type of selection(SINGLE_SELECT
+                      or MULTI_SELECT).
                     type: str
                   selectionValues:
                     description: Selection values.
@@ -264,7 +289,8 @@ options:
         description: Description of template.
         type: str
       deviceTypes:
-        description: Configuration Template Import Template's deviceTypes.
+        description: Configuration Template Import Template's
+          deviceTypes.
         elements: dict
         suboptions:
           productFamily:
@@ -278,7 +304,8 @@ options:
             type: str
         type: list
       failurePolicy:
-        description: Define failure policy if template provisioning fails.
+        description: Define failure policy if template
+          provisioning fails.
         type: str
       id:
         description: UUID of template.
@@ -308,7 +335,8 @@ options:
         description: Rollback template content.
         type: str
       rollbackTemplateParams:
-        description: Configuration Template Import Template's rollbackTemplateParams.
+        description: Configuration Template Import Template's
+          rollbackTemplateParams.
         elements: dict
         suboptions:
           binding:
@@ -357,7 +385,8 @@ options:
             description: Provider.
             type: str
           range:
-            description: Configuration Template Import Template's range.
+            description: Configuration Template Import
+              Template's range.
             elements: dict
             suboptions:
               id:
@@ -374,7 +403,8 @@ options:
             description: Is param required.
             type: bool
           selection:
-            description: Configuration Template Import Template's selection.
+            description: Configuration Template Import
+              Template's selection.
             suboptions:
               defaultSelectedValues:
                 description: Default selection values.
@@ -384,7 +414,8 @@ options:
                 description: UUID of selection.
                 type: str
               selectionType:
-                description: Type of selection(SINGLE_SELECT or MULTI_SELECT).
+                description: Type of selection(SINGLE_SELECT
+                  or MULTI_SELECT).
                 type: str
               selectionValues:
                 description: Selection values.
@@ -401,7 +432,8 @@ options:
         description: Applicable device software version.
         type: str
       tags:
-        description: Configuration Template Import Template's tags.
+        description: Configuration Template Import Template's
+          tags.
         elements: dict
         suboptions:
           id:
@@ -415,7 +447,8 @@ options:
         description: Template content.
         type: str
       templateParams:
-        description: Configuration Template Import Template's templateParams.
+        description: Configuration Template Import Template's
+          templateParams.
         elements: dict
         suboptions:
           binding:
@@ -464,7 +497,8 @@ options:
             description: Provider.
             type: str
           range:
-            description: Configuration Template Import Template's range.
+            description: Configuration Template Import
+              Template's range.
             elements: dict
             suboptions:
               id:
@@ -481,7 +515,8 @@ options:
             description: Is param required.
             type: bool
           selection:
-            description: Configuration Template Import Template's selection.
+            description: Configuration Template Import
+              Template's selection.
             suboptions:
               defaultSelectedValues:
                 description: Default selection values.
@@ -491,7 +526,8 @@ options:
                 description: UUID of selection.
                 type: str
               selectionType:
-                description: Type of selection(SINGLE_SELECT or MULTI_SELECT).
+                description: Type of selection(SINGLE_SELECT
+                  or MULTI_SELECT).
                 type: str
               selectionValues:
                 description: Selection values.
@@ -499,13 +535,16 @@ options:
             type: dict
         type: list
       validationErrors:
-        description: Configuration Template Import Template's validationErrors.
+        description: Configuration Template Import Template's
+          validationErrors.
         suboptions:
           rollbackTemplateErrors:
-            description: Validation or design conflicts errors of rollback template.
+            description: Validation or design conflicts
+              errors of rollback template.
             type: dict
           templateErrors:
-            description: Validation or design conflicts errors.
+            description: Validation or design conflicts
+              errors.
             type: dict
           templateId:
             description: UUID of template.
@@ -519,27 +558,27 @@ options:
         type: str
     type: list
   projectName:
-    description: ProjectName path parameter. Project name to create template under the
-      project.
+    description: ProjectName path parameter. Project
+      name to create template under the project.
     type: str
 requirements:
-- dnacentersdk >= 2.4.9
-- python >= 3.5
+  - dnacentersdk >= 2.10.1
+  - python >= 3.5
 seealso:
-- name: Cisco DNA Center documentation for Configuration Templates ImportsTheTemplatesProvidedV1
-  description: Complete reference of the ImportsTheTemplatesProvidedV1 API.
-  link: https://developer.cisco.com/docs/dna-center/#!imports-the-templates-provided
+  - name: Cisco DNA Center documentation for Configuration
+      Templates ImportsTheTemplatesProvided
+    description: Complete reference of the ImportsTheTemplatesProvided
+      API.
+    link: https://developer.cisco.com/docs/dna-center/#!imports-the-templates-provided
 notes:
   - SDK Method used are
-    configuration_templates.ConfigurationTemplates.imports_the_templates_provided_v1,
-
+    configuration_templates.ConfigurationTemplates.imports_the_templates_provided,
   - Paths used are
     post /dna/intent/api/v1/template-programmer/project/name/{projectName}/template/importtemplates,
-  - It should be noted that this module is an alias of configuration_template_import_template_v1
-
 """
 
 EXAMPLES = r"""
+---
 - name: Create
   cisco.dnac.configuration_template_import_template:
     dnac_host: "{{dnac_host}}"
@@ -551,164 +590,163 @@ EXAMPLES = r"""
     dnac_debug: "{{dnac_debug}}"
     doVersion: true
     payload:
-    - author: string
-      composite: true
-      containingTemplates:
-      - composite: true
+      - author: string
+        composite: true
+        containingTemplates:
+          - composite: true
+            description: string
+            deviceTypes:
+              - productFamily: string
+                productSeries: string
+                productType: string
+            id: string
+            language: string
+            name: string
+            projectName: string
+            rollbackTemplateParams:
+              - binding: string
+                customOrder: 0
+                dataType: string
+                defaultValue: string
+                description: string
+                displayName: string
+                group: string
+                id: string
+                instructionText: string
+                key: string
+                notParam: true
+                order: 0
+                paramArray: true
+                parameterName: string
+                provider: string
+                range:
+                  - id: string
+                    maxValue: 0
+                    minValue: 0
+                required: true
+                selection:
+                  defaultSelectedValues:
+                    - string
+                  id: string
+                  selectionType: string
+                  selectionValues: {}
+            tags:
+              - id: string
+                name: string
+            templateContent: string
+            templateParams:
+              - binding: string
+                customOrder: 0
+                dataType: string
+                defaultValue: string
+                description: string
+                displayName: string
+                group: string
+                id: string
+                instructionText: string
+                key: string
+                notParam: true
+                order: 0
+                paramArray: true
+                parameterName: string
+                provider: string
+                range:
+                  - id: string
+                    maxValue: 0
+                    minValue: 0
+                required: true
+                selection:
+                  defaultSelectedValues:
+                    - string
+                  id: string
+                  selectionType: string
+                  selectionValues: {}
+            version: string
+        createTime: 0
+        customParamsOrder: true
         description: string
         deviceTypes:
-        - productFamily: string
-          productSeries: string
-          productType: string
+          - productFamily: string
+            productSeries: string
+            productType: string
+        failurePolicy: string
         id: string
         language: string
+        lastUpdateTime: 0
+        latestVersionTime: 0
         name: string
+        parentTemplateId: string
+        projectId: string
         projectName: string
+        rollbackTemplateContent: string
         rollbackTemplateParams:
-        - binding: string
-          customOrder: 0
-          dataType: string
-          defaultValue: string
-          description: string
-          displayName: string
-          group: string
-          id: string
-          instructionText: string
-          key: string
-          notParam: true
-          order: 0
-          paramArray: true
-          parameterName: string
-          provider: string
-          range:
-          - id: string
-            maxValue: 0
-            minValue: 0
-          required: true
-          selection:
-            defaultSelectedValues:
-            - string
+          - binding: string
+            customOrder: 0
+            dataType: string
+            defaultValue: string
+            description: string
+            displayName: string
+            group: string
             id: string
-            selectionType: string
-            selectionValues: {}
+            instructionText: string
+            key: string
+            notParam: true
+            order: 0
+            paramArray: true
+            parameterName: string
+            provider: string
+            range:
+              - id: string
+                maxValue: 0
+                minValue: 0
+            required: true
+            selection:
+              defaultSelectedValues:
+                - string
+              id: string
+              selectionType: string
+              selectionValues: {}
+        softwareType: string
+        softwareVariant: string
+        softwareVersion: string
         tags:
-        - id: string
-          name: string
+          - id: string
+            name: string
         templateContent: string
         templateParams:
-        - binding: string
-          customOrder: 0
-          dataType: string
-          defaultValue: string
-          description: string
-          displayName: string
-          group: string
-          id: string
-          instructionText: string
-          key: string
-          notParam: true
-          order: 0
-          paramArray: true
-          parameterName: string
-          provider: string
-          range:
-          - id: string
-            maxValue: 0
-            minValue: 0
-          required: true
-          selection:
-            defaultSelectedValues:
-            - string
+          - binding: string
+            customOrder: 0
+            dataType: string
+            defaultValue: string
+            description: string
+            displayName: string
+            group: string
             id: string
-            selectionType: string
-            selectionValues: {}
+            instructionText: string
+            key: string
+            notParam: true
+            order: 0
+            paramArray: true
+            parameterName: string
+            provider: string
+            range:
+              - id: string
+                maxValue: 0
+                minValue: 0
+            required: true
+            selection:
+              defaultSelectedValues:
+                - string
+              id: string
+              selectionType: string
+              selectionValues: {}
+        validationErrors:
+          rollbackTemplateErrors: {}
+          templateErrors: {}
+          templateId: string
+          templateVersion: string
         version: string
-      createTime: 0
-      customParamsOrder: true
-      description: string
-      deviceTypes:
-      - productFamily: string
-        productSeries: string
-        productType: string
-      failurePolicy: string
-      id: string
-      language: string
-      lastUpdateTime: 0
-      latestVersionTime: 0
-      name: string
-      parentTemplateId: string
-      projectId: string
-      projectName: string
-      rollbackTemplateContent: string
-      rollbackTemplateParams:
-      - binding: string
-        customOrder: 0
-        dataType: string
-        defaultValue: string
-        description: string
-        displayName: string
-        group: string
-        id: string
-        instructionText: string
-        key: string
-        notParam: true
-        order: 0
-        paramArray: true
-        parameterName: string
-        provider: string
-        range:
-        - id: string
-          maxValue: 0
-          minValue: 0
-        required: true
-        selection:
-          defaultSelectedValues:
-          - string
-          id: string
-          selectionType: string
-          selectionValues: {}
-      softwareType: string
-      softwareVariant: string
-      softwareVersion: string
-      tags:
-      - id: string
-        name: string
-      templateContent: string
-      templateParams:
-      - binding: string
-        customOrder: 0
-        dataType: string
-        defaultValue: string
-        description: string
-        displayName: string
-        group: string
-        id: string
-        instructionText: string
-        key: string
-        notParam: true
-        order: 0
-        paramArray: true
-        parameterName: string
-        provider: string
-        range:
-        - id: string
-          maxValue: 0
-          minValue: 0
-        required: true
-        selection:
-          defaultSelectedValues:
-          - string
-          id: string
-          selectionType: string
-          selectionValues: {}
-      validationErrors:
-        rollbackTemplateErrors: {}
-        templateErrors: {}
-        templateId: string
-        templateVersion: string
-      version: string
     projectName: string
-
 """
 RETURN = r"""
 dnac_response:
