@@ -33,13 +33,13 @@ options:
       - Offset query parameter. The first record to
         show for this page; the first record is numbered
         1.
-    type: float
+    type: int
   limit:
     description:
       - Limit query parameter. The number of records
         to show for this page; the minimum is 1, and
         the maximum is 500.
-    type: float
+    type: int
 requirements:
   - dnacentersdk >= 2.10.1
   - python >= 3.5
