@@ -4,13 +4,18 @@
 # Copyright (c) 2021, Cisco Systems
 # GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)
 
-
 DOCUMENTATION = r"""
 ---
 module: wireless_accesspoint_configuration_summary_info
-short_description: Information module for Wireless Accesspoint Configuration Summary Info
+short_description: Information module for Wireless Accesspoint
+  Configuration Summary
 description:
-- This module represents an alias of the module wireless_accesspoint_configuration_summary_v1_info
+  - Get all Wireless Accesspoint Configuration Summary.
+    - > Users can query access point configuration information
+    for a specific device by using the Ethernet MAC
+    address as a 'key' filter. If no key is specified,
+    all access point details will be retrieved based
+    on the combination of filters provided.
 version_added: '3.1.0'
 extends_documentation_fragment:
   - cisco.dnac.module_info
@@ -21,59 +26,68 @@ options:
     type: dict
   key:
     description:
-    - Key query parameter. The ethernet MAC address of Access point.
+      - Key query parameter. The ethernet MAC address
+        of Access point.
     type: str
   wlcIpAddress:
     description:
-    - WlcIpAddress query parameter. WLC IP Address.
+      - WlcIpAddress query parameter. WLC IP Address.
     type: str
   apMode:
     description:
-    - >
-      ApMode query parameter. AP Mode. Allowed values are Local, Bridge, Monitor, FlexConnect, Sniffer, Rogue
-      Detector, SE-Connect, Flex+Bridge, Sensor.
+      - >
+        ApMode query parameter. AP Mode. Allowed values
+        are Local, Bridge, Monitor, FlexConnect, Sniffer,
+        Rogue Detector, SE-Connect, Flex+Bridge, Sensor.
     type: str
   apModel:
     description:
-    - ApModel query parameter. AP Model.
+      - ApModel query parameter. AP Model.
     type: str
   meshRole:
     description:
-    - MeshRole query parameter. Mesh Role. Allowed values are RAP or MAP.
+      - MeshRole query parameter. Mesh Role. Allowed
+        values are RAP or MAP.
     type: str
   provisioned:
     description:
-    - Provisioned query parameter. Indicate whether AP provisioned or not. Allowed values are True or False.
+      - Provisioned query parameter. Indicate whether
+        AP provisioned or not. Allowed values are True
+        or False.
     type: str
   limit:
     description:
-    - >
-      Limit query parameter. The number of records to show for this page. The default is 500 if not specified. The
-      maximum allowed limit is 500.
+      - >
+        Limit query parameter. The number of records
+        to show for this page. The default is 500 if
+        not specified. The maximum allowed limit is
+        500.
     type: float
   offset:
     description:
-    - Offset query parameter. The first record to show for this page; the first record is numbered 1.
+      - Offset query parameter. The first record to
+        show for this page; the first record is numbered
+        1.
     type: float
 requirements:
-- dnacentersdk >= 2.4.9
-- python >= 3.5
+  - dnacentersdk >= 2.10.1
+  - python >= 3.5
 seealso:
-- name: Cisco DNA Center documentation for Wireless GetAccessPointConfigurationV1
-  description: Complete reference of the GetAccessPointConfigurationV1 API.
-  link: https://developer.cisco.com/docs/dna-center/#!get-access-point-configuration
+  - name: Cisco DNA Center documentation for Wireless
+      GetAccessPointConfiguration
+    description: Complete reference of the GetAccessPointConfiguration
+      API.
+    link: https://developer.cisco.com/docs/dna-center/#!get-access-point-configuration
 notes:
   - SDK Method used are
-    wireless.Wireless.get_access_point_configuration_v1,
-
+    wireless.Wireless.get_access_point_configuration,
   - Paths used are
     get /dna/intent/api/v1/wireless/accesspoint-configuration/summary,
-  - It should be noted that this module is an alias of wireless_accesspoint_configuration_summary_v1_info
-
 """
 
 EXAMPLES = r"""
-- name: Get all Wireless Accesspoint Configuration Summary Info
+---
+- name: Get all Wireless Accesspoint Configuration Summary
   cisco.dnac.wireless_accesspoint_configuration_summary_info:
     dnac_host: "{{dnac_host}}"
     dnac_username: "{{dnac_username}}"
@@ -92,7 +106,6 @@ EXAMPLES = r"""
     limit: 0
     offset: 0
   register: result
-
 """
 RETURN = r"""
 dnac_response:
@@ -124,6 +137,28 @@ dnac_response:
       "wlcIpAddress": "string",
       "reachabilityStatus": "string",
       "managementIpAddress": "string",
-      "provisioned": "string"
+      "provisioningStatus": "string",
+      "radioDTOs": [
+        {
+          "ifType": 0,
+          "ifTypeValue": "string",
+          "slotId": 0,
+          "macAddress": "string",
+          "adminStatus": "string",
+          "powerAssignmentMode": "string",
+          "powerlevel": 0,
+          "channelAssignmentMode": "string",
+          "channelNumber": 0,
+          "channelWidth": "string",
+          "antennaPatternName": "string",
+          "antennaAngle": 0,
+          "antennaElevAngle": 0,
+          "antennaGain": 0,
+          "radioRoleAssignment": {},
+          "radioBand": {},
+          "cleanAirSI": "string",
+          "dualRadioMode": "string"
+        }
+      ]
     }
 """
