@@ -35,6 +35,8 @@ class TestDnacAccesspointWorkflow(TestDnacModule):
     get_device_detail_all_data = test_data.get("get_device_detail_all_data")
     playbook_config_update_some_missing_data = test_data.get("playbook_config_update_some_missing_data")
     playbook_config_update_some_error_data = test_data.get("playbook_config_update_some_error_data")
+    playbook_invalid_config_complete = test_data.get("playbook_invalid_config_complete")
+    playbook_config_provision_new_positive = test_data.get("playbook_config_provision_new_positive")
 
     def setUp(self):
         super(TestDnacAccesspointWorkflow, self).setUp()
@@ -61,23 +63,20 @@ class TestDnacAccesspointWorkflow(TestDnacModule):
         """
         if "provision_device" in self._testMethodName:
             self.run_dnac_exec.side_effect = [
-                self.test_data.get("get_device_detail"),
-                self.test_data.get("get_site_exist_response"),
-                self.test_data.get("get_device_detail"),
-                self.test_data.get("verify_get_device_info"),
-                self.test_data.get("get_accesspoint_config"),
-                self.test_data.get("assign_to_site_response"),
-                self.test_data.get("assign_to_site_task_response"),
-                self.test_data.get("provision_ap_response"),
-                self.test_data.get("provision_ap_task_response"),
-                self.test_data.get("ap_update_response"),
-                self.test_data.get("ap_task_status"),
-                self.test_data.get("get_device_detail"),
-                self.test_data.get("get_site_exist_response"),
-                self.test_data.get("get_device_detail"),
-                self.test_data.get("verify_get_device_info"),
-                self.test_data.get("get_accesspoint_config_verify")
+                self.test_data.get("get_device_detail_for_provision"),
+                self.test_data.get("get_config_detail_for_provision"),
+                self.test_data.get("get_site_for_provision"),
+                self.test_data.get("get_device_for_site_for_provision"),
+                self.test_data.get("get_wlc_device_for_provision"),
+                self.test_data.get("get_site_for_provision"),
+                self.test_data.get("get_deviceip_for_deviceid_provision"),
+                self.test_data.get("assign_site_for_task_execution"),
+                self.test_data.get("assign_device_to_site_for_provision"),
+                self.test_data.get("provision_site_for_task_execution"),
+                self.test_data.get("task_details_for_provision")
             ]
+        elif "invalid_mac_address" in self._testMethodName:
+            self.run_dnac_exec.side_effect = []
         elif "invalid_wlc_device" in self._testMethodName:
             self.run_dnac_exec.side_effect = [
                 self.test_data.get("get_device_detail"),
@@ -137,39 +136,15 @@ class TestDnacAccesspointWorkflow(TestDnacModule):
                 dnac_password="dummy",
                 dnac_log=True,
                 state="merged",
-                dnac_version="2.3.7.6",
+                dnac_version="3.1.3.0",
                 config_verify=True,
-                config=self.playbook_config_complete
-            )
-        )
-        result = self.execute_module(changed=True, failed=False)
-        self.assertEqual(
-            result.get('ap_update_msg'),
-            "AP Configuration - LTTS_Test_9124_T2 updated Successfully"
-        )
-
-    def test_invalid_wlc_device(self):
-        """
-        Test case for access point workfollow manager check invalid wireless controller.
-
-        This test case checks the behavior of the access point workflow of invalid wlc specified Cisco Catalyst Center.
-        """
-        set_module_args(
-            dict(
-                dnac_host="1.1.1.1",
-                dnac_username="dummy",
-                dnac_password="dummy",
-                dnac_log=True,
-                state="merged",
-                dnac_version="2.3.7.6",
-                config=self.playbook_config_provision
+                config=self.playbook_config_provision_new_positive
             )
         )
         result = self.execute_module(changed=False, failed=True)
-        self.maxDiff = None
-        self.assertEqual(
-            result.get('msg'),
-            "Wireles controller is not provisioned:"
+        self.assertIn(
+            "Provided device is not Access Point",
+            result.get('msg', '')
         )
 
     def test_accesspoint_workflow_manager_some_error_data_update_accesspoint(self):
@@ -192,10 +167,9 @@ class TestDnacAccesspointWorkflow(TestDnacModule):
         )
         result = self.execute_module(changed=True, failed=True)
         self.maxDiff = None
-        self.assertEqual(
-            result.get('msg'),
-            'The provided site name \'Global/USA/New York/BLDNYCGlobal/USA/New York/BLDNYCGlobal/USA/iikk/FLOOR2FLOOR2FLOOR2FLOOR2FLOOR2FLOOR2FLOO\' ' +
-            'is either invalid or not present in the                         Cisco Catalyst Center.'
+        self.assertIn(
+            'get_sites',
+            result.get('msg')
         )
 
     def test_accesspoint_workflow_manager_negative_config_input(self):
@@ -218,41 +192,9 @@ class TestDnacAccesspointWorkflow(TestDnacModule):
         )
         result = self.execute_module(changed=False, failed=True)
         self.maxDiff = None
-        self.assertEqual(
-            result.get('msg'),
-            'Invalid parameters in playbook config: \'[["Access Point series \'Cisco 9164I Series Unified Access Points\' not supported ' +
-            'for the radio type xor_radio allowed series 280", "Access Point series \'Cisco 9164I Series Unified Access Points\' not supported ' +
-            'for the radio type xor_radio allowed series 380", "Access Point series \'Cisco 9164I Series Unified Access Points\' not supported ' +
-            'for the radio type xor_radio allowed series 480", "Access Point series \'Cisco 9164I Series Unified Access Points\' not supported ' +
-            'for the radio type xor_radio allowed series 9120", "Access Point series \'Cisco 9164I Series Unified Access Points\' not supported ' +
-            'for the radio type xor_radio allowed series 9166", "Access Point series \'Cisco 9164I Series Unified Access Points\' not supported ' +
-            'for the radio type xor_radio allowed series IW9167EH", "Access Point series \'Cisco 9164I Series Unified Access Points\' not supported ' +
-            'for the radio type xor_radio allowed series IW9165E", "Access Point series \'Cisco 9164I Series Unified Access Points\' not supported ' +
-            'for the radio type xor_radio allowed series IW9165DH"], "management_ip_address: Invalid Management IP ' +
-            'Address \'204.192.12.201dsd\'                            in playbook.", \'ap_name:hostname,family,type,mac_address,management_ip_address,' +
-            'ap_ethernet_mac_address : The string exceeds the allowed range of max 32 char\', "led_status: Invalid LED Status \'Enableddd\' in ' +
-            'playbook.", "ap_mode: Invalid value \'Monitorw\' for ap_mode in playbook. Must be one of: Local, Monitor, Sniffer or ' +
-            'Bridge.", "failover_priority: Invalid value \'Lossw\' for failover_priority in playbook. Must be one of: Low, Medium, High or ' +
-            'Critical.", "clean_air_si_2.4ghz: Invalid value \'Disableds\' in playbook. Must be ' +
-            'either \'Enabled\' or \'Disabled\'.", "clean_air_si_5ghz: Invalid value \'Disableds\' in playbook. Must be ' +
-            'either \'Enabled\' or \'Disabled\'.", "clean_air_si_6ghz: Invalid value \'Enableds\' in playbook. Must be ' +
-            'either \'Enabled\' or \'Disabled\'.", "primary_ip_address: Invalid primary_ip_address \'{\'address\': \'204.192.4.20dfasd0\'}\' in ' +
-            'playbook", "secondary_ip_address: Invalid secondary_ip_address \'{\'address\': \'204.192.4.20dfasd0\'}\' in playbook", "tertiary_ip_address: ' +
-            'Invalid tertiary_ip_address \'{\'address\': \'204.192.4.20dfasd0\'}\' in playbook", \'Radio Params cannot be changed when AP mode is in ' +
-            'Monitorw.\', "admin_status: Invalid value \'Enabledsds\' for admin_status in playbook. Must be ' +
-            'either \'Enabled\' or \'Disabled\'.", "channel_assignment_mode: Invalid value \'any\' for Channel Assignment Mode in playbook. Must be ' +
-            'either \'Global\' or \'Custom\'.", "channel_number: Invalid value \'22\' for Channel Number in playbook. Must be one of: ' +
-            '[1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14].", "channel_width: Invalid value \'5\' for Channel width in playbook. Must be one ' +
-            'of: \'20 MHz\', \'40 MHz\', \'80 MHz\', \'160 MHz\', or \'320 MHz\'.", "power_assignment_mode: Invalid ' +
-            'value \'any\' for Power assignment mode in ' +
-            'playbook. Must be either \'Global\' or \'Custom\'.", \'powerlevel: This configuration is only supported with Client-Serving Radio Role ' +
-            'Assignment None \', "radio_role_assignment: Invalid value \'any\' for radio role assignment in playbook. Must be one ' +
-            'of: \'Auto\', \'Monitor\' or \'Client-Serving\'.", \'Radio Params cannot be changed when AP mode is in Monitorw.\', "admin_status: ' +
-            'Invalid value \'Enabledsds\' for admin_status in playbook. Must be either \'Enabled\' or \'Disabled\'.", "antenna_gain: Invalid \'41\' in ' +
-            'playbook, allowed range of min: 0 and max: 40", "channel_assignment_mode: Invalid value \'any\' for Channel Assignment Mode in playbook. ' +
-            'Must be either \'Global\' or \'Custom\'.", ' +
-            '"radio_role_assignment: Invalid value \'Client-Serving\'. Hence, AP mode is not Local. Kindly change the AP mode to Local then ' +
-            'change the radio_role_assignment to Auto."]\' '
+        self.assertIn(
+            "Invalid parameters in playbook config:",
+            result.get('msg')
         )
 
     def test_accesspoint_workflow_manager_reboot_accesspoint(self):
@@ -279,31 +221,6 @@ class TestDnacAccesspointWorkflow(TestDnacModule):
             "APs ['34:b8:83:15:7c:6c'] rebooted successfully"
         )
 
-    def test_accesspoint_workflow_manager_provision_old_version(self):
-        """
-        Test case for access point workfollow manager provision device old version.
-
-        This test case checks the behavior of the access point workflow when provisioned in the specified Cisco Catalyst Center.
-        """
-        set_module_args(
-            dict(
-                dnac_host="1.1.1.1",
-                dnac_username="dummy",
-                dnac_password="dummy",
-                dnac_log=True,
-                state="merged",
-                dnac_version="2.3.5.3",
-                config_verify=True,
-                config=self.playbook_config_provision_old_version
-            )
-        )
-        result = self.execute_module(changed=False, failed=True)
-        self.maxDiff = None
-        self.assertEqual(
-            result.get('msg'),
-            "The provided site name 'Global/Chennai/LTTS/FLOOR1' is either invalid or not present in the                         Cisco Catalyst Center."
-        )
-
     def test_accesspoint_workflow_manager_task_error_update_accesspoint(self):
         """
         Test case for access point workfollow manager and negative test verify ap update.
@@ -323,9 +240,9 @@ class TestDnacAccesspointWorkflow(TestDnacModule):
             )
         )
         result = self.execute_module(changed=False, failed=True)
-        self.assertEqual(
-            result.get('msg'),
-            "Unable to get success response, hence AP config not updated"
+        self.assertIn(
+            "An error occurred while executing API call to Function: 'get_task_details_by_id'",
+            result.get('msg')
         )
 
     def test_invalid_site_exists(self):
@@ -349,7 +266,7 @@ class TestDnacAccesspointWorkflow(TestDnacModule):
         print(result)
         self.assertEqual(
             result.get('msg'),
-            "MAC Address is not Access point"
+            "Provided device is not Access Point."
         )
 
     def test_accesspoint_workflow_invalid_state(self):
@@ -390,13 +307,46 @@ class TestDnacAccesspointWorkflow(TestDnacModule):
                 dnac_password="dummy",
                 dnac_log=True,
                 state="merged",
-                dnac_version="2.3.7.6",
-                config=self.get_membership_empty
+                dnac_version="2.3.7.9",
+                config=self.playbook_invalid_config_complete
             )
         )
         result = self.execute_module(changed=False, failed=True)
         print(result)
         self.assertEqual(
-            result.get('msg'),
+            result.get('response'),
             "Required param of mac_address,ip_address or hostname is not in playbook config"
         )
+
+    def test_accesspoint_workflow_manager_invalid_mac_address(self):
+        """
+        Test case for invalid MAC address format.
+
+        This test case checks validation of MAC address format.
+        """
+        invalid_config = [{
+            "mac_address": "invalid-mac",
+            "site": {
+                "floor": {
+                    "name": "FLOOR1",
+                    "parent_name": "Global/Chennai/LTTS"
+                }
+            }
+        }]
+
+        set_module_args(
+            dict(
+                dnac_host="1.1.1.1",
+                dnac_username="dummy",
+                dnac_password="dummy",
+                dnac_log=True,
+                state="merged",
+                dnac_version="2.3.7.6",
+                config=invalid_config
+            )
+        )
+        result = self.execute_module(changed=False, failed=True)
+        self.assertIn(
+            "mac",
+            result.get('msg', '').lower()
+        )
