@@ -27,11 +27,9 @@ import sys
 
 from contextlib import contextmanager
 from io import BytesIO, StringIO
+from unittest import TestCase
 
 from ansible.module_utils._text import to_bytes
-from ansible.module_utils.six import PY3
-
-from ansible_collections.cisco.ios.tests.unit.compat import unittest
 
 
 @contextmanager
@@ -42,7 +40,7 @@ def swap_stdin_and_argv(stdin_data="", argv_data=tuple()):
     real_stdin = sys.stdin
     real_argv = sys.argv
 
-    if PY3:
+    if sys.version_info[0] == 3:
         fake_stream = StringIO(stdin_data)
         fake_stream.buffer = BytesIO(to_bytes(stdin_data))
     else:
@@ -65,7 +63,7 @@ def swap_stdout():
     """
     old_stdout = sys.stdout
 
-    if PY3:
+    if sys.version_info[0] == 3:
         fake_stream = StringIO()
     else:
         fake_stream = BytesIO()
@@ -78,10 +76,13 @@ def swap_stdout():
         sys.stdout = old_stdout
 
 
-class ModuleTestCase(unittest.TestCase):
+class ModuleTestCase(TestCase):
     def setUp(self, module_args=None):
         if module_args is None:
-            module_args = {"_ansible_remote_tmp": "/tmp", "_ansible_keep_remote_files": False}
+            module_args = {
+                "_ansible_remote_tmp": "/tmp",
+                "_ansible_keep_remote_files": False,
+            }
 
         args = json.dumps(dict(ANSIBLE_MODULE_ARGS=module_args))
 
