@@ -7,11 +7,13 @@ from __future__ import absolute_import, division, print_function
 
 
 __metaclass__ = type
+
+from unittest import TestCase
+
 from ansible_collections.cisco.iosxr.plugins.module_utils.network.iosxr.utils.utils import Version
-from ansible_collections.cisco.iosxr.tests.unit.compat import unittest
 
 
-class TestIosxrUtils(unittest.TestCase):
+class TestIosxrUtils(TestCase):
     def setUp(self):
         pass
 
