@@ -52,9 +52,9 @@ options:
     - The ID of the node (border leaf switch) where to deploy the L3Out routing protocol and node-level protocol configurations.
     - This parameter is required when O(path) is specified.
     - This parameter is required when the node configuration does not exist under the L3Out template.
-    - The node configuration is created under the L3Out template when it does not exist.
-    - The node configuration is updated under the L3Out template when it already exists.
-    - The node configuration is deleted under the L3Out template when there are no interfaces referencing it.
+    - When specified, the node configuration is created under the L3Out template when it does not exist.
+    - When specified, the node configuration is updated under the L3Out template when it already exists.
+    - When specified, the node configuration is deleted under the L3Out template when there are no interfaces referencing it.
     type: str
     aliases: [ node, border_leaf ]
   node_router_id:
@@ -79,15 +79,14 @@ options:
   path:
     description:
     - The path of the interface.
-    - The path is an existing physical port (eth1/1).
-    - This parameter or O(port_channel) is required.
+    - The path must be an existing physical port (eg. eth1/1).
     type: str
     aliases: [ interface ]
   port_channel:
     description:
     - The port channel details.
-    - This parameter or O(path) is required.
     type: dict
+    aliases: [ pc ]
     suboptions:
       uuid:
         description:
@@ -204,13 +203,24 @@ notes:
   The M(cisco.mso.ndo_template) module can be used for this.
 - The O(l3out) or O(l3out_uuid) must exist before using this module in your playbook.
   The M(cisco.mso.ndo_l3out_template) module can be used for this.
+- The O(node_group_policy) must exist before using this module in your playbook.
+  The M(cisco.mso.ndo_l3out_node_group_policy) module can be used for this.
+- The O(interface_group_policy) must exist before using this module in your playbook.
+  The M(cisco.mso.ndo_l3out_interface_group_policy) module can be used for this.
 - The O(port_channel) must exist before using this module in your playbook.
   The M(cisco.mso.ndo_port_channel_interface) module can be used for this.
+- The O(ptp.user_profile) must exist before using this module in your playbook.
+  The M(cisco.mso.ndo_ptp_policy_profiles) module can be used for this.
 seealso:
 - module: cisco.mso.ndo_template
 - module: cisco.mso.ndo_l3out_template
+- module: cisco.mso.ndo_l3out_node_group_policy
+- module: cisco.mso.ndo_l3out_interface_group_policy
 - module: cisco.mso.ndo_port_channel_interface
-extends_documentation_fragment: cisco.mso.modules
+- module: cisco.mso.ndo_ptp_policy_profiles
+extends_documentation_fragment:
+- cisco.mso.modules
+- cisco.mso.l3out_interface_ptp
 """
 
 EXAMPLES = r"""
@@ -233,6 +243,9 @@ EXAMPLES = r"""
     node_router_id: 1.1.1.1
     node_group_policy: node_group_policy_name
     use_router_id_as_loopback: true
+    ptp:
+      user_profile:
+        uuid: '{{ ptp_profile.current.uuid }}'
     state: present
 
 - name: Create a L3Out Routed Interface of type port_channel with reference and L3Out Node configuration
@@ -260,6 +273,16 @@ EXAMPLES = r"""
     node_group_policy: node_group_policy_name
     use_router_id_as_loopback: false
     node_loopback_ip: 10.0.0.1
+    ptp:
+      mode: unicast_master
+      user_profile:
+        reference:
+          name: ptp_profile_name
+          template: fabric_policy_template_name
+      source_address: 12.0.0.1
+      unicast_destinations:
+        - 12.0.0.2
+        - 12.0.0.3
     state: present
 
 - name: Update a L3Out Routed Interface of type port_channel with uuid and L3Out Node configuration
@@ -287,6 +310,18 @@ EXAMPLES = r"""
     node_loopback_ip: 10.0.0.1
     state: present
 
+- name: Remove PTP configuration from a L3Out Routed Interface of type port
+  cisco.mso.ndo_l3out_routed_interface:
+    host: mso_host
+    username: admin
+    password: SomeSecretPassword
+    template: l3out_template
+    l3out: l3out_name
+    node_id: 101
+    path: eth1/1
+    ptp: {}
+    state: present
+
 - name: Query an existing L3Out Routed Interface of type port with L3Out Node configuration
   cisco.mso.ndo_l3out_routed_interface:
     host: mso_host
@@ -338,10 +373,10 @@ RETURN = r"""
 """
 
 from ansible.module_utils.basic import AnsibleModule
-from ansible_collections.cisco.mso.plugins.module_utils.mso import MSOModule, mso_argument_spec, ndo_l3out_port_channel_spec
+from ansible_collections.cisco.mso.plugins.module_utils.mso import MSOModule, mso_argument_spec, ndo_l3out_port_channel_spec, ndo_l3out_ptp_spec
 from ansible_collections.cisco.mso.plugins.module_utils.templates import MSOTemplates
-from ansible_collections.cisco.mso.plugins.module_utils.constants import TARGET_DSCP_MAP
-from ansible_collections.cisco.mso.plugins.module_utils.utils import append_update_ops_data, delete_none_values
+from ansible_collections.cisco.mso.plugins.module_utils.constants import TARGET_DSCP_MAP, PTP_MODES
+from ansible_collections.cisco.mso.plugins.module_utils.utils import append_update_ops_data, delete_none_values, check_if_all_elements_are_none
 from ansible_collections.cisco.mso.plugins.module_utils.l3out_node import L3OutNode
 import copy
 
@@ -368,6 +403,7 @@ def main():
         mac=dict(type="str"),
         mtu=dict(type="str"),
         target_dscp=dict(type="str", choices=list(TARGET_DSCP_MAP)),
+        ptp=ndo_l3out_ptp_spec(),
         state=dict(type="str", default="query", choices=["absent", "query", "present"]),
     )
 
@@ -415,6 +451,10 @@ def main():
     mac = mso.params.get("mac")
     mtu = mso.params.get("mtu")
     target_dscp = mso.params.get("target_dscp")
+    ptp = mso.params.get("ptp")
+    if ptp is not None and check_if_all_elements_are_none(ptp.values()):
+        ptp = {}
+
     state = mso.params.get("state")
 
     mso_template = mso_templates.get_template("l3out", template_name, template_id)
@@ -438,9 +478,9 @@ def main():
                 port_channel_uuid,
                 port_channel.get("reference").get("name"),
                 fail_module=True,
-            )
-            port_channel_uuid = port_channel_match.details.get("uuid")
-            node_id = port_channel_match.details.get("node")
+            ).details
+            port_channel_uuid = port_channel_match.get("uuid")
+        node_id = port_channel_match.get("node")
 
     pod_id = None
     if path or port_channel:
@@ -453,10 +493,10 @@ def main():
 
     match = mso_template.get_l3out_routed_interface(l3out_object.details, pod_id, node_id, path, port_channel_uuid)
     if (path or port_channel) and match:
-        set_routed_interface_details(mso_template, match.details, l3out_object)
+        set_routed_interface_details(mso_template, match.details, l3out_object, mso_templates)
         mso.existing = mso.previous = copy.deepcopy(match.details)  # Query a specific object
     elif match:
-        mso.existing = [set_routed_interface_details(mso_template, obj, l3out_object) for obj in match]
+        mso.existing = [set_routed_interface_details(mso_template, obj, l3out_object, mso_templates) for obj in match]
 
     l3out_interface_path = "/l3outTemplate/l3outs/{0}/interfaces/{1}".format(l3out_object.index, match.index if match else "-")
 
@@ -477,6 +517,27 @@ def main():
             "targetDscp": target_dscp,
         }
 
+        ptp_policy_profile_uuid = None
+        if ptp and ptp.get("user_profile") is not None:
+            ptp_user_profile = ptp.get("user_profile")
+            if ptp_user_profile.get("uuid"):
+                ptp_policy_profile_uuid = ptp_user_profile.get("uuid")
+            else:
+                ptp_policy_profile_uuid = (
+                    mso_templates.get_template(
+                        "fabric_policy",
+                        ptp_user_profile.get("reference").get("template"),
+                        ptp_user_profile.get("reference").get("template_id"),
+                        fail_module=True,
+                    )
+                    .get_ptp_policy_profile_object(
+                        ptp_policy_profile_uuid,
+                        ptp_user_profile.get("reference").get("name"),
+                        fail_module=True,
+                    )
+                    .details.get("uuid")
+                )
+
         if path:
             mso_values["nodeID"] = node_id
             mso_values["podID"] = pod_id
@@ -496,6 +557,19 @@ def main():
                 mso_values[("microBfd", "address")] = port_channel.get("micro_bfd_address")
                 mso_values[("microBfd", "startTimer")] = port_channel.get("micro_bfd_start_timer")
 
+            if ptp == {}:
+                remove_data.append("ptpConfig")
+            elif ptp:
+                if not match.details.get("ptpConfig"):
+                    mso_values["ptpConfig"] = {}
+                if ptp.get("unicast_destinations") == []:
+                    remove_data.append(("ptpConfig", "destIPs"))
+                elif ptp.get("unicast_destinations"):
+                    mso_values[("ptpConfig", "destIPs")] = ptp.get("unicast_destinations")
+                mso_values[("ptpConfig", "mode")] = PTP_MODES.get(ptp.get("mode"))
+                mso_values[("ptpConfig", "srcIP")] = ptp.get("source_address")
+                mso_values[("ptpConfig", "ptpProfileRef")] = ptp_policy_profile_uuid
+
             append_update_ops_data(ops, match.details, l3out_interface_path, mso_values, remove_data)
             mso.sanitize(match.details, collate=True, unwanted=remove_data)
 
@@ -507,6 +581,14 @@ def main():
                 "ipV6DAD": ipv6_dad,
             }
 
+            if ptp:
+                mso_values["ptpConfig"] = {
+                    "mode": PTP_MODES.get(ptp.get("mode")),
+                    "ptpProfileRef": ptp_policy_profile_uuid,
+                    "srcIP": ptp.get("source_address"),
+                    "destIPs": ptp.get("unicast_destinations"),
+                }
+
             if port_channel and port_channel.get("micro_bfd_enabled") is True:
                 mso_values["microBfd"] = {
                     "address": port_channel.get("micro_bfd_address"),
@@ -519,8 +601,8 @@ def main():
 
             # update mso.proposed with interface details that are not included in the interface payload and node details
             mso.proposed["node"] = l3out_node.construct_node_payload()
-            set_routed_interface_details(mso_template, mso.proposed, l3out_object)
 
+        set_routed_interface_details(mso_template, mso.proposed, l3out_object, mso_templates)
         l3out_node.update_ops(ops)
 
     elif state == "absent":
@@ -529,11 +611,12 @@ def main():
 
     if not mso.module.check_mode and ops:
         ignore_errors = ["node {0}-{1} doesn't have an interface configured".format(pod_id, node_id)]
-        response = mso.l3out_interface_request(mso_template, ops, ignore_errors, state, l3out_node.get_node_remove_op())
+        remove_ops = {ignore_errors[0]: l3out_node.get_node_remove_op()}
+        response = mso.l3out_interface_request(mso_template, ops, ignore_errors, state, remove_ops)
         l3out_object = mso_template.get_l3out_object(l3out_uuid, l3out, True, search_object=response)
         match = mso_template.get_l3out_routed_interface(l3out_object.details, pod_id, node_id, path, port_channel_uuid)
         if match:
-            set_routed_interface_details(mso_template, match.details, l3out_object)
+            set_routed_interface_details(mso_template, match.details, l3out_object, mso_templates)
             mso.existing = match.details  # When the state is present
         else:
             mso.existing = {}  # When the state is absent
@@ -542,9 +625,10 @@ def main():
     mso.exit_json()
 
 
-def set_routed_interface_details(mso_template, routed_interface, l3out_object):
+def set_routed_interface_details(mso_template, routed_interface, l3out_object, mso_templates):
     mso_template.update_config_with_port_channel_references(routed_interface)
     mso_template.update_config_with_node_references(routed_interface, l3out_object)
+    mso_template.update_config_with_ptp_references(routed_interface, mso_templates)
     return routed_interface
 
 
