@@ -10,8 +10,6 @@ __metaclass__ = type
 import platform
 import re
 
-from ansible.module_utils.six import iteritems
-
 from ansible_collections.cisco.nxos.plugins.module_utils.network.nxos.nxos import (
     get_capabilities,
     get_config,
@@ -38,7 +36,7 @@ class FactsBase(object):
 
     def run(self, command, output="text"):
         command_string = command
-        if output == "json":
+        if output == "json" and self.capabilities.get("network_api") != "nxapi":
             # Not all devices support | json-pretty but is a workaround for
             # libssh issue https://github.com/ansible/pylibssh/issues/208
             output = "json-pretty"
@@ -162,6 +160,30 @@ class Hardware(FactsBase):
                 self.facts["memtotal_mb"] = self.parse_memtotal_mb(data)
                 self.facts["memfree_mb"] = self.parse_memfree_mb(data)
 
+        data = None
+        data = self.run("show processes cpu | json")
+
+        if data:
+            self.facts["cpu_utilization"] = self.parse_cpu_utilization(data)
+
+    def parse_cpu_utilization(self, data):
+        onemin = data.get("onemin_percent", ["0"])
+        if not isinstance(onemin, list):
+            onemin = [str(onemin)]
+        onemin_value = onemin[0]
+        return {
+            "core": {
+                "five_minutes": int(data.get("fivemin_percent", 0)),
+                "five_seconds": int(
+                    data.get("fivesec_percent", 0),
+                ),
+                "five_seconds_interrupt": int(
+                    data.get("fivesec_intr_percent", 0),
+                ),
+                "one_minute": int(onemin_value),
+            },
+        }
+
     def parse_filesystems(self, data):
         return re.findall(r"^Usage for (\S+)//", data, re.M)
 
@@ -203,9 +225,13 @@ class Interfaces(FactsBase):
         ],
     )
 
-    INTERFACE_IPV4_MAP = frozenset([("eth_ip_addr", "address"), ("eth_ip_mask", "masklen")])
+    INTERFACE_IPV4_MAP = frozenset(
+        [("eth_ip_addr", "address"), ("eth_ip_mask", "masklen")],
+    )
 
-    INTERFACE_SVI_IPV4_MAP = frozenset([("svi_ip_addr", "address"), ("svi_ip_mask", "masklen")])
+    INTERFACE_SVI_IPV4_MAP = frozenset(
+        [("svi_ip_addr", "address"), ("svi_ip_mask", "masklen")],
+    )
 
     INTERFACE_IPV6_MAP = frozenset([("addr", "address"), ("prefix", "subnet")])
 
@@ -225,6 +251,7 @@ class Interfaces(FactsBase):
         self.facts["neighbors"] = {}
         data = None
 
+        # Gets the interface data
         data = self.run("show interface", output="json")
 
         if data:
@@ -235,7 +262,7 @@ class Interfaces(FactsBase):
                 self.facts["interfaces"] = self.populate_interfaces(interfaces)
 
         if self.ipv6_structure_op_supported():
-            data = self.run("show ipv6 interface", output="json")
+            data = self.run("show ipv6 interface vrf all", output="json")
         else:
             data = None
         if data:
@@ -248,14 +275,18 @@ class Interfaces(FactsBase):
         data = self.run("show lldp neighbors", output="json")
         if data:
             if isinstance(data, dict):
-                self.facts["neighbors"].update(self.populate_structured_neighbors_lldp(data))
+                self.facts["neighbors"].update(
+                    self.populate_structured_neighbors_lldp(data),
+                )
             else:
                 self.facts["neighbors"].update(self.populate_neighbors(data))
 
         data = self.run("show cdp neighbors detail", output="json")
         if data:
             if isinstance(data, dict):
-                self.facts["neighbors"].update(self.populate_structured_neighbors_cdp(data))
+                self.facts["neighbors"].update(
+                    self.populate_structured_neighbors_cdp(data),
+                )
             else:
                 self.facts["neighbors"].update(self.populate_neighbors_cdp(data))
 
@@ -296,14 +327,17 @@ class Interfaces(FactsBase):
                 if isinstance(data, dict):
                     data = [data]
                 for item in data:
-                    name = item["ROW_intf"]["intf-name"]
-                    intf = self.facts["interfaces"][name]
-                    intf["ipv6"] = self.transform_dict(item, self.INTERFACE_IPV6_MAP)
-                    try:
-                        addr = item["ROW_intf"]["addr"]
-                    except KeyError:
-                        addr = item["ROW_intf"]["TABLE_addr"]["ROW_addr"]["addr"]
-                    self.facts["all_ipv6_addresses"].append(addr)
+                    row_intf = item["ROW_intf"]
+                    if isinstance(row_intf, dict):
+                        row_intf = [row_intf]
+                    for item in row_intf:
+                        intf = self.facts["interfaces"][item["intf-name"]]
+                        intf["ipv6"] = self.transform_dict(item, self.INTERFACE_IPV6_MAP)
+                        try:
+                            addr = item["addr"]
+                        except KeyError:
+                            addr = item["TABLE_addr"]["ROW_addr"]["addr"]
+                        self.facts["all_ipv6_addresses"].append(addr)
             else:
                 return ""
         except TypeError:
@@ -311,7 +345,12 @@ class Interfaces(FactsBase):
 
     def populate_structured_neighbors_lldp(self, data):
         objects = dict()
-        data = data["TABLE_nbor"]["ROW_nbor"]
+        try:
+            data = data["TABLE_nbor"]["ROW_nbor"]
+        except KeyError:
+            return (
+                objects  # No neighbors found as the TABLE_nbor key is missing and return empty dict
+            )
 
         if isinstance(data, dict):
             data = [data]
@@ -359,13 +398,15 @@ class Interfaces(FactsBase):
                 match = re.match(r"^(\S+)", line)
                 if match:
                     key = match.group(1)
-                    if not key.startswith("admin") or not key.startswith("IPv6 Interface"):
+                    if not key.startswith("admin") or not key.startswith(
+                        "IPv6 Interface",
+                    ):
                         parsed[key] = line
         return parsed
 
     def populate_interfaces(self, interfaces):
         facts = dict()
-        for key, value in iteritems(interfaces):
+        for key, value in interfaces.items():
             intf = dict()
             if get_interface_type(key) == "svi":
                 intf["state"] = self.parse_state(key, value, intf_type="svi")
@@ -519,7 +560,7 @@ class Interfaces(FactsBase):
 
     def populate_ipv6_interfaces(self, interfaces):
         facts = dict()
-        for key, value in iteritems(interfaces):
+        for key, value in interfaces.items():
             intf = dict()
             intf["ipv6"] = self.parse_ipv6_address(value)
             facts[key] = intf
@@ -761,9 +802,9 @@ class Legacy(FactsBase):
 
                 match = re.search(r"\d\s*\d*\s*(.+)$", line, re.M)
                 if match:
-                    l = match.group(1).split("  ")
+                    line = match.group(1).split("  ")
                     items = list()
-                    for item in l:
+                    for item in line:
                         if item == "":
                             continue
                         items.append(item.strip())
@@ -779,28 +820,28 @@ class Legacy(FactsBase):
     def parse_fan_info(self, data):
         objects = list()
 
-        for l in data.splitlines():
-            if "-----------------" in l or "Status" in l:
+        for line in data.splitlines():
+            if "-----------------" in line or "Status" in line:
                 continue
-            line = l.split()
-            if len(line) > 1:
+            split_line = line.split()
+            if len(split_line) > 1:
                 obj = {}
-                obj["name"] = line[0]
-                obj["model"] = line[1]
-                obj["hw_ver"] = line[-2]
-                obj["status"] = line[-1]
+                obj["name"] = split_line[0]
+                obj["model"] = split_line[1]
+                obj["hw_ver"] = split_line[-2]
+                obj["status"] = split_line[-1]
                 objects.append(obj)
         return objects
 
     def parse_power_supply_info(self, data):
         objects = list()
 
-        for l in data.splitlines():
-            if l == "":
+        for line in data.splitlines():
+            if line == "":
                 break
-            if l[0].isdigit():
+            if line[0].isdigit():
                 obj = {}
-                line = l.split()
+                line = line.split()
                 obj["model"] = line[1]
                 obj["number"] = line[0]
                 obj["status"] = line[-1]
