@@ -171,7 +171,7 @@ options:
             type: dict
             suboptions:
               set:
-                description: Activiate graceful-shutdown.
+                description: Activate graceful-shutdown.
                 type: bool
               route_map:
                 description: Apply route-map to modify attributes for outbound.
@@ -203,7 +203,7 @@ options:
           neighbor_address:
             description: IP address/Prefix of the neighbor or interface.
             type: str
-            required: True
+            required: true
           bfd:
             description: Bidirectional Fast Detection for the neighbor.
             type: dict
@@ -252,7 +252,7 @@ options:
                 description: Suppress 4-byte AS Capability.
                 type: bool
           description:
-            description: Neighbor specific descripion.
+            description: Neighbor specific description.
             type: str
           disable_connected_check:
             description: Disable check for directly connected peer.
@@ -294,8 +294,31 @@ options:
                 description: Peer-session template to inherit.
                 type: str
           local_as:
-            description: Specify the local-as number for the eBGP neighbor.
+            description:
+            - Specify the local-as number for the eBGP neighbor.
+            - B(Deprecated), Use local_as_config instead, the facts would always render local_as information as a part of local_as_config as_number
+            - This option has been deprecated and will be removed in a release after 2027-01-01.
             type: str
+          local_as_config:
+            description: Local Autonomous System Number options.
+            type: dict
+            suboptions:
+              as_number:
+                description:
+                - Set Specify the local-as number for the eBGP neighbor.
+                type: str
+              no_prepend:
+                description:
+                - Do not prepend the local-as number to updates from the eBGP neighbor.
+                type: bool
+              replace_as:
+                description:
+                - Prepend only the local-as number to updates to eBGP neighbor.
+                type: bool
+              dual_as:
+                description:
+                - Connect using either the local-as number or the real as.
+                type: bool
           log_neighbor_changes:
             description: Log message for neighbor up/down event.
             type: dict
@@ -309,7 +332,7 @@ options:
                 - Disable logging of neighbor up/down event.
                 type: bool
           low_memory:
-            description: Behaviour in low memory situations.
+            description: Behavior in low memory situations.
             type: dict
             suboptions:
               exempt:
@@ -543,16 +566,16 @@ EXAMPLES = """
       router_id: 192.168.1.1
       bestpath:
         as_path:
-          multipath_relax: True
-        compare_neighborid: True
-        cost_community_ignore: True
+          multipath_relax: true
+        compare_neighborid: true
+        cost_community_ignore: true
       confederation:
         identifier: 42
         peers:
           - 65020
           - 65030
           - 65040
-      log_neighbor_changes: True
+      log_neighbor_changes: true
       maxas_limit: 20
       neighbors:
         - neighbor_address: 192.168.1.100
@@ -562,19 +585,19 @@ EXAMPLES = """
           remote_as: 65563
           description: NBR-1
           low_memory:
-            exempt: True
+            exempt: true
         - neighbor_address: 192.168.1.101
           remote_as: 65563
           password:
             encryption: 7
             key: 12090404011C03162E
       neighbor_down:
-        fib_accelerate: True
+        fib_accelerate: true
       vrfs:
         - vrf: site-1
           allocate_index: 5000
           local_as: 200
-          log_neighbor_changes: True
+          log_neighbor_changes: true
           neighbors:
             - neighbor_address: 198.51.100.1
               description: site-1-nbr-1
@@ -587,7 +610,7 @@ EXAMPLES = """
               description: site-1-nbr-2
         - vrf: site-2
           local_as: 300
-          log_neighbor_changes: True
+          log_neighbor_changes: true
           neighbors:
             - neighbor_address: 203.0.113.2
               description: site-2-nbr-1
@@ -596,7 +619,7 @@ EXAMPLES = """
                 key: AF92F4C16A0A0EC5BDF56CF58BC030F6
               remote_as: 65568
           neighbor_down:
-            fib_accelerate: True
+            fib_accelerate: true
 
 # Task output:
 # ------------
@@ -795,8 +818,8 @@ EXAMPLES = """
       as_number: 65563
       router_id: 192.168.1.1
       bestpath:
-        compare_neighborid: True
-        cost_community_ignore: True
+        compare_neighborid: true
+        cost_community_ignore: true
       confederation:
         identifier: 42
         peers:
@@ -812,20 +835,20 @@ EXAMPLES = """
           remote_as: 65563
           description: NBR-1
           low_memory:
-            exempt: True
+            exempt: true
       neighbor_down:
-        fib_accelerate: True
+        fib_accelerate: true
       vrfs:
         - vrf: site-2
           local_as: 300
-          log_neighbor_changes: True
+          log_neighbor_changes: true
           neighbors:
             - neighbor_address: 203.0.113.2
               password:
                 encryption: 7
                 key: 12090404011C03162E
           neighbor_down:
-            fib_accelerate: True
+            fib_accelerate: true
     state: replaced
 
 # Task output:
@@ -1258,16 +1281,16 @@ EXAMPLES = """
       router_id: 192.168.1.1
       bestpath:
         as_path:
-          multipath_relax: True
-        compare_neighborid: True
-        cost_community_ignore: True
+          multipath_relax: true
+        compare_neighborid: true
+        cost_community_ignore: true
       confederation:
         identifier: 42
         peers:
           - 65020
           - 65030
           - 65040
-      log_neighbor_changes: True
+      log_neighbor_changes: true
       maxas_limit: 20
       neighbors:
         - neighbor_address: 192.168.1.100
@@ -1277,19 +1300,19 @@ EXAMPLES = """
           remote_as: 65563
           description: NBR-1
           low_memory:
-            exempt: True
+            exempt: true
         - neighbor_address: 192.168.1.101
           remote_as: 65563
           password:
             encryption: 7
             key: 12090404011C03162E
       neighbor_down:
-        fib_accelerate: True
+        fib_accelerate: true
       vrfs:
         - vrf: site-1
           allocate_index: 5000
           local_as: 200
-          log_neighbor_changes: True
+          log_neighbor_changes: true
           neighbors:
             - neighbor_address: 198.51.100.1
               description: site-1-nbr-1
@@ -1302,7 +1325,7 @@ EXAMPLES = """
               description: site-1-nbr-2
         - vrf: site-2
           local_as: 300
-          log_neighbor_changes: True
+          log_neighbor_changes: true
           neighbors:
             - neighbor_address: 203.0.113.2
               description: site-1-nbr-1
@@ -1311,7 +1334,7 @@ EXAMPLES = """
                 key: AF92F4C16A0A0EC5BDF56CF58BC030F6
               remote_as: 65568
           neighbor_down:
-            fib_accelerate: True
+            fib_accelerate: true
 
 # Task output:
 # ------------
@@ -1561,7 +1584,7 @@ EXAMPLES = """
       as_number: 65536
       router_id: 198.51.100.2
       maxas_limit: 20
-      log_neighbor_changes: True
+      log_neighbor_changes: true
       neighbors:
         - neighbor_address: 192.0.2.1
           remote_as: 65537
@@ -1605,7 +1628,7 @@ EXAMPLES = """
       as_number: 65536
       router_id: 198.51.100.2
       maxas_limit: 20
-      log_neighbor_changes: True
+      log_neighbor_changes: true
       neighbors:
         - neighbor_address: 192.0.2.1
           remote_as: 65537
@@ -1615,7 +1638,7 @@ EXAMPLES = """
       vrfs:
         - vrf: site-2
           neighbor_down:
-            fib_accelerate: True
+            fib_accelerate: true
     state: replaced
 
 # Task output:
