@@ -19,15 +19,6 @@ from ansible_collections.amazon.aws.plugins.module_utils.botocore import HAS_BOT
 from ansible_collections.amazon.aws.plugins.module_utils.ec2 import boto3_conn
 from ansible_collections.amazon.aws.plugins.module_utils.ec2 import get_aws_connection_info
 
-# Magic...  Incorrectly identified by pylint as unused
-# isort: off
-# pylint: disable=unused-import
-from ansible_collections.amazon.aws.tests.unit.utils.amazon_placebo_fixtures import maybe_sleep
-from ansible_collections.amazon.aws.tests.unit.utils.amazon_placebo_fixtures import placeboify
-
-# pylint: enable=unused-import
-# isort: on
-
 from ansible_collections.community.aws.plugins.modules import directconnect_link_aggregation_group as lag_module
 
 if not HAS_BOTO3:
@@ -36,8 +27,8 @@ if not HAS_BOTO3:
     )
 
 
-@pytest.fixture(scope="module")
-def dependencies():
+@pytest.fixture(scope="module", name="dependencies")
+def fixture_dependencies():
     # each LAG dict will contain the keys: module, connections, virtual_interfaces
     Dependencies = collections.namedtuple("Dependencies", ["lag_1", "lag_2"])
     lag_1 = dict()
