@@ -14,15 +14,6 @@ import pytest
 
 from ansible_collections.amazon.aws.plugins.module_utils.botocore import HAS_BOTO3
 
-# Magic...  Incorrectly identified by pylint as unused
-# isort: off
-# pylint: disable=unused-import
-from ansible_collections.amazon.aws.tests.unit.utils.amazon_placebo_fixtures import maybe_sleep
-from ansible_collections.amazon.aws.tests.unit.utils.amazon_placebo_fixtures import placeboify
-
-# pylint: enable=unused-import
-# isort: on
-
 from ansible_collections.community.aws.plugins.modules import directconnect_virtual_interface
 
 if not HAS_BOTO3:
