@@ -2,8 +2,7 @@
 # GNU General Public License v3.0+ (see LICENSES/GPL-3.0-or-later.txt or https://www.gnu.org/licenses/gpl-3.0.txt)
 # SPDX-License-Identifier: GPL-3.0-or-later
 
-from __future__ import absolute_import, division, print_function
-__metaclass__ = type
+from __future__ import annotations
 
 
 def get_major_minor_version(version):
@@ -31,7 +30,7 @@ def version_lookup(data, distribution, os_family, distribution_version, distribu
     return python_version in data
 
 
-class FilterModule(object):
+class FilterModule:
     """ IP address and network manipulation filters """
 
     def filters(self):
