@@ -6,6 +6,8 @@
 # SPDX-License-Identifier: GPL-3.0-or-later
 
 from __future__ import absolute_import, division, print_function
+
+
 __metaclass__ = type
 
 
@@ -46,6 +48,9 @@ options:
       values:
         description:
           - The TXT values to look for.
+          - The alias O(records[].entries) has been added in community.dns 3.4.0.
+        aliases:
+          - entries
         type: list
         elements: str
         required: true
@@ -119,13 +124,13 @@ EXAMPLES = r"""
 - name: Wait for a TXT entry to appear
   community.dns.wait_for_txt:
     records:
-    # We want that www.example.com has a single TXT record with value 'Hello world!'.
-    # There should not be any other TXT record for www.example.com.
+      # We want that www.example.com has a single TXT record with value 'Hello world!'.
+      # There should not be any other TXT record for www.example.com.
       - name: www.example.com
         values: "Hello world!"
         mode: equals
-    # We want that example.com has a specific SPF record set.
-    # We do not care about other TXT records.
+      # We want that example.com has a specific SPF record set.
+      # We do not care about other TXT records.
       - name: www.example.com
         values: "v=spf1 a mx -all"
         mode: subset
@@ -158,6 +163,18 @@ records:
         - Once the check completed for all TXT records retrieved, the TXT records for this DNS name are no longer checked.
         - If these are multiple TXT entries for a nameserver, the order is as it was received from that nameserver. This might
           not be the same order provided in the check.
+        - B(The field has been renamed) to RV(records[].entries) in community.dns 3.4.0.
+          While the old name will be around for a longer time, prefer using the new one.
+      returned: lookup was done at least once
+      type: dict
+      elements: list
+    entries:
+      description:
+        - For every authoritative nameserver for the DNS name, lists the TXT records retrieved during the last lookup made.
+        - Once the check completed for all TXT records retrieved, the TXT records for this DNS name are no longer checked.
+        - If these are multiple TXT entries for a nameserver, the order is as it was received from that nameserver. This might
+          not be the same order provided in the check.
+        - This field has been called RV(records[].values) before.
       returned: lookup was done at least once
       type: dict
       elements: list
@@ -167,6 +184,7 @@ records:
           - TXT value 2
         ns2.example.com:
           - TXT value 2
+      version_added: 3.4.0
     check_count:
       description:
         - How often the TXT records for this DNS name were checked.
@@ -176,7 +194,7 @@ records:
   sample:
     - name: example.com
       done: true
-      values: [a, b, c]
+      entries: [a, b, c]
       check_count: 1
     - name: foo.example.org
       done: false
@@ -191,20 +209,21 @@ completed:
 
 import time
 
+
 try:
     from time import monotonic
 except ImportError:
-    from time import clock as monotonic
+    from time import clock as monotonic  # type: ignore
 
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.common.text.converters import to_text
-
 from ansible_collections.community.dns.plugins.module_utils.resolver import (
     ResolveDirectlyFromNameServers,
     assert_requirements_present,
     guarded_run,
 )
 
+
 try:
     import dns.rdatatype
 except ImportError:
@@ -219,8 +238,8 @@ def lookup(resolver, name):
         if txt is not None:
             for data in txt:
                 line = []
-                for str in data.strings:
-                    line.append(to_text(str))
+                for txtstring in data.strings:
+                    line.append(to_text(txtstring))
                 res.append(u''.join(line))
         result[key] = res
         txts[key] = []
@@ -243,7 +262,7 @@ def validate_check(record_values, expected_values, comparison_mode):
     if comparison_mode == 'equals_ordered':
         return record_values == expected_values
 
-    raise Exception('Internal error!')  # pragma: no cover
+    raise AssertionError('Internal error!')  # pragma: no cover
 
 
 class Waiter(object):
@@ -262,22 +281,22 @@ class Waiter(object):
         self.max_sleep = self.module.params['max_sleep']
 
         self.results = [None] * len(self.records)
-        for index in range(len(self.records)):
+        for index, record in enumerate(self.records):
             self.results[index] = {
-                'name': self.records[index]['name'],
+                'name': record['name'],
                 'done': False,
                 'check_count': 0,
             }
         self.finished_checks = 0
 
     def _run(self):
-        self.start_time = monotonic()
+        start_time = monotonic()
 
         step = 0
         while True:
             has_timeout = False
             if self.timeout is not None:
-                expired = monotonic() - self.start_time
+                expired = monotonic() - start_time
                 has_timeout = expired > self.timeout
 
             done = True
@@ -286,6 +305,7 @@ class Waiter(object):
                     continue
                 txts = lookup(self.resolver, record['name'])
                 self.results[index]['values'] = txts
+                self.results[index]['entries'] = txts
                 self.results[index]['check_count'] += 1
                 if txts and all(validate_check(txt, record['values'], record['mode']) for txt in txts.values()):
                     self.results[index]['done'] = True
@@ -309,17 +329,17 @@ class Waiter(object):
             wait = min(2 + step * 0.5, self.max_sleep)
             if self.timeout is not None:
                 # Make sure we do not exceed the timeout by much by waiting
-                expired = monotonic() - self.start_time
+                expired = monotonic() - start_time
                 wait = max(min(wait, self.timeout - expired + 0.1), 0.1)
 
             time.sleep(wait)
             step += 1
 
     def _generate_additional_results(self):
-        return dict(
-            records=self.results,
-            completed=self.finished_checks,
-        )
+        return {
+            'records': self.results,
+            'completed': self.finished_checks,
+        }
 
     def run(self):
         guarded_run(self._run, self.module, generate_additional_results=self._generate_additional_results)
@@ -327,20 +347,20 @@ class Waiter(object):
 
 def main():
     module = AnsibleModule(
-        argument_spec=dict(
-            records=dict(required=True, type='list', elements='dict', options=dict(
-                name=dict(required=True, type='str'),
-                values=dict(required=True, type='list', elements='str'),
-                mode=dict(type='str', default='subset', choices=['subset', 'superset', 'superset_not_empty', 'equals', 'equals_ordered']),
-            )),
-            query_retry=dict(type='int', default=3),
-            query_timeout=dict(type='float', default=10),
-            timeout=dict(type='float'),
-            max_sleep=dict(type='float', default=10),
-            always_ask_default_resolver=dict(type='bool', default=True),
-            servfail_retries=dict(type='int', default=0),
-            server=dict(type='list', elements='str'),
-        ),
+        argument_spec={
+            'records': {'required': True, 'type': 'list', 'elements': 'dict', 'options': {
+                'name': {'required': True, 'type': 'str'},
+                'values': {'required': True, 'type': 'list', 'elements': 'str', 'aliases': ['entries']},
+                'mode': {'type': 'str', 'default': 'subset', 'choices': ['subset', 'superset', 'superset_not_empty', 'equals', 'equals_ordered']},
+            }},
+            'query_retry': {'type': 'int', 'default': 3},
+            'query_timeout': {'type': 'float', 'default': 10},
+            'timeout': {'type': 'float'},
+            'max_sleep': {'type': 'float', 'default': 10},
+            'always_ask_default_resolver': {'type': 'bool', 'default': True},
+            'servfail_retries': {'type': 'int', 'default': 0},
+            'server': {'type': 'list', 'elements': 'str'},
+        },
         supports_check_mode=True,
     )
     assert_requirements_present(module)
