@@ -3,18 +3,22 @@
 # GNU General Public License v3.0+ (see LICENSES/GPL-3.0-or-later.txt or https://www.gnu.org/licenses/gpl-3.0.txt)
 # SPDX-License-Identifier: GPL-3.0-or-later
 
-from __future__ import (absolute_import, division, print_function)
+from __future__ import absolute_import, division, print_function
+
+
 __metaclass__ = type
 
+from ansible_collections.community.internal_test_tools.tests.unit.plugins.modules.utils import (
+    extract_warnings_texts,
+)
 from ansible_collections.community.internal_test_tools.tests.unit.utils.fetch_url_module_framework import (
     BaseTestModule,
     FetchUrlCall,
 )
 
-from ansible_collections.community.dns.plugins.modules import hetzner_dns_record_set
-
 # These imports are needed so patching below works
 import ansible_collections.community.dns.plugins.module_utils.http  # noqa: F401, pylint: disable=unused-import
+from ansible_collections.community.dns.plugins.modules import hetzner_dns_record_set
 
 from .hetzner import (
     HETZNER_JSON_DEFAULT_ENTRIES,
@@ -425,7 +429,7 @@ class TestHetznerDNSRecordJSON(BaseTestModule):
 
         assert result['changed'] is False
         assert result['zone_id'] == '42'
-        assert 'warnings' not in result
+        assert extract_warnings_texts(result) == []  # pylint: disable=use-implicit-booleaness-not-comparison
 
     def test_idempotency_absent_record_warn(self, mocker):
         result = self.run_module_success(mocker, hetzner_dns_record_set, {
@@ -462,7 +466,7 @@ class TestHetznerDNSRecordJSON(BaseTestModule):
 
         assert result['changed'] is False
         assert result['zone_id'] == '42'
-        assert list(result['warnings']) == ["Record already exists with different value. Set on_existing=replace to remove it"]
+        assert extract_warnings_texts(result) == ["Record already exists with different value. Set on_existing=replace to remove it"]
 
     def test_idempotency_absent_record_fail(self, mocker):
         result = self.run_module_failed(mocker, hetzner_dns_record_set, {
@@ -841,6 +845,7 @@ class TestHetznerDNSRecordJSON(BaseTestModule):
                     'ttl': 3600,
                     'zone_id': '42',
                 },
+                'error': {},
             }),
         ])
 
@@ -1043,7 +1048,7 @@ class TestHetznerDNSRecordJSON(BaseTestModule):
             'value': ['helium.ns.hetzner.de.', 'hydrogen.ns.hetzner.com.', 'oxygen.ns.hetzner.com.'],
         }
         assert result['diff']['after'] == result['diff']['before']
-        assert list(result['warnings']) == ["Record already exists with different value. Set on_existing=replace to replace it"]
+        assert extract_warnings_texts(result) == ["Record already exists with different value. Set on_existing=replace to replace it"]
 
     def test_change_modify_list_keep(self, mocker):
         result = self.run_module_success(mocker, hetzner_dns_record_set, {
@@ -1080,7 +1085,7 @@ class TestHetznerDNSRecordJSON(BaseTestModule):
             .result_json(HETZNER_JSON_ZONE_RECORDS_GET_RESULT),
         ])
 
-        assert 'warnings' not in result
+        assert extract_warnings_texts(result) == []  # pylint: disable=use-implicit-booleaness-not-comparison
         assert result['changed'] is False
         assert result['zone_id'] == '42'
         assert 'diff' in result
