@@ -6,29 +6,32 @@
 # Make coding more python3-ish
 from __future__ import absolute_import, division, print_function
 
+
 __metaclass__ = type
 
 
 import pytest
-
-from ansible_collections.community.internal_test_tools.tests.unit.compat.mock import MagicMock, patch
-
+from ansible_collections.community.internal_test_tools.tests.unit.compat.mock import (
+    MagicMock,
+    patch,
+)
 from ansible_collections.community.internal_test_tools.tests.unit.plugins.modules.utils import (
-    set_module_args,
-    ModuleTestCase,
     AnsibleExitJson,
     AnsibleFailJson,
+    ModuleTestCase,
+    set_module_args,
 )
 
 from ansible_collections.community.dns.plugins.modules import wait_for_txt
 
 from ..module_utils.resolver_helper import (
-    mock_resolver,
-    mock_query_udp,
     create_mock_answer,
     create_mock_response,
+    mock_query_udp,
+    mock_resolver,
 )
 
+
 # We need dnspython
 dns = pytest.importorskip('dns')
 
@@ -192,7 +195,7 @@ class TestWaitForTXT(ModuleTestCase):
                 with patch('dns.query.udp', mock_query_udp(udp_sequence)):
                     with patch('time.sleep', mock_sleep):
                         with pytest.raises(AnsibleExitJson) as exc:
-                            set_module_args({
+                            with set_module_args({
                                 'records': [
                                     {
                                         'name': 'www.example.com',
@@ -201,8 +204,8 @@ class TestWaitForTXT(ModuleTestCase):
                                         ]
                                     },
                                 ],
-                            })
-                            wait_for_txt.main()
+                            }):
+                                wait_for_txt.main()
 
         print(exc.value.args[0])
         assert exc.value.args[0]['changed'] is False
@@ -214,6 +217,10 @@ class TestWaitForTXT(ModuleTestCase):
             'ns.example.com': ['asdf'],
             'ns.example.org': ['asdf'],
         }
+        assert exc.value.args[0]['records'][0]['entries'] == {
+            'ns.example.com': ['asdf'],
+            'ns.example.org': ['asdf'],
+        }
         assert exc.value.args[0]['records'][0]['check_count'] == 1
 
     def test_double(self):
@@ -341,7 +348,7 @@ class TestWaitForTXT(ModuleTestCase):
                 with patch('dns.query.udp', mock_query_udp(udp_sequence)):
                     with patch('time.sleep', mock_sleep):
                         with pytest.raises(AnsibleExitJson) as exc:
-                            set_module_args({
+                            with set_module_args({
                                 'records': [
                                     {
                                         'name': 'www.example.com',
@@ -352,7 +359,7 @@ class TestWaitForTXT(ModuleTestCase):
                                     },
                                     {
                                         'name': 'mail.example.com',
-                                        'values': [
+                                        'entries': [
                                             'foo bar',
                                             'any bar',
                                         ],
@@ -360,8 +367,8 @@ class TestWaitForTXT(ModuleTestCase):
                                     },
                                 ],
                                 'timeout': 10,
-                            })
-                            wait_for_txt.main()
+                            }):
+                                wait_for_txt.main()
 
         print(exc.value.args[0])
         assert exc.value.args[0]['changed'] is False
@@ -372,12 +379,18 @@ class TestWaitForTXT(ModuleTestCase):
         assert exc.value.args[0]['records'][0]['values'] == {
             'ns.example.com': ['asdf'],
         }
+        assert exc.value.args[0]['records'][0]['entries'] == {
+            'ns.example.com': ['asdf'],
+        }
         assert exc.value.args[0]['records'][0]['check_count'] == 3
         assert exc.value.args[0]['records'][1]['name'] == 'mail.example.com'
         assert exc.value.args[0]['records'][1]['done'] is True
         assert exc.value.args[0]['records'][1]['values'] == {
             'ns.example.com': ['any bar'],
         }
+        assert exc.value.args[0]['records'][1]['entries'] == {
+            'ns.example.com': ['any bar'],
+        }
         assert exc.value.args[0]['records'][1]['check_count'] == 1
 
     def test_subset(self):
@@ -472,7 +485,7 @@ class TestWaitForTXT(ModuleTestCase):
                 with patch('dns.query.udp', mock_query_udp(udp_sequence)):
                     with patch('time.sleep', mock_sleep):
                         with pytest.raises(AnsibleExitJson) as exc:
-                            set_module_args({
+                            with set_module_args({
                                 'records': [
                                     {
                                         'name': 'example.com',
@@ -484,8 +497,8 @@ class TestWaitForTXT(ModuleTestCase):
                                         'mode': 'subset',
                                     },
                                 ],
-                            })
-                            wait_for_txt.main()
+                            }):
+                                wait_for_txt.main()
 
         print(exc.value.args[0])
         assert exc.value.args[0]['changed'] is False
@@ -496,6 +509,9 @@ class TestWaitForTXT(ModuleTestCase):
         assert exc.value.args[0]['records'][0]['values'] == {
             'ns.example.com': ['foo bar', 'another one', 'asdf'],
         }
+        assert exc.value.args[0]['records'][0]['entries'] == {
+            'ns.example.com': ['foo bar', 'another one', 'asdf'],
+        }
         assert exc.value.args[0]['records'][0]['check_count'] == 3
 
     def test_superset(self):
@@ -620,11 +636,11 @@ class TestWaitForTXT(ModuleTestCase):
                 with patch('dns.query.udp', mock_query_udp(udp_sequence)):
                     with patch('time.sleep', mock_sleep):
                         with pytest.raises(AnsibleExitJson) as exc:
-                            set_module_args({
+                            with set_module_args({
                                 'records': [
                                     {
                                         'name': 'www.example.com',
-                                        'values': [
+                                        'entries': [
                                             'asdf',
                                             'bee',
                                         ],
@@ -639,8 +655,8 @@ class TestWaitForTXT(ModuleTestCase):
                                         'mode': 'superset',
                                     },
                                 ],
-                            })
-                            wait_for_txt.main()
+                            }):
+                                wait_for_txt.main()
 
         print(exc.value.args[0])
         assert exc.value.args[0]['changed'] is False
@@ -651,12 +667,18 @@ class TestWaitForTXT(ModuleTestCase):
         assert exc.value.args[0]['records'][0]['values'] == {
             'ns.example.com': ['asdf', 'bee'],
         }
+        assert exc.value.args[0]['records'][0]['entries'] == {
+            'ns.example.com': ['asdf', 'bee'],
+        }
         assert exc.value.args[0]['records'][0]['check_count'] == 3
         assert exc.value.args[0]['records'][1]['name'] == 'mail.example.com'
         assert exc.value.args[0]['records'][1]['done'] is True
         assert exc.value.args[0]['records'][1]['values'] == {
             'ns.example.com': [],
         }
+        assert exc.value.args[0]['records'][1]['entries'] == {
+            'ns.example.com': [],
+        }
         assert exc.value.args[0]['records'][1]['check_count'] == 1
 
     def test_superset_not_empty(self):
@@ -756,19 +778,19 @@ class TestWaitForTXT(ModuleTestCase):
                 with patch('dns.query.udp', mock_query_udp(udp_sequence)):
                     with patch('time.sleep', mock_sleep):
                         with pytest.raises(AnsibleExitJson) as exc:
-                            set_module_args({
+                            with set_module_args({
                                 'records': [
                                     {
                                         'name': 'example.com',
-                                        'values': [
+                                        'entries': [
                                             'bumble',
                                             'bee',
                                         ],
                                         'mode': 'superset_not_empty',
                                     },
                                 ],
-                            })
-                            wait_for_txt.main()
+                            }):
+                                wait_for_txt.main()
 
         print(exc.value.args[0])
         assert exc.value.args[0]['changed'] is False
@@ -779,6 +801,9 @@ class TestWaitForTXT(ModuleTestCase):
         assert exc.value.args[0]['records'][0]['values'] == {
             'ns.example.com': ['bumble', 'bee'],
         }
+        assert exc.value.args[0]['records'][0]['entries'] == {
+            'ns.example.com': ['bumble', 'bee'],
+        }
         assert exc.value.args[0]['records'][0]['check_count'] == 4
 
     def test_equals(self):
@@ -878,7 +903,7 @@ class TestWaitForTXT(ModuleTestCase):
                 with patch('dns.query.udp', mock_query_udp(udp_sequence)):
                     with patch('time.sleep', mock_sleep):
                         with pytest.raises(AnsibleExitJson) as exc:
-                            set_module_args({
+                            with set_module_args({
                                 'records': [
                                     {
                                         'name': 'example.com',
@@ -890,8 +915,8 @@ class TestWaitForTXT(ModuleTestCase):
                                         'mode': 'equals',
                                     },
                                 ],
-                            })
-                            wait_for_txt.main()
+                            }):
+                                wait_for_txt.main()
 
         print(exc.value.args[0])
         assert exc.value.args[0]['changed'] is False
@@ -902,6 +927,9 @@ class TestWaitForTXT(ModuleTestCase):
         assert exc.value.args[0]['records'][0]['values'] == {
             'ns.example.com': ['bumble bee', 'wizard', 'foo'],
         }
+        assert exc.value.args[0]['records'][0]['entries'] == {
+            'ns.example.com': ['bumble bee', 'wizard', 'foo'],
+        }
         assert exc.value.args[0]['records'][0]['check_count'] == 4
 
     def test_equals_ordered(self):
@@ -1002,7 +1030,7 @@ class TestWaitForTXT(ModuleTestCase):
                 with patch('dns.query.udp', mock_query_udp(udp_sequence)):
                     with patch('time.sleep', mock_sleep):
                         with pytest.raises(AnsibleExitJson) as exc:
-                            set_module_args({
+                            with set_module_args({
                                 'records': [
                                     {
                                         'name': 'example.com',
@@ -1014,8 +1042,8 @@ class TestWaitForTXT(ModuleTestCase):
                                         'mode': 'equals_ordered',
                                     },
                                 ],
-                            })
-                            wait_for_txt.main()
+                            }):
+                                wait_for_txt.main()
 
         print(exc.value.args[0])
         assert exc.value.args[0]['changed'] is False
@@ -1026,6 +1054,9 @@ class TestWaitForTXT(ModuleTestCase):
         assert exc.value.args[0]['records'][0]['values'] == {
             'ns.example.com': ['foo', 'bumble bee', 'wizard'],
         }
+        assert exc.value.args[0]['records'][0]['entries'] == {
+            'ns.example.com': ['foo', 'bumble bee', 'wizard'],
+        }
         assert exc.value.args[0]['records'][0]['check_count'] == 4
 
     def test_timeout(self):
@@ -1155,7 +1186,7 @@ class TestWaitForTXT(ModuleTestCase):
                         with patch('ansible_collections.community.dns.plugins.modules.wait_for_txt.monotonic',
                                    mock_monotonic([0, 0.01, 1.2, 6.013, 7.41, 12.021])):
                             with pytest.raises(AnsibleFailJson) as exc:
-                                set_module_args({
+                                with set_module_args({
                                     'records': [
                                         {
                                             'name': 'www.example.com',
@@ -1174,8 +1205,8 @@ class TestWaitForTXT(ModuleTestCase):
                                         },
                                     ],
                                     'timeout': 12,
-                                })
-                                wait_for_txt.main()
+                                }):
+                                    wait_for_txt.main()
 
         print(exc.value.args[0])
         assert exc.value.args[0]['msg'] == 'Timeout (1 out of 2 check(s) passed).'
@@ -1186,12 +1217,18 @@ class TestWaitForTXT(ModuleTestCase):
         assert exc.value.args[0]['records'][0]['values'] == {
             'ns.example.com': ['asdfasdf'],
         }
+        assert exc.value.args[0]['records'][0]['entries'] == {
+            'ns.example.com': ['asdfasdf'],
+        }
         assert exc.value.args[0]['records'][0]['check_count'] == 3
         assert exc.value.args[0]['records'][1]['name'] == 'mail.example.com'
         assert exc.value.args[0]['records'][1]['done'] is True
         assert exc.value.args[0]['records'][1]['values'] == {
             'ns.example.com': ['any bar'],
         }
+        assert exc.value.args[0]['records'][1]['entries'] == {
+            'ns.example.com': ['any bar'],
+        }
         assert exc.value.args[0]['records'][1]['check_count'] == 1
 
     def test_nxdomain(self):
@@ -1273,7 +1310,7 @@ class TestWaitForTXT(ModuleTestCase):
                         with patch('ansible_collections.community.dns.plugins.modules.wait_for_txt.monotonic',
                                    mock_monotonic([0, 0.01, 1.2, 6.013])):
                             with pytest.raises(AnsibleFailJson) as exc:
-                                set_module_args({
+                                with set_module_args({
                                     'records': [
                                         {
                                             'name': 'www.example.com',
@@ -1283,8 +1320,8 @@ class TestWaitForTXT(ModuleTestCase):
                                         },
                                     ],
                                     'timeout': 2,
-                                })
-                                wait_for_txt.main()
+                                }):
+                                    wait_for_txt.main()
 
         print(exc.value.args[0])
         assert exc.value.args[0]['failed'] is True
@@ -1294,7 +1331,9 @@ class TestWaitForTXT(ModuleTestCase):
         assert exc.value.args[0]['records'][0]['name'] == 'www.example.com'
         assert exc.value.args[0]['records'][0]['done'] is False
         assert len(exc.value.args[0]['records'][0]['values']) == 1
+        assert len(exc.value.args[0]['records'][0]['entries']) == 1
         assert exc.value.args[0]['records'][0]['values']['ns.example.com'] == []
+        assert exc.value.args[0]['records'][0]['entries']['ns.example.com'] == []
         assert exc.value.args[0]['records'][0]['check_count'] == 2
 
     def test_servfail(self):
@@ -1315,7 +1354,7 @@ class TestWaitForTXT(ModuleTestCase):
                 with patch('dns.query.udp', mock_query_udp(udp_sequence)):
                     with patch('time.sleep', mock_sleep):
                         with pytest.raises(AnsibleFailJson) as exc:
-                            set_module_args({
+                            with set_module_args({
                                 'records': [
                                     {
                                         'name': 'www.example.com',
@@ -1324,8 +1363,8 @@ class TestWaitForTXT(ModuleTestCase):
                                         ],
                                     },
                                 ],
-                            })
-                            wait_for_txt.main()
+                            }):
+                                wait_for_txt.main()
 
         print(exc.value.args[0])
         assert exc.value.args[0]['msg'] == 'Unexpected resolving error: Error SERVFAIL while querying 1.1.1.1 with query get NS for "com."'
@@ -1334,6 +1373,7 @@ class TestWaitForTXT(ModuleTestCase):
         assert exc.value.args[0]['records'][0]['name'] == 'www.example.com'
         assert exc.value.args[0]['records'][0]['done'] is False
         assert 'values' not in exc.value.args[0]['records'][0]
+        assert 'entries' not in exc.value.args[0]['records'][0]
         assert exc.value.args[0]['records'][0]['check_count'] == 0
 
     def test_cname_loop(self):
@@ -1455,7 +1495,7 @@ class TestWaitForTXT(ModuleTestCase):
                 with patch('dns.query.udp', mock_query_udp(udp_sequence)):
                     with patch('time.sleep', mock_sleep):
                         with pytest.raises(AnsibleFailJson) as exc:
-                            set_module_args({
+                            with set_module_args({
                                 'records': [
                                     {
                                         'name': 'www.example.com',
@@ -1464,8 +1504,8 @@ class TestWaitForTXT(ModuleTestCase):
                                         ],
                                     },
                                 ],
-                            })
-                            wait_for_txt.main()
+                            }):
+                                wait_for_txt.main()
 
         print(exc.value.args[0])
         assert exc.value.args[0]['msg'] == 'Unexpected resolving error: Found CNAME loop starting at www.example.com'
@@ -1474,4 +1514,5 @@ class TestWaitForTXT(ModuleTestCase):
         assert exc.value.args[0]['records'][0]['name'] == 'www.example.com'
         assert exc.value.args[0]['records'][0]['done'] is False
         assert 'values' not in exc.value.args[0]['records'][0]
+        assert 'entries' not in exc.value.args[0]['records'][0]
         assert exc.value.args[0]['records'][0]['check_count'] == 0
