@@ -4,8 +4,7 @@
 # GNU General Public License v3.0+ (see LICENSES/GPL-3.0-or-later.txt or https://www.gnu.org/licenses/gpl-3.0.txt)
 # SPDX-License-Identifier: GPL-3.0-or-later
 
-from __future__ import absolute_import, division, print_function
-__metaclass__ = type
+from __future__ import annotations
 
 
 DOCUMENTATION = r"""
@@ -19,9 +18,9 @@ description:
   - Creates an archive (tarball) from one or more Docker images.
   - This can be copied to another machine and loaded with M(community.docker.docker_image_load).
 extends_documentation_fragment:
-  - community.docker.docker.api_documentation
-  - community.docker.attributes
-  - community.docker.attributes.actiongroup_docker
+  - community.docker._docker.api_documentation
+  - community.docker._attributes
+  - community.docker._attributes.actiongroup_docker
 
 attributes:
   check_mode:
@@ -29,7 +28,13 @@ attributes:
   diff_mode:
     support: none
   idempotent:
-    support: full
+    support: partial
+    details:
+      - Whether the module is idempotent depends on the storage API used for images,
+        which determines how the image ID is computed. The idempotency check needs
+        that the image ID equals the ID stored in archive's C(manifest.json).
+        This seemed to have worked fine with the default storage backend up to Docker 28,
+        but seems to have changed in Docker 29.
 
 options:
   names:
@@ -71,6 +76,7 @@ seealso:
 """
 
 EXAMPLES = r"""
+---
 - name: Export an image
   community.docker.docker_image_export:
     name: pacur/centos-7
@@ -94,160 +100,166 @@ images:
 """
 
 import traceback
+import typing as t
 
-from ansible.module_utils.common.text.converters import to_native
-
-from ansible_collections.community.docker.plugins.module_utils.common_api import (
+from ansible_collections.community.docker.plugins.module_utils._api.constants import (
+    DEFAULT_DATA_CHUNK_SIZE,
+)
+from ansible_collections.community.docker.plugins.module_utils._api.errors import (
+    DockerException,
+)
+from ansible_collections.community.docker.plugins.module_utils._api.utils.utils import (
+    parse_repository_tag,
+)
+from ansible_collections.community.docker.plugins.module_utils._common_api import (
     AnsibleDockerClient,
     RequestException,
 )
-
-from ansible_collections.community.docker.plugins.module_utils.image_archive import (
-    load_archived_image_manifest,
-    api_image_id,
+from ansible_collections.community.docker.plugins.module_utils._image_archive import (
     ImageArchiveInvalidException,
+    api_image_id,
+    load_archived_image_manifest,
 )
-
-from ansible_collections.community.docker.plugins.module_utils.util import (
+from ansible_collections.community.docker.plugins.module_utils._util import (
     DockerBaseClass,
     is_image_name_id,
     is_valid_tag,
 )
-from ansible_collections.community.docker.plugins.module_utils._api.constants import (
-    DEFAULT_DATA_CHUNK_SIZE,
-)
-from ansible_collections.community.docker.plugins.module_utils._api.errors import DockerException
-from ansible_collections.community.docker.plugins.module_utils._api.utils.utils import (
-    parse_repository_tag,
-)
 
 
 class ImageExportManager(DockerBaseClass):
-    def __init__(self, client):
-        super(ImageExportManager, self).__init__()
+    def __init__(self, client: AnsibleDockerClient) -> None:
+        super().__init__()
 
         self.client = client
         parameters = self.client.module.params
         self.check_mode = self.client.check_mode
 
-        self.path = parameters['path']
-        self.force = parameters['force']
-        self.tag = parameters['tag']
+        self.path = parameters["path"]
+        self.force = parameters["force"]
+        self.tag = parameters["tag"]
 
         if not is_valid_tag(self.tag, allow_empty=True):
-            self.fail('"{0}" is not a valid docker tag'.format(self.tag))
+            self.fail(f'"{self.tag}" is not a valid docker tag')
 
         # If name contains a tag, it takes precedence over tag parameter.
         self.names = []
-        for name in parameters['names']:
+        for name in parameters["names"]:
             if is_image_name_id(name):
-                self.names.append({'id': name, 'joined': name})
+                self.names.append({"id": name, "joined": name})
             else:
                 repo, repo_tag = parse_repository_tag(name)
                 if not repo_tag:
                     repo_tag = self.tag
-                self.names.append({'name': repo, 'tag': repo_tag, 'joined': '%s:%s' % (repo, repo_tag)})
+                self.names.append(
+                    {"name": repo, "tag": repo_tag, "joined": f"{repo}:{repo_tag}"}
+                )
 
         if not self.names:
-            self.fail('At least one image name must be specified')
+            self.fail("At least one image name must be specified")
 
-    def fail(self, msg):
+    def fail(self, msg: str) -> t.NoReturn:
         self.client.fail(msg)
 
-    def get_export_reason(self):
+    def get_export_reason(self) -> str | None:
         if self.force:
-            return 'Exporting since force=true'
+            return "Exporting since force=true"
 
         try:
             archived_images = load_archived_image_manifest(self.path)
             if archived_images is None:
-                return 'Overwriting since no image is present in archive'
+                return "Overwriting since no image is present in archive"
         except ImageArchiveInvalidException as exc:
-            self.log('Unable to extract manifest summary from archive: %s' % to_native(exc))
-            return 'Overwriting an unreadable archive file'
+            self.log(f"Unable to extract manifest summary from archive: {exc}")
+            return "Overwriting an unreadable archive file"
 
         left_names = list(self.names)
         for archived_image in archived_images:
             found = False
             for i, name in enumerate(left_names):
-                if name['id'] == api_image_id(archived_image.image_id) and [name['joined']] == archived_image.repo_tags:
+                if (
+                    name["id"] == api_image_id(archived_image.image_id)
+                    and [name["joined"]] == archived_image.repo_tags
+                ):
                     del left_names[i]
                     found = True
                     break
             if not found:
-                return 'Overwriting archive since it contains unexpected image %s named %s' % (
-                    archived_image.image_id, ', '.join(archived_image.repo_tags)
-                )
+                return f"Overwriting archive since it contains unexpected image {archived_image.image_id} named {', '.join(archived_image.repo_tags)}"
         if left_names:
-            return 'Overwriting archive since it is missing image(s) %s' % (', '.join([name['joined'] for name in left_names]))
+            return f"Overwriting archive since it is missing image(s) {', '.join([name['joined'] for name in left_names])}"
 
         return None
 
-    def write_chunks(self, chunks):
+    def write_chunks(self, chunks: t.Generator[bytes]) -> None:
         try:
-            with open(self.path, 'wb') as fd:
+            with open(self.path, "wb") as fd:
                 for chunk in chunks:
                     fd.write(chunk)
-        except Exception as exc:
-            self.fail("Error writing image archive %s - %s" % (self.path, to_native(exc)))
+        except Exception as exc:  # pylint: disable=broad-exception-caught
+            self.fail(f"Error writing image archive {self.path} - {exc}")
 
-    def export_images(self):
-        image_names = [name['joined'] for name in self.names]
-        image_names_str = ', '.join(image_names)
+    def export_images(self) -> None:
+        image_names = [name["joined"] for name in self.names]
+        image_names_str = ", ".join(image_names)
         if len(image_names) == 1:
-            self.log("Getting archive of image %s" % image_names[0])
-            try:
-                chunks = self.client._stream_raw_result(
-                    self.client._get(self.client._url('/images/{0}/get', image_names[0]), stream=True),
-                    DEFAULT_DATA_CHUNK_SIZE,
-                    False,
-                )
-            except Exception as exc:
-                self.fail("Error getting image %s - %s" % (image_names[0], to_native(exc)))
-        else:
-            self.log("Getting archive of images %s" % image_names_str)
+            self.log(f"Getting archive of image {image_names[0]}")
             try:
                 chunks = self.client._stream_raw_result(
                     self.client._get(
-                        self.client._url('/images/get'),
-                        stream=True,
-                        params={'names': image_names},
+                        self.client._url("/images/{0}/get", image_names[0]), stream=True
                     ),
-                    DEFAULT_DATA_CHUNK_SIZE,
-                    False,
+                    chunk_size=DEFAULT_DATA_CHUNK_SIZE,
+                    decode=False,
                 )
-            except Exception as exc:
-                self.fail("Error getting images %s - %s" % (image_names_str, to_native(exc)))
+            except Exception as exc:  # pylint: disable=broad-exception-caught
+                self.fail(f"Error getting image {image_names[0]} - {exc}")
+        else:
+            self.log(f"Getting archive of images {image_names_str}")
+            try:
+                chunks = self.client._stream_raw_result(
+                    self.client._get(
+                        self.client._url("/images/get"),
+                        stream=True,
+                        params={"names": image_names},
+                    ),
+                    chunk_size=DEFAULT_DATA_CHUNK_SIZE,
+                    decode=False,
+                )
+            except Exception as exc:  # pylint: disable=broad-exception-caught
+                self.fail(f"Error getting images {image_names_str} - {exc}")
 
         self.write_chunks(chunks)
 
-    def run(self):
+    def run(self) -> dict[str, t.Any]:
         tag = self.tag
         if not tag:
             tag = "latest"
 
         images = []
         for name in self.names:
-            if 'id' in name:
-                image = self.client.find_image_by_id(name['id'], accept_missing_image=True)
+            if "id" in name:
+                image = self.client.find_image_by_id(
+                    name["id"], accept_missing_image=True
+                )
             else:
-                image = self.client.find_image(name=name['name'], tag=name['tag'])
+                image = self.client.find_image(name=name["name"], tag=name["tag"])
             if not image:
-                self.fail("Image %s not found" % name['joined'])
+                self.fail(f"Image {name['joined']} not found")
             images.append(image)
 
             # Will have a 'sha256:' prefix
-            name['id'] = image['Id']
+            name["id"] = image["Id"]
 
         results = {
-            'changed': False,
-            'images': images,
+            "changed": False,
+            "images": images,
         }
 
         reason = self.get_export_reason()
         if reason is not None:
-            results['msg'] = reason
-            results['changed'] = True
+            results["msg"] = reason
+            results["changed"] = True
 
             if not self.check_mode:
                 self.export_images()
@@ -255,13 +267,18 @@ class ImageExportManager(DockerBaseClass):
         return results
 
 
-def main():
-    argument_spec = dict(
-        path=dict(type='path'),
-        force=dict(type='bool', default=False),
-        names=dict(type='list', elements='str', required=True, aliases=['name']),
-        tag=dict(type='str', default='latest'),
-    )
+def main() -> None:
+    argument_spec = {
+        "path": {"type": "path"},
+        "force": {"type": "bool", "default": False},
+        "names": {
+            "type": "list",
+            "elements": "str",
+            "required": True,
+            "aliases": ["name"],
+        },
+        "tag": {"type": "str", "default": "latest"},
+    }
 
     client = AnsibleDockerClient(
         argument_spec=argument_spec,
@@ -272,12 +289,16 @@ def main():
         results = ImageExportManager(client).run()
         client.module.exit_json(**results)
     except DockerException as e:
-        client.fail('An unexpected Docker error occurred: {0}'.format(to_native(e)), exception=traceback.format_exc())
+        client.fail(
+            f"An unexpected Docker error occurred: {e}",
+            exception=traceback.format_exc(),
+        )
     except RequestException as e:
         client.fail(
-            'An unexpected requests error occurred when trying to talk to the Docker daemon: {0}'.format(to_native(e)),
-            exception=traceback.format_exc())
+            f"An unexpected requests error occurred when trying to talk to the Docker daemon: {e}",
+            exception=traceback.format_exc(),
+        )
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
