@@ -9,17 +9,17 @@ set -euo pipefail
 
 cleanup() {
     echo "Cleanup"
-    ansible-playbook playbooks/swarm_cleanup.yml
+    ansible-playbook playbooks/swarm_cleanup.yml "$@"
     echo "Done"
 }
 
 trap cleanup INT TERM EXIT
 
 echo "Setup"
-ANSIBLE_ROLES_PATH=.. ansible-playbook  playbooks/swarm_setup.yml
+ANSIBLE_ROLES_PATH=.. ansible-playbook  playbooks/swarm_setup.yml "$@"
 
 echo "Test docker_swarm inventory 1"
-ansible-playbook -i inventory_1.docker_swarm.yml playbooks/test_inventory_1.yml
+ansible-playbook -i inventory_1.docker_swarm.yml playbooks/test_inventory_1.yml "$@"
 
 echo "Test docker_swarm inventory 2"
-ansible-playbook -i inventory_2.docker_swarm.yml playbooks/test_inventory_2.yml
+ansible-playbook -i inventory_2.docker_swarm.yml playbooks/test_inventory_2.yml "$@"
