@@ -2,11 +2,9 @@
 # GNU General Public License v3.0+ (see LICENSES/GPL-3.0-or-later.txt or https://www.gnu.org/licenses/gpl-3.0.txt)
 # SPDX-License-Identifier: GPL-3.0-or-later
 
-from __future__ import (absolute_import, division, print_function)
-__metaclass__ = type
+from __future__ import annotations
 
 import pytest
-import tarfile
 
 from ansible_collections.community.docker.plugins.module_utils._scramble import (
     scramble,
@@ -14,16 +12,19 @@ from ansible_collections.community.docker.plugins.module_utils._scramble import
 )
 
 
-@pytest.mark.parametrize('plaintext, key, scrambled', [
-    (u'', b'0', '=S='),
-    (u'hello', b'\x00', '=S=aGVsbG8='),
-    (u'hello', b'\x01', '=S=aWRtbW4='),
-])
-def test_scramble_unscramble(plaintext, key, scrambled):
+@pytest.mark.parametrize(
+    "plaintext, key, scrambled",
+    [
+        ("", b"0", "=S="),
+        ("hello", b"\x00", "=S=aGVsbG8="),
+        ("hello", b"\x01", "=S=aWRtbW4="),
+    ],
+)
+def test_scramble_unscramble(plaintext: str, key: bytes, scrambled: str) -> None:
     scrambled_ = scramble(plaintext, key)
-    print('{0!r} == {1!r}'.format(scrambled_, scrambled))
+    print(f"{scrambled_!r} == {scrambled!r}")
     assert scrambled_ == scrambled
 
     plaintext_ = unscramble(scrambled, key)
-    print('{0!r} == {1!r}'.format(plaintext_, plaintext))
+    print(f"{plaintext_!r} == {plaintext!r}")
     assert plaintext_ == plaintext
