@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # Copyright (c) 2017, Brian Coca
 # Copyright (c) 2017 Ansible Project
 # GNU General Public License v3.0+ (see LICENSES/GPL-3.0-or-later.txt or https://www.gnu.org/licenses/gpl-3.0.txt)
@@ -17,7 +16,7 @@ options:
   _uri:
     required: true
     description:
-      - Path in which the cache plugin will save the files.
+      - Path in which the cache plugin saves the files.
     env:
       - name: ANSIBLE_CACHE_PLUGIN_CONNECTION
     ini:
@@ -43,12 +42,8 @@ options:
     type: float
 """
 
-try:
-    import cPickle as pickle
-except ImportError:
-    import pickle
+import pickle
 
-from ansible.module_utils.six import PY3
 from ansible.plugins.cache import BaseFileCacheModule
 
 
@@ -57,15 +52,14 @@ class CacheModule(BaseFileCacheModule):
     A caching module backed by pickle files.
     """
 
+    _persistent = False  # prevent unnecessary JSON serialization and key munging
+
     def _load(self, filepath):
         # Pickle is a binary format
-        with open(filepath, 'rb') as f:
-            if PY3:
-                return pickle.load(f, encoding='bytes')
-            else:
-                return pickle.load(f)
+        with open(filepath, "rb") as f:
+            return pickle.load(f, encoding="bytes")
 
     def _dump(self, value, filepath):
-        with open(filepath, 'wb') as f:
+        with open(filepath, "wb") as f:
             # Use pickle protocol 2 which is compatible with Python 2.3+.
             pickle.dump(value, f, protocol=2)
