@@ -1,67 +1,67 @@
-# -*- coding: utf-8 -*-
 # Copyright (c) 2017, Edward Nunez <edward.nunez@cyberark.com>
 # Copyright (c) 2017 Ansible Project
 # GNU General Public License v3.0+ (see LICENSES/GPL-3.0-or-later.txt or https://www.gnu.org/licenses/gpl-3.0.txt)
 # SPDX-License-Identifier: GPL-3.0-or-later
-from __future__ import (absolute_import, division, print_function)
-__metaclass__ = type
+from __future__ import annotations
 
-DOCUMENTATION = '''
-    author: Unknown (!UNKNOWN)
-    name: cyberarkpassword
-    short_description: get secrets from CyberArk AIM
-    requirements:
-      - CyberArk AIM tool installed
+DOCUMENTATION = r"""
+author: Unknown (!UNKNOWN)
+name: cyberarkpassword
+short_description: Get secrets from CyberArk AIM
+requirements:
+  - CyberArk AIM tool installed
+description:
+  - Get secrets from CyberArk AIM.
+options:
+  _command:
+    description: Cyberark CLI utility.
+    type: string
+    env:
+      - name: AIM_CLIPASSWORDSDK_CMD
+    default: '/opt/CARKaim/sdk/clipasswordsdk'
+  appid:
+    description: Defines the unique ID of the application that is issuing the password request.
+    type: string
+    required: true
+  query:
+    description: Describes the filter criteria for the password retrieval.
+    type: string
+    required: true
+  output:
     description:
-      - Get secrets from CyberArk AIM.
-    options :
-      _command:
-        description: Cyberark CLI utility.
-        type: string
-        env:
-          - name: AIM_CLIPASSWORDSDK_CMD
-        default: '/opt/CARKaim/sdk/clipasswordsdk'
-      appid:
-        description: Defines the unique ID of the application that is issuing the password request.
-        type: string
-        required: true
-      query:
-        description: Describes the filter criteria for the password retrieval.
-        type: string
-        required: true
-      output:
-        description:
-          - Specifies the desired output fields separated by commas.
-          - "They could be: Password, PassProps.<property>, PasswordChangeInProcess"
-        type: string
-        default: 'password'
-      _extra:
-        description: for extra_params values please check parameters for clipasswordsdk in CyberArk's "Credential Provider and ASCP Implementation Guide"
-    notes:
-      - For Ansible on Windows, please change the -parameters (-p, -d, and -o) to /parameters (/p, /d, and /o) and change the location of CLIPasswordSDK.exe.
-'''
-
-EXAMPLES = """
-  - name: passing options to the lookup
-    ansible.builtin.debug:
-        msg: '{{ lookup("community.general.cyberarkpassword", cyquery) }}'
-    vars:
-      cyquery:
-        appid: "app_ansible"
-        query: "safe=CyberArk_Passwords;folder=root;object=AdminPass"
-        output: "Password,PassProps.UserName,PassProps.Address,PasswordChangeInProcess"
-
-
-  - name: used in a loop
-    ansible.builtin.debug:
-        msg: "{{item}}"
-    with_community.general.cyberarkpassword:
-        appid: 'app_ansible'
-        query: 'safe=CyberArk_Passwords;folder=root;object=AdminPass'
-        output: 'Password,PassProps.UserName,PassProps.Address,PasswordChangeInProcess'
+      - Specifies the desired output fields separated by commas.
+      - 'They could be: Password, PassProps.<property>, PasswordChangeInProcess.'
+    type: string
+    default: 'password'
+  _extra:
+    description: For extra_params values please check parameters for clipasswordsdk in CyberArk's "Credential Provider and
+      ASCP Implementation Guide".
+notes:
+  - For Ansible on Windows, please change the -parameters (C(-p), C(-d), and C(-o)) to /parameters (C(/p), C(/d), and C(/o))
+    and change the location of C(CLIPasswordSDK.exe).
 """
 
-RETURN = """
+EXAMPLES = r"""
+- name: passing options to the lookup
+  ansible.builtin.debug:
+    msg: '{{ lookup("community.general.cyberarkpassword", cyquery) }}'
+  vars:
+    cyquery:
+      appid: "app_ansible"
+      query: "safe=CyberArk_Passwords;folder=root;object=AdminPass"
+      output: "Password,PassProps.UserName,PassProps.Address,PasswordChangeInProcess"
+
+
+- name: used in a loop
+  ansible.builtin.debug:
+    msg: "{{item}}"
+  with_community.general.cyberarkpassword:
+    appid: 'app_ansible'
+    query: 'safe=CyberArk_Passwords;folder=root;object=AdminPass'
+    output: 'Password,PassProps.UserName,PassProps.Address,PasswordChangeInProcess'
+"""
+
+RETURN = r"""
 _result:
   description: A list containing one dictionary.
   type: list
@@ -69,12 +69,12 @@ _result:
   contains:
     password:
       description:
-        - The actual value stored
+        - The actual value stored.
     passprops:
-      description: properties assigned to the entry
+      description: Properties assigned to the entry.
       type: dictionary
     passwordchangeinprocess:
-      description: did the password change?
+      description: Did the password change?
 """
 
 import os
@@ -89,13 +89,11 @@ from ansible.utils.display import Display
 
 display = Display()
 
-CLIPASSWORDSDK_CMD = os.getenv('AIM_CLIPASSWORDSDK_CMD', '/opt/CARKaim/sdk/clipasswordsdk')
+CLIPASSWORDSDK_CMD = os.getenv("AIM_CLIPASSWORDSDK_CMD", "/opt/CARKaim/sdk/clipasswordsdk")
 
 
 class CyberarkPassword:
-
     def __init__(self, appid=None, query=None, output=None, **kwargs):
-
         self.appid = appid
         self.query = query
         self.output = output
@@ -104,7 +102,7 @@ class CyberarkPassword:
         # FailRequestOnPasswordChange, Queryformat, Reason, etc.
         self.extra_parms = []
         for key, value in kwargs.items():
-            self.extra_parms.append('-p')
+            self.extra_parms.append("-p")
             self.extra_parms.append(f"{key}={value}")
 
         if self.appid is None:
@@ -123,17 +121,21 @@ class CyberarkPassword:
         self.b_delimiter = b"@#@"  # Known delimiter to split output results
 
     def get(self):
-
         result_dict = {}
 
         try:
             all_parms = [
                 CLIPASSWORDSDK_CMD,
-                'GetPassword',
-                '-p', f'AppDescs.AppID={self.appid}',
-                '-p', f'Query={self.query}',
-                '-o', self.output,
-                '-d', self.b_delimiter]
+                "GetPassword",
+                "-p",
+                f"AppDescs.AppID={self.appid}",
+                "-p",
+                f"Query={self.query}",
+                "-o",
+                self.output,
+                "-d",
+                self.b_delimiter,
+            ]
             all_parms.extend(self.extra_parms)
 
             b_credential = b""
@@ -146,7 +148,7 @@ class CyberarkPassword:
             if tmp_error:
                 raise AnsibleError(f"ERROR => {tmp_error} ")
 
-            if b_credential and b_credential.endswith(b'\n'):
+            if b_credential and b_credential.endswith(b"\n"):
                 b_credential = b_credential[:-1]
 
             output_names = self.output.split(",")
@@ -162,15 +164,16 @@ class CyberarkPassword:
                     result_dict[output_names[i]] = to_native(output_values[i])
 
         except subprocess.CalledProcessError as e:
-            raise AnsibleError(e.output)
+            raise AnsibleError(e.output) from e
         except OSError as e:
-            raise AnsibleError(f"ERROR - AIM not installed or clipasswordsdk not in standard location. ERROR=({e.errno}) => {e.strerror} ")
+            raise AnsibleError(
+                f"ERROR - AIM not installed or clipasswordsdk not in standard location. ERROR=({e.errno}) => {e.strerror} "
+            ) from e
 
         return [result_dict]
 
 
 class LookupModule(LookupBase):
-
     """
     USAGE:
 
