@@ -1,17 +1,20 @@
-# -*- coding: utf-8 -*-
 # Copyright (c) 2024, Alexei Znamensky <russoz@gmail.com>
 # GNU General Public License v3.0+ (see LICENSES/GPL-3.0-or-later.txt or https://www.gnu.org/licenses/gpl-3.0.txt)
 # SPDX-License-Identifier: GPL-3.0-or-later
 
-from __future__ import absolute_import, division, print_function
-__metaclass__ = type
+from __future__ import annotations
 
+import typing as t
 
 from ansible.module_utils.common.dict_transformations import dict_merge
 from ansible_collections.community.general.plugins.module_utils import cmd_runner_fmt
 from ansible_collections.community.general.plugins.module_utils.python_runner import PythonRunner
 from ansible_collections.community.general.plugins.module_utils.module_helper import ModuleHelper
 
+if t.TYPE_CHECKING:
+    from ansible.module_utils.basic import AnsibleModule
+    from ansible_collections.community.general.plugins.module_utils.cmd_runner import ArgFormatter
+
 
 django_std_args = dict(
     # environmental options
@@ -34,7 +37,7 @@ _pks = dict(
     primary_keys=dict(type="list", elements="str"),
 )
 
-_django_std_arg_fmts = dict(
+_django_std_arg_fmts: dict[str, ArgFormatter] = dict(
     all=cmd_runner_fmt.as_bool("--all"),
     app=cmd_runner_fmt.as_opt_val("--app"),
     apps=cmd_runner_fmt.as_list(),
@@ -69,52 +72,60 @@ _django_std_arg_fmts = dict(
 # keys can be used in _django_args
 _args_menu = dict(
     std=(django_std_args, _django_std_arg_fmts),
-    database=(_database_dash, {"database": _django_std_arg_fmts["database_dash"]}),    # deprecate, remove in 13.0.0
+    database=(_database_dash, {"database": _django_std_arg_fmts["database_dash"]}),  # deprecate, remove in 13.0.0
     noinput=({}, {"noinput": cmd_runner_fmt.as_fixed("--noinput")}),  # deprecate, remove in 13.0.0
-    dry_run=({}, {"dry_run": cmd_runner_fmt.as_bool("--dry-run")}),   # deprecate, remove in 13.0.0
-    check=({}, {"check": cmd_runner_fmt.as_bool("--check")}),         # deprecate, remove in 13.0.0
+    dry_run=({}, {"dry_run": cmd_runner_fmt.as_bool("--dry-run")}),  # deprecate, remove in 13.0.0
+    check=({}, {"check": cmd_runner_fmt.as_bool("--check")}),  # deprecate, remove in 13.0.0
     database_dash=(_database_dash, {}),
     data=(_data, {}),
 )
 
 
 class _DjangoRunner(PythonRunner):
-    def __init__(self, module, arg_formats=None, **kwargs):
+    def __init__(self, module: AnsibleModule, arg_formats=None, **kwargs) -> None:
         arg_fmts = dict(arg_formats) if arg_formats else {}
         arg_fmts.update(_django_std_arg_fmts)
 
-        super(_DjangoRunner, self).__init__(module, ["-m", "django"], arg_formats=arg_fmts, **kwargs)
+        super().__init__(module, ["-m", "django"], arg_formats=arg_fmts, **kwargs)
 
     def __call__(self, output_process=None, check_mode_skip=False, check_mode_return=None, **kwargs):
         args_order = (
-            ("command", "no_color", "settings", "pythonpath", "traceback", "verbosity", "skip_checks") + self._prepare_args_order(self.default_args_order)
+            "command",
+            "no_color",
+            "settings",
+            "pythonpath",
+            "traceback",
+            "verbosity",
+            "skip_checks",
+        ) + self._prepare_args_order(self.default_args_order)
+        return super().__call__(
+            args_order, output_process, check_mode_skip=check_mode_skip, check_mode_return=check_mode_return, **kwargs
         )
-        return super(_DjangoRunner, self).__call__(args_order, output_process, check_mode_skip=check_mode_skip, check_mode_return=check_mode_return, **kwargs)
 
     def bare_context(self, *args, **kwargs):
-        return super(_DjangoRunner, self).__call__(*args, **kwargs)
+        return super().__call__(*args, **kwargs)
 
 
 class DjangoModuleHelper(ModuleHelper):
     module = {}
-    django_admin_cmd = None
-    arg_formats = {}
-    django_admin_arg_order = ()
-    _django_args = []
-    _check_mode_arg = ""
+    django_admin_cmd: str | None = None
+    arg_formats: dict[str, ArgFormatter] = {}
+    django_admin_arg_order: tuple[str, ...] | str = ()
+    _django_args: list[str] = []
+    _check_mode_arg: str = ""
 
-    def __init__(self):
-        self.module["argument_spec"], self.arg_formats = self._build_args(self.module.get("argument_spec", {}),
-                                                                          self.arg_formats,
-                                                                          *(["std"] + self._django_args))
-        super(DjangoModuleHelper, self).__init__(self.module)
+    def __init__(self) -> None:
+        self.module["argument_spec"], self.arg_formats = self._build_args(
+            self.module.get("argument_spec", {}), self.arg_formats, *(["std"] + self._django_args)
+        )
+        super().__init__(self.module)
         if self.django_admin_cmd is not None:
             self.vars.command = self.django_admin_cmd
 
     @staticmethod
-    def _build_args(arg_spec, arg_format, *names):
-        res_arg_spec = {}
-        res_arg_fmts = {}
+    def _build_args(arg_spec, arg_format, *names) -> tuple[dict[str, t.Any], dict[str, ArgFormatter]]:
+        res_arg_spec: dict[str, t.Any] = {}
+        res_arg_fmts: dict[str, ArgFormatter] = {}
         for name in names:
             args, fmts = _args_menu[name]
             res_arg_spec = dict_merge(res_arg_spec, args)
@@ -125,11 +136,13 @@ class DjangoModuleHelper(ModuleHelper):
         return res_arg_spec, res_arg_fmts
 
     def __run__(self):
-        runner = _DjangoRunner(self.module,
-                               default_args_order=self.django_admin_arg_order,
-                               arg_formats=self.arg_formats,
-                               venv=self.vars.venv,
-                               check_rc=True)
+        runner = _DjangoRunner(
+            self.module,
+            default_args_order=self.django_admin_arg_order,
+            arg_formats=self.arg_formats,
+            venv=self.vars.venv,
+            check_rc=True,
+        )
 
         run_params = self.vars.as_dict()
         if self._check_mode_arg:
