@@ -1,21 +1,18 @@
-# -*- coding: utf-8 -*-
-
 # Copyright (c) 2022, Alexei Znamensky <russoz@gmail.com>
 #
 # GNU General Public License v3.0+ (see LICENSES/GPL-3.0-or-later.txt or https://www.gnu.org/licenses/gpl-3.0.txt)
 # SPDX-License-Identifier: GPL-3.0-or-later
 
-from __future__ import absolute_import, division, print_function
-__metaclass__ = type
+from __future__ import annotations
 
 
 import os
 import time
 
 
-def download_updates_file(updates_expiration):
-    updates_filename = 'jenkins-plugin-cache.json'
-    updates_dir = os.path.expanduser('~/.ansible/tmp')
+def download_updates_file(updates_expiration: int | float) -> tuple[str, bool]:
+    updates_filename = "jenkins-plugin-cache.json"
+    updates_dir = os.path.expanduser("~/.ansible/tmp")
     updates_file = os.path.join(updates_dir, updates_filename)
     download_updates = True
 
