@@ -1,15 +1,18 @@
-# -*- coding: utf-8 -*-
 # Copyright (c) 2025, Dexter Le <dextersydney2001@gmail.com>
 # GNU General Public License v3.0+ (see LICENSES/GPL-3.0-or-later.txt or https://www.gnu.org/licenses/gpl-3.0.txt)
 # SPDX-License-Identifier: GPL-3.0-or-later
 
-from __future__ import absolute_import, division, print_function
-__metaclass__ = type
+from __future__ import annotations
 
 import re
+import typing as t
 
 from ansible_collections.community.general.plugins.module_utils.cmd_runner import CmdRunner, cmd_runner_fmt
 
+if t.TYPE_CHECKING:
+    from ansible.module_utils.basic import AnsibleModule
+
+
 _state_map = {
     "present": "create",
     "absent": "remove",
@@ -26,25 +29,29 @@ _state_map = {
 
 
 def fmt_resource_type(value):
-    return [":".join(value[k] for k in ['resource_standard', 'resource_provider', 'resource_name'] if value.get(k) is not None)]
+    return [
+        ":".join(
+            value[k] for k in ["resource_standard", "resource_provider", "resource_name"] if value.get(k) is not None
+        )
+    ]
 
 
 def fmt_resource_operation(value):
     cmd = []
     for op in value:
         cmd.append("op")
-        cmd.append(op.get('operation_action'))
-        for operation_option in op.get('operation_option'):
+        cmd.append(op.get("operation_action"))
+        for operation_option in op.get("operation_option"):
             cmd.append(operation_option)
 
     return cmd
 
 
 def fmt_resource_argument(value):
-    return ['--group' if value['argument_action'] == 'group' else value['argument_action']] + value['argument_option']
+    return ["--group" if value["argument_action"] == "group" else value["argument_action"]] + value["argument_option"]
 
 
-def get_pacemaker_maintenance_mode(runner):
+def get_pacemaker_maintenance_mode(runner: CmdRunner) -> bool:
     with runner("cli_action config") as ctx:
         rc, out, err = ctx.run(cli_action="property")
         maint_mode_re = re.compile(r"maintenance-mode.*true", re.IGNORECASE)
@@ -52,8 +59,8 @@ def get_pacemaker_maintenance_mode(runner):
         return bool(maintenance_mode_output)
 
 
-def pacemaker_runner(module, **kwargs):
-    runner_command = ['pcs']
+def pacemaker_runner(module: AnsibleModule, **kwargs) -> CmdRunner:
+    runner_command = ["pcs"]
     runner = CmdRunner(
         module,
         command=runner_command,
@@ -76,6 +83,6 @@ def pacemaker_runner(module, **kwargs):
             version=cmd_runner_fmt.as_fixed("--version"),
             output_format=cmd_runner_fmt.as_opt_eq_val("--output-format"),
         ),
-        **kwargs
+        **kwargs,
     )
     return runner
