@@ -1,12 +1,10 @@
 #!/usr/bin/python
-# -*- coding: utf-8 -*-
 #
 # Copyright (c) 2018, Ansible Project
 # GNU General Public License v3.0+ (see LICENSES/GPL-3.0-or-later.txt or https://www.gnu.org/licenses/gpl-3.0.txt)
 # SPDX-License-Identifier: GPL-3.0-or-later
 
-from __future__ import (absolute_import, division, print_function)
-__metaclass__ = type
+from __future__ import annotations
 
 DOCUMENTATION = r"""
 module: github_webhook_info
@@ -35,17 +33,14 @@ options:
     description:
       - Password to authenticate to GitHub with.
     type: str
-    required: false
   token:
     description:
       - Token to authenticate to GitHub with.
     type: str
-    required: false
   github_url:
     description:
       - Base URL of the GitHub API.
     type: str
-    required: false
     default: https://api.github.com
 
 author:
@@ -94,13 +89,13 @@ import traceback
 GITHUB_IMP_ERR = None
 try:
     import github
+
     HAS_GITHUB = True
 except ImportError:
     GITHUB_IMP_ERR = traceback.format_exc()
     HAS_GITHUB = False
 
 from ansible.module_utils.basic import AnsibleModule, missing_required_lib
-from ansible.module_utils.common.text.converters import to_native
 
 
 def _munge_hook(hook_obj):
@@ -122,56 +117,53 @@ def _munge_hook(hook_obj):
 def main():
     module = AnsibleModule(
         argument_spec=dict(
-            repository=dict(type='str', required=True, aliases=["repo"]),
-            user=dict(type='str', required=True),
-            password=dict(type='str', no_log=True),
-            token=dict(type='str', no_log=True),
-            github_url=dict(
-                type='str', default="https://api.github.com")),
-        mutually_exclusive=(('password', 'token'), ),
-        required_one_of=(("password", "token"), ),
-        supports_check_mode=True)
+            repository=dict(type="str", required=True, aliases=["repo"]),
+            user=dict(type="str", required=True),
+            password=dict(type="str", no_log=True),
+            token=dict(type="str", no_log=True),
+            github_url=dict(type="str", default="https://api.github.com"),
+        ),
+        mutually_exclusive=(("password", "token"),),
+        required_one_of=(("password", "token"),),
+        supports_check_mode=True,
+    )
 
     if not HAS_GITHUB:
-        module.fail_json(msg=missing_required_lib('PyGithub'),
-                         exception=GITHUB_IMP_ERR)
+        module.fail_json(msg=missing_required_lib("PyGithub"), exception=GITHUB_IMP_ERR)
 
     try:
         github_conn = github.Github(
             module.params["user"],
             module.params.get("password") or module.params.get("token"),
-            base_url=module.params["github_url"])
+            base_url=module.params["github_url"],
+        )
     except github.GithubException as err:
-        module.fail_json(msg="Could not connect to GitHub at %s: %s" % (
-            module.params["github_url"], to_native(err)))
+        module.fail_json(msg=f"Could not connect to GitHub at {module.params['github_url']}: {err}")
 
     try:
         repo = github_conn.get_repo(module.params["repository"])
     except github.BadCredentialsException as err:
-        module.fail_json(msg="Could not authenticate to GitHub at %s: %s" % (
-            module.params["github_url"], to_native(err)))
+        module.fail_json(msg=f"Could not authenticate to GitHub at {module.params['github_url']}: {err}")
     except github.UnknownObjectException as err:
         module.fail_json(
-            msg="Could not find repository %s in GitHub at %s: %s" % (
-                module.params["repository"], module.params["github_url"],
-                to_native(err)))
+            msg=f"Could not find repository {module.params['repository']} in GitHub at {module.params['github_url']}: {err}"
+        )
     except Exception as err:
         module.fail_json(
-            msg="Could not fetch repository %s from GitHub at %s: %s" %
-            (module.params["repository"], module.params["github_url"],
-             to_native(err)),
-            exception=traceback.format_exc())
+            msg=f"Could not fetch repository {module.params['repository']} from GitHub at {module.params['github_url']}: {err}",
+            exception=traceback.format_exc(),
+        )
 
     try:
         hooks = [_munge_hook(h) for h in repo.get_hooks()]
     except github.GithubException as err:
         module.fail_json(
-            msg="Unable to get hooks from repository %s: %s" %
-            (module.params["repository"], to_native(err)),
-            exception=traceback.format_exc())
+            msg=f"Unable to get hooks from repository {module.params['repository']}: {err}",
+            exception=traceback.format_exc(),
+        )
 
     module.exit_json(changed=False, hooks=hooks)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
