@@ -1,5 +1,4 @@
 #!/usr/bin/python
-# -*- coding: utf-8 -*-
 
 # Copyright (c) 2016, Loic Blot <loic.blot@unix-experience.fr>
 # Copyright (c) 2018, Ansible Project
@@ -9,8 +8,7 @@
 # GNU General Public License v3.0+ (see LICENSES/GPL-3.0-or-later.txt or https://www.gnu.org/licenses/gpl-3.0.txt)
 # SPDX-License-Identifier: GPL-3.0-or-later
 
-from __future__ import absolute_import, division, print_function
-__metaclass__ = type
+from __future__ import annotations
 
 
 DOCUMENTATION = r"""
@@ -67,24 +65,26 @@ from ansible.module_utils.basic import AnsibleModule
 class Icinga2FeatureHelper:
     def __init__(self, module):
         self.module = module
-        self._icinga2 = module.get_bin_path('icinga2', True)
-        self.feature_name = self.module.params['name']
-        self.state = self.module.params['state']
+        self._icinga2 = module.get_bin_path("icinga2", True)
+        self.feature_name = self.module.params["name"]
+        self.state = self.module.params["state"]
 
     def _exec(self, args):
-        cmd = [self._icinga2, 'feature']
+        cmd = [self._icinga2, "feature"]
         rc, out, err = self.module.run_command(cmd + args, check_rc=True)
         return rc, out
 
     def manage(self):
         rc, out = self._exec(["list"])
         if rc != 0:
-            self.module.fail_json(msg="Unable to list icinga2 features. "
-                                      "Ensure icinga2 is installed and present in binary path.")
+            self.module.fail_json(
+                msg="Unable to list icinga2 features. Ensure icinga2 is installed and present in binary path."
+            )
 
         # If feature is already in good state, just exit
-        if (re.search("Disabled features:.* %s[ \n]" % self.feature_name, out) and self.state == "absent") or \
-                (re.search("Enabled features:.* %s[ \n]" % self.feature_name, out) and self.state == "present"):
+        if (re.search(f"Disabled features:.* {self.feature_name}[ \n]", out) and self.state == "absent") or (
+            re.search(f"Enabled features:.* {self.feature_name}[ \n]", out) and self.state == "present"
+        ):
             self.module.exit_json(changed=False)
 
         if self.module.check_mode:
@@ -97,10 +97,9 @@ class Icinga2FeatureHelper:
         change_applied = False
         if self.state == "present":
             if rc != 0:
-                self.module.fail_json(msg="Failed to %s feature %s."
-                                          " icinga2 command returned %s" % (feature_enable_str,
-                                                                            self.feature_name,
-                                                                            out))
+                self.module.fail_json(
+                    msg=f"Failed to {feature_enable_str} feature {self.feature_name}. icinga2 command returned {out}"
+                )
 
             if re.search("already enabled", out) is None:
                 change_applied = True
@@ -108,10 +107,10 @@ class Icinga2FeatureHelper:
             if rc == 0:
                 change_applied = True
             # RC is not 0 for this already disabled feature, handle it as no change applied
-            elif re.search("Cannot disable feature '%s'. Target file .* does not exist" % self.feature_name, out):
+            elif re.search(f"Cannot disable feature '{self.feature_name}'. Target file .* does not exist", out):
                 change_applied = False
             else:
-                self.module.fail_json(msg="Failed to disable feature. Command returns %s" % out)
+                self.module.fail_json(msg=f"Failed to disable feature. Command returns {out}")
 
         self.module.exit_json(changed=change_applied)
 
@@ -119,15 +118,15 @@ class Icinga2FeatureHelper:
 def main():
     module = AnsibleModule(
         argument_spec=dict(
-            name=dict(type='str', required=True),
-            state=dict(type='str', choices=["present", "absent"], default="present")
+            name=dict(type="str", required=True),
+            state=dict(type="str", choices=["present", "absent"], default="present"),
         ),
-        supports_check_mode=True
+        supports_check_mode=True,
     )
 
-    module.run_command_environ_update = dict(LANG='C', LC_ALL='C', LC_MESSAGES='C', LC_CTYPE='C')
+    module.run_command_environ_update = dict(LANG="C", LC_ALL="C", LC_MESSAGES="C", LC_CTYPE="C")
     Icinga2FeatureHelper(module).manage()
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
