@@ -1,12 +1,10 @@
 #!/usr/bin/python
-# -*- coding: utf-8 -*-
 #
 # Copyright (c) 2015, René Moser <mail@renemoser.net>
 # GNU General Public License v3.0+ (see LICENSES/GPL-3.0-or-later.txt or https://www.gnu.org/licenses/gpl-3.0.txt)
 # SPDX-License-Identifier: GPL-3.0-or-later
 
-from __future__ import absolute_import, division, print_function
-__metaclass__ = type
+from __future__ import annotations
 
 
 DOCUMENTATION = r"""
@@ -24,7 +22,7 @@ options:
   api_url:
     description:
       - URL of the ipify.org API service.
-      - C(?format=json) will be appended per default.
+      - C(?format=json) is appended by default.
     type: str
     default: https://api.ipify.org/
   timeout:
@@ -34,7 +32,7 @@ options:
     default: 10
   validate_certs:
     description:
-      - When set to V(false), SSL certificates will not be validated.
+      - When set to V(false), SSL certificates are not validated.
     type: bool
     default: true
 notes:
@@ -68,23 +66,22 @@ from ansible.module_utils.urls import fetch_url
 from ansible.module_utils.common.text.converters import to_text
 
 
-class IpifyFacts(object):
-
+class IpifyFacts:
     def __init__(self):
-        self.api_url = module.params.get('api_url')
-        self.timeout = module.params.get('timeout')
+        self.api_url = module.params.get("api_url")
+        self.timeout = module.params.get("timeout")
 
     def run(self):
-        result = {
-            'ipify_public_ip': None
-        }
-        (response, info) = fetch_url(module=module, url=self.api_url + "?format=json", force=True, timeout=self.timeout)
+        result = {"ipify_public_ip": None}
+        (response, info) = fetch_url(module=module, url=f"{self.api_url}?format=json", force=True, timeout=self.timeout)
 
         if not response:
-            module.fail_json(msg="No valid or no response from url %s within %s seconds (timeout)" % (self.api_url, self.timeout))
+            module.fail_json(
+                msg=f"No valid or no response from url {self.api_url} within {self.timeout} seconds (timeout)"
+            )
 
         data = json.loads(to_text(response.read()))
-        result['ipify_public_ip'] = data.get('ip')
+        result["ipify_public_ip"] = data.get("ip")
         return result
 
 
@@ -92,9 +89,9 @@ def main():
     global module
     module = AnsibleModule(
         argument_spec=dict(
-            api_url=dict(type='str', default='https://api.ipify.org/'),
-            timeout=dict(type='int', default=10),
-            validate_certs=dict(type='bool', default=True),
+            api_url=dict(type="str", default="https://api.ipify.org/"),
+            timeout=dict(type="int", default=10),
+            validate_certs=dict(type="bool", default=True),
         ),
         supports_check_mode=True,
     )
@@ -104,5 +101,5 @@ def main():
     module.exit_json(**ipify_facts_result)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
