@@ -1,17 +1,14 @@
 #!/usr/bin/python
-# -*- coding: utf-8 -*-
 # Copyright (c) 2022, Alexei Znamensky <russoz@gmail.com>
 # Copyright (c) 2017, Daniel Korn <korndaniel1@gmail.com>
 # Copyright (c) 2017, Yaacov Zamir <yzamir@redhat.com>
 # GNU General Public License v3.0+ (see LICENSES/GPL-3.0-or-later.txt or https://www.gnu.org/licenses/gpl-3.0.txt)
 # SPDX-License-Identifier: GPL-3.0-or-later
 
-from __future__ import absolute_import, division, print_function
-__metaclass__ = type
+from __future__ import annotations
 
 
-DOCUMENTATION = '''
-
+DOCUMENTATION = r"""
 module: manageiq_policies_info
 version_added: 5.8.0
 
@@ -24,16 +21,27 @@ extends_documentation_fragment:
 author: Alexei Znamensky (@russoz)
 description:
   - The manageiq_policies module supports listing policy_profiles in ManageIQ.
-
 options:
   resource_type:
     type: str
     description:
       - The type of the resource to obtain the profile for.
     required: true
-    choices: ['provider', 'host', 'vm', 'blueprint', 'category', 'cluster',
-        'data store', 'group', 'resource pool', 'service', 'service template',
-        'template', 'tenant', 'user']
+    choices:
+      - provider
+      - host
+      - vm
+      - blueprint
+      - category
+      - cluster
+      - data store
+      - group
+      - resource pool
+      - service
+      - service template
+      - template
+      - tenant
+      - user
   resource_name:
     type: str
     description:
@@ -44,9 +52,9 @@ options:
     description:
       - The ID of the resource to obtain the profile for.
       - Must be specified if O(resource_name) is not set. Both options are mutually exclusive.
-'''
+"""
 
-EXAMPLES = '''
+EXAMPLES = r"""
 - name: List current policy_profile and policies for a provider in ManageIQ
   community.general.manageiq_policies_info:
     resource_name: 'EngLab'
@@ -56,9 +64,9 @@ EXAMPLES = '''
       username: 'admin'
       password: 'smartvm'
   register: result
-'''
+"""
 
-RETURN = '''
+RETURN = r"""
 profiles:
   description:
     - List current policy_profile and policies for a provider in ManageIQ.
@@ -78,18 +86,21 @@ profiles:
           name: schedule compliance after smart state analysis
       profile_description: OpenSCAP profile
       profile_name: openscap profile
-'''
+"""
 
 from ansible.module_utils.basic import AnsibleModule
-from ansible_collections.community.general.plugins.module_utils.manageiq import ManageIQ, manageiq_argument_spec, manageiq_entities
+from ansible_collections.community.general.plugins.module_utils.manageiq import (
+    ManageIQ,
+    manageiq_argument_spec,
+    manageiq_entities,
+)
 
 
 def main():
     argument_spec = dict(
-        resource_id=dict(required=False, type='int'),
-        resource_name=dict(required=False, type='str'),
-        resource_type=dict(required=True, type='str',
-                           choices=list(manageiq_entities().keys())),
+        resource_id=dict(type="int"),
+        resource_name=dict(type="str"),
+        resource_type=dict(required=True, type="str", choices=list(manageiq_entities().keys())),
     )
     # add the manageiq connection arguments to the arguments
     argument_spec.update(manageiq_argument_spec())
@@ -101,9 +112,9 @@ def main():
         supports_check_mode=True,
     )
 
-    resource_id = module.params['resource_id']
-    resource_type_key = module.params['resource_type']
-    resource_name = module.params['resource_name']
+    resource_id = module.params["resource_id"]
+    resource_type_key = module.params["resource_type"]
+    resource_name = module.params["resource_name"]
 
     # get the resource type
     resource_type = manageiq_entities()[resource_type_key]
