@@ -1,11 +1,9 @@
 #!/usr/bin/python
-# -*- coding: utf-8 -*-
 # Copyright (c) 2016-2017 Hewlett Packard Enterprise Development LP
 # GNU General Public License v3.0+ (see LICENSES/GPL-3.0-or-later.txt or https://www.gnu.org/licenses/gpl-3.0.txt)
 # SPDX-License-Identifier: GPL-3.0-or-later
 
-from __future__ import (absolute_import, division, print_function)
-__metaclass__ = type
+from __future__ import annotations
 
 DOCUMENTATION = r"""
 module: oneview_fcoe_network
@@ -25,8 +23,8 @@ options:
   state:
     description:
       - Indicates the desired state for the FCoE Network resource.
-      - V(present) will ensure data properties are compliant with OneView.
-      - V(absent) will remove the resource from OneView, if it exists.
+      - V(present) ensures data properties are compliant with OneView.
+      - V(absent) removes the resource from OneView, if it exists.
     type: str
     default: present
     choices: ['present', 'absent']
@@ -83,37 +81,35 @@ from ansible_collections.community.general.plugins.module_utils.oneview import O
 
 
 class FcoeNetworkModule(OneViewModuleBase):
-    MSG_CREATED = 'FCoE Network created successfully.'
-    MSG_UPDATED = 'FCoE Network updated successfully.'
-    MSG_DELETED = 'FCoE Network deleted successfully.'
-    MSG_ALREADY_PRESENT = 'FCoE Network is already present.'
-    MSG_ALREADY_ABSENT = 'FCoE Network is already absent.'
-    RESOURCE_FACT_NAME = 'fcoe_network'
+    MSG_CREATED = "FCoE Network created successfully."
+    MSG_UPDATED = "FCoE Network updated successfully."
+    MSG_DELETED = "FCoE Network deleted successfully."
+    MSG_ALREADY_PRESENT = "FCoE Network is already present."
+    MSG_ALREADY_ABSENT = "FCoE Network is already absent."
+    RESOURCE_FACT_NAME = "fcoe_network"
 
     def __init__(self):
+        additional_arg_spec = dict(
+            data=dict(required=True, type="dict"), state=dict(default="present", choices=["present", "absent"])
+        )
 
-        additional_arg_spec = dict(data=dict(required=True, type='dict'),
-                                   state=dict(default='present',
-                                              choices=['present', 'absent']))
-
-        super(FcoeNetworkModule, self).__init__(additional_arg_spec=additional_arg_spec,
-                                                validate_etag_support=True)
+        super().__init__(additional_arg_spec=additional_arg_spec, validate_etag_support=True)
 
         self.resource_client = self.oneview_client.fcoe_networks
 
     def execute_module(self):
-        resource = self.get_by_name(self.data.get('name'))
+        resource = self.get_by_name(self.data.get("name"))
 
-        if self.state == 'present':
+        if self.state == "present":
             return self.__present(resource)
-        elif self.state == 'absent':
+        elif self.state == "absent":
             return self.resource_absent(resource)
 
     def __present(self, resource):
-        scope_uris = self.data.pop('scopeUris', None)
+        scope_uris = self.data.pop("scopeUris", None)
         result = self.resource_present(resource, self.RESOURCE_FACT_NAME)
         if scope_uris is not None:
-            result = self.resource_scopes_set(result, 'fcoe_network', scope_uris)
+            result = self.resource_scopes_set(result, "fcoe_network", scope_uris)
         return result
 
 
@@ -121,5 +117,5 @@ def main():
     FcoeNetworkModule().run()
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
