@@ -1,5 +1,4 @@
 #!/usr/bin/python
-# -*- coding: utf-8 -*-
 #
 # Scaleway Serverless container registry info module
 #
@@ -7,9 +6,8 @@
 # GNU General Public License v3.0+ (see LICENSES/GPL-3.0-or-later.txt or https://www.gnu.org/licenses/gpl-3.0.txt)
 # SPDX-License-Identifier: GPL-3.0-or-later
 
-from __future__ import absolute_import, division, print_function
+from __future__ import annotations
 
-__metaclass__ = type
 
 DOCUMENTATION = r"""
 module: scaleway_container_registry_info
@@ -21,8 +19,13 @@ description:
 extends_documentation_fragment:
   - community.general.scaleway
   - community.general.attributes
+  - community.general.scaleway.actiongroup_scaleway
   - community.general.attributes.info_module
 
+attributes:
+  action_group:
+    version_added: 11.3.0
+
 options:
   project_id:
     type: str
@@ -79,7 +82,9 @@ container_registry:
 """
 
 from ansible_collections.community.general.plugins.module_utils.scaleway import (
-    SCALEWAY_REGIONS, scaleway_argument_spec, Scaleway,
+    SCALEWAY_REGIONS,
+    scaleway_argument_spec,
+    Scaleway,
 )
 from ansible.module_utils.basic import AnsibleModule
 
@@ -89,18 +94,15 @@ def info_strategy(api, wished_cn):
     cn_lookup = {cn["name"]: cn for cn in cn_list}
 
     if wished_cn["name"] not in cn_lookup:
-        msg = "Error during container registries lookup: Unable to find container registry named '%s' in project '%s'" % (wished_cn["name"],
-                                                                                                                          wished_cn["project_id"])
+        msg = f"Error during container registries lookup: Unable to find container registry named '{wished_cn['name']}' in project '{wished_cn['project_id']}'"
 
         api.module.fail_json(msg=msg)
 
     target_cn = cn_lookup[wished_cn["name"]]
 
-    response = api.get(path=api.api_path + "/%s" % target_cn["id"])
+    response = api.get(path=f"{api.api_path}/{target_cn['id']}")
     if not response.ok:
-        msg = "Error during container registry lookup: %s: '%s' (%s)" % (response.info['msg'],
-                                                                         response.json['message'],
-                                                                         response.json)
+        msg = f"Error during container registry lookup: {response.info['msg']}: '{response.json['message']}' ({response.json})"
         api.module.fail_json(msg=msg)
 
     return response.json
@@ -108,13 +110,10 @@ def info_strategy(api, wished_cn):
 
 def core(module):
     region = module.params["region"]
-    wished_container_namespace = {
-        "project_id": module.params["project_id"],
-        "name": module.params["name"]
-    }
+    wished_container_namespace = {"project_id": module.params["project_id"], "name": module.params["name"]}
 
     api = Scaleway(module=module)
-    api.api_path = "registry/v1/regions/%s/namespaces" % region
+    api.api_path = f"registry/v1/regions/{region}/namespaces"
 
     summary = info_strategy(api=api, wished_cn=wished_container_namespace)
 
@@ -123,11 +122,13 @@ def core(module):
 
 def main():
     argument_spec = scaleway_argument_spec()
-    argument_spec.update(dict(
-        project_id=dict(type='str', required=True),
-        region=dict(type='str', required=True, choices=SCALEWAY_REGIONS),
-        name=dict(type='str', required=True)
-    ))
+    argument_spec.update(
+        dict(
+            project_id=dict(type="str", required=True),
+            region=dict(type="str", required=True, choices=SCALEWAY_REGIONS),
+            name=dict(type="str", required=True),
+        )
+    )
     module = AnsibleModule(
         argument_spec=argument_spec,
         supports_check_mode=True,
@@ -136,5 +137,5 @@ def main():
     core(module)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
