@@ -1,5 +1,4 @@
 #!/usr/bin/python
-# -*- coding: utf-8 -*-
 #
 # Scaleway Serverless function info module
 #
@@ -7,9 +6,8 @@
 # GNU General Public License v3.0+ (see LICENSES/GPL-3.0-or-later.txt or https://www.gnu.org/licenses/gpl-3.0.txt)
 # SPDX-License-Identifier: GPL-3.0-or-later
 
-from __future__ import absolute_import, division, print_function
+from __future__ import annotations
 
-__metaclass__ = type
 
 DOCUMENTATION = r"""
 module: scaleway_function_info
@@ -93,7 +91,9 @@ function:
 """
 
 from ansible_collections.community.general.plugins.module_utils.scaleway import (
-    SCALEWAY_REGIONS, scaleway_argument_spec, Scaleway
+    SCALEWAY_REGIONS,
+    scaleway_argument_spec,
+    Scaleway,
 )
 from ansible.module_utils.basic import AnsibleModule
 
@@ -103,18 +103,15 @@ def info_strategy(api, wished_fn):
     fn_lookup = {fn["name"]: fn for fn in fn_list}
 
     if wished_fn["name"] not in fn_lookup:
-        msg = "Error during function lookup: Unable to find function named '%s' in namespace '%s'" % (wished_fn["name"],
-                                                                                                      wished_fn["namespace_id"])
+        msg = f"Error during function lookup: Unable to find function named '{wished_fn['name']}' in namespace '{wished_fn['namespace_id']}'"
 
         api.module.fail_json(msg=msg)
 
     target_fn = fn_lookup[wished_fn["name"]]
 
-    response = api.get(path=api.api_path + "/%s" % target_fn["id"])
+    response = api.get(path=f"{api.api_path}/{target_fn['id']}")
     if not response.ok:
-        msg = "Error during function lookup: %s: '%s' (%s)" % (response.info['msg'],
-                                                               response.json['message'],
-                                                               response.json)
+        msg = f"Error during function lookup: {response.info['msg']}: '{response.json['message']}' ({response.json})"
         api.module.fail_json(msg=msg)
 
     return response.json
@@ -122,13 +119,10 @@ def info_strategy(api, wished_fn):
 
 def core(module):
     region = module.params["region"]
-    wished_function = {
-        "namespace_id": module.params["namespace_id"],
-        "name": module.params["name"]
-    }
+    wished_function = {"namespace_id": module.params["namespace_id"], "name": module.params["name"]}
 
     api = Scaleway(module=module)
-    api.api_path = "functions/v1beta1/regions/%s/functions" % region
+    api.api_path = f"functions/v1beta1/regions/{region}/functions"
 
     summary = info_strategy(api=api, wished_fn=wished_function)
 
@@ -137,11 +131,13 @@ def core(module):
 
 def main():
     argument_spec = scaleway_argument_spec()
-    argument_spec.update(dict(
-        namespace_id=dict(type='str', required=True),
-        region=dict(type='str', required=True, choices=SCALEWAY_REGIONS),
-        name=dict(type='str', required=True)
-    ))
+    argument_spec.update(
+        dict(
+            namespace_id=dict(type="str", required=True),
+            region=dict(type="str", required=True, choices=SCALEWAY_REGIONS),
+            name=dict(type="str", required=True),
+        )
+    )
     module = AnsibleModule(
         argument_spec=argument_spec,
         supports_check_mode=True,
@@ -150,5 +146,5 @@ def main():
     core(module)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
