@@ -1,5 +1,4 @@
 #!/usr/bin/python
-# -*- coding: utf-8 -*-
 #
 # Scaleway IP management module
 #
@@ -7,33 +6,33 @@
 # GNU General Public License v3.0+ (see LICENSES/GPL-3.0-or-later.txt or https://www.gnu.org/licenses/gpl-3.0.txt)
 # SPDX-License-Identifier: GPL-3.0-or-later
 
-from __future__ import absolute_import, division, print_function
+from __future__ import annotations
 
-__metaclass__ = type
 
-DOCUMENTATION = '''
----
+DOCUMENTATION = r"""
 module: scaleway_ip
 short_description: Scaleway IP management module
 author: Remy Leone (@remyleone)
 description:
-    - This module manages IP on Scaleway account
-      U(https://developer.scaleway.com)
+  - This module manages IP on Scaleway account U(https://developer.scaleway.com).
 extends_documentation_fragment:
-    - community.general.scaleway
-    - community.general.attributes
+  - community.general.scaleway
+  - community.general.attributes
+  - community.general.scaleway.actiongroup_scaleway
 
 attributes:
   check_mode:
     support: full
   diff_mode:
     support: none
+  action_group:
+    version_added: 11.3.0
 
 options:
   state:
     type: str
     description:
-     - Indicate desired state of the IP.
+      - Indicate desired state of the IP.
     default: present
     choices:
       - present
@@ -42,42 +41,45 @@ options:
   organization:
     type: str
     description:
-      - Scaleway organization identifier
+      - Scaleway organization identifier.
     required: true
 
   region:
     type: str
     description:
-     - Scaleway region to use (for example par1).
+      - Scaleway region to use (for example par1).
     required: true
     choices:
       - ams1
       - EMEA-NL-EVS
+      - ams2
+      - ams3
       - par1
       - EMEA-FR-PAR1
       - par2
       - EMEA-FR-PAR2
+      - par3
       - waw1
       - EMEA-PL-WAW1
+      - waw2
+      - waw3
 
   id:
     type: str
     description:
-    - id of the Scaleway IP (UUID)
-
+      - ID of the Scaleway IP (UUID).
   server:
     type: str
     description:
-    - id of the server you want to attach an IP to.
-    - To unattach an IP don't specify this option
-
+      - ID of the server you want to attach an IP to.
+      - To unattach an IP do not specify this option.
   reverse:
     type: str
     description:
-    - Reverse to assign to the IP
-'''
+      - Reverse to assign to the IP.
+"""
 
-EXAMPLES = '''
+EXAMPLES = r"""
 - name: Create an IP
   community.general.scaleway_ip:
     organization: '{{ scw_org }}'
@@ -90,30 +92,35 @@ EXAMPLES = '''
     id: '{{ ip_creation_task.scaleway_ip.id }}'
     state: absent
     region: par1
-'''
+"""
 
-RETURN = '''
+RETURN = r"""
 data:
-    description: This is only present when I(state=present).
-    returned: when I(state=present)
-    type: dict
-    sample: {
+  description: This is only present when O(state=present).
+  returned: when O(state=present)
+  type: dict
+  sample:
+    {
       "ips": [
         {
-            "organization": "951df375-e094-4d26-97c1-ba548eeb9c42",
-            "reverse": null,
-            "id": "dd9e8df6-6775-4863-b517-e0b0ee3d7477",
-            "server": {
-                "id": "3f1568ca-b1a2-4e98-b6f7-31a0588157f1",
-                "name": "ansible_tuto-1"
-            },
-            "address": "212.47.232.136"
+          "organization": "951df375-e094-4d26-97c1-ba548eeb9c42",
+          "reverse": null,
+          "id": "dd9e8df6-6775-4863-b517-e0b0ee3d7477",
+          "server": {
+            "id": "3f1568ca-b1a2-4e98-b6f7-31a0588157f1",
+            "name": "ansible_tuto-1"
+          },
+          "address": "212.47.232.136"
         }
-    ]
+      ]
     }
-'''
+"""
 
-from ansible_collections.community.general.plugins.module_utils.scaleway import SCALEWAY_LOCATION, scaleway_argument_spec, Scaleway
+from ansible_collections.community.general.plugins.module_utils.scaleway import (
+    SCALEWAY_LOCATION,
+    scaleway_argument_spec,
+    Scaleway,
+)
 from ansible.module_utils.basic import AnsibleModule
 
 
@@ -145,24 +152,18 @@ def ip_attributes_should_be_changed(api, target_ip, wished_ip):
 
 
 def payload_from_wished_ip(wished_ip):
-    return dict(
-        (k, v)
-        for k, v in wished_ip.items()
-        if k != 'id' and v is not None
-    )
+    return {k: v for k, v in wished_ip.items() if k != "id" and v is not None}
 
 
 def present_strategy(api, wished_ip):
     changed = False
 
-    response = api.get('ips')
+    response = api.get("ips")
     if not response.ok:
-        api.module.fail_json(msg='Error getting IPs [{0}: {1}]'.format(
-            response.status_code, response.json['message']))
+        api.module.fail_json(msg=f"Error getting IPs [{response.status_code}: {response.json['message']}]")
 
     ips_list = response.json["ips"]
-    ip_lookup = dict((ip["id"], ip)
-                     for ip in ips_list)
+    ip_lookup = {ip["id"]: ip for ip in ips_list}
 
     if wished_ip["id"] not in ip_lookup.keys():
         changed = True
@@ -170,13 +171,10 @@ def present_strategy(api, wished_ip):
             return changed, {"status": "An IP would be created."}
 
         # Create IP
-        creation_response = api.post('/ips',
-                                     data=payload_from_wished_ip(wished_ip))
+        creation_response = api.post("/ips", data=payload_from_wished_ip(wished_ip))
 
         if not creation_response.ok:
-            msg = "Error during ip creation: %s: '%s' (%s)" % (creation_response.info['msg'],
-                                                               creation_response.json['message'],
-                                                               creation_response.json)
+            msg = f"Error during ip creation: {creation_response.info['msg']}: '{creation_response.json['message']}' ({creation_response.json})"
             api.module.fail_json(msg=msg)
         return changed, creation_response.json["ip"]
 
@@ -190,18 +188,18 @@ def present_strategy(api, wished_ip):
     if api.module.check_mode:
         return changed, {"status": "IP attributes would be changed."}
 
-    ip_patch_response = api.patch(path="ips/%s" % target_ip["id"],
-                                  data=patch_payload)
+    ip_patch_response = api.patch(path=f"ips/{target_ip['id']}", data=patch_payload)
 
     if not ip_patch_response.ok:
-        api.module.fail_json(msg='Error during IP attributes update: [{0}: {1}]'.format(
-            ip_patch_response.status_code, ip_patch_response.json['message']))
+        api.module.fail_json(
+            msg=f"Error during IP attributes update: [{ip_patch_response.status_code}: {ip_patch_response.json['message']}]"
+        )
 
     return changed, ip_patch_response.json["ip"]
 
 
 def absent_strategy(api, wished_ip):
-    response = api.get('ips')
+    response = api.get("ips")
     changed = False
 
     status_code = response.status_code
@@ -209,11 +207,9 @@ def absent_strategy(api, wished_ip):
     ips_list = ips_json["ips"]
 
     if not response.ok:
-        api.module.fail_json(msg='Error getting IPs [{0}: {1}]'.format(
-            status_code, response.json['message']))
+        api.module.fail_json(msg=f"Error getting IPs [{status_code}: {response.json['message']}]")
 
-    ip_lookup = dict((ip["id"], ip)
-                     for ip in ips_list)
+    ip_lookup = {ip["id"]: ip for ip in ips_list}
     if wished_ip["id"] not in ip_lookup.keys():
         return changed, {}
 
@@ -221,24 +217,23 @@ def absent_strategy(api, wished_ip):
     if api.module.check_mode:
         return changed, {"status": "IP would be destroyed"}
 
-    response = api.delete('/ips/' + wished_ip["id"])
+    response = api.delete(f"/ips/{wished_ip['id']}")
     if not response.ok:
-        api.module.fail_json(msg='Error deleting IP [{0}: {1}]'.format(
-            response.status_code, response.json))
+        api.module.fail_json(msg=f"Error deleting IP [{response.status_code}: {response.json}]")
 
     return changed, response.json
 
 
 def core(module):
     wished_ip = {
-        "organization": module.params['organization'],
+        "organization": module.params["organization"],
         "reverse": module.params["reverse"],
         "id": module.params["id"],
-        "server": module.params["server"]
+        "server": module.params["server"],
     }
 
     region = module.params["region"]
-    module.params['api_url'] = SCALEWAY_LOCATION[region]["api_endpoint"]
+    module.params["api_url"] = SCALEWAY_LOCATION[region]["api_endpoint"]
 
     api = Scaleway(module=module)
     if module.params["state"] == "absent":
@@ -250,14 +245,16 @@ def core(module):
 
 def main():
     argument_spec = scaleway_argument_spec()
-    argument_spec.update(dict(
-        state=dict(default='present', choices=['absent', 'present']),
-        organization=dict(required=True),
-        server=dict(),
-        reverse=dict(),
-        region=dict(required=True, choices=list(SCALEWAY_LOCATION.keys())),
-        id=dict()
-    ))
+    argument_spec.update(
+        dict(
+            state=dict(default="present", choices=["absent", "present"]),
+            organization=dict(required=True),
+            server=dict(),
+            reverse=dict(),
+            region=dict(required=True, choices=list(SCALEWAY_LOCATION.keys())),
+            id=dict(),
+        )
+    )
     module = AnsibleModule(
         argument_spec=argument_spec,
         supports_check_mode=True,
@@ -266,5 +263,5 @@ def main():
     core(module)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
