@@ -1,12 +1,10 @@
 #!/usr/bin/python
-# -*- coding: utf-8 -*-
 #
 # Copyright (c) 2018, Yanis Guenane <yanis+ansible@guenane.org>
 # GNU General Public License v3.0+ (see LICENSES/GPL-3.0-or-later.txt or https://www.gnu.org/licenses/gpl-3.0.txt)
 # SPDX-License-Identifier: GPL-3.0-or-later
 
-from __future__ import (absolute_import, division, print_function)
-__metaclass__ = type
+from __future__ import annotations
 
 DOCUMENTATION = r"""
 module: scaleway_snapshot_info
@@ -90,25 +88,26 @@ from ansible_collections.community.general.plugins.module_utils.scaleway import
     Scaleway,
     ScalewayException,
     scaleway_argument_spec,
-    SCALEWAY_LOCATION
+    SCALEWAY_LOCATION,
 )
 
 
 class ScalewaySnapshotInfo(Scaleway):
-
     def __init__(self, module):
-        super(ScalewaySnapshotInfo, self).__init__(module)
-        self.name = 'snapshots'
+        super().__init__(module)
+        self.name = "snapshots"
 
         region = module.params["region"]
-        self.module.params['api_url'] = SCALEWAY_LOCATION[region]["api_endpoint"]
+        self.module.params["api_url"] = SCALEWAY_LOCATION[region]["api_endpoint"]
 
 
 def main():
     argument_spec = scaleway_argument_spec()
-    argument_spec.update(dict(
-        region=dict(required=True, choices=list(SCALEWAY_LOCATION.keys())),
-    ))
+    argument_spec.update(
+        dict(
+            region=dict(required=True, choices=list(SCALEWAY_LOCATION.keys())),
+        )
+    )
 
     module = AnsibleModule(
         argument_spec=argument_spec,
@@ -116,12 +115,10 @@ def main():
     )
 
     try:
-        module.exit_json(
-            scaleway_snapshot_info=ScalewaySnapshotInfo(module).get_resources()
-        )
+        module.exit_json(scaleway_snapshot_info=ScalewaySnapshotInfo(module).get_resources())
     except ScalewayException as exc:
         module.fail_json(msg=exc.message)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
