@@ -1,18 +1,16 @@
-# -*- coding: utf-8 -*-
 # Copyright (c) 2020, Adam Migus <adam@migus.org>
 # GNU General Public License v3.0+ (see LICENSES/GPL-3.0-or-later.txt or https://www.gnu.org/licenses/gpl-3.0.txt)
 # SPDX-License-Identifier: GPL-3.0-or-later
 
 # Make coding more python3-ish
-from __future__ import absolute_import, division, print_function
+from __future__ import annotations
 
-__metaclass__ = type
-
-from ansible_collections.community.general.tests.unit.compat.unittest import TestCase
-from ansible_collections.community.general.tests.unit.compat.mock import (
+from unittest import TestCase
+from unittest.mock import (
     patch,
     MagicMock,
 )
+
 from ansible_collections.community.general.plugins.lookup import dsv
 from ansible.plugins.loader import lookup_loader
 
@@ -39,6 +37,10 @@ class TestLookupModule(TestCase):
             self.lookup.run(
                 ["/dummy"],
                 [],
-                **{"tenant": "dummy", "client_id": "dummy", "client_secret": "dummy", }
+                **{
+                    "tenant": "dummy",
+                    "client_id": "dummy",
+                    "client_secret": "dummy",
+                },
             ),
         )
