@@ -1,11 +1,8 @@
-# -*- coding: utf-8 -*-
-
 # Copyright (c) 2023, Zoran Krleza (zoran.krleza@true-north.hr)
 # GNU General Public License v3.0+ (see LICENSES/GPL-3.0-or-later.txt or https://www.gnu.org/licenses/gpl-3.0.txt)
 # SPDX-License-Identifier: GPL-3.0-or-later
 
-from __future__ import (absolute_import, division, print_function)
-__metaclass__ = type
+from __future__ import annotations
 
 import pytest
 import gitlab
@@ -17,7 +14,7 @@ PYTHON_GITLAB_MINIMAL_VERSION = (3, 1)
 
 
 def python_gitlab_version_match_requirement():
-    return tuple(map(int, gitlab.__version__.split('.'))) >= PYTHON_GITLAB_MINIMAL_VERSION
+    return tuple(map(int, gitlab.__version__.split("."))) >= PYTHON_GITLAB_MINIMAL_VERSION
 
 
 def _dummy(x):
@@ -28,17 +25,19 @@ def _dummy(x):
 
 pytestmark = []
 try:
-    from .gitlab import (GitlabModuleTestCase,
-                         resp_get_user,
-                         resp_get_group,
-                         resp_list_group_access_tokens,
-                         resp_create_group_access_tokens,
-                         resp_revoke_group_access_tokens)
+    from .gitlab import (
+        GitlabModuleTestCase,
+        resp_get_user,
+        resp_get_group,
+        resp_list_group_access_tokens,
+        resp_create_group_access_tokens,
+        resp_revoke_group_access_tokens,
+    )
 
 except ImportError:
     pytestmark.append(pytest.mark.skip("Could not load gitlab module required for testing"))
     # Need to set these to something so that we don't fail when parsing
-    GitlabModuleTestCase = object
+    GitlabModuleTestCase = object  # type: ignore
     resp_list_group_access_tokens = _dummy
     resp_create_group_access_tokens = _dummy
     resp_revoke_group_access_tokens = _dummy
@@ -56,9 +55,11 @@ except ImportError:
 class TestGitlabGroupAccessToken(GitlabModuleTestCase):
     @with_httmock(resp_get_user)
     def setUp(self):
-        super(TestGitlabGroupAccessToken, self).setUp()
+        super().setUp()
         if not python_gitlab_version_match_requirement():
-            self.skipTest("python-gitlab %s+ is needed for gitlab_group_access_token" % ",".join(map(str, PYTHON_GITLAB_MINIMAL_VERSION)))
+            self.skipTest(
+                f"python-gitlab {'.'.join(map(str, PYTHON_GITLAB_MINIMAL_VERSION))}+ is needed for gitlab_group_access_token"
+            )
 
         self.moduleUtil = GitLabGroupAccessToken(module=self.mock_module, gitlab_instance=self.gitlab_instance)
 
@@ -68,9 +69,33 @@ class TestGitlabGroupAccessToken(GitlabModuleTestCase):
         group = self.gitlab_instance.groups.get(1)
         self.assertIsNotNone(group)
 
-        rvalue = self.moduleUtil.find_access_token(group, "token1")
+        rvalue = self.moduleUtil.find_access_token(group, "test-token")
         self.assertEqual(rvalue, False)
         self.assertIsNotNone(self.moduleUtil.access_token_object)
+        self.assertEqual(self.moduleUtil.access_token_object.id, 691)
+        self.assertFalse(self.moduleUtil.access_token_object.revoked)
+
+    @with_httmock(resp_get_group)
+    @with_httmock(resp_list_group_access_tokens)
+    def test_find_access_token_old_format(self):
+        group = self.gitlab_instance.groups.get(1)
+        self.assertIsNotNone(group)
+
+        rvalue = self.moduleUtil.find_access_token(group, "test-token-no-revoked")
+        self.assertEqual(rvalue, False)
+        self.assertIsNotNone(self.moduleUtil.access_token_object)
+        self.assertEqual(self.moduleUtil.access_token_object.id, 695)
+        self.assertFalse(hasattr(self.moduleUtil.access_token_object, "revoked"))
+
+    @with_httmock(resp_get_group)
+    @with_httmock(resp_list_group_access_tokens)
+    def test_find_revoked_access_token(self):
+        group = self.gitlab_instance.groups.get(1)
+        self.assertIsNotNone(group)
+
+        rvalue = self.moduleUtil.find_access_token(group, "test-token-three")
+        self.assertEqual(rvalue, False)
+        self.assertIsNone(self.moduleUtil.access_token_object)
 
     @with_httmock(resp_get_group)
     @with_httmock(resp_list_group_access_tokens)
@@ -88,7 +113,9 @@ class TestGitlabGroupAccessToken(GitlabModuleTestCase):
         groups = self.gitlab_instance.groups.get(1)
         self.assertIsNotNone(groups)
 
-        rvalue = self.moduleUtil.create_access_token(groups, {'name': "tokenXYZ", 'scopes': ["api"], 'access_level': 20, 'expires_at': "2024-12-31"})
+        rvalue = self.moduleUtil.create_access_token(
+            groups, {"name": "tokenXYZ", "scopes": ["api"], "access_level": 20, "expires_at": "2024-12-31"}
+        )
         self.assertEqual(rvalue, True)
         self.assertIsNotNone(self.moduleUtil.access_token_object)
 
@@ -99,7 +126,7 @@ class TestGitlabGroupAccessToken(GitlabModuleTestCase):
         groups = self.gitlab_instance.groups.get(1)
         self.assertIsNotNone(groups)
 
-        rvalue = self.moduleUtil.find_access_token(groups, "token1")
+        rvalue = self.moduleUtil.find_access_token(groups, "test-token")
         self.assertEqual(rvalue, False)
         self.assertIsNotNone(self.moduleUtil.access_token_object)
 
