@@ -2,16 +2,13 @@
 # GNU General Public License v3.0+ (see LICENSES/GPL-3.0-or-later.txt or https://www.gnu.org/licenses/gpl-3.0.txt)
 # SPDX-License-Identifier: GPL-3.0-or-later
 
-from __future__ import absolute_import, division, print_function
+from __future__ import annotations
 
-__metaclass__ = type
-
-from ansible_collections.community.general.tests.unit.compat import unittest
+import unittest
 from ansible_collections.community.general.plugins.module_utils.homebrew import HomebrewValidate
 
 
 class TestHomebrewModule(unittest.TestCase):
-
     def setUp(self):
         self.brew_app_names = ["git-ssh", "awscli@1", "bash"]
 
