@@ -2,21 +2,28 @@
 # GNU General Public License v3.0+ (see LICENSES/GPL-3.0-or-later.txt or https://www.gnu.org/licenses/gpl-3.0.txt)
 # SPDX-License-Identifier: GPL-3.0-or-later
 
-from __future__ import (absolute_import, division, print_function)
-__metaclass__ = type
+from __future__ import annotations
 
 from io import BytesIO
+import json
+from collections import OrderedDict
+from collections.abc import Mapping
+from unittest.mock import (
+    MagicMock,
+    patch,
+)
 
 from ansible_collections.community.general.plugins.modules.jenkins_plugin import JenkinsPlugin
-from ansible.module_utils.common._collections_compat import Mapping
+from ansible.module_utils.urls import basic_auth_header
 
 
 def pass_function(*args, **kwargs):
     pass
 
 
-GITHUB_DATA = {"url": u'https://api.github.com/repos/ansible/ansible',
-               "response": b"""
+GITHUB_DATA = {
+    "url": "https://api.github.com/repos/ansible/ansible",
+    "response": b"""
 {
   "id": 3638964,
   "name": "ansible",
@@ -127,30 +134,25 @@ GITHUB_DATA = {"url": u'https://api.github.com/repos/ansible/ansible',
   "network_count": 8893,
   "subscribers_count": 1733
 }
-"""
-               }
+""",
+}
 
 
 def test__get_json_data(mocker):
     "test the json conversion of _get_url_data"
 
     timeout = 30
-    params = {
-        'url': GITHUB_DATA['url'],
-        'timeout': timeout
-    }
+    params = {"url": GITHUB_DATA["url"], "timeout": timeout}
     module = mocker.Mock()
     module.params = params
 
     JenkinsPlugin._csrf_enabled = pass_function
     JenkinsPlugin._get_installed_plugins = pass_function
     JenkinsPlugin._get_url_data = mocker.Mock()
-    JenkinsPlugin._get_url_data.return_value = BytesIO(GITHUB_DATA['response'])
+    JenkinsPlugin._get_url_data.return_value = BytesIO(GITHUB_DATA["response"])
     jenkins_plugin = JenkinsPlugin(module)
 
-    json_data = jenkins_plugin._get_json_data(
-        "{url}".format(url=GITHUB_DATA['url']),
-        'CSRF')
+    json_data = jenkins_plugin._get_json_data(f"{GITHUB_DATA['url']}", "CSRF")
 
     assert isinstance(json_data, Mapping)
 
@@ -185,8 +187,102 @@ def test__new_fallback_urls(mocker):
 
 
 def isInList(l, i):
-    print("checking if %s in %s" % (i, l))
-    for item in l:
-        if item == i:
-            return True
-    return False
+    print(f"checking if {i} in {l}")
+    return any(item == i for item in l)  # TODO: check if return `i in l` works
+
+
+@patch("ansible_collections.community.general.plugins.modules.jenkins_plugin.fetch_url")
+def test__get_latest_compatible_plugin_version(fetch_mock, mocker):
+    "test the latest compatible plugin version retrieval"
+
+    params = {
+        "url": "http://fake.jenkins.server",
+        "timeout": 30,
+        "name": "git",
+        "version": "latest",
+        "updates_url": ["https://some.base.url"],
+        "plugin_versions_url_segment": ["plugin-versions.json"],
+        "latest_plugins_url_segments": ["test_latest"],
+        "jenkins_home": "/var/lib/jenkins",
+    }
+    module = mocker.Mock()
+    module.params = params
+
+    jenkins_info = {"x-jenkins": "2.263.1"}
+    jenkins_response = MagicMock()
+    jenkins_response.read.return_value = b"{}"
+
+    plugin_data = {
+        "plugins": {
+            "git": OrderedDict(
+                [
+                    ("4.8.2", {"requiredCore": "2.263.1"}),
+                    ("4.8.3", {"requiredCore": "2.263.1"}),
+                    ("4.9.0", {"requiredCore": "2.289.1"}),
+                    ("4.9.1", {"requiredCore": "2.289.1"}),
+                ]
+            )
+        }
+    }
+    plugin_versions_response = MagicMock()
+    plugin_versions_response.read.return_value = json.dumps(plugin_data).encode("utf-8")
+    plugin_versions_info = {"status": 200}
+
+    def fetch_url_side_effect(module, url, **kwargs):
+        if "plugin-versions.json" in url:
+            return (plugin_versions_response, plugin_versions_info)
+        else:
+            return (jenkins_response, jenkins_info)
+
+    fetch_mock.side_effect = fetch_url_side_effect
+
+    JenkinsPlugin._csrf_enabled = lambda self: False
+    JenkinsPlugin._get_installed_plugins = lambda self: None
+
+    jenkins_plugin = JenkinsPlugin(module)
+    latest_version = jenkins_plugin._get_latest_compatible_plugin_version()
+    assert latest_version == "4.8.3"
+
+
+@patch("ansible_collections.community.general.plugins.modules.jenkins_plugin.fetch_url")
+def test__get_urls_data_sets_correct_headers(fetch_mock, mocker):
+    params = {
+        "url": "http://jenkins.example.com",
+        "timeout": 30,
+        "name": "git",
+        "jenkins_home": "/var/lib/jenkins",
+        "updates_url": ["http://updates.example.com"],
+        "latest_plugins_url_segments": ["latest"],
+        "update_json_url_segment": ["update-center.json"],
+        "versioned_plugins_url_segments": ["plugins"],
+        "url_username": "jenkins_user",
+        "url_password": "jenkins_pass",
+        "updates_url_username": "update_user",
+        "updates_url_password": "update_pass",
+    }
+    module = mocker.Mock()
+    module.params = params
+
+    dummy_response = MagicMock()
+    fetch_mock.return_value = (dummy_response, {"status": 200})
+
+    JenkinsPlugin._csrf_enabled = lambda self: False
+    JenkinsPlugin._get_installed_plugins = lambda self: None
+
+    jp = JenkinsPlugin(module)
+
+    update_url = "http://updates.example.com/plugin-versions.json"
+    jp._get_urls_data([update_url])
+
+    jenkins_url = "http://jenkins.example.com/some-endpoint"
+    jp._get_urls_data([jenkins_url])
+
+    calls = fetch_mock.call_args_list
+
+    dummy, kwargs_2 = calls[1]
+    jenkins_auth = basic_auth_header("jenkins_user", "jenkins_pass")
+    assert kwargs_2["headers"]["Authorization"] == jenkins_auth
+
+    dummy, kwargs_1 = calls[0]
+    updates_auth = basic_auth_header("update_user", "update_pass")
+    assert kwargs_1["headers"]["Authorization"] == updates_auth
