@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # Author: Dexter Le (dextersydney2001@gmail.com)
 # Largely adapted from test_redhat_subscription by
 # Jiri Hnidek (jhnidek@redhat.com)
@@ -9,8 +8,7 @@
 # GNU General Public License v3.0+ (see LICENSES/GPL-3.0-or-later.txt or https://www.gnu.org/licenses/gpl-3.0.txt)
 # SPDX-License-Identifier: GPL-3.0-or-later
 
-from __future__ import (absolute_import, division, print_function)
-__metaclass__ = type
+from __future__ import annotations
 
 
 from ansible_collections.community.general.plugins.modules import pacemaker_stonith
