@@ -76,7 +76,6 @@ EXAMPLES = r"""
 RETURN = r"""#"""
 
 from ansible.module_utils.basic import AnsibleModule
-from ansible.module_utils.six.moves.urllib.parse import urlencode
 
 from ansible_collections.community.hrobot.plugins.module_utils.robot import (
     BASE_URL,
@@ -84,6 +83,12 @@ from ansible_collections.community.hrobot.plugins.module_utils.robot import (
     fetch_url_json,
 )
 
+try:
+    from urllib.parse import urlencode
+except ImportError:
+    # Python 2.x fallback:
+    from urllib import urlencode
+
 
 def main():
     argument_spec = dict(
