@@ -17,9 +17,8 @@ from datetime import timedelta, datetime
 from decimal import Decimal
 from os import environ
 
-from ansible.module_utils._text import to_native
+from ansible.module_utils.common.text.converters import to_native
 from ansible.module_utils.basic import missing_required_lib
-from ansible.module_utils.six import iteritems
 from ansible_collections.community.postgresql.plugins.module_utils.version import \
     LooseVersion
 
@@ -81,15 +80,39 @@ def postgres_common_argument_spec():
     return dict(
         login_user=dict(
             default='postgres' if not env_vars.get("PGUSER") else env_vars.get("PGUSER"),
-            aliases=['login']
+            aliases=['login'], deprecated_aliases=[
+                {
+                    'name': 'login',
+                    'version': '5.0.0',
+                    'collection_name': 'community.postgresql',
+                }
+            ],
         ),
         login_password=dict(default='', no_log=True),
-        login_host=dict(default='', aliases=['host']),
-        login_unix_socket=dict(default='', aliases=['unix_socket']),
-        port=dict(
+        login_host=dict(default='', aliases=['host'], deprecated_aliases=[
+            {
+                'name': 'host',
+                'version': '5.0.0',
+                'collection_name': 'community.postgresql',
+            }],
+        ),
+        login_unix_socket=dict(default='', aliases=['unix_socket'], deprecated_aliases=[
+            {
+                'name': 'unix_socket',
+                'version': '5.0.0',
+                'collection_name': 'community.postgresql',
+            }],
+        ),
+        login_port=dict(
             type='int',
             default=int(env_vars.get("PGPORT", 5432)),
-            aliases=['login_port']
+            aliases=['port'], deprecated_aliases=[
+                {
+                    'name': 'port',
+                    'version': '5.0.0',
+                    'collection_name': 'community.postgresql',
+                }
+            ],
         ),
         ssl_mode=dict(
             default='prefer',
@@ -268,7 +291,7 @@ def get_conn_params(module, params_dict, warn_db_default=True):
         "login_host": "host",
         "login_user": "user",
         "login_password": "password",
-        "port": "port",
+        "login_port": "port",
         "ssl_mode": "sslmode",
         "ca_cert": "sslrootcert",
         "ssl_cert": "sslcert",
@@ -299,7 +322,7 @@ def get_conn_params(module, params_dict, warn_db_default=True):
                 module.warn('Database name has not been passed, '
                             'used default database to connect to.')
 
-    kw = dict((params_map[k], v) for (k, v) in iteritems(params_dict)
+    kw = dict((params_map[k], v) for (k, v) in params_dict.items()
               if k in params_map and v != '' and v is not None)
 
     # If a login_unix_socket is specified, incorporate it here.
@@ -481,7 +504,7 @@ def convert_elements_to_pg_arrays(obj):
         obj (dict or list): Object with converted elements.
     """
     if isinstance(obj, dict):
-        for (key, elem) in iteritems(obj):
+        for (key, elem) in obj.items():
             if isinstance(elem, list):
                 obj[key] = list_to_pg_array(elem)
 
