@@ -63,11 +63,14 @@ options:
       - interface bridge settings
       - interface bridge vlan
       - interface detect-internet
+      - interface dot1x client
+      - interface dot1x server
       - interface eoip
       - interface ethernet
       - interface ethernet poe
       - interface ethernet switch
       - interface ethernet switch port
+      - interface ethernet switch port-isolation
       - interface gre
       - interface gre6
       - interface l2tp-client
@@ -136,6 +139,7 @@ options:
       - ip dhcp-server option sets
       - ip dns
       - ip dns adlist
+      - ip dns forwarders
       - ip dns static
       - ip firewall address-list
       - ip firewall connection tracking
@@ -145,8 +149,15 @@ options:
       - ip firewall nat
       - ip firewall raw
       - ip firewall service-port
+      - ip hotspot
+      - ip hotspot profile
       - ip hotspot service-port
+      - ip hotspot user
+      - ip hotspot user profile
+      - ip hotspot walled-garden
+      - ip hotspot walled-garden ip
       - ip ipsec identity
+      - ip ipsec mode-config
       - ip ipsec peer
       - ip ipsec policy
       - ip ipsec profile
@@ -201,6 +212,7 @@ options:
       - queue type
       - radius
       - radius incoming
+      - routing bfd configuration
       - routing bgp aggregate
       - routing bgp connection
       - routing bgp instance
@@ -323,6 +335,7 @@ seealso:
 """
 
 EXAMPLES = r"""
+---
 - name: Get IP addresses
   community.routeros.api_info:
     hostname: "{{ hostname }}"
