@@ -1,83 +1,78 @@
-# -*- coding: utf-8 -*-
-
 # Copyright (c) 2021, Felix Fontein <felix@fontein.de>
 # GNU General Public License v3.0+ (see LICENSES/GPL-3.0-or-later.txt or https://www.gnu.org/licenses/gpl-3.0.txt)
 # SPDX-License-Identifier: GPL-3.0-or-later
 
-from __future__ import absolute_import, division, print_function
-__metaclass__ = type
+from __future__ import annotations
 
-DOCUMENTATION = '''
+DOCUMENTATION = r"""
 name: decrpyt
 short_description: Decrypt SOPS-encrypted data
 version_added: 1.1.0
 author:
-    - Felix Fontein (@felixfontein)
+  - Felix Fontein (@felixfontein)
 description:
-    - Decrypt SOPS-encrypted data.
-    - Allows to decrypt data that has been provided by an arbitrary source.
-    - Note that due to Ansible lazy-evaluating expressions, it is better to use M(ansible.builtin.set_fact)
-      to store the result of an evaluation in a fact to avoid recomputing the value every time the expression
-      is used.
+  - Decrypt SOPS-encrypted data.
+  - Allows to decrypt data that has been provided by an arbitrary source.
+  - Note that due to Ansible lazy-evaluating expressions, it is better to use M(ansible.builtin.set_fact) to store the result
+    of an evaluation in a fact to avoid recomputing the value every time the expression is used.
 options:
-    _input:
-        description:
-            - The data to decrypt.
-        type: string
-        required: true
-    rstrip:
-        description:
-            - Whether to remove trailing newlines and spaces.
-        type: bool
-        default: true
-    input_type:
-        description:
-            - Tell SOPS how to interpret the encrypted data.
-            - There is no auto-detection since we do not have a filename. By default
-              SOPS is told to treat the input as YAML. If that is wrong, please set this
-              option to the correct value.
-            - The value V(ini) is available since community.sops 1.9.0.
-        type: str
-        choices:
-            - binary
-            - json
-            - yaml
-            - dotenv
-            - ini
-        default: yaml
-    output_type:
-        description:
-            - Tell SOPS how to interpret the decrypted file.
-            - Please note that the output is always text or bytes, depending on the value of O(decode_output).
-              To parse the resulting JSON or YAML, use corresponding filters such as P(ansible.builtin.from_json#filter)
-              and P(ansible.builtin.from_yaml#filter).
-            - The value V(ini) is available since community.sops 1.9.0.
-        type: str
-        choices:
-            - binary
-            - json
-            - yaml
-            - dotenv
-            - ini
-        default: yaml
-    decode_output:
-        description:
-            - Whether to decode the output to bytes.
-            - When O(output_type=binary), and the file isn't known to contain UTF-8 encoded text,
-              this should better be set to V(false) to prevent mangling the data with UTF-8 decoding.
-        type: bool
-        default: true
+  _input:
+    description:
+      - The data to decrypt.
+    type: string
+    required: true
+  rstrip:
+    description:
+      - Whether to remove trailing newlines and spaces.
+    type: bool
+    default: true
+  input_type:
+    description:
+      - Tell SOPS how to interpret the encrypted data.
+      - There is no auto-detection since we do not have a filename. By default SOPS is told to treat the input as YAML. If
+        that is wrong, please set this option to the correct value.
+      - The value V(ini) is available since community.sops 1.9.0.
+    type: str
+    choices:
+      - binary
+      - json
+      - yaml
+      - dotenv
+      - ini
+    default: yaml
+  output_type:
+    description:
+      - Tell SOPS how to interpret the decrypted file.
+      - Please note that the output is always text or bytes, depending on the value of O(decode_output). To parse the resulting
+        JSON or YAML, use corresponding filters such as P(ansible.builtin.from_json#filter) and P(ansible.builtin.from_yaml#filter).
+      - The value V(ini) is available since community.sops 1.9.0.
+    type: str
+    choices:
+      - binary
+      - json
+      - yaml
+      - dotenv
+      - ini
+    default: yaml
+  decode_output:
+    description:
+      - Whether to decode the output to bytes.
+      - When O(output_type=binary), and the file is not known to contain UTF-8 encoded text, this should better be set to
+        V(false) to prevent mangling the data with UTF-8 decoding.
+    type: bool
+    default: true
 extends_documentation_fragment:
-    - community.sops.sops
+  - community.sops.sops
 seealso:
-    - plugin: community.sops.sops
-      plugin_type: lookup
-    - plugin: community.sops.sops
-      plugin_type: vars
-    - module: community.sops.load_vars
-'''
+  - plugin: community.sops.sops
+    plugin_type: lookup
+  - plugin: community.sops.sops
+    plugin_type: vars
+  - module: community.sops.load_vars
+"""
 
-EXAMPLES = '''
+EXAMPLES = r"""
+---
 - name: Decrypt file fetched from URL
   hosts: localhost
   gather_facts: false
@@ -99,14 +94,14 @@ EXAMPLES = '''
     - name: Show decrypted data
       debug:
         msg: "{{ decrypted_data }}"
-'''
+"""
 
-RETURN = '''
+RETURN = r"""
 _value:
-    description:
-        - Decrypted data as text (O(decode_output=true), default) or binary string (O(decode_output=false)).
-    type: string
-'''
+  description:
+    - Decrypted data as text (O(decode_output=true), default) or binary string (O(decode_output=false)).
+  type: string
+"""
 
 from ansible.errors import AnsibleFilterError
 from ansible.module_utils.common.text.converters import to_bytes, to_native
@@ -120,7 +115,7 @@ _VALID_TYPES = set(['binary', 'json', 'yaml', 'dotenv', 'ini'])
 
 def decrypt_filter(data, input_type='yaml', output_type='yaml', sops_binary='sops', rstrip=True, decode_output=True,
                    aws_profile=None, aws_access_key_id=None, aws_secret_access_key=None, aws_session_token=None,
-                   config_path=None, enable_local_keyservice=False, keyservice=None, age_key=None, age_keyfile=None):
+                   config_path=None, enable_local_keyservice=True, keyservice=None, age_key=None, age_keyfile=None, age_ssh_private_keyfile=None):
     '''Decrypt sops-encrypted data.'''
 
     # Check parameters
@@ -139,6 +134,8 @@ def decrypt_filter(data, input_type='yaml', output_type='yaml', sops_binary='sop
             return age_key
         if argument_name == 'age_keyfile':
             return age_keyfile
+        if argument_name == 'age_ssh_private_keyfile':
+            return age_ssh_private_keyfile
         if argument_name == 'aws_profile':
             return aws_profile
         if argument_name == 'aws_access_key_id':
@@ -167,7 +164,7 @@ def decrypt_filter(data, input_type='yaml', output_type='yaml', sops_binary='sop
     return output
 
 
-class FilterModule(object):
+class FilterModule:
     '''Ansible jinja2 filters'''
 
     def filters(self):
