@@ -1,11 +1,8 @@
-# -*- coding: utf-8 -*-
-#
 # Copyright (c) 2018 Edoardo Tenani <e.tenani@arduino.cc> (@endorama)
 # GNU General Public License v3.0+ (see LICENSES/GPL-3.0-or-later.txt or https://www.gnu.org/licenses/gpl-3.0.txt)
 # SPDX-License-Identifier: GPL-3.0-or-later
 
-from __future__ import (absolute_import, division, print_function)
-__metaclass__ = type
+from __future__ import annotations
 
 DOCUMENTATION = r"""
 name: sops
@@ -104,22 +101,43 @@ seealso:
 """
 
 import os
+from collections.abc import Sequence, Mapping
+
 from ansible.errors import AnsibleParserError
-from ansible.module_utils.common.text.converters import to_bytes, to_native, to_text
-from ansible.plugins.vars import BaseVarsPlugin
 from ansible.inventory.host import Host
 from ansible.inventory.group import Group
+from ansible.module_utils.common.text.converters import to_bytes, to_native, to_text
+from ansible.plugins.vars import BaseVarsPlugin
+from ansible.utils.display import Display
 from ansible.utils.vars import combine_vars
 from ansible_collections.community.sops.plugins.module_utils.sops import Sops, SopsError
 
-from ansible.utils.display import Display
-display = Display()
+try:
+    from ansible.template import trust_as_template as _trust_as_template
+    HAS_DATATAGGING = True
+except ImportError:
+    HAS_DATATAGGING = False
 
 
+display = Display()
+
 FOUND = {}
 DECRYPTED = {}
 
 
+def _make_safe(value):
+    if isinstance(value, str):
+        # must come *before* Sequence, as strings are also instances of Sequence
+        if HAS_DATATAGGING and isinstance(value, str):
+            return _trust_as_template(value)
+        return value
+    if isinstance(value, Sequence):
+        return [_make_safe(v) for v in value]
+    if isinstance(value, Mapping):
+        return dict((k, _make_safe(v)) for k, v in value.items())
+    return value
+
+
 class VarsModule(BaseVarsPlugin):
 
     def get_vars(self, loader, path, entities, cache=None):
@@ -128,7 +146,7 @@ class VarsModule(BaseVarsPlugin):
         if not isinstance(entities, list):
             entities = [entities]
 
-        super(VarsModule, self).get_vars(loader, path, entities)
+        super().get_vars(loader, path, entities)
 
         def get_option_value(argument_name):
             return self.get_option(argument_name)
@@ -214,7 +232,7 @@ class VarsModule(BaseVarsPlugin):
                                     continue
                                 raise
                             DECRYPTED[found] = file_content
-                        new_data = loader.load(file_content)
+                        new_data = _make_safe(loader.load(file_content))
                         if new_data:  # ignore empty files
                             data = combine_vars(data, new_data)
 
