@@ -107,7 +107,7 @@ options:
         description: The absolute file path of KMS signed CSR downloaded from O(make_kms_trust_vc.download_client_csr).
         type: path
 extends_documentation_fragment:
-- community.vmware.vmware.documentation
+- vmware.vmware.base_options
 '''
 
 EXAMPLES = r'''
@@ -185,9 +185,9 @@ except ImportError:
 
 import os
 from ansible.module_utils.basic import AnsibleModule
-from ansible.module_utils._text import to_native
+from ansible.module_utils.common.text.converters import to_native
 from ansible_collections.community.vmware.plugins.module_utils.vmware import PyVmomi
-from ansible_collections.community.vmware.plugins.module_utils._argument_spec import base_argument_spec
+from ansible_collections.vmware.vmware.plugins.module_utils.argument_spec import base_argument_spec
 
 
 class PyVmomiHelper(PyVmomi):
