@@ -17,7 +17,6 @@ short_description: Manage VMware categories
 description:
 - This module can be used to create / delete / update VMware categories.
 - Tag feature is introduced in vSphere 6 version, so this module is not supported in the earlier versions of vSphere.
-- All variables and VMware object names are case sensitive.
 author:
 - Abhijeet Kasurde (@Akasurde)
 requirements:
@@ -88,7 +87,8 @@ options:
       type: list
       elements: str
 extends_documentation_fragment:
-- community.vmware.vmware_rest_client.documentation
+- vmware.vmware.base_options
+- vmware.vmware.additional_rest_options
 
 '''
 
@@ -153,11 +153,10 @@ category_results:
     }
 '''
 
-from ansible.module_utils._text import to_native
+from ansible.module_utils.common.text.converters import to_native
 from ansible.module_utils.basic import AnsibleModule
-from ansible.module_utils.compat.version import LooseVersion
-from ansible_collections.community.vmware.plugins.module_utils.vmware import connect_to_api
 from ansible_collections.community.vmware.plugins.module_utils.vmware_rest_client import VmwareRestClient
+from ansible_collections.vmware.vmware.plugins.module_utils.argument_spec import rest_compatible_argument_spec
 
 try:
     from pyVmomi.VmomiSupport import XMLNS_VMODL_BASE
@@ -178,7 +177,6 @@ class VmwareCategory(VmwareRestClient):
         self.global_categories = dict()
         self.category_name = self.params.get('category_name')
         self.get_all_categories()
-        self.content = connect_to_api(self.module, return_si=False)
 
     def ensure_state(self):
         """Manage internal states of categories. """
@@ -237,9 +235,6 @@ class VmwareCategory(VmwareRestClient):
             for obj_type in associable_object_types:
                 lower_obj_type = obj_type.lower()
                 if lower_obj_type == 'all objects':
-                    if LooseVersion(self.content.about.version) < LooseVersion('7'):
-                        break
-
                     for category in list(associable_data.values()):
                         if isinstance(category, list):
                             obj_types_set.extend(category)
@@ -355,7 +350,7 @@ class VmwareCategory(VmwareRestClient):
 
 
 def main():
-    argument_spec = VmwareRestClient.vmware_client_argument_spec()
+    argument_spec = rest_compatible_argument_spec()
     argument_spec.update(
         category_name=dict(type='str', required=True),
         category_description=dict(type='str', default='', required=False),
