@@ -46,7 +46,7 @@ options:
       required: false
       type: str
 extends_documentation_fragment:
-- community.vmware.vmware.documentation
+- vmware.vmware.base_options
 
 '''
 
@@ -109,7 +109,7 @@ from ansible_collections.community.vmware.plugins.module_utils.vmware import (
     wait_for_task,
     find_cluster_by_name,
     get_all_objs)
-from ansible_collections.community.vmware.plugins.module_utils._argument_spec import base_argument_spec
+from ansible_collections.vmware.vmware.plugins.module_utils.argument_spec import base_argument_spec
 from ansible.module_utils.common.text.converters import to_native
 
 
