@@ -36,14 +36,12 @@ options:
         - Cluster to deploy to.
         - This is a required parameter, if O(esxi_hostname) is not set and O(hostname) is set to the vCenter server.
         - O(esxi_hostname) and O(cluster) are mutually exclusive parameters.
-        - This parameter is case sensitive.
         type: str
     esxi_hostname:
         description:
         - The ESXi hostname where the virtual machine will run.
         - This is a required parameter, if O(cluster) is not set and O(hostname) is set to the vCenter server.
         - O(esxi_hostname) and O(cluster) are mutually exclusive parameters.
-        - This parameter is case sensitive.
         type: str
     datastore:
         default: datastore1
@@ -153,7 +151,7 @@ options:
         - This requires vmware-tools (vmtoolsd) to properly work after creation.
         type: bool
 extends_documentation_fragment:
-- community.vmware.vmware.documentation
+- vmware.vmware.base_options
 
 '''
 
@@ -222,20 +220,19 @@ import xml.etree.ElementTree as ET
 
 from threading import Thread
 
-from ansible.module_utils._text import to_native
+from ansible.module_utils.common.text.converters import to_native
 from ansible.module_utils.basic import AnsibleModule
-from ansible.module_utils.six import string_types
-from ansible.module_utils.six.moves.urllib.request import Request, urlopen
+from urllib.request import Request, urlopen
 from ansible.module_utils.urls import generic_urlparse, open_url, urlparse, urlunparse
 from ansible_collections.community.vmware.plugins.module_utils.vmware import (
     find_all_networks_by_name,
     find_vm_by_name,
     PyVmomi,
     gather_vm_facts,
-    vmware_argument_spec,
     wait_for_task,
     wait_for_vm_ip,
     set_vm_power_state)
+from ansible_collections.vmware.vmware.plugins.module_utils.argument_spec import base_argument_spec
 try:
     from ansible_collections.community.vmware.plugins.module_utils.vmware import vim
     from pyVmomi import vmodl
@@ -244,7 +241,7 @@ except ImportError:
 
 
 def path_exists(value):
-    if not isinstance(value, string_types):
+    if not isinstance(value, str):
         value = str(value)
     value = os.path.expanduser(os.path.expandvars(value))
     if not os.path.exists(value):
@@ -259,7 +256,6 @@ class WebHandle(object):
         self.ssl_context = None
 
         self.parsed_url = self._parse_url(url)
-
         self.https = self.parsed_url.group('scheme') == 'https://'
 
         if self.https:
@@ -269,17 +265,36 @@ class WebHandle(object):
 
             self.thumbprint = self._get_thumbprint(
                 self.parsed_url.group('hostname'))
-            r = urlopen(url=url, context=self.ssl_context)
+            r = urlopen(Request(url, method="HEAD"), context=self.ssl_context)
         else:
-            r = urlopen(url)
+            r = urlopen(Request(url, method="HEAD"))
+
         if r.code != 200:
             raise FileNotFoundError(url)
         self.headers = self._headers_to_dict(r)
-        if 'accept-ranges' not in self.headers:
-            raise Exception("Site does not accept ranges")
+
+        if 'content-length' not in self.headers:
+            raise Exception("Missing content-length in response")
         self.st_size = int(self.headers['content-length'])
+
+        # Perform a real range test instead of checking 'accept-ranges'
+        if not self._supports_range_request():
+            raise Exception("Site does not support range requests (no valid response to Range header)")
+
         self.offset = 0
 
+    def _supports_range_request(self):
+        req = Request(self.url)
+        req.add_header('Range', 'bytes=0-0')
+        try:
+            if self.ssl_context:
+                r = urlopen(req, context=self.ssl_context)
+            else:
+                r = urlopen(req)
+            return r.status == 206  # Partial Content
+        except Exception:
+            return False
+
     def _parse_url(self, url):
         HTTP_SCHEMA_PATTERN = (
             r"(?P<url>(?:(?P<scheme>[a-zA-Z]+:\/\/)?(?P<hostname>(?:[-a-zA-Z0-9@%_\+~#=]{1,256}\.){1,256}(?:[-a-zA-Z0-9@%_\+~#=]{1,256})))"
@@ -290,10 +305,8 @@ class WebHandle(object):
 
     def _get_thumbprint(self, hostname):
         pem = ssl.get_server_certificate((hostname, 443))
-        sha1 = hashlib.sha1(
-            ssl.PEM_cert_to_DER_cert(pem)).hexdigest().upper()
+        sha1 = hashlib.sha1(ssl.PEM_cert_to_DER_cert(pem)).hexdigest().upper()
         colon_notion = ':'.join(sha1[i:i + 2] for i in range(0, len(sha1), 2))
-
         return None if sha1 is None else colon_notion
 
     def _headers_to_dict(self, r):
@@ -814,7 +827,7 @@ class VMwareDeployOvf(PyVmomi):
 
 
 def main():
-    argument_spec = vmware_argument_spec()
+    argument_spec = base_argument_spec()
     argument_spec.update({
         'name': {},
         'datastore': {
