@@ -71,7 +71,7 @@ options:
                     - isolated
                 type: str
 extends_documentation_fragment:
-- community.vmware.vmware.documentation
+- vmware.vmware.base_options
 '''
 
 EXAMPLES = r'''
@@ -157,7 +157,7 @@ from ansible.module_utils.common.text.converters import to_native
 from ansible_collections.community.vmware.plugins.module_utils.vmware import (
     PyVmomi, TaskError, find_dvs_by_name, wait_for_task
 )
-from ansible_collections.community.vmware.plugins.module_utils._argument_spec import base_argument_spec
+from ansible_collections.vmware.vmware.plugins.module_utils.argument_spec import base_argument_spec
 
 
 class VMwareDvSwitchPvlans(PyVmomi):
