@@ -16,7 +16,6 @@ module: vmware_guest_controller
 short_description: Manage disk or USB controllers related to virtual machine in given vCenter infrastructure
 description:
     - This module can be used to add, remove disk controllers or USB controllers belonging to given virtual machine.
-    - All parameters and VMware object names are case sensitive.
 author:
     - Diane Wang (@Tomorrow9) <dianew@vmware.com>
 options:
@@ -70,8 +69,8 @@ options:
      suboptions:
        controller_number:
          description:
-         - Disk controller bus number. When O(controllers.state=absent), this parameter is required.
-         - When O(controllers.type=usb2) or O(controllers.type=usb3), this parameter is not required.
+         - Disk controller bus number. When O(controllers[].state=absent), this parameter is required.
+         - When O(controllers[].type=usb2) or O(controllers[].type=usb3), this parameter is not required.
          type: int
          choices:
            - 0
@@ -128,7 +127,7 @@ options:
      default: 10
      type: int
 extends_documentation_fragment:
-- community.vmware.vmware.documentation
+- vmware.vmware.base_options
 
 '''
 
@@ -246,8 +245,9 @@ except ImportError:
 
 import time
 from ansible.module_utils.basic import AnsibleModule
-from ansible.module_utils._text import to_native
-from ansible_collections.community.vmware.plugins.module_utils.vmware import PyVmomi, vmware_argument_spec, wait_for_task, TaskError
+from ansible.module_utils.common.text.converters import to_native
+from ansible_collections.community.vmware.plugins.module_utils.vmware import PyVmomi, wait_for_task, TaskError
+from ansible_collections.vmware.vmware.plugins.module_utils.argument_spec import base_argument_spec
 from ansible_collections.community.vmware.plugins.module_utils.vm_device_helper import PyVmomiDeviceHelper
 
 
@@ -345,7 +345,7 @@ class PyVmomiHelper(PyVmomi):
         for device in self.current_vm_obj.config.hardware.device:
             ctl_facts_dict = dict()
             if isinstance(device, tuple(self.controller_types.values())):
-                ctl_facts_dict[device.busNumber] = dict(
+                ctl_facts_dict[str(device.busNumber)] = dict(
                     controller_summary=device.deviceInfo.summary,
                     controller_label=device.deviceInfo.label,
                     controller_busnumber=device.busNumber,
@@ -355,7 +355,7 @@ class PyVmomiHelper(PyVmomi):
                     controller_disks_devicekey=device.device,
                 )
                 if hasattr(device, 'sharedBus'):
-                    ctl_facts_dict[device.busNumber]['controller_bus_sharing'] = device.sharedBus
+                    ctl_facts_dict[str(device.busNumber)]['controller_bus_sharing'] = device.sharedBus
                 if isinstance(device, tuple(self.device_helper.scsi_device_type.values())):
                     disk_ctl_facts['scsi'].update(ctl_facts_dict)
                 if isinstance(device, self.device_helper.nvme_device_type):
@@ -490,7 +490,7 @@ class PyVmomiHelper(PyVmomi):
 
 
 def main():
-    argument_spec = vmware_argument_spec()
+    argument_spec = base_argument_spec()
     argument_spec.update(
         name=dict(type='str'),
         uuid=dict(type='str'),
