@@ -17,24 +17,23 @@ module: vmware_guest_disk_info
 short_description: Gather info about disks of given virtual machine
 description:
     - This module can be used to gather information about disks belonging to given virtual machine.
-    - All parameters and VMware object names are case sensitive.
 author:
     - Abhijeet Kasurde (@Akasurde) <akasurde@redhat.com>
 options:
    name:
      description:
      - Name of the virtual machine.
-     - This is required parameter, if parameter C(uuid) or C(moid) is not supplied.
+     - This is required parameter, if parameter O(uuid) or O(moid) is not supplied.
      type: str
    uuid:
      description:
      - UUID of the instance to gather information if known, this is VMware's unique identifier.
-     - This is required parameter, if parameter C(name) or C(moid) is not supplied.
+     - This is required parameter, if parameter O(name) or O(moid) is not supplied.
      type: str
    moid:
      description:
      - Managed Object ID of the instance to manage if known, this is a unique identifier only within a single vCenter instance.
-     - This is required if C(name) or C(uuid) is not supplied.
+     - This is required if O(name) or O(uuid) is not supplied.
      type: str
    use_instance_uuid:
      description:
@@ -60,10 +59,10 @@ options:
    datacenter:
      description:
      - The datacenter name to which virtual machine belongs to.
-     required: True
+     required: true
      type: str
 extends_documentation_fragment:
-- community.vmware.vmware.documentation
+- vmware.vmware.base_options
 
 '''
 
@@ -148,13 +147,14 @@ guest_disk_info:
 '''
 
 from ansible.module_utils.basic import AnsibleModule
-from ansible.module_utils._text import to_text
-from ansible_collections.community.vmware.plugins.module_utils.vmware import PyVmomi, vmware_argument_spec
+from ansible.module_utils.common.text.converters import to_text
+from ansible_collections.community.vmware.plugins.module_utils.vmware import PyVmomi
+from ansible_collections.vmware.vmware.plugins.module_utils.argument_spec import base_argument_spec
 from ansible_collections.community.vmware.plugins.module_utils.vm_device_helper import PyVmomiDeviceHelper
 
 
 def main():
-    argument_spec = vmware_argument_spec()
+    argument_spec = base_argument_spec()
     argument_spec.update(
         name=dict(type='str'),
         uuid=dict(type='str'),
