@@ -154,7 +154,7 @@ options:
         version_added: '3.1.0'
 
 extends_documentation_fragment:
-- community.vmware.vmware.documentation
+- vmware.vmware.base_options
 
 '''
 
@@ -235,7 +235,7 @@ from ansible.module_utils.common.text.converters import to_bytes, to_native
 from ansible_collections.community.vmware.plugins.module_utils.vmware import (
     PyVmomi, find_cluster_by_name, find_datacenter_by_name,
     find_vm_by_id)
-from ansible_collections.community.vmware.plugins.module_utils._argument_spec import base_argument_spec
+from ansible_collections.vmware.vmware.plugins.module_utils.argument_spec import base_argument_spec
 
 
 class VmwareGuestFileManager(PyVmomi):
