@@ -15,7 +15,6 @@ module: vmware_host_lockdown
 short_description: Manage administrator permission for the local administrative account for the ESXi host
 description:
 - This module can be used to manage administrator permission for the local administrative account for the host when ESXi hostname is given.
-- All parameters and VMware objects values are case sensitive.
 - This module is destructive as administrator permission are managed using APIs used, please read options carefully and proceed.
 - Please specify O(hostname) as vCenter IP or hostname only, as lockdown operations are not possible from standalone ESXi server.
 author:
@@ -47,7 +46,7 @@ options:
     choices: [ disabled, normal, strict ]
     type: str
 extends_documentation_fragment:
-- community.vmware.vmware.documentation
+- vmware.vmware.base_options
 
 '''
 
@@ -120,13 +119,13 @@ results:
 
 try:
     from pyVmomi import vim
-    HAS_PYVMOMI = True
 except ImportError:
-    HAS_PYVMOMI = False
+    pass
 
 from ansible.module_utils.basic import AnsibleModule
-from ansible_collections.community.vmware.plugins.module_utils.vmware import vmware_argument_spec, PyVmomi
-from ansible.module_utils._text import to_native
+from ansible_collections.community.vmware.plugins.module_utils.vmware import PyVmomi
+from ansible_collections.vmware.vmware.plugins.module_utils.argument_spec import base_argument_spec
+from ansible.module_utils.common.text.converters import to_native
 
 
 class VmwareLockdownManager(PyVmomi):
@@ -182,7 +181,7 @@ class VmwareLockdownManager(PyVmomi):
 
 
 def main():
-    argument_spec = vmware_argument_spec()
+    argument_spec = base_argument_spec()
     argument_spec.update(
         cluster_name=dict(type='str', required=False),
         esxi_hostname=dict(type='list', required=False, elements='str'),
@@ -197,9 +196,6 @@ def main():
         ]
     )
 
-    if not HAS_PYVMOMI:
-        module.fail_json(msg='pyvmomi required for this module')
-
     vmware_lockdown_mgr = VmwareLockdownManager(module)
     vmware_lockdown_mgr.ensure()
 
