@@ -37,13 +37,13 @@ options:
   state:
     description:
       - The state of the health checks.
-      - If set to C(present), all given health checks will be silenced.
-      - If set to C(absent), all given health checks will be removed from the list of silent checks.
+      - If set to V(present), all given health checks will be silenced.
+      - If set to V(absent), all given health checks will be removed from the list of silent checks.
     default: 'present'
     choices: [ 'present', 'absent' ]
     type: str
 extends_documentation_fragment:
-  - community.vmware.vmware.documentation
+  - vmware.vmware.base_options
 '''
 
 EXAMPLES = r'''
@@ -84,7 +84,8 @@ except ImportError:
     HAS_VSANPYTHONSDK = False
 
 from ansible.module_utils.basic import AnsibleModule
-from ansible_collections.community.vmware.plugins.module_utils.vmware import PyVmomi, vmware_argument_spec
+from ansible_collections.community.vmware.plugins.module_utils.vmware import PyVmomi
+from ansible_collections.vmware.vmware.plugins.module_utils.argument_spec import base_argument_spec
 
 
 class VsanApi(PyVmomi):
@@ -127,7 +128,7 @@ class VsanApi(PyVmomi):
 
 
 def main():
-    argument_spec = vmware_argument_spec()
+    argument_spec = base_argument_spec()
 
     argument_spec.update(dict(
         checks=dict(type='list', elements='str', required=False),
