@@ -8,34 +8,23 @@ testinfra_hosts = testinfra.utils.ansible_runner.AnsibleRunner(
 ).get_hosts("all")
 
 
-@pytest.mark.parametrize(
-    "server, redhat, debian",
-    [
-        ("zabbix-server-pgsql", "zabbix-web-pgsql", "zabbix-frontend-php"),
-        ("zabbix-server-mysql", "zabbix-web-mysql", "zabbix-frontend-php"),
-    ],
-)
-def test_zabbix_package(host, server, redhat, debian):
-    host = host.backend.get_hostname()
-    host = host.replace("-centos7", "")
-    host = host.replace("-centos8", "")
-    host = host.replace("-debian", "")
-    host = host.replace("-ubuntu", "")
+def test_zabbix_package(host):
+    ansible_data = host.ansible.get_variables()
+    version = ansible_data['zabbix_web_version']
+    webserver = ansible_data['zabbix_web_http_server']
 
-    if host == server:
-        if host.system_info.distribution in ["debian", "ubuntu"]:
-            zabbix_web = host.package(debian)
-            assert zabbix_web.version.startswith("1:6.4")
-        elif host.system_info.distribution == "centos":
-            zabbix_web = host.package(redhat)
-            assert zabbix_web.version.startswith("6.4")
-        assert zabbix_web.is_installed
+    package_name = f'zabbix-{webserver}-conf'
+    if host.system_info.distribution == "opensuse-leap" and version == 7.0:
+        package_name = f'zabbix-{webserver}-conf-php8'
+    
+    zabbix_web = host.package(package_name)
+    assert str(version) in zabbix_web.version
 
 
 def test_zabbix_web(host):
     zabbix_web = host.file("/etc/zabbix/web/zabbix.conf.php")
     ansible_variables = host.ansible.get_variables()
-    zabbix_websrv = str(ansible_variables["zabbix_websrv"])
+    zabbix_websrv = str(ansible_variables["zabbix_web_http_server"])
 
     if host.system_info.distribution in ["debian", "ubuntu"]:
         assert zabbix_web.user == "www-data"
@@ -47,14 +36,26 @@ def test_zabbix_web(host):
         elif zabbix_websrv == "nginx":
             assert zabbix_web.user == "nginx"
             assert zabbix_web.group == "nginx"
+    elif host.system_info.distribution == "opensuse-leap":
+        if zabbix_websrv == "apache":
+            assert zabbix_web.user == "wwwrun"
+            assert zabbix_web.group == "wwwrun"
+        elif zabbix_websrv == "nginx":
+            assert zabbix_web.user == "nginx"
+            assert zabbix_web.group == "nginx"
     assert zabbix_web.mode == 0o640
 
 
 def test_zabbix_api(host):
     my_host = host.ansible.get_variables()
+    version = my_host['zabbix_web_version']
     zabbix_api_server_url = str(my_host["zabbix_api_server_url"])
     hostname = "http://" + zabbix_api_server_url + "/api_jsonrpc.php"
-    post_data = '{"jsonrpc": "2.0", "method": "user.login", "params": { "username": "Admin", "password": "zabbix" }, "id": 1, "auth": null}'
+    if version <= 7.0:
+        post_data = '{"jsonrpc": "2.0", "method": "user.login", "params": { "username": "Admin", "password": "zabbix" }, "id": 1, "auth": null}'
+    else:
+        post_data = '{"jsonrpc": "2.0", "method": "user.login", "params": { "username": "Admin", "password": "zabbix" }, "id": 1}'
+        
     headers = "Content-Type: application/json-rpc"
     command = (
         "curl -XPOST -H '"
