@@ -1,6 +1,6 @@
 #
 # -*- coding: utf-8 -*-
-# Copyright 2019 Red Hat
+# © Copyright 2025 Dell Inc. or its subsidiaries. All Rights Reserved.
 # GNU General Public License v3.0+
 # (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
 """
@@ -31,9 +31,17 @@ from ansible_collections.dellemc.enterprise_sonic.plugins.module_utils.network.s
     get_speed_from_breakout_mode,
     get_breakout_mode,
 )
+from ansible_collections.dellemc.enterprise_sonic.plugins.module_utils.network.sonic.utils.formatted_diff_utils import (
+    __DELETE_CONFIG_IF_NO_SUBCONFIG,
+    get_new_config,
+    get_formatted_config_diff
+)
 
 PATCH = 'patch'
 DELETE = 'delete'
+TEST_KEYS_generate_config = [
+    {'config': {'name': '', '__delete_op': __DELETE_CONFIG_IF_NO_SUBCONFIG}},
+]
 
 
 class Port_breakout(ConfigBase):
@@ -90,6 +98,20 @@ class Port_breakout(ConfigBase):
         if result['changed']:
             result['after'] = changed_port_breakout_facts
 
+        new_config = changed_port_breakout_facts
+        old_config = existing_port_breakout_facts
+        if self._module.check_mode:
+            result.pop('after', None)
+            new_config = get_new_config(commands, existing_port_breakout_facts,
+                                        TEST_KEYS_generate_config)
+            result['after(generated)'] = new_config
+
+        if self._module._diff:
+            new_config.sort(key=lambda x: x['name'])
+            old_config.sort(key=lambda x: x['name'])
+            result['diff'] = get_formatted_config_diff(old_config,
+                                                       new_config,
+                                                       self._module._verbosity)
         result['warnings'] = warnings
         return result
 
