@@ -1,6 +1,6 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
-# Copyright 2020 Dell Inc. or its subsidiaries. All Rights Reserved
+# Copyright 2025 Dell Inc. or its subsidiaries. All Rights Reserved.
 # GNU General Public License v3.0+
 # (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
 """
@@ -57,6 +57,7 @@ options:
       - interfaces
       - l2_interfaces
       - l3_interfaces
+      - ipv6_router_advertisement
       - lag_interfaces
       - bgp
       - bgp_af
@@ -65,18 +66,75 @@ options:
       - bgp_as_paths
       - bgp_communities
       - bgp_ext_communities
+      - ospfv2_interfaces
+      - ospfv2
+      - ospfv3
+      - ospfv3_area
+      - ospfv3_interfaces
       - mclag
       - prefix_lists
+      - vlan_mapping
       - vrfs
+      - vrrp
       - vxlans
       - users
       - system
       - port_breakout
+      - pms
       - aaa
+      - ldap
       - tacacs_server
       - radius_server
       - static_routes
       - ntp
+      - logging
+      - pki
+      - ip_neighbor
+      - ip_neighbor_interfaces
+      - port_group
+      - dhcp_relay
+      - acl_interfaces
+      - l2_acls
+      - l3_acls
+      - lldp_global
+      - ptp_default_ds
+      - mac
+      - bfd
+      - copp
+      - route_maps
+      - lldp_interfaces
+      - stp
+      - poe
+      - dhcp_snooping
+      - sflow
+      - fips
+      - roce
+      - qos_buffer
+      - qos_pfc
+      - qos_maps
+      - qos_scheduler
+      - qos_wred
+      - qos_interfaces
+      - pim_global
+      - pim_interfaces
+      - login_lockout
+      - mgmt_servers
+      - ospf_area
+      - ssh
+      - lst
+      - ptp_port_ds
+      - fbs_classifiers
+      - fbs_groups
+      - fbs_policies
+      - ars
+      - network_policy
+      - br_l2pt
+      - dcbx
+      - mirroring
+      - drop_counter
+      - evpn_esi_multihome
+      - ssh_server
+      - ecmp_load_share
 """
 
 EXAMPLES = """
