@@ -22,11 +22,8 @@ class TestSonicQosBufferModule(TestSonicModule):
         cls.mock_facts_edit_config = patch(
             "ansible_collections.dellemc.enterprise_sonic.plugins.module_utils.network.sonic.facts.qos_buffer.qos_buffer.edit_config"
         )
-        cls.mock_config_edit_config = patch(
-            "ansible_collections.dellemc.enterprise_sonic.plugins.module_utils.network.sonic.config.qos_buffer.qos_buffer.edit_config"
-        )
-        cls.mock_utils_edit_config = patch(
-            "ansible_collections.dellemc.enterprise_sonic.plugins.module_utils.network.sonic.utils.utils.edit_config"
+        cls.mock_config_edit_config_reboot = patch(
+            "ansible_collections.dellemc.enterprise_sonic.plugins.module_utils.network.sonic.config.qos_buffer.qos_buffer.edit_config_reboot"
         )
         cls.mock_get_interface_naming_mode = patch(
             "ansible_collections.dellemc.enterprise_sonic.plugins.module_utils.network.sonic.utils.utils.get_device_interface_naming_mode"
@@ -36,20 +33,17 @@ class TestSonicQosBufferModule(TestSonicModule):
     def setUp(self):
         super(TestSonicQosBufferModule, self).setUp()
         self.facts_edit_config = self.mock_facts_edit_config.start()
-        self.config_edit_config = self.mock_config_edit_config.start()
+        self.config_edit_config = self.mock_config_edit_config_reboot.start()
         self.facts_edit_config.side_effect = self.facts_side_effect
         self.config_edit_config.side_effect = self.config_side_effect
         self.get_interface_naming_mode = self.mock_get_interface_naming_mode.start()
         self.get_interface_naming_mode.return_value = 'native'
-        self.utils_edit_config = self.mock_utils_edit_config.start()
-        self.utils_edit_config.side_effect = self.config_side_effect
 
     def tearDown(self):
         super(TestSonicQosBufferModule, self).tearDown()
         self.mock_facts_edit_config.stop()
-        self.mock_config_edit_config.stop()
+        self.mock_config_edit_config_reboot.stop()
         self.mock_get_interface_naming_mode.stop()
-        self.mock_utils_edit_config.stop()
 
     def test_sonic_qos_buffer_merged_01(self):
         set_module_args(self.fixture_data['merged_01']['module_args'])
@@ -58,6 +52,20 @@ class TestSonicQosBufferModule(TestSonicModule):
         result = self.execute_module(changed=True)
         self.validate_config_requests()
 
+    def test_sonic_qos_buffer_merged_02(self):
+        set_module_args(self.fixture_data['merged_02']['module_args'])
+        self.initialize_facts_get_requests(self.fixture_data['merged_02']['existing_qos_buffer_config'])
+        self.initialize_config_requests(self.fixture_data['merged_02']['expected_config_requests'])
+        result = self.execute_module(changed=True)
+        self.validate_config_requests()
+
+    def test_sonic_qos_buffer_merged_03(self):
+        set_module_args(self.fixture_data['merged_03']['module_args'])
+        self.initialize_facts_get_requests(self.fixture_data['merged_03']['existing_qos_buffer_config'])
+        self.initialize_config_requests(self.fixture_data['merged_03']['expected_config_requests'])
+        result = self.execute_module(changed=True)
+        self.validate_config_requests()
+
     def test_sonic_qos_buffer_deleted_01(self):
         set_module_args(self.fixture_data['deleted_01']['module_args'])
         self.initialize_facts_get_requests(self.fixture_data['deleted_01']['existing_qos_buffer_config'])
