@@ -62,7 +62,7 @@ class TestSonicStpModule(TestSonicModule):
         set_module_args(self.fixture_data['merged_02']['module_args'])
         self.initialize_facts_get_requests(self.fixture_data['merged_02']['existing_stp_config'])
         self.initialize_config_requests(self.fixture_data['merged_02']['expected_config_requests'])
-        result = self.execute_module(changed=True)
+        result = self.execute_module(changed=False)
         self.validate_config_requests()
 
     def test_sonic_stp_merged_03(self):
@@ -72,6 +72,13 @@ class TestSonicStpModule(TestSonicModule):
         result = self.execute_module(changed=True)
         self.validate_config_requests()
 
+    def test_sonic_stp_merged_04(self):
+        set_module_args(self.fixture_data['merged_04']['module_args'])
+        self.initialize_facts_get_requests(self.fixture_data['merged_04']['existing_stp_config'])
+        self.initialize_config_requests(self.fixture_data['merged_04']['expected_config_requests'])
+        result = self.execute_module(changed=True)
+        self.validate_config_requests()
+
     def test_sonic_stp_replaced_01(self):
         set_module_args(self.fixture_data['replaced_01']['module_args'])
         self.initialize_facts_get_requests(self.fixture_data['replaced_01']['existing_stp_config'])
@@ -119,6 +126,13 @@ class TestSonicStpModule(TestSonicModule):
         result = self.execute_module(changed=True)
         self.validate_config_requests()
 
+    def test_sonic_stp_replaced_08(self):
+        set_module_args(self.fixture_data['replaced_08']['module_args'])
+        self.initialize_facts_get_requests(self.fixture_data['replaced_08']['existing_stp_config'])
+        self.initialize_config_requests(self.fixture_data['replaced_08']['expected_config_requests'])
+        result = self.execute_module(changed=False)
+        self.validate_config_requests()
+
     def test_sonic_stp_overridden_01(self):
         set_module_args(self.fixture_data['overridden_01']['module_args'])
         self.initialize_facts_get_requests(self.fixture_data['overridden_01']['existing_stp_config'])
@@ -126,6 +140,13 @@ class TestSonicStpModule(TestSonicModule):
         result = self.execute_module(changed=True)
         self.validate_config_requests()
 
+    def test_sonic_stp_overridden_02(self):
+        set_module_args(self.fixture_data['overridden_02']['module_args'])
+        self.initialize_facts_get_requests(self.fixture_data['overridden_02']['existing_stp_config'])
+        self.initialize_config_requests(self.fixture_data['overridden_02']['expected_config_requests'])
+        result = self.execute_module(changed=False)
+        self.validate_config_requests()
+
     def test_sonic_stp_deleted_01(self):
         set_module_args(self.fixture_data['deleted_01']['module_args'])
         self.initialize_facts_get_requests(self.fixture_data['deleted_01']['existing_stp_config'])
