@@ -2,9 +2,9 @@
 # -*- coding: utf-8 -*-
 
 #
-# Dell EMC OpenManage Ansible Modules
-# Version 5.0.1
-# Copyright (C) 2019-2022 Dell Inc. or its subsidiaries. All Rights Reserved.
+# Dell OpenManage Ansible Modules
+# Version 7.1.0
+# Copyright (C) 2019-2025 Dell Inc. or its subsidiaries. All Rights Reserved.
 
 # GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
 #
@@ -18,6 +18,11 @@ DOCUMENTATION = r'''
 module: dellemc_idrac_storage_volume
 short_description: Configures the RAID configuration attributes
 version_added: "2.0.0"
+deprecated:
+  removed_at_date: "2026-03-31"
+  why: Replaced with M(dellemc.openmanage.idrac_storage_volume).
+  alternative: Use M(dellemc.openmanage.idrac_storage_volume) instead.
+  removed_from_collection: dellemc.openmanage
 description:
   - This module is responsible for configuring the RAID attributes.
 extends_documentation_fragment:
@@ -123,10 +128,11 @@ options:
 
 requirements:
   - "omsdk >= 1.2.488"
-  - "python >= 3.8.6"
+  - "python >= 3.9.6"
 author: "Felix Stephen (@felixs88)"
 notes:
-    - Run this module from a system that has direct access to DellEMC iDRAC.
+    - Run this module from a system that has direct access to Dell iDRAC.
+    - This module supports both IPv4 and IPv6 address for I(idrac_ip).
     - This module supports C(check_mode).
 '''
 
@@ -172,7 +178,7 @@ EXAMPLES = r'''
         span_length: 3
         span_depth: 1
         drives:
-           location: [7,3,5]
+          location: [7, 3, 5]
         disk_cache_policy: "Disabled"
         write_cache_policy: "WriteBack"
         read_cache_policy: "NoReadAhead"
