@@ -3,8 +3,8 @@
 
 #
 # Dell OpenManage Ansible Modules
-# Version 6.3.0
-# Copyright (C) 2022 Dell Inc. or its subsidiaries. All Rights Reserved.
+# Version 9.12.1
+# Copyright (C) 2022-2025 Dell Inc. or its subsidiaries. All Rights Reserved.
 
 # GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
 #
@@ -21,7 +21,7 @@ version_added: "6.3.0"
 description:
   - This module allows to configure Remote File Share settings.
 extends_documentation_fragment:
-  - dellemc.openmanage.idrac_auth_options
+  - dellemc.openmanage.idrac_x_auth_options
 options:
   virtual_media:
     required: true
@@ -78,7 +78,7 @@ options:
     type: str
     description: Resource id of the iDRAC, if not specified manager collection id will be used.
 requirements:
-    - "python >= 3.8.6"
+    - "python >= 3.9.6"
 author:
     - "Felix Stephen (@felixs88)"
 notes:
@@ -217,8 +217,8 @@ import copy
 import time
 from ansible.module_utils.six.moves.urllib.error import URLError, HTTPError
 from ansible.module_utils.urls import ConnectionError, SSLValidationError
-from ansible_collections.dellemc.openmanage.plugins.module_utils.idrac_redfish import iDRACRedfishAPI, idrac_auth_params
-from ansible.module_utils.basic import AnsibleModule
+from ansible_collections.dellemc.openmanage.plugins.module_utils.idrac_redfish import iDRACRedfishAPI, IdracAnsibleModule
+
 
 MANAGER_BASE = "/redfish/v1/Managers/iDRAC.Embedded.1/VirtualMedia"
 SYSTEM_BASE = "/redfish/v1/Systems/System.Embedded.1/VirtualMedia"
@@ -441,8 +441,8 @@ def main():
         "force": {"required": False, "type": "bool", "default": False},
         "resource_id": {"required": False, "type": 'str'},
     }
-    specs.update(idrac_auth_params)
-    module = AnsibleModule(argument_spec=specs, supports_check_mode=True)
+
+    module = IdracAnsibleModule(argument_spec=specs, supports_check_mode=True)
     try:
         with iDRACRedfishAPI(module.params, req_session=True) as idrac:
             vr_media = module.params["virtual_media"]
@@ -456,12 +456,12 @@ def main():
                 module.fail_json(msg=FAIL_MSG, error_info=resp)
             module.exit_json(msg=SUCCESS_MSG, changed=True)
     except HTTPError as err:
-        module.fail_json(msg=str(err), error_info=json.load(err))
+        module.exit_json(msg=str(err), error_info=json.load(err), failed=True)
     except URLError as err:
         module.exit_json(msg=str(err), unreachable=True)
     except (RuntimeError, SSLValidationError, ConnectionError, KeyError,
             ImportError, ValueError, TypeError) as err:
-        module.fail_json(msg=str(err))
+        module.exit_json(msg=str(err), failed=True)
 
 
 if __name__ == '__main__':
