@@ -3,8 +3,8 @@
 
 #
 # Dell OpenManage Ansible Modules
-# Version 7.0.0
-# Copyright (C) 2020-2022 Dell Inc. or its subsidiaries. All Rights Reserved.
+# Version 10.0.1
+# Copyright (C) 2020-2025 Dell Inc. or its subsidiaries. All Rights Reserved.
 
 # GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
 #
@@ -63,9 +63,10 @@ options:
               'Storage - iSCSI', 'Storage - FCoE', 'Storage - Data Replication',
               'VM Migration', 'VMWare FT Logging']
 requirements:
-    - "python >= 3.8.6"
+    - "python >= 3.9.6"
 author:
     - "Jagadeesh N V(@jagadeeshnv)"
+    - "Meenakshi Dembi(@meenakshidembi691)"
 notes:
     - Run this module from a system that has direct access to Dell OpenManage Enterprise.
     - This module supports C(check_mode).
@@ -181,10 +182,8 @@ error_info:
     }
 '''
 
-import json
 from ssl import SSLError
-from ansible.module_utils.basic import AnsibleModule
-from ansible_collections.dellemc.openmanage.plugins.module_utils.ome import RestOME, ome_auth_params
+from ansible_collections.dellemc.openmanage.plugins.module_utils.ome import RestOME, OmeAnsibleModule
 from ansible.module_utils.urls import ConnectionError, SSLValidationError
 from ansible.module_utils.six.moves.urllib.error import URLError, HTTPError
 
@@ -233,20 +232,21 @@ def check_overlapping_vlan_range(payload, vlans):
 def create_vlan(module, rest_obj, vlans):
     payload = format_payload(module.params)
     if not all(payload.values()):
-        module.fail_json(msg="The vlan_minimum, vlan_maximum and type values are required for creating a VLAN.")
+        module.exit_json(msg="The vlan_minimum, vlan_maximum and type values are required for "
+                         "creating a VLAN.", failed=True)
     if payload["VlanMinimum"] > payload["VlanMaximum"]:
-        module.fail_json(msg=VLAN_VALUE_MSG)
+        module.exit_json(msg=VLAN_VALUE_MSG, failed=True)
     overlap = check_overlapping_vlan_range(payload, vlans)
     if overlap:
-        module.fail_json(msg=VLAN_RANGE_OVERLAP.format(vlan_name=overlap["Name"], vlan_min=overlap["VlanMinimum"],
-                                                       vlan_max=overlap["VlanMaximum"]))
+        module.exit_json(msg=VLAN_RANGE_OVERLAP.format(vlan_name=overlap["Name"], vlan_min=overlap["VlanMinimum"],
+                                                       vlan_max=overlap["VlanMaximum"]), failed=True)
     if module.check_mode:
         module.exit_json(changed=True, msg=CHECK_MODE_MSG)
     if module.params.get("description"):
         payload["Description"] = module.params.get("description")
     payload["Type"], types = get_item_id(rest_obj, module.params["type"], VLAN_TYPES)
     if not payload["Type"]:
-        module.fail_json(msg="Network type '{0}' not found.".format(module.params["type"]))
+        module.exit_json(msg="Network type '{0}' not found.".format(module.params["type"]), failed=True)
     resp = rest_obj.invoke_request("POST", VLAN_CONFIG, data=payload)
     module.exit_json(msg="Successfully created the VLAN.", vlan_status=resp.json_data, changed=True)
 
@@ -264,7 +264,7 @@ def modify_vlan(module, rest_obj, vlan_id, vlans):
     if module.params.get("type"):
         payload["Type"], types = get_item_id(rest_obj, module.params["type"], VLAN_TYPES)
         if not payload["Type"]:
-            module.fail_json(msg="Network type '{0}' not found.".format(module.params["type"]))
+            module.exit_json(msg="Network type '{0}' not found.".format(module.params["type"]), failed=True)
     if module.params.get("new_name"):
         payload["Name"] = module.params["new_name"]
     current_setting = {}
@@ -282,11 +282,11 @@ def modify_vlan(module, rest_obj, vlan_id, vlans):
         else:
             payload[config] = current_setting.get(config)
     if payload["VlanMinimum"] > payload["VlanMaximum"]:
-        module.fail_json(msg=VLAN_VALUE_MSG)
+        module.exit_json(msg=VLAN_VALUE_MSG, failed=True)
     overlap = check_overlapping_vlan_range(payload, vlans)
     if overlap:
-        module.fail_json(msg=VLAN_RANGE_OVERLAP.format(vlan_name=overlap["Name"], vlan_min=overlap["VlanMinimum"],
-                                                       vlan_max=overlap["VlanMaximum"]))
+        module.exit_json(msg=VLAN_RANGE_OVERLAP.format(vlan_name=overlap["Name"], vlan_min=overlap["VlanMinimum"],
+                                                       vlan_max=overlap["VlanMaximum"]), failed=True)
     if diff == 0:  # Idempotency
         if module.check_mode:
             module.exit_json(msg="No changes found to be applied to the VLAN configuration.")
@@ -318,8 +318,8 @@ def main():
                              'Storage - iSCSI', 'Storage - FCoE', 'Storage - Data Replication', 'VM Migration',
                              'VMWare FT Logging']}
     }
-    specs.update(ome_auth_params)
-    module = AnsibleModule(
+
+    module = OmeAnsibleModule(
         argument_spec=specs,
         required_if=[['state', 'present', ('new_name', 'description', 'vlan_minimum', 'vlan_maximum', 'type',), True]],
         supports_check_mode=True
@@ -338,11 +338,11 @@ def main():
                     module.exit_json(msg="No changes found to be applied to the VLAN configuration.")
                 module.exit_json(msg="VLAN {0} does not exist.".format(module.params["name"]))
     except HTTPError as err:
-        module.fail_json(msg=str(err), error_info=json.load(err))
+        module.exit_json(msg=str(err), failed=True)
     except URLError as err:
         module.exit_json(msg=str(err), unreachable=True)
     except (IOError, ValueError, TypeError, ConnectionError, SSLValidationError, SSLError, OSError) as err:
-        module.fail_json(msg=str(err))
+        module.exit_json(msg=str(err), failed=True)
 
 
 if __name__ == "__main__":
