@@ -2,8 +2,8 @@
 
 #
 # Dell OpenManage Ansible Modules
-# Version 8.3.0
-# Copyright (C) 2023 Dell Inc.
+# Version 10.0.1
+# Copyright (C) 2023-2025 Dell Inc.
 
 # GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
 # All rights reserved. Dell, EMC, and other trademarks are trademarks of Dell Inc. or its subsidiaries.
@@ -17,13 +17,15 @@ __metaclass__ = type
 import pytest
 from ansible.module_utils.urls import ConnectionError, SSLValidationError
 from ansible.module_utils.six.moves.urllib.error import URLError, HTTPError
-from ansible_collections.dellemc.openmanage.plugins.module_utils.redfish import Redfish, OpenURLResponse
+from ansible_collections.dellemc.openmanage.plugins.module_utils.redfish \
+    import Redfish, OpenURLResponse
 from unittest.mock import MagicMock
 import json
 
 MODULE_UTIL_PATH = 'ansible_collections.dellemc.openmanage.plugins.module_utils.'
 OPEN_URL = 'redfish.open_url'
 TEST_PATH = "/testpath"
+MANAGER_URI = "/redfish/v1/Managers/iDRAC.Embedded.1"
 
 
 class TestRedfishRest(object):
@@ -48,6 +50,53 @@ class TestRedfishRest(object):
         redfish_obj = Redfish(module_params=module_params)
         return redfish_obj
 
+    def mock_get_dynamic_redfish_invoke_request(self, *args, **kwargs):
+        obj = MagicMock()
+        obj.status_code = 200
+        obj.success = True
+        if 'path' in kwargs and kwargs['path'] == MANAGER_URI:
+            obj.json_data = {'Model': '17G Monolithic',
+                             'FirmwareVersion': 'x.x.x.x'}
+        else:
+            obj.json_data = {'Attributes': {'Info.1.HWModel': 'iDRAC 10'}}
+        return obj
+
+    def test_get_server_generation(self, mocker, module_params):
+        mocker.patch(MODULE_UTIL_PATH + 'redfish.Redfish.invoke_request', self.mock_get_dynamic_redfish_invoke_request)
+        req_session = False
+        module_params.update({'x_auth_token': 'token_id'})
+        with Redfish(module_params, req_session) as obj:
+            response = obj.get_server_generation
+        assert response == (17, 'x.x.x.x', 'iDRAC 10')
+
+    def test_invoke_request_with_session_with_header(self, mock_response, mocker, module_params):
+        Redfish.get_server_generation = [12]
+        mocker.patch(MODULE_UTIL_PATH + OPEN_URL,
+                     return_value=mock_response)
+        req_session = False
+        module_params.update({'x_auth_token': 'token_id'})
+        with Redfish(module_params, req_session) as obj:
+            response = obj.invoke_request(TEST_PATH, "GET", headers={
+                                          "application": "octstream"})
+        assert response.status_code == 200
+        assert response.json_data == {"value": "data"}
+        assert response.success is True
+
+    def test_invoke_request_without_session(self, mock_response, mocker):
+        mocker.patch(MODULE_UTIL_PATH + OPEN_URL,
+                     return_value=mock_response)
+        mocker.patch(MODULE_UTIL_PATH + OPEN_URL,
+                     return_value=mock_response)
+        module_params = {'baseuri': '[2001:db8:3333:4444:5555:6666:7777:8888]:443', 'username': 'username',
+                         'password': 'password', "port": 443}
+        req_session = False
+        with Redfish(module_params, req_session) as obj:
+            response = obj.invoke_request(TEST_PATH, "GET")
+        assert response.status_code == 200
+        assert response.json_data == {"value": "data"}
+        assert response.success is True
+        assert response.headers == {"X-Auth-Token": "token_id"}
+
     def test_invoke_request_with_session(self, mock_response, mocker, module_params):
         mocker.patch(MODULE_UTIL_PATH + OPEN_URL,
                      return_value=mock_response)
