@@ -18,7 +18,7 @@ import pytest
 from ansible.module_utils import basic
 from ansible_collections.dellemc.openmanage.tests.unit.plugins.modules.utils import exit_json, \
     fail_json, AnsibleFailJson, AnsibleExitJson
-from mock import MagicMock
+from unittest.mock import MagicMock
 
 MODULE_PATH = 'ansible_collections.dellemc.openmanage.plugins.modules.'
 MODULE_UTIL_PATH = 'ansible_collections.dellemc.openmanage.plugins.module_utils.'
@@ -61,6 +61,13 @@ def ome_default_args():
     return default_args
 
 
+@pytest.fixture
+def omevv_default_args():
+    default_args = {'hostname': 'XX.XX.XX.XX', 'vcenter_uuid': 'vcenter_uuid', 'vcenter_username': 'vcenter_username',
+                    'vcenter_password': 'vcenter_password', "ca_path": "/path/ca_bundle"}
+    return default_args
+
+
 @pytest.fixture
 def idrac_default_args():
     default_args = {"idrac_ip": "idrac_ip", "idrac_user": "idrac_user", "idrac_password": "idrac_password",
