@@ -2,8 +2,8 @@
 
 #
 # Dell OpenManage Ansible Modules
-# Version 7.0.0
-# Copyright (C) 2021-2022 Dell Inc. or its subsidiaries. All Rights Reserved.
+# Version 9.12.4
+# Copyright (C) 2021-2025 Dell Inc. or its subsidiaries. All Rights Reserved.
 
 # GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
 #
@@ -18,6 +18,7 @@ import pytest
 from ansible.module_utils.six.moves.urllib.error import HTTPError, URLError
 from ansible.module_utils.urls import SSLValidationError
 from io import StringIO
+from ssl import SSLError
 from copy import deepcopy
 from ansible.module_utils._text import to_text
 from ansible_collections.dellemc.openmanage.plugins.modules import ome_application_network_settings
@@ -354,7 +355,7 @@ class TestOmeApplicationNetworkSettings(FakeAnsibleModule):
         assert err.value.args[0] == NO_CHANGES
 
     @pytest.mark.parametrize("exc_type",
-                             [HTTPError, URLError])
+                             [IOError, ValueError, SSLError, TypeError, ConnectionError, HTTPError, URLError])
     def test_session_inactivity_settings_main_exception_case(self, mocker, exc_type, ome_connection_mock_for_ns,
                                                              ome_response_mock,
                                                              ome_default_args):
@@ -371,11 +372,11 @@ class TestOmeApplicationNetworkSettings(FakeAnsibleModule):
             assert result["unreachable"] is True
         elif exc_type not in [HTTPError, SSLValidationError]:
             mocker.patch(MODULE_PATH + 'fetch_session_inactivity_settings', side_effect=exc_type("exception message"))
-            result = self._run_module_with_fail_json(ome_default_args)
+            result = self._run_module(ome_default_args)
             assert result['failed'] is True
         else:
             mocker.patch(MODULE_PATH + 'fetch_session_inactivity_settings',
                          side_effect=exc_type('https://testhost.com', 400, 'http error message',
                                               {"accept-type": "application/json"}, StringIO(json_str)))
-            result = self._run_module_with_fail_json(ome_default_args)
+            result = self._run_module(ome_default_args)
             assert result['failed'] is True
