@@ -2,8 +2,8 @@
 
 #
 # Dell OpenManage Ansible Modules
-# Version 7.0.0
-# Copyright (C) 2019-2020 Dell Inc. or its subsidiaries. All Rights Reserved.
+# Version 9.12.4
+# Copyright (C) 2019-2025 Dell Inc. or its subsidiaries. All Rights Reserved.
 
 # GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
 #
@@ -18,6 +18,7 @@ import pytest
 from ansible.module_utils.six.moves.urllib.error import HTTPError, URLError
 from ansible.module_utils.urls import ConnectionError, SSLValidationError
 from io import StringIO
+from ssl import SSLError
 from ansible.module_utils._text import to_text
 from ansible_collections.dellemc.openmanage.plugins.modules import ome_application_network_webserver
 from ansible_collections.dellemc.openmanage.tests.unit.plugins.modules.common import FakeAnsibleModule
@@ -49,7 +50,7 @@ class TestOmeAppNetwork(FakeAnsibleModule):
         mocker.patch(MODULE_PATH + "ome_application_network_webserver.get_updated_payload",
                      return_value=(resp, port_change))
         ome_response_mock.json_data = resp
-        result = self.execute_module(ome_default_args)
+        result = self._run_module(ome_default_args)
         assert result['changed'] is True
         assert "msg" in result
         assert "webserver_configuration" in result and result["webserver_configuration"] == resp
@@ -111,7 +112,7 @@ class TestOmeAppNetwork(FakeAnsibleModule):
             self.module.get_updated_payload(ome_connection_mock_for_application_network_webserver, f_module)
 
     @pytest.mark.parametrize("exc_type",
-                             [IOError, ValueError, TypeError, ConnectionError, HTTPError, URLError])
+                             [IOError, ValueError, SSLError, TypeError, ConnectionError, HTTPError, URLError])
     def test_ome_application_network_webserver_main_error_cases(self, exc_type, mocker, ome_default_args,
                                                                 ome_connection_mock_for_application_network_webserver,
                                                                 ome_response_mock):
@@ -128,7 +129,7 @@ class TestOmeAppNetwork(FakeAnsibleModule):
             mocker.patch(
                 MODULE_PATH + 'ome_application_network_webserver.get_updated_payload',
                 side_effect=exc_type("exception message"))
-            result = self._run_module_with_fail_json(ome_default_args)
+            result = self._run_module(ome_default_args)
             assert result['failed'] is True
         else:
             mocker.patch(
@@ -137,7 +138,7 @@ class TestOmeAppNetwork(FakeAnsibleModule):
                                      'http error message',
                                      {"accept-type": "application/json"},
                                      StringIO(json_str)))
-            result = self._run_module_with_fail_json(ome_default_args)
+            result = self._run_module(ome_default_args)
             assert result['failed'] is True
         assert 'webserver_configuration' not in result
         assert 'msg' in result
