@@ -2,8 +2,8 @@
 
 #
 # Dell OpenManage Ansible Modules
-# Version 7.0.0
-# Copyright (C) 2021-2022 Dell Inc. or its subsidiaries. All Rights Reserved.
+# Version 10.0.1
+# Copyright (C) 2021-2024 Dell Inc. or its subsidiaries. All Rights Reserved.
 
 # GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
 #
@@ -558,13 +558,13 @@ class TestOmeConfigCompBaseline(FakeAnsibleModule):
             assert result["unreachable"] is True
         elif exc_type not in [HTTPError, SSLValidationError]:
             mocker.patch(MODULE_PATH + 'compliance_operation', side_effect=exc_type("exception message"))
-            result = self._run_module_with_fail_json(ome_default_args)
+            result = self._run_module(ome_default_args)
             assert result['failed'] is True
         else:
             mocker.patch(MODULE_PATH + 'compliance_operation',
                          side_effect=exc_type('https://testhost.com', 400, 'http error message',
                                               {"accept-type": "application/json"}, StringIO(json_str)))
-            result = self._run_module_with_fail_json(ome_default_args)
+            result = self._run_module(ome_default_args)
             assert result['failed'] is True
         assert 'msg' in result
 
@@ -924,17 +924,26 @@ class TestOmeConfigCompBaseline(FakeAnsibleModule):
 
     @pytest.mark.parametrize("val", ["3.4.1", "3.4.5", "3.4.0", "3.4", "3.3", "3.3.0", "3.0.0", "2.1"])
     def test_create_remediate_payload_case01_for_old_releases(self, val, mocker, ome_connection_mock_for_compliance):
+        f_module = self.get_module_mock(
+            params={"run_later": True, "cron": "0 00 11 14 02 ? 2033"}
+        )
+        time_string = "2024-06-18 16:23:02.628"
         mocker.patch(MODULE_PATH + 'get_ome_version',
                      return_value=val)
-        payload = self.module.create_remediate_payload([Constants.device_id1], baseline_output,
+        mocker.patch(MODULE_PATH + 'validate_time',
+                     return_value=time_string)
+        payload = self.module.create_remediate_payload(f_module, [Constants.device_id1], baseline_output,
                                                        ome_connection_mock_for_compliance)
         assert "TargetIds" in payload
 
     @pytest.mark.parametrize("val", ["3.5.1", "3.5.5", "3.5.0", "3.5"])
     def test_create_remediate_payload_case01_for_new_releases(self, val, mocker, ome_connection_mock_for_compliance):
+        f_module = self.get_module_mock(
+            params={"staged_at_reboot": True}
+        )
         mocker.patch(MODULE_PATH + 'get_ome_version',
                      return_value=val)
-        payload = self.module.create_remediate_payload([Constants.device_id1], baseline_output,
+        payload = self.module.create_remediate_payload(f_module, [Constants.device_id1], baseline_output,
                                                        ome_connection_mock_for_compliance)
         assert "DeviceIds" in payload
 
