@@ -2,8 +2,8 @@
 
 #
 # Dell OpenManage Ansible Modules
-# Version 6.1.0
-# Copyright (C) 2022 Dell Inc. or its subsidiaries. All Rights Reserved.
+# Version 10.0.0
+# Copyright (C) 2022-2025 Dell Inc. or its subsidiaries. All Rights Reserved.
 
 # GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
 #
@@ -17,8 +17,7 @@ import json
 from ssl import SSLError
 from io import StringIO
 from ansible_collections.dellemc.openmanage.plugins.modules import ome_device_group
-from ansible_collections.dellemc.openmanage.tests.unit.plugins.modules.common import FakeAnsibleModule, Constants, \
-    AnsibleFailJSonException
+from ansible_collections.dellemc.openmanage.tests.unit.plugins.modules.common import FakeAnsibleModule, Constants
 from ansible.module_utils.six.moves.urllib.error import HTTPError, URLError
 from ansible.module_utils.urls import ConnectionError, SSLValidationError
 from ansible.module_utils._text import to_text
@@ -32,7 +31,6 @@ INVALID_IP_FORMAT = "The format {0} of the IP address provided is not supported
 IP_NOT_EXISTS = "The IP addresses provided do not exist in OpenManage Enterprise."
 try:
     from netaddr import IPAddress, IPNetwork, IPRange
-    from netaddr.core import AddrFormatError
 
     HAS_NETADDR = True
 except ImportError:
@@ -67,7 +65,7 @@ class TestOMEDeviceGroup(FakeAnsibleModule):
     def test_ome_device_group_get_group_id_case02(self, ome_connection_mock_for_device_group, ome_response_mock):
         f_module = self.get_module_mock(params={"group_id": 1234,
                                                 "device_ids": [25011], "device_service_tags": []})
-        ome_connection_mock_for_device_group.invoke_request.side_effect = HTTPError('http://testhost.com', 400,
+        ome_connection_mock_for_device_group.invoke_request.side_effect = HTTPError('https://testhost.com', 400,
                                                                                     'http error message',
                                                                                     {"accept-type": "application/json"},
                                                                                     StringIO(to_text(json.dumps(
@@ -151,30 +149,30 @@ class TestOMEDeviceGroup(FakeAnsibleModule):
     def test_ome_device_group_argument_exception_case1(self, ome_default_args):
         ome_default_args.update({"name": "Storage Services", "device_ids": [25011, 25012], "group_id": 1234})
         result = self._run_module_with_fail_json(ome_default_args)
-        assert result["msg"] == "parameters are mutually exclusive: name|group_id"
+        assert result['failed'] is True
 
     def test_ome_device_group_argument_exception_case2(self, ome_default_args):
         ome_default_args.update(
             {"device_ids": [25011, 25012], "group_id": 1234, "device_service_tags": [Constants.service_tag1]})
         result = self._run_module_with_fail_json(ome_default_args)
-        assert result["msg"] == "parameters are mutually exclusive: device_ids|device_service_tags|ip_addresses"
+        assert result['failed'] is True
 
     def test_ome_device_group_argument_exception_case3(self, ome_default_args):
         ome_default_args.update({"device_ids": [25011, 25012]})
         result = self._run_module_with_fail_json(ome_default_args)
-        assert result["msg"] == "one of the following is required: name, group_id"
+        assert result['failed'] is True
 
     def test_ome_device_group_argument_exception_case4(self, ome_default_args):
         ome_default_args.update(
             {"group_id": 1234})
         result = self._run_module_with_fail_json(ome_default_args)
-        assert result["msg"] == "one of the following is required: device_ids, device_service_tags, ip_addresses"
+        assert result['failed'] is True
 
     def test_ome_device_group_argument_exception_case5(self, ome_default_args):
         ome_default_args.update(
             {"device_ids": None, "group_id": 1234, "device_service_tags": None})
         result = self._run_module_with_fail_json(ome_default_args)
-        assert result["msg"] == "parameters are mutually exclusive: device_ids|device_service_tags|ip_addresses"
+        assert result['failed'] is True
 
     @pytest.mark.parametrize("exc_type",
                              [IOError, ValueError, SSLError, TypeError, ConnectionError, HTTPError, URLError])
@@ -191,13 +189,13 @@ class TestOMEDeviceGroup(FakeAnsibleModule):
             assert result["unreachable"] is True
         elif exc_type not in [HTTPError, SSLValidationError]:
             mocker.patch(MODULE_PATH + 'get_group_id', side_effect=exc_type("exception message"))
-            result = self._run_module_with_fail_json(ome_default_args)
+            result = self._run_module(ome_default_args)
             assert result['failed'] is True
         else:
             mocker.patch(MODULE_PATH + 'get_group_id',
-                         side_effect=exc_type('http://testhost.com', 400, 'http error message',
+                         side_effect=exc_type('https://testhost.com', 400, 'http error message',
                                               {"accept-type": "application/json"}, StringIO(json_str)))
-            result = self._run_module_with_fail_json(ome_default_args)
+            result = self._run_module(ome_default_args)
             assert result['failed'] is True
         assert 'msg' in result
 
