@@ -1,9 +1,9 @@
 # -*- coding: utf-8 -*-
 
 #
-# Dell EMC OpenManage Ansible Modules
-# Version 5.1.0
-# Copyright (C) 2019-2022 Dell Inc. or its subsidiaries. All Rights Reserved.
+# Dell OpenManage Ansible Modules
+# Version 8.1.0
+# Copyright (C) 2019-2023 Dell Inc. or its subsidiaries. All Rights Reserved.
 
 # GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
 #
@@ -23,6 +23,7 @@ resource_detailed_inventory = {"detailed_inventory:": {"device_id": {Constants.d
                                                            Constants.device_id2: Constants.service_tag1}}}
 
 MODULE_PATH = 'ansible_collections.dellemc.openmanage.plugins.modules.'
+HTTPS_ADDRESS = 'https://testhost.com'
 
 
 class TestOmeDeviceInfo(FakeAnsibleModule):
@@ -61,13 +62,17 @@ class TestOmeDeviceInfo(FakeAnsibleModule):
                                                            validate_device_inputs_mock, ome_connection_mock,
                                                            get_device_resource_parameters_mock, ome_response_mock):
         quer_param_mock = mocker.patch(MODULE_PATH + 'ome_device_info._get_query_parameters')
-        quer_param_mock.return_value = {"filter": "Type eq '1000'"}
-        ome_response_mock.json_data = {"value": [{"device_id1": "details", "device_id2": "details"}]}
+        quer_param_mock.return_value = {"filter": "Type eq 1000"}
+        ome_response_mock.json_data = {
+            "value": [{"device_id1": "details", "device_id2": "details"}],
+            "@odata.context": "/api/$metadata#Collection(DeviceService.Device)",
+            "@odata.count": 2,
+        }
         ome_response_mock.status_code = 200
         result = self._run_module(ome_default_args)
         assert result['changed'] is False
         assert 'device_info' in result
-        assert result["device_info"] == {"value": [{"device_id1": "details", "device_id2": "details"}]}
+        assert "@odata.context" in result["device_info"]
 
     def test_main_basic_inventory_failure_case(self, ome_default_args, module_mock, validate_device_inputs_mock,
                                                ome_connection_mock,
@@ -108,14 +113,14 @@ class TestOmeDeviceInfo(FakeAnsibleModule):
             "device_id": {Constants.device_id1: "DeviceService/Devices(Constants.device_id1)/InventoryDetails"},
             "device_service_tag": {Constants.service_tag1: "DeviceService/Devices(4321)/InventoryDetails"}}}
         get_device_resource_parameters_mock.return_value = detailed_inventory
-        ome_connection_mock.invoke_request.side_effect = HTTPError('http://testhost.com', 400, '', {}, None)
+        ome_connection_mock.invoke_request.side_effect = HTTPError(HTTPS_ADDRESS, 400, '', {}, None)
         result = self._run_module(ome_default_args)
         assert 'device_info' in result
 
     def test_main_HTTPError_error_case(self, ome_default_args, module_mock, validate_device_inputs_mock,
                                        ome_connection_mock,
                                        get_device_resource_parameters_mock, ome_response_mock):
-        ome_connection_mock.invoke_request.side_effect = HTTPError('http://testhost.com', 400, '', {}, None)
+        ome_connection_mock.invoke_request.side_effect = HTTPError(HTTPS_ADDRESS, 400, '', {}, None)
         ome_response_mock.json_data = {"value": [{"device_id1": "details", "device_id2": "details"}]}
         ome_response_mock.status_code = 400
         result = self._run_module(ome_default_args)
@@ -197,7 +202,7 @@ class TestOmeDeviceInfo(FakeAnsibleModule):
         self.module._get_device_id_from_service_tags([Constants.service_tag1, "INVALID"], ome_connection_mock)
 
     def test_get_device_id_from_service_tags_error_case(self, ome_connection_mock, ome_response_mock):
-        ome_connection_mock.get_all_report_details.side_effect = HTTPError('http://testhost.com', 400, '', {}, None)
+        ome_connection_mock.get_all_report_details.side_effect = HTTPError(HTTPS_ADDRESS, 400, '', {}, None)
         with pytest.raises(HTTPError) as ex:
             self.module._get_device_id_from_service_tags(["INVALID"], ome_connection_mock)
 
@@ -224,7 +229,7 @@ class TestOmeDeviceInfo(FakeAnsibleModule):
         error_msg = '400: Bad Request'
         service_tag_dict = {}
         non_available_tags = [Constants.service_tag2]
-        ome_connection_mock.invoke_request.side_effect = HTTPError('http://testhost.com', 400, error_msg, {}, None)
+        ome_connection_mock.invoke_request.side_effect = HTTPError(HTTPS_ADDRESS, 400, error_msg, {}, None)
         with pytest.raises(HTTPError, match=error_msg) as ex:
             self.module.update_device_details_with_filtering(non_available_tags, service_tag_dict, ome_connection_mock)
 
