@@ -2,7 +2,7 @@
 
 #
 # Dell OpenManage Ansible Modules
-# Version 8.2.0
+# Version 10.0.1
 # Copyright (C) 2021-2023 Dell Inc. or its subsidiaries. All Rights Reserved.
 
 # GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
@@ -112,36 +112,36 @@ class TestOMEMDeviceLocation(FakeAnsibleModule):
 
     @pytest.mark.parametrize("params", [
         {"json_data": {"value": [
-            {'Id': 1234, 'PublicAddress': "1.2.3.4",
+            {'Id': 1234, 'PublicAddress': "xxx.xxx.x.x",
                 'DeviceId': 1234, "Type": 1000},
-            {'PublicAddress': "1.2.3.5", 'DeviceId': 1235, "Type": 1000}]},
+            {'PublicAddress': "X.X.X.X", 'DeviceId': 1235, "Type": 1000}]},
             'message': "Successfully updated the location settings.",
-            'mparams': {"hostname": "1.2.3.4",
+            'mparams': {"hostname": "xxx.xxx.x.x",
                         "device_id": 1234, "data_center": "data center",
                         "room": "room", "aisle": "aisle", "rack": "rack"}
          },
         {"json_data": {"value": [
             {'Id': 1234, 'DeviceServiceTag': 'ABCD123',
-                'PublicAddress': "1.2.3.4", 'DeviceId': 1234, "Type": 1000},
-            {'PublicAddress': "1.2.3.5", 'DeviceId': 1235, "Type": 1000}]},
+                'PublicAddress': "xxx.xxx.x.x", 'DeviceId': 1234, "Type": 1000},
+            {'PublicAddress': "X.X.X.X", 'DeviceId': 1235, "Type": 1000}]},
             'message': "Successfully updated the location settings.",
-            'mparams': {"hostname": "1.2.3.4",
+            'mparams': {"hostname": "xxx.xxx.x.x",
                         "device_service_tag": "ABCD123", "data_center": "data center",
                         "room": "room", "aisle": "aisle", "rack": "rack"}
          },
         {"json_data": {"value": [
-            {'Id': 1234, 'PublicAddress': "1.2.3.4",
+            {'Id': 1234, 'PublicAddress': "xxx.xxx.x.x",
                 'DeviceId': 1234, "Type": 1000},
-            {'PublicAddress': "1.2.3.5", 'DeviceId': 1235, "Type": 1000}]},
+            {'PublicAddress': "X.X.X.X", 'DeviceId': 1235, "Type": 1000}]},
             'message': "Successfully updated the location settings.",
-            'mparams': {"hostname": "1.2.3.4",
+            'mparams': {"hostname": "xxx.xxx.x.x",
                         "data_center": "data center",
                         "room": "room", "aisle": "aisle", "rack": "rack"}
          },
         {"json_data": {"value": [
             {'Id': 1234, 'PublicAddress': "dummyhost_shouldnotexist",
                 'DeviceId': 1234, "Type": 1000},
-            {'PublicAddress': "1.2.3.5", 'DeviceId': 1235, "Type": 1000}]},
+            {'PublicAddress': "X.X.X.X", 'DeviceId': 1235, "Type": 1000}]},
             'message': "Successfully updated the location settings.",
             'mparams': {"hostname": "dummyhost_shouldnotexist",
                         "data_center": "data center",
@@ -159,9 +159,9 @@ class TestOMEMDeviceLocation(FakeAnsibleModule):
 
     @pytest.mark.parametrize("params", [
         {"json_data": {"value": [
-            {'Id': 1234, 'PublicAddress': "1.2.3.4",
+            {'Id': 1234, 'PublicAddress': "xxx.xxx.x.x",
                 'DeviceId': 1234, "Type": 1000},
-            {'PublicAddress': "1.2.3.5", 'DeviceId': 1235, "Type": 1000}]},
+            {'PublicAddress': "X.X.X.X", 'DeviceId': 1235, "Type": 1000}]},
             'message': "The device location settings operation is supported only on OpenManage Enterprise Modular systems.",
             'http_error_json': {
                 "error": {
@@ -179,14 +179,14 @@ class TestOMEMDeviceLocation(FakeAnsibleModule):
                     ]
                 }
         },
-            'mparams': {"hostname": "1.2.3.4",
+            'mparams': {"hostname": "xxx.xxx.x.x",
                         "data_center": "data center",
                         "room": "room", "aisle": "aisle", "rack": "rack"}
         },
         {"json_data": {"value": [
-            {'Id': 1234, 'PublicAddress': "1.2.3.4",
+            {'Id': 1234, 'PublicAddress': "xxx.xxx.x.x",
                 'DeviceId': 1234, "Type": 1000},
-            {'PublicAddress': "1.2.3.5", 'DeviceId': 1235, "Type": 1000}]},
+            {'PublicAddress': "X.X.X.X", 'DeviceId': 1235, "Type": 1000}]},
             'message': "Unable to complete the operation because the location settings are not supported on the specified device.",
             'http_error_json': {
                 "error": {
@@ -206,16 +206,16 @@ class TestOMEMDeviceLocation(FakeAnsibleModule):
         },
             'check_domain_service': 'mocked_check_domain_service',
             'standalone_chassis': ('Id', 1234),
-            'mparams': {"hostname": "1.2.3.4",
+            'mparams': {"hostname": "xxx.xxx.x.x",
                         "data_center": "data center",
                         "room": "room", "aisle": "aisle", "rack": "rack"}
         },
         {"json_data": {"value": [
-            {'Id': 1234, 'PublicAddress': "1.2.3.4",
+            {'Id': 1234, 'PublicAddress': "xxx.xxx.x.x",
                 'DeviceId': 1234, "Type": 1000},
-            {'PublicAddress': "1.2.3.5", 'DeviceId': 1235, "Type": 1000}]},
+            {'PublicAddress': "X.X.X.X", 'DeviceId': 1235, "Type": 1000}]},
             'message': "Unable to complete the operation because the entered target device id '123' is invalid.",
-            'mparams': {"hostname": "1.2.3.4", "device_id": 123,
+            'mparams': {"hostname": "xxx.xxx.x.x.x.x.x.x", "device_id": 123,
                         "data_center": "data center",
                         "room": "room", "aisle": "aisle", "rack": "rack"}
          },
@@ -235,7 +235,7 @@ class TestOMEMDeviceLocation(FakeAnsibleModule):
                     "accept-type": "application/json"},
                 StringIO(json_str))
         ome_default_args.update(params['mparams'])
-        result = self._run_module_with_fail_json(ome_default_args)
+        result = self._run_module(ome_default_args)
         assert result['msg'] == params['message']
 
     @pytest.mark.parametrize("exc_type",
@@ -256,12 +256,12 @@ class TestOMEMDeviceLocation(FakeAnsibleModule):
         elif exc_type not in [HTTPError, SSLValidationError]:
             mocker.patch(MODULE_PATH + 'check_domain_service',
                          side_effect=exc_type("exception message"))
-            result = self._run_module_with_fail_json(ome_default_args)
+            result = self._run_module(ome_default_args)
             assert result['failed'] is True
         else:
             mocker.patch(MODULE_PATH + 'check_domain_service',
                          side_effect=exc_type('https://testhost.com', 400, 'http error message',
                                               {"accept-type": "application/json"}, StringIO(json_str)))
-            result = self._run_module_with_fail_json(ome_default_args)
+            result = self._run_module(ome_default_args)
             assert result['failed'] is True
         assert 'msg' in result
