@@ -2,8 +2,8 @@
 
 #
 # Dell OpenManage Ansible Modules
-# Version 7.0.0
-# Copyright (C) 2021-2022 Dell Inc. or its subsidiaries. All Rights Reserved.
+# Version 10.0.1
+# Copyright (C) 2021-2025 Dell Inc. or its subsidiaries. All Rights Reserved.
 
 # GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
 #
@@ -75,9 +75,10 @@ class TestOMEMDeviceNetworkService(FakeAnsibleModule):
         assert value == 25011
 
     def test_main_validation(self, ome_conn_mock_network, ome_default_args, ome_response_mock, mocker):
-        resp = self._run_module_with_fail_json(ome_default_args)
-        assert resp['msg'] == "one of the following is required: snmp_settings, " \
-                              "ssh_settings, remote_racadm_settings"
+        with pytest.raises(Exception) as ex:
+            self._run_module(ome_default_args)
+        assert ex.value.args[0]['msg'] == "one of the following is required: snmp_settings, " \
+            "ssh_settings, remote_racadm_settings"
         mocker.patch(MODULE_PATH + "check_domain_service", return_value=None)
         mocker.patch(MODULE_PATH + "fetch_device_details", return_value=ome_response_mock)
         ome_response_mock.json_data = {"value": [{"Id": 25011, "DeviceServiceTag": "XE3FRS"}],
@@ -172,12 +173,12 @@ class TestOMEMDeviceNetworkService(FakeAnsibleModule):
             assert result["unreachable"] is True
         elif exc_type not in [HTTPError, SSLValidationError]:
             mocker.patch(MODULE_PATH + 'check_domain_service', side_effect=exc_type("exception message"))
-            result = self._run_module_with_fail_json(ome_default_args)
+            result = self._run_module(ome_default_args)
             assert result['failed'] is True
         else:
             mocker.patch(MODULE_PATH + 'check_domain_service',
                          side_effect=exc_type('https://testhost.com', 400, 'http error message',
                                               {"accept-type": "application/json"}, StringIO(json_str)))
-            result = self._run_module_with_fail_json(ome_default_args)
+            result = self._run_module(ome_default_args)
             assert result['failed'] is True
         assert 'msg' in result
