@@ -368,7 +368,7 @@ class TestOmeFirmware(FakeAnsibleModule):
         ome_response_mock.json_data = [{"Id": 1024,
                                         "Name": "Servers"}]
         ome_response_mock.success = False
-        data = self._run_module_with_fail_json(ome_default_args)
+        data = self._run_module(ome_default_args)
         assert data["msg"] == "Unable to complete the operation because the entered target device group name(s)" \
                               " '{0}' are invalid.".format(",".join(set(["Servers"])))
 
@@ -545,12 +545,12 @@ class TestOmeFirmware(FakeAnsibleModule):
             assert result["unreachable"] is True
         elif exc_type not in [HTTPError, SSLValidationError]:
             mocker.patch(MODULE_PATH + 'ome_firmware._validate_device_attributes', side_effect=exc_type("exception message"))
-            result = self._run_module_with_fail_json(ome_default_args)
+            result = self._run_module(ome_default_args)
             assert result['failed'] is True
         else:
             mocker.patch(MODULE_PATH + 'ome_firmware._validate_device_attributes',
                          side_effect=exc_type('https://testhost.com', 400, 'http error message',
                                               {"accept-type": "application/json"}, StringIO(json_str)))
-            result = self._run_module_with_fail_json(ome_default_args)
+            result = self._run_module(ome_default_args)
             assert result['failed'] is True
         assert 'msg' in result
