@@ -1,12 +1,9 @@
 # -*- coding: utf-8 -*-
-
-#
 # Dell OpenManage Ansible Modules
-# Version 7.0.0
-# Copyright (C) 2020-2022 Dell Inc. or its subsidiaries. All Rights Reserved.
-
-# GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
-#
+# Version 9.12.4
+# Copyright (C) 2020-2025 Dell Inc. or its subsidiaries. All Rights Reserved.
+# GNU General Public License v3.0+
+# (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
 
 from __future__ import (absolute_import, division, print_function)
 
@@ -14,7 +11,9 @@ __metaclass__ = type
 
 import pytest
 from ansible_collections.dellemc.openmanage.plugins.modules import ome_identity_pool
+from ansible_collections.dellemc.openmanage.plugins.modules.ome_identity_pool import mac_to_base64_conversion
 from ansible_collections.dellemc.openmanage.tests.unit.plugins.modules.common import FakeAnsibleModule
+from ansible_collections.dellemc.openmanage.tests.unit.plugins.modules.common import AnsibleFailJSonException
 from ansible.module_utils.six.moves.urllib.error import URLError, HTTPError
 from ansible.module_utils.urls import ConnectionError, SSLValidationError
 from ssl import SSLError
@@ -72,7 +71,7 @@ class TestOMeIdentityPool(FakeAnsibleModule):
         mocker.patch(MODULE_PATH + 'ome_identity_pool.pool_create_modify',
                      return_value=message_return)
         ome_default_args.update(sub_param)
-        result = self.execute_module(ome_default_args)
+        result = self._run_module(ome_default_args)
         assert result['changed'] is True
         assert 'pool_status' in result and "msg" in result
         assert result["msg"] == "Successfully created an identity pool."
@@ -96,7 +95,7 @@ class TestOMeIdentityPool(FakeAnsibleModule):
         elif exc_type not in [HTTPError, SSLValidationError]:
             mocker.patch(MODULE_PATH + 'ome_identity_pool.pool_create_modify',
                          side_effect=exc_type("exception message"))
-            result = self._run_module_with_fail_json(ome_default_args)
+            result = self._run_module(ome_default_args)
             assert result['failed'] is True
         else:
             mocker.patch(MODULE_PATH + 'ome_identity_pool.pool_create_modify',
@@ -104,13 +103,12 @@ class TestOMeIdentityPool(FakeAnsibleModule):
                                               'http error message',
                                               {"accept-type": "application/json"},
                                               StringIO(json_str)))
-            result = self._run_module_with_fail_json(ome_default_args)
+            result = self._run_module(ome_default_args)
             assert result['failed'] is True
         assert 'pool_status' not in result
         assert 'msg' in result
 
-    def test_main_ome_identity_pool_no_mandatory_arg_passed_failure_case(self, ome_default_args,
-                                                                         ome_connection_mock_for_identity_pool):
+    def test_main_ome_identity_pool_no_mandatory_arg_passed_failure_case(self, ome_default_args):
         result = self._run_module_with_fail_json(ome_default_args)
         assert 'pool_status' not in result
 
@@ -409,23 +407,6 @@ class TestOMeIdentityPool(FakeAnsibleModule):
             payload = self.module.get_payload(f_module)
         else:
             payload = self.module.get_payload(f_module, 11)
-        return_setting = {
-            "Name": "pool2",
-            "Description": "Identity pool with fc_settings",
-            "EthernetSettings": None,
-            "IscsiSettings": None,
-            "FcoeSettings": None,
-            "FcSettings": {
-                "Wwnn": {
-                    "IdentityCount": 48,
-                    "StartingAddress": "IABAQEBAQCI="
-                },
-                "Wwpn": {
-                    "IdentityCount": 48,
-                    "StartingAddress": "IAFAQEBAQCI="
-                }
-            }
-        }
 
         assert payload["FcSettings"]["Wwnn"]["StartingAddress"] == "IABAQEBAQCI="
         assert payload["FcSettings"]["Wwpn"]["StartingAddress"] == "IAFAQEBAQCI="
@@ -580,7 +561,7 @@ class TestOMeIdentityPool(FakeAnsibleModule):
         pool_list = {"resp_obj": ome_response_mock, "report_list": [{"Name": "pool1", "Id": 10},
                                                                     {"Name": "pool11", "Id": 11}]}
         ome_connection_mock_for_identity_pool.get_all_report_details.return_value = pool_list
-        pool_id, attributes = self.module.get_identity_pool_id_by_name("pool1", ome_connection_mock_for_identity_pool)
+        pool_id, _ = self.module.get_identity_pool_id_by_name("pool1", ome_connection_mock_for_identity_pool)  # pylint: disable=disallowed-name
         assert pool_id == 10
 
     def test_get_identity_pool_id_by_name_non_exist_case(self, mocker, ome_connection_mock_for_identity_pool,
@@ -977,6 +958,14 @@ class TestOMeIdentityPool(FakeAnsibleModule):
         base_64_val = self.module.mac_to_base64_conversion(mac_address, f_module)
         assert base_64_val == base_64_val_expected
 
+    def test_mac_to_base64_invalid_hex_raises_exit_json(self):
+        f_module = self.get_module_mock()
+        mac_input = "00:11:22:GG:44:55"  # Invalid hex character 'GG'
+        with pytest.raises(AnsibleFailJSonException) as exc_info:
+            mac_to_base64_conversion(mac_input, f_module)
+
+        assert "Encoding of MAC address" in str(exc_info.value)
+
     def test_pool_delete_case_01(self, ome_connection_mock_for_identity_pool, mocker):
         params = {"pool_name": "pool_name"}
         mocker.patch(
@@ -996,6 +985,24 @@ class TestOMeIdentityPool(FakeAnsibleModule):
             self.module.pool_delete(f_module, ome_connection_mock_for_identity_pool)
         assert exc.value.args[0] == "The identity pool '{0}' is not present in the system.".format(params["pool_name"])
 
+    def test_delete_identity_pool_check_mode(self, mocker, ome_connection_mock_for_identity_pool):
+        params = {"pool_name": "pool_name"}
+        f_module = self.get_module_mock(params=params)
+        f_module.check_mode = True
+        mocker.patch(
+            MODULE_PATH + 'ome_identity_pool.get_identity_pool_id_by_name', return_value=(1, {"value": "data"}))
+        with pytest.raises(AnsibleFailJSonException) as exc:
+            self.module.pool_delete(f_module, ome_connection_mock_for_identity_pool)
+        assert "Changes found to be applied." in str(exc.value)
+
+    def test_create_modify_identity_pool_check_mode(self, ome_connection_mock_for_identity_pool):
+        params = {"pool_name": "pool_name"}
+        f_module = self.get_module_mock(params=params)
+        f_module.check_mode = True
+        with pytest.raises(AnsibleFailJSonException) as exc:
+            self.module.pool_create_modify(f_module, ome_connection_mock_for_identity_pool)
+        assert "Changes found to be applied." in str(exc.value)
+
     def test_pool_delete_error_case_02(self, mocker, ome_connection_mock_for_identity_pool, ome_response_mock):
         msg = "exception message"
         params = {"pool_name": "pool_name"}
@@ -1004,7 +1011,7 @@ class TestOMeIdentityPool(FakeAnsibleModule):
             return_value=(1, "data"))
         f_module = self.get_module_mock(params=params)
         ome_connection_mock_for_identity_pool.invoke_request.side_effect = Exception(msg)
-        with pytest.raises(Exception, match=msg) as exc:
+        with pytest.raises(Exception, match=msg):
             self.module.pool_delete(f_module, ome_connection_mock_for_identity_pool)
 
     def test_main_ome_identity_pool_delete_success_case1(self, mocker, ome_default_args,
@@ -1015,7 +1022,7 @@ class TestOMeIdentityPool(FakeAnsibleModule):
         mocker.patch(MODULE_PATH + 'ome_identity_pool.pool_delete',
                      return_value=message_return)
         ome_default_args.update(sub_param)
-        result = self.execute_module(ome_default_args)
+        result = self._run_module(ome_default_args)
         assert 'pool_status' not in result
         assert result["msg"] == "Successfully deleted the identity pool."
 
@@ -1094,7 +1101,7 @@ class TestOMeIdentityPool(FakeAnsibleModule):
         f_module = self.get_module_mock()
         msg = "Both starting MAC address and identity count is required to {0} an identity pool using {1} settings.".format(
             action, ''.join(setting.split('Settings')))
-        with pytest.raises(Exception, match=msg) as exc:
+        with pytest.raises(Exception, match=msg):
             self.module.validate_modify_create_payload(modify_payload, f_module, action)
 
     modify_fc_setting1 = {"FcSettings": {
@@ -1142,21 +1149,7 @@ class TestOMeIdentityPool(FakeAnsibleModule):
         f_module = self.get_module_mock()
         msg = "Both starting MAC address and identity count is required to {0} an identity pool using Fc settings.".format(
             action)
-        with pytest.raises(Exception, match=msg) as exc:
-            self.module.validate_modify_create_payload(modify_payload, f_module, action)
-
-    @pytest.mark.parametrize("action", ["create", "modify"])
-    @pytest.mark.parametrize("modify_payload",
-                             [modify_fc_setting1, modify_fc_setting2, modify_fc_setting3, modify_fc_setting4,
-                              modify_fc_setting5])
-    # @pytest.mark.parametrize("modify_payload", [modify_fc_setting1])
-    def test_validate_modify_create_payload_failure_fc_setting_case(self, modify_payload, action):
-        payload = {"Id": 59, "Name": "pool_new"}
-        modify_payload.update(payload)
-        f_module = self.get_module_mock()
-        msg = "Both starting MAC address and identity count is required to {0} an identity pool using Fc settings.".format(
-            action)
-        with pytest.raises(Exception, match=msg) as exc:
+        with pytest.raises(Exception, match=msg):
             self.module.validate_modify_create_payload(modify_payload, f_module, action)
 
     payload_iscsi1 = {"IscsiSettings": {
@@ -1180,7 +1173,7 @@ class TestOMeIdentityPool(FakeAnsibleModule):
         f_module = self.get_module_mock()
         msg = "Both starting MAC address and identity count is required to {0} an identity pool using Iscsi settings.".format(
             action)
-        with pytest.raises(Exception, match=msg) as exc:
+        with pytest.raises(Exception, match=msg):
             self.module.validate_modify_create_payload(modify_payload, f_module, action)
 
     payload_iscsi3 = {
@@ -1269,7 +1262,7 @@ class TestOMeIdentityPool(FakeAnsibleModule):
         setting_type = "FcSettings"
         f_module = self.get_module_mock()
         msg = "Please provide the valid starting address format for FC settings."
-        with pytest.raises(Exception, match=msg) as exc:
+        with pytest.raises(Exception, match=msg):
             self.module.update_fc_settings(payload, setting_params, setting_type, f_module)
 
     @pytest.mark.parametrize("mac", [{'50-50-50-50-50-50': ['20-00-', '20-01-']},
