@@ -1,8 +1,8 @@
 # -*- coding: utf-8 -*-
 
 #
-# Dell EMC OpenManage Ansible Modules
-# Version 3.3.0
+# Dell OpenManage Ansible Modules
+# Version 7.0.0
 # Copyright (C) 2020-2021 Dell Inc. or its subsidiaries. All Rights Reserved.
 
 # GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
@@ -422,11 +422,11 @@ class TestOmePowerstate(FakeAnsibleModule):
         else:
             mocker.patch(
                 MODULE_PATH + 'ome_powerstate.spawn_update_job',
-                side_effect=exc_type('http://testhost.com', 400, 'http error message',
+                side_effect=exc_type('https://testhost.com', 400, 'http error message',
                                      {"accept-type": "application/json"}, StringIO(json_str)))
             mocker.patch(
                 MODULE_PATH + 'ome_powerstate.get_device_resource',
-                side_effect=exc_type('http://testhost.com', 400, 'http error message',
+                side_effect=exc_type('https://testhost.com', 400, 'http error message',
                                      {"accept-type": "application/json"}, StringIO(json_str)))
         result = self._run_module_with_fail_json(ome_default_args)
         assert 'power_state' not in result
