@@ -5,7 +5,11 @@
 from __future__ import (absolute_import, division, print_function)
 
 __metaclass__ = type
+import copy
+
 import pytest
+from ansible_collections.dellemc.powerflex.plugins.module_utils.storage.dell \
+    import utils
 # pylint: disable=unused-import
 from ansible_collections.dellemc.powerflex.tests.unit.plugins.module_utils.libraries import initial_mock
 from mock.mock import MagicMock
@@ -17,13 +21,15 @@ class PowerFlexUnitBase:
 
     '''Powerflex Unit Test Base Class'''
 
-    @pytest.fixture
+    @pytest.fixture(autouse=True)
     def powerflex_module_mock(self, mocker, module_object):
-        powerflex_module_mock = module_object()
-        powerflex_module_mock.module = MagicMock()
-        powerflex_module_mock.module.fail_json = fail_json
-        powerflex_module_mock.module.check_mode = False
-        return powerflex_module_mock
+        utils.is_version_less = MagicMock(return_value=False)
+        utils.is_version_ge_or_eq = MagicMock(return_value=False)
+        self.powerflex_module_mock = module_object()
+        self.powerflex_module_mock.module = MagicMock()
+        self.powerflex_module_mock.module.fail_json = fail_json
+        self.powerflex_module_mock.module.check_mode = False
+        return self.powerflex_module_mock
 
     def capture_fail_json_call(self, error_msg, module_mock, module_handler=None, invoke_perform_module=False):
         try:
@@ -35,6 +41,11 @@ class PowerFlexUnitBase:
             if error_msg not in fj_object.message:
                 raise AssertionError(fj_object.message)
 
-    def set_module_params(self, module_mock, get_module_args, params):
+    def set_module_params(self, module_mock, get_module_args, params, deep_copy=True):
+        if deep_copy:
+            get_module_args = copy.deepcopy(get_module_args)
         get_module_args.update(params)
-        module_mock.module.params = get_module_args
+        if module_mock is None:
+            self.powerflex_module_mock.module.params = get_module_args
+        else:
+            module_mock.module.params = get_module_args
