@@ -1,6 +1,6 @@
 # Copyright: (c) 2023, Dell Technologies
 
-# Apache License version 2.0 (see MODULE-LICENSE or http://www.apache.org/licenses/LICENSE-2.0.txt)
+# GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
 
 """Unit Tests for snapshot policy module on PowerFlex"""
 
@@ -35,7 +35,10 @@ class TestPowerflexSnapshotPolicy():
     def snapshot_policy_module_mock(self, mocker):
         snapshot_policy_module_mock = PowerFlexSnapshotPolicy()
         snapshot_policy_module_mock.module.check_mode = False
+        snapshot_policy_module_mock.module._diff = True
         snapshot_policy_module_mock.module.fail_json = fail_json
+        snapshot_policy_module_mock.powerflex_conn.system.api_version =\
+            MagicMock(return_value="4.5")
         return snapshot_policy_module_mock
 
     def capture_fail_json_call(self, error_msg, snapshot_policy_module_mock):
@@ -458,7 +461,7 @@ class TestPowerflexSnapshotPolicy():
         SnapshotPolicyHandler().handle(snapshot_policy_module_mock, snapshot_policy_module_mock.module.params)
         snapshot_policy_module_mock.powerflex_conn.snapshot_policy.resume.assert_called()
 
-    def test_pause_snapshot_policy_exception(self, snapshot_policy_module_mock):
+    def test_pause_paused_snapshot_policy(self, snapshot_policy_module_mock):
         self.get_module_args.update({
             "snapshot_policy_name": "testing_2",
             "pause": True,
@@ -471,7 +474,23 @@ class TestPowerflexSnapshotPolicy():
         snapshot_policy_module_mock.powerflex_conn.snapshot_policy.get_statistics = MagicMock(
             return_value=MockSnapshotPolicyApi.SNAPSHOT_POLICY_STATISTICS
         )
-        snapshot_policy_module_mock.powerflex_conn.volume.pause = MagicMock(
+        SnapshotPolicyHandler().handle(snapshot_policy_module_mock, snapshot_policy_module_mock.module.params)
+        snapshot_policy_module_mock.powerflex_conn.snapshot_policy.pause.assert_not_called()
+
+    def test_pause_snapshot_policy_exception(self, snapshot_policy_module_mock):
+        self.get_module_args.update({
+            "snapshot_policy_name": "testing_2",
+            "pause": True,
+            "state": "present"
+        })
+        snapshot_policy_module_mock.module.params = self.get_module_args
+        snapshot_policy_module_mock.powerflex_conn.snapshot_policy.get = MagicMock(
+            return_value=MockSnapshotPolicyApi.SNAPSHOT_POLICY_GET_LIST
+        )
+        snapshot_policy_module_mock.powerflex_conn.snapshot_policy.get_statistics = MagicMock(
+            return_value=MockSnapshotPolicyApi.SNAPSHOT_POLICY_STATISTICS
+        )
+        snapshot_policy_module_mock.powerflex_conn.snapshot_policy.pause = MagicMock(
             side_effect=MockApiException
         )
         self.capture_fail_json_call(MockSnapshotPolicyApi.get_snapshot_policy_exception_response('pause_exception'),
@@ -500,3 +519,48 @@ class TestPowerflexSnapshotPolicy():
         )
         self.capture_fail_json_call(MockSnapshotPolicyApi.get_snapshot_policy_exception_response('get_vol_details_exception'),
                                     snapshot_policy_module_mock)
+
+    def test_add_duplicated_source_volume_on_gen2(self, snapshot_policy_module_mock):
+        self.get_module_args.update({
+            "snapshot_policy_name": "testing",
+            "source_volume": [{
+                "name": "source_volume_name",
+                "id": None,
+                "auto_snap_removal_action": None,
+                "detach_locked_auto_snapshots": None,
+                "state": "present"}],
+            "state": "present"
+        })
+        snapshot_policy_module_mock.module.params = self.get_module_args
+        snapshot_policy_module_mock.module._diff = False
+        snapshot_policy_module_mock.powerflex_conn.system.api_version =\
+            MagicMock(return_value="5.0")
+        snapshot_policy_module_mock.powerflex_conn.snapshot_policy.get = MagicMock(
+            return_value=MockSnapshotPolicyApi.SNAPSHOT_POLICY_GET_LIST
+        )
+        snapshot_policy_module_mock.powerflex_conn.snapshot_policy.get_statistics = MagicMock(
+            return_value=MockSnapshotPolicyApi.SNAPSHOT_POLICY_STATISTICS
+        )
+        volume_detail = MockSnapshotPolicyApi.VOLUME_GET_LIST
+        volume_detail[0]['snplIdOfSourceVolume'] = MockSnapshotPolicyApi.SNAPSHOT_POLICY_GET_LIST[0]['id']
+        snapshot_policy_module_mock.powerflex_conn.volume.get = MagicMock(return_value=volume_detail)
+        SnapshotPolicyHandler().handle(snapshot_policy_module_mock, snapshot_policy_module_mock.module.params)
+        snapshot_policy_module_mock.powerflex_conn.snapshot_policy.add_source_volume.assert_not_called()
+        snapshot_policy_module_mock.powerflex_conn.snapshot_policy.get_statistics.assert_not_called()
+
+    def test_create_snapshot_policy_in_check_mode(self, snapshot_policy_module_mock):
+        self.get_module_args.update({
+            "snapshot_policy_name": "testing",
+            "access_mode": "ReadOnly",
+            "secure_snapshots": True,
+            "auto_snapshot_creation_cadence": {
+                "time": 1,
+                "unit": "Hour"},
+            "num_of_retained_snapshots_per_level": [20],
+            "state": "present"
+        })
+        snapshot_policy_module_mock.module.params = self.get_module_args
+        snapshot_policy_module_mock.module.check_mode = True
+        snapshot_policy_module_mock.powerflex_conn.snapshot_policy.get = MagicMock(return_value=None)
+        SnapshotPolicyHandler().handle(snapshot_policy_module_mock, snapshot_policy_module_mock.module.params)
+        snapshot_policy_module_mock.powerflex_conn.snapshot_policy.create.assert_not_called()
