@@ -1,7 +1,6 @@
 #!/usr/bin/python
-# Copyright: (c) 2022, Dell Technologies
-
-# Apache License version 2.0 (see MODULE-LICENSE or http://www.apache.org/licenses/LICENSE-2.0.txt)
+# Copyright: (c) 2022-2025, Dell Technologies
+# GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
 
 """Ansible module for managing Interfaces on Unity"""
 
@@ -79,55 +78,55 @@ notes:
 
 EXAMPLES = r'''
 
-    - name: Add Interface as Backup to NAS Server
-      dellemc.unity.interface:
-        unispherehost: "{{unispherehost}}"
-        username: "{{username}}"
-        password: "{{password}}"
-        validate_certs: "{{validate_certs}}"
-        nas_server_name: "dummy_nas"
-        ethernet_port_name: "SP A 4-Port Card Ethernet Port 0"
-        role: "BACKUP"
-        interface_ip: "xx.xx.xx.xx"
-        netmask: "xx.xx.xx.xx"
-        gateway: "xx.xx.xx.xx"
-        vlan_id: 324
-        state: "present"
+- name: Add Interface as Backup to NAS Server
+  interface:
+    unispherehost: "{{unispherehost}}"
+    username: "{{username}}"
+    password: "{{password}}"
+    validate_certs: "{{validate_certs}}"
+    nas_server_name: "dummy_nas"
+    ethernet_port_name: "SP A 4-Port Card Ethernet Port 0"
+    role: "BACKUP"
+    interface_ip: "xx.xx.xx.xx"
+    netmask: "xx.xx.xx.xx"
+    gateway: "xx.xx.xx.xx"
+    vlan_id: 324
+    state: "present"
 
-    - name: Add Interface as Production to NAS Server
-      dellemc.unity.interface:
-        unispherehost: "{{unispherehost}}"
-        username: "{{username}}"
-        password: "{{password}}"
-        validate_certs: "{{validate_certs}}"
-        nas_server_name: "dummy_nas"
-        ethernet_port_name: "SP A 4-Port Card Ethernet Port 0"
-        role: "PRODUCTION"
-        interface_ip: "xx.xx.xx.xx"
-        netmask: "xx.xx.xx.xx"
-        gateway: "xx.xx.xx.xx"
-        vlan_id: 324
-        state: "present"
+- name: Add Interface as Production to NAS Server
+  interface:
+    unispherehost: "{{unispherehost}}"
+    username: "{{username}}"
+    password: "{{password}}"
+    validate_certs: "{{validate_certs}}"
+    nas_server_name: "dummy_nas"
+    ethernet_port_name: "SP A 4-Port Card Ethernet Port 0"
+    role: "PRODUCTION"
+    interface_ip: "xx.xx.xx.xx"
+    netmask: "xx.xx.xx.xx"
+    gateway: "xx.xx.xx.xx"
+    vlan_id: 324
+    state: "present"
 
-    - name: Get interface details
-      dellemc.unity.interface:
-        unispherehost: "{{unispherehost}}"
-        username: "{{username}}"
-        password: "{{password}}"
-        validate_certs: "{{validate_certs}}"
-        nas_server_name: "dummy_nas"
-        interface_ip: "xx.xx.xx.xx"
-        state: "present"
+- name: Get interface details
+  interface:
+    unispherehost: "{{unispherehost}}"
+    username: "{{username}}"
+    password: "{{password}}"
+    validate_certs: "{{validate_certs}}"
+    nas_server_name: "dummy_nas"
+    interface_ip: "xx.xx.xx.xx"
+    state: "present"
 
-    - name: Delete Interface
-      dellemc.unity.interface:
-      unispherehost: "{{unispherehost}}"
-      username: "{{username}}"
-      password: "{{password}}"
-      validate_certs: "{{validate_certs}}"
-      nas_server_name: "dummy_nas"
-      interface_ip: "xx.xx.xx.xx"
-      state: "absent"
+- name: Delete Interface
+  interface:
+    unispherehost: "{{unispherehost}}"
+    username: "{{username}}"
+    password: "{{password}}"
+    validate_certs: "{{validate_certs}}"
+    nas_server_name: "dummy_nas"
+    interface_ip: "xx.xx.xx.xx"
+    state: "absent"
 '''
 
 RETURN = r'''
