@@ -1,7 +1,6 @@
 #!/usr/bin/python
-# Copyright: (c) 2020, Dell Technologies
-
-# Apache License version 2.0 (see MODULE-LICENSE or http://www.apache.org/licenses/LICENSE-2.0.txt)
+# Copyright: (c) 2020-2025, Dell Technologies
+# GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
 
 """Ansible module for managing snapshot schedules on Unity"""
 
@@ -122,7 +121,7 @@ notes:
 
 EXAMPLES = r"""
 - name: Create snapshot schedule (Rule Type - every_n_hours)
-  dellemc.unity.snapshotschedule:
+  snapshotschedule:
       unispherehost: "{{unispherehost}}"
       validate_certs: "{{validate_certs}}"
       username: "{{username}}"
@@ -134,7 +133,7 @@ EXAMPLES = r"""
       state: "{{state_present}}"
 
 - name: Create snapshot schedule (Rule Type - every_day)
-  dellemc.unity.snapshotschedule:
+  snapshotschedule:
       unispherehost: "{{unispherehost}}"
       validate_certs: "{{validate_certs}}"
       username: "{{username}}"
@@ -142,13 +141,13 @@ EXAMPLES = r"""
       name: "Ansible_Every_Day_Testing"
       type: "every_day"
       hours_of_day:
-        - 8
-        - 14
-      auto_delete: True
+          - 8
+          - 14
+      auto_delete: true
       state: "{{state_present}}"
 
 - name: Create snapshot schedule (Rule Type - every_n_days)
-  dellemc.unity.snapshotschedule:
+  snapshotschedule:
       unispherehost: "{{unispherehost}}"
       validate_certs: "{{validate_certs}}"
       username: "{{username}}"
@@ -161,7 +160,7 @@ EXAMPLES = r"""
       state: "{{state_present}}"
 
 - name: Create snapshot schedule (Rule Type - every_week)
-  dellemc.unity.snapshotschedule:
+  snapshotschedule:
       unispherehost: "{{unispherehost}}"
       validate_certs: "{{validate_certs}}"
       username: "{{username}}"
@@ -169,15 +168,15 @@ EXAMPLES = r"""
       name: "Ansible_Every_Week_Testing"
       type: "every_week"
       days_of_week:
-        - MONDAY
-        - FRIDAY
+          - MONDAY
+          - FRIDAY
       hour: 12
       minute: 30
       desired_retention: 200
       state: "{{state_present}}"
 
 - name: Create snapshot schedule (Rule Type - every_month)
-  dellemc.unity.snapshotschedule:
+  snapshotschedule:
       unispherehost: "{{unispherehost}}"
       validate_certs: "{{validate_certs}}"
       username: "{{username}}"
@@ -185,11 +184,11 @@ EXAMPLES = r"""
       name: "Ansible_Every_Month_Testing"
       type: "every_month"
       day_of_month: 17
-      auto_delete: True
+      auto_delete: true
       state: "{{state_present}}"
 
 - name: Get snapshot schedule details using name
-  dellemc.unity.snapshotschedule:
+  snapshotschedule:
       unispherehost: "{{unispherehost}}"
       validate_certs: "{{validate_certs}}"
       username: "{{username}}"
@@ -198,7 +197,7 @@ EXAMPLES = r"""
       state: "{{state_present}}"
 
 - name: Get snapshot schedule details using id
-  dellemc.unity.snapshotschedule:
+  snapshotschedule:
       unispherehost: "{{unispherehost}}"
       validate_certs: "{{validate_certs}}"
       username: "{{username}}"
@@ -207,7 +206,7 @@ EXAMPLES = r"""
       state: "{{state_present}}"
 
 - name: Modify snapshot schedule details id
-  dellemc.unity.snapshotschedule:
+  snapshotschedule:
       unispherehost: "{{unispherehost}}"
       validate_certs: "{{validate_certs}}"
       username: "{{username}}"
@@ -218,7 +217,7 @@ EXAMPLES = r"""
       state: "{{state_present}}"
 
 - name: Modify snapshot schedule using name
-  dellemc.unity.snapshotschedule:
+  snapshotschedule:
       unispherehost: "{{unispherehost}}"
       validate_certs: "{{validate_certs}}"
       username: "{{username}}"
@@ -226,11 +225,11 @@ EXAMPLES = r"""
       name: "Ansible_Every_Day_Testing"
       type: "every_day"
       desired_retention: 200
-      auto_delete: False
+      auto_delete: false
       state: "{{state_present}}"
 
 - name: Delete snapshot schedule using id
-  dellemc.unity.snapshotschedule:
+  snapshotschedule:
       unispherehost: "{{unispherehost}}"
       validate_certs: "{{validate_certs}}"
       username: "{{username}}"
@@ -239,7 +238,7 @@ EXAMPLES = r"""
       state: "{{state_absent}}"
 
 - name: Delete snapshot schedule using name
-  dellemc.unity.snapshotschedule:
+  snapshotschedule:
       unispherehost: "{{unispherehost}}"
       validate_certs: "{{validate_certs}}"
       username: "{{username}}"
@@ -253,7 +252,7 @@ changed:
     description: Whether or not the resource has changed.
     returned: always
     type: bool
-    sample: True
+    sample: true
 
 snapshot_schedule_details:
     description: Details of the snapshot schedule.
@@ -385,14 +384,13 @@ snapshot_schedule_details:
     }
 """
 
-import logging
 from ansible.module_utils.basic import AnsibleModule
 from ansible_collections.dellemc.unity.plugins.module_utils.storage.dell \
     import utils
 
 LOG = utils.get_logger('snapshotschedule')
 
-application_type = "Ansible/1.6.0"
+application_type = "Ansible/1.7.1"
 
 
 class SnapshotSchedule(object):
