@@ -83,14 +83,14 @@ EXAMPLES = r'''
     pool: my-regkey-pool
     key: XXXX-XXXX-XXXX-XXXX-XXXX
     device: 1.1.1.1
-    managed: no
+    managed: false
     device_username: admin
     device_password: secret
     state: present
     provider:
       user: admin
       password: secret
-      server: lb.mydomain.com
+      server: cm.mydomain.com
   delegate_to: localhost
 
 - name: Register a managed device, by name
@@ -98,12 +98,12 @@ EXAMPLES = r'''
     pool: my-regkey-pool
     key: XXXX-XXXX-XXXX-XXXX-XXXX
     device: bigi1.foo.com
-    managed: yes
+    managed: true
     state: present
     provider:
       user: admin
       password: secret
-      server: lb.mydomain.com
+      server: cm.mydomain.com
   delegate_to: localhost
 
 - name: Register a managed device, by UUID
@@ -111,12 +111,12 @@ EXAMPLES = r'''
     pool: my-regkey-pool
     key: XXXX-XXXX-XXXX-XXXX-XXXX
     device: 7141a063-7cf8-423f-9829-9d40599fa3e0
-    managed: yes
+    managed: true
     state: present
     provider:
       user: admin
       password: secret
-      server: lb.mydomain.com
+      server: cm.mydomain.com
   delegate_to: localhost
 '''
 
