@@ -39,21 +39,11 @@ version_added: "1.0.0"
 
 import time
 import json
-import traceback
 from ansible.plugins.httpapi import HttpApiBase
 from ansible.module_utils.basic import to_text
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import (
-    BASE_HEADERS,
-)
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import (
-    FMGBaseException,
-)
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import (
-    FMGRCommon,
-)
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import (
-    FMGRMethods,
-)
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import BASE_HEADERS
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import FMGBaseException
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import FMGRCommon
 from datetime import datetime
 
 
@@ -63,9 +53,7 @@ class HttpApi(HttpApiBase):
         self._req_id = 0
         self._sid = None
         self._url = "/jsonrpc"
-        self._host = None
         self._tools = FMGRCommon
-        self._debug = False
         self._connected_fmgr = None
         self._last_response_msg = None
         self._last_response_code = None
@@ -82,26 +70,15 @@ class HttpApi(HttpApiBase):
         self._log = None
         self._prelocking_user_params = list()
         self._access_token = None
+        self._login_method = None
+        self._status = {}
+        self.customer_options = {}
 
-    def get_forticloud_access_token(self):
-        try:
-            token = self.connection.get_option("forticloud_access_token")
-            return token
-        except Exception as e:
-            return None
-
-    def get_access_token(self):
-        try:
-            token = self.connection.get_option("access_token")
-            return token
-        except Exception as e:
-            return None
+    def set_customer_option(self, key, value):
+        self.customer_options[key] = value
 
     def log(self, msg):
-        try:
-            log_enabled = self.connection.get_option("enable_log")
-        except Exception as e:
-            return
+        log_enabled = self.customer_options.get("enable_log", False)
         if not log_enabled:
             return
         if not self._log:
@@ -129,7 +106,7 @@ class HttpApi(HttpApiBase):
         return None
 
     def forticloud_login(self):
-        login_data = '{"access_token": "%s"}' % (self.get_forticloud_access_token())
+        login_data = '{"access_token": "%s"}' % (self.customer_options.get("forticloud_access_token", None))
         try:
             response, response_data = self.connection.send(
                 path=to_text("/p/forticloud_jsonrpc_login/"),
@@ -152,63 +129,47 @@ class HttpApi(HttpApiBase):
         """
         self.log("login begin, user: %s" % (username))
         self._logged_in_user = username
-        forticloud_access_token = self.get_forticloud_access_token()
-        self._access_token = self.get_access_token()
-        self.log(
-            "forticloud access token: %s"
-            % (forticloud_access_token if forticloud_access_token else "(not set)")
-        )
-        login_method = 'None'
-        if self._access_token:
-            login_method = 'access_token'
-        elif not forticloud_access_token:
-            login_method = 'normal'
-            self.send_request(
-                FMGRMethods.EXEC,
-                self._tools.format_request(
-                    FMGRMethods.EXEC, "sys/login/user", passwd=password, user=username
-                ),
-            )
-        else:
-            login_method = 'forticloud'
+        forticloud_access_token = self.customer_options.get("forticloud_access_token", None)
+        self._access_token = self.customer_options.get("access_token", None)
+        if username is not None and password is not None:
+            self._login_method = 'username_password'
+            self.send_request("exec", self._tools.format_request("exec", "sys/login/user", passwd=password, user=username))
+        elif self._access_token:
+            self._login_method = 'access_token'
+        elif forticloud_access_token:
+            self._login_method = 'forticloud'
             self.forticloud_login()
-        self.log('login method: ' + login_method)
-        self.log(self)
-        if "FortiManager object connected to FortiManager" in self.__str__():
+        else:
+            err_msg = "Please check whether you provide the correct information."
+            raise AssertionError(err_msg)
+        self.log('login method: ' + self._login_method)
+        if (self.sid or self._access_token) and self.connection._url is not None:
             # If Login worked, then inspect the FortiManager for Workspace Mode, and it's system information.
             self.inspect_fmgr()
             self._logged = True
             for param in self._prelocking_user_params:
                 self.process_workspace_locking_internal(param)
         else:
-            raise FMGBaseException(
-                msg="Unknown error while logging in...connection was lost during login operation...."
-                " Exiting"
-            )
+            err_msg = "Can't login. Your login method is %s. Please check whether you provide the correct information." % (self._login_method)
+            raise FMGBaseException(msg=err_msg)
 
     def inspect_fmgr(self):
         # CHECK FOR WORKSPACE MODE TO SEE IF WE HAVE TO ENABLE ADOM LOCKS
-        status = self.get_system_status()
-        self.log("system status:\n" + json.dumps(status, indent=4))
-        if status[0] == -11:
+        rc, status = self.get_system_status()
+        if rc == -11:
             # THE CONNECTION GOT LOST SOMEHOW, REMOVE THE SID AND REPORT BAD LOGIN
             self.logout()
-            raise FMGBaseException(
-                msg="Error -11 -- the Session ID was likely malformed somehow. Contact authors."
-                " Exiting"
-            )
-        elif status[0] == 0:
+            raise FMGBaseException(msg="Error -11 -- Failed to get the FMG system status. Exiting")
+        elif rc == 0:
             try:
                 self.check_mode()
                 if self._uses_adoms:
                     self.get_adom_list()
                 if self._uses_workspace:
                     self.get_locked_adom_list()
-                self._connected_fmgr = status[1]
-                self._host = self._connected_fmgr["data"]["Hostname"]
+                self._connected_fmgr = status
             except Exception as e:
                 self.log("inspect_fmgr exception: %s" % (e))
-                self.log(traceback.format_exc())
 
     def logout(self):
         """
@@ -218,17 +179,13 @@ class HttpApi(HttpApiBase):
             "log out, using workspace:%s user: %s sid: %s"
             % (self._uses_workspace, self._logged_in_user, self.sid)
         )
+        # IF WE WERE USING WORKSPACES, THEN CLEAN UP OUR LOCKS IF THEY STILL EXIST
+        if self._uses_workspace:
+            self.run_unlock()
         if self.sid:
-            # IF WE WERE USING WORKSPACES, THEN CLEAN UP OUR LOCKS IF THEY STILL EXIST
-            if self._uses_workspace:
-                # self.get_lock_info()
-                self.run_unlock()
-            ret_code, response = self.send_request(
-                FMGRMethods.EXEC,
-                self._tools.format_request(FMGRMethods.EXEC, "sys/logout"),
-            )
+            rc, response = self.send_request("exec", self._tools.format_request("exec", "sys/logout"))
             self.sid = None
-            return ret_code, response
+            return rc, response
 
     def send_request(self, method, params):
         """
@@ -243,7 +200,7 @@ class HttpApi(HttpApiBase):
         if self.sid is None and params[0]["url"] != "sys/login/user":
             if not self.connection._connected:
                 self.connection._connect()
-        if params[0]["url"] == "sys/login/user" and "passwd" in params[0]["data"]:
+        if params[0]["url"] == "sys/login/user" and "data" in params[0] and "passwd" in params[0]["data"]:
             params[0]["data"]["passwd"] = str(params[0]["data"]["passwd"])
         self._update_request_id()
         json_request = {
@@ -254,27 +211,29 @@ class HttpApi(HttpApiBase):
             "verbose": 1,
         }
         data = json.dumps(json_request, ensure_ascii=False).replace("\\\\", "\\")
-        log_data = data
+
         # Don't log sensitive information
-        if params[0]["url"] == "sys/login/user" and "passwd" in params[0]["data"]:
+        if params[0]["url"] == "sys/login/user" and "data" in params[0] and "passwd" in params[0]["data"]:
             json_request["params"][0]["data"]["passwd"] = "******"
-            log_data = json.dumps(json_request, ensure_ascii=False).replace("\\\\", "\\")
+        if "session" in params[0]:
+            json_request["params"][0]["session"] = "******"
+        log_data = json.dumps(json_request, ensure_ascii=False).replace("\\\\", "\\")
         self.log("request: %s" % (log_data))
-        try:
-            # Sending URL and Data in Unicode, per Ansible Specifications for Connection Plugins
-            header_data = BASE_HEADERS
-            if self._access_token:
-                header_data["Authorization"] = "Bearer " + self._access_token
-            response, response_data = self.connection.send(
-                path=to_text(self._url), data=to_text(data), headers=header_data
-            )
-            # Get Unicode Response - Must convert from StringIO to unicode first so we can do a replace function below
-            result = json.loads(to_text(response_data.getvalue()))
-            self.log("response: %s" % (str(self._jsonize(result))))
-            self._update_self_from_response(result, self._url, data)
-            return self._handle_response(result)
-        except Exception as err:
-            raise FMGBaseException(err)
+
+        # Sending URL and Data in Unicode, per Ansible Specifications for Connection Plugins
+        access_token_str = ''
+        header_data = BASE_HEADERS
+        if self._login_method == "access_token":
+            access_token_str = '?access_token=' + self._access_token
+            header_data["Authorization"] = "Bearer " + self._access_token
+        response, response_data = self.connection.send(
+            path=to_text(self._url) + access_token_str, data=to_text(data), headers=header_data
+        )
+        # Get Unicode Response - Must convert from StringIO to unicode first so we can do a replace function below
+        result = json.loads(to_text(response_data.getvalue()))
+        self.log("response: %s" % (str(self._jsonize(result))))
+        self._update_self_from_response(result, self._url, data)
+        return self._handle_response(result)
 
     def _jsonize(self, data):
         ret = None
@@ -308,30 +267,22 @@ class HttpApi(HttpApiBase):
         if self.sid is None and "session" in response:
             self.sid = response["session"]
 
-    def return_connected_fmgr(self):
-        """
-        Returns the data stored under self._connected_fmgr
-
-        :return: dict
-        """
-        try:
-            if self._connected_fmgr:
-                return self._connected_fmgr
-        except Exception:
-            raise FMGBaseException("Couldn't Retrieve Connected FMGR Stats")
-
     def get_system_status(self):
         """
         Returns the system status page from the FortiManager, for logging and other uses.
         return: status
         """
-        status = self.send_request(
-            FMGRMethods.GET, self._tools.format_request(FMGRMethods.GET, "sys/status")
-        )
-        return status
+        if not self.connection._connected:
+            self.connection._connect()
+        if self._status:
+            return 0, self._status
+        rc, self._status = self.send_request("get", self._tools.format_request("get", "/sys/status"))
+        if rc == -11:
+            rc, self._status = self.send_request("get", self._tools.format_request("get", "/cli/global/system/status"))
+        return rc, self._status
 
     def process_workspace_locking_internal(self, param):
-        if not self._uses_workspace or not self.sid:
+        if not self._uses_workspace or not self._logged:
             return
         if "workspace_locking_adom" not in param or not param["workspace_locking_adom"]:
             # The FortiManager is running in workspace mode, please `workspace_locking_adom` in your playbook
@@ -344,47 +295,34 @@ class HttpApi(HttpApiBase):
             "trying to acquire lock for adom: %s within %s seconds by user: %s"
             % (adom_to_lock, adom_to_lock_timeout, self._logged_in_user)
         )
-        if (
-            adom_to_lock in self._locked_adoms_by_user
-            and self._locked_adoms_by_user[adom_to_lock] == self._logged_in_user
-        ):
-            # XXX: here is a situation where user can still has no permission to access resources:
-            # indeed the worksapce lock is acquired by the user himself, but the lock is not
-            # associated with this session.
-            self.log(
-                "adom: %s has already been acquired by user: %s"
-                % (adom_to_lock, self._logged_in_user)
-            )
-        elif (
-            adom_to_lock in self._locked_adoms_by_user
-            and self._locked_adoms_by_user[adom_to_lock] != self._logged_in_user
-        ):
-            total_wait_time = 0
-            while total_wait_time < adom_to_lock_timeout:
-                code, dummy = self.lock_adom(adom_to_lock)
+        if adom_to_lock in self._locked_adoms_by_user:
+            if self._locked_adoms_by_user[adom_to_lock] == self._logged_in_user:
+                # XXX: here is a situation where user can still has no permission to access resources:
+                # indeed the worksapce lock is acquired by the user himself, but the lock is not
+                # associated with this session.
                 self.log(
-                    "waiting adom:%s lock to be released by %s, total time spent:%s seconds status:%s"
-                    % (
-                        adom_to_lock,
-                        self._locked_adoms_by_user[adom_to_lock],
-                        total_wait_time,
-                        "success" if code == 0 else "failure",
-                    )
+                    "adom: %s has already been acquired by user: %s"
+                    % (adom_to_lock, self._logged_in_user)
                 )
-                if code == 0:
-                    self._locked_adoms_by_user[adom_to_lock] = self._logged_in_user
-                    break
-                time.sleep(5)
-                total_wait_time += 5
+            else:
+                total_wait_time = 0
+                while total_wait_time < adom_to_lock_timeout:
+                    code, resp_obj = self.lock_adom(adom_to_lock)
+                    self.log(
+                        "waiting adom:%s lock to be released by %s, total time spent:%s seconds status:%s"
+                        % (adom_to_lock, self._locked_adoms_by_user[adom_to_lock],
+                           total_wait_time, "success" if code == 0 else "failure")
+                    )
+                    if code == 0:
+                        self._locked_adoms_by_user[adom_to_lock] = self._logged_in_user
+                        break
+                    time.sleep(5)
+                    total_wait_time += 5
         else:
-            code, dummy = self.lock_adom(adom_to_lock)
+            code, resp_obj = self.lock_adom(adom_to_lock)
             self.log(
                 "adom:%s locked by user: %s status:%s"
-                % (
-                    adom_to_lock,
-                    self._logged_in_user,
-                    "success" if code == 0 else "failure",
-                )
+                % (adom_to_lock, self._logged_in_user, "success" if code == 0 else "failure")
             )
             if code == 0:
                 self._locked_adoms_by_user[adom_to_lock] = self._logged_in_user
@@ -398,14 +336,6 @@ class HttpApi(HttpApiBase):
         else:
             self.process_workspace_locking_internal(param)
 
-    @property
-    def debug(self):
-        return self._debug
-
-    @debug.setter
-    def debug(self, val):
-        self._debug = val
-
     @property
     def req_id(self):
         return self._req_id
@@ -427,33 +357,13 @@ class HttpApi(HttpApiBase):
 
     def __str__(self):
         if (self.sid or self._access_token) and self.connection._url is not None:
-            return "FortiManager object connected to FortiManager: " + to_text(
-                self.connection._url
-            )
-        return (
-            "FortiManager object with no valid connection to a FortiManager appliance."
-        )
+            return "FortiManager object connected to FortiManager: " + to_text(self.connection._url)
+        return "FortiManager object with no valid connection to a FortiManager appliance."
 
     ##################################
     # BEGIN DATABASE LOCK CONTEXT CODE
     ##################################
 
-    @property
-    def uses_workspace(self):
-        return self._uses_workspace
-
-    @uses_workspace.setter
-    def uses_workspace(self, val):
-        self._uses_workspace = val
-
-    @property
-    def uses_adoms(self):
-        return self._uses_adoms
-
-    @uses_adoms.setter
-    def uses_adoms(self, val):
-        self._uses_adoms = val
-
     def add_adom_to_lock_list(self, adom):
         if adom not in self._locked_adom_list:
             self._locked_adom_list.append(adom)
@@ -467,32 +377,16 @@ class HttpApi(HttpApiBase):
         Checks FortiManager for the use of Workspace mode
         """
         url = "/cli/global/system/global"
-        code, resp_obj = self.send_request(
-            FMGRMethods.GET,
-            self._tools.format_request(
-                FMGRMethods.GET, url, fields=["workspace-mode", "adom-status"]
-            ),
-        )
-        try:
-            if resp_obj["data"]["workspace-mode"] in ["workflow", "normal"]:  # per-adom
-                self._uses_workspace = True
-            else:
-                self._uses_workspace = False
-        except KeyError:
-            raise FMGBaseException(
-                msg="Couldn't determine workspace-mode in the plugin"
-            )
-        try:
-            if resp_obj["data"]["adom-status"] in [1, "enable"]:
+        rc, resp_obj = self.send_request("get", self._tools.format_request("get", url, fields=["workspace-mode", "adom-status"]))
+        # Skip this step if user is not permitted to access this resource
+        if rc == -11:
+            self.log("Skip workspace-mode check due to no permission to access /cli/global/system/global")
+        if "data" in resp_obj and isinstance(resp_obj["data"], dict):
+            if resp_obj["data"].get("adom-status", "") in [1, "enable"]:
                 self._uses_adoms = True
-            else:
-                self._uses_adoms = False
-        except KeyError:
-            raise FMGBaseException(msg="Couldn't determine adom-status in the plugin")
-        self.log(
-            "workspace-mode: %s adom-status: %s"
-            % (self._uses_workspace, self._uses_adoms)
-        )
+            if resp_obj["data"].get("workspace-mode", "") in ["workflow", "normal", "per-adom"]:
+                self._uses_workspace = True
+        self.log("workspace-mode: %s adom-status: %s" % (self._uses_workspace, self._uses_adoms))
 
     def run_unlock(self):
         """
@@ -505,7 +399,7 @@ class HttpApi(HttpApiBase):
                 self.unlock_adom(adom_locked)
                 self.log("unlock adom: %s with session_id:%s" % (adom_locked, self.sid))
 
-    def lock_adom(self, adom=None, *args, **kwargs):
+    def lock_adom(self, adom=None):
         """
         Locks an ADOM for changes
         """
@@ -516,14 +410,12 @@ class HttpApi(HttpApiBase):
                 url = "/dvmdb/adom/{adom}/workspace/lock/".format(adom=adom)
         else:
             url = "/dvmdb/adom/root/workspace/lock"
-        code, respobj = self.send_request(
-            FMGRMethods.EXEC, self._tools.format_request(FMGRMethods.EXEC, url)
-        )
+        code, respobj = self.send_request("exec", self._tools.format_request("exec", url))
         if code == 0 and respobj["status"]["message"].lower() == "ok":
             self.add_adom_to_lock_list(adom)
         return code, respobj
 
-    def unlock_adom(self, adom=None, *args, **kwargs):
+    def unlock_adom(self, adom=None):
         """
         Unlocks an ADOM after changes
         """
@@ -534,14 +426,12 @@ class HttpApi(HttpApiBase):
                 url = "/dvmdb/adom/{adom}/workspace/unlock/".format(adom=adom)
         else:
             url = "/dvmdb/adom/root/workspace/unlock"
-        code, respobj = self.send_request(
-            FMGRMethods.EXEC, self._tools.format_request(FMGRMethods.EXEC, url)
-        )
+        code, respobj = self.send_request("exec", self._tools.format_request("exec", url))
         if code == 0 and respobj["status"]["message"].lower() == "ok":
             self.remove_adom_from_lock_list(adom)
         return code, respobj
 
-    def commit_changes(self, adom=None, aux=False, *args, **kwargs):
+    def commit_changes(self, adom=None, aux=False):
         """
         Commits changes to an ADOM
         """
@@ -555,40 +445,22 @@ class HttpApi(HttpApiBase):
                     url = "/dvmdb/adom/{adom}/workspace/commit".format(adom=adom)
         else:
             url = "/dvmdb/adom/root/workspace/commit"
-        return self.send_request(
-            FMGRMethods.EXEC, self._tools.format_request(FMGRMethods.EXEC, url)
-        )
+        return self.send_request("exec", self._tools.format_request("exec", url))
 
     def get_lock_info(self, adom=None):
         """
         Gets ADOM lock info so it can be displayed with the error messages. Or if determined to be locked by ansible
         for some reason, then unlock it.
         """
-        if not adom or adom == "root":
-            url = "/dvmdb/adom/root/workspace/lockinfo"
-        else:
+        url = "/dvmdb/adom/root/workspace/lockinfo"
+        if adom and adom != "root":
             if adom.lower() == "global":
-                url = "/dvmdb/global/workspace/lockinfo/"
+                url = "/dvmdb/global/workspace/lockinfo"
             else:
                 url = "/dvmdb/adom/{adom}/workspace/lockinfo/".format(adom=adom)
-        datagram = {}
-        data = self._tools.format_request(FMGRMethods.GET, url, **datagram)
-        resp_obj = self.send_request(FMGRMethods.GET, data)
-        code = resp_obj[0]
-        if code != 0:
-            self._module.fail_json(
-                msg=(
-                    "An error occurred trying to get the ADOM Lock Info. "
-                    "Error: " + to_text(resp_obj)
-                )
-            )
-        elif code == 0:
-            try:
-                if resp_obj[1]["status"]["message"] == "OK":
-                    self._lock_info = None
-            except Exception:
-                self._lock_info = resp_obj[1]
-        return resp_obj
+        rc, resp_obj = self.send_request("get", self._tools.format_request("get", url))
+        # rc=-9: current adom is not in the workspace mode.
+        return rc, resp_obj
 
     def get_adom_list(self):
         """
@@ -596,26 +468,18 @@ class HttpApi(HttpApiBase):
         """
         if self._uses_adoms:
             url = "/dvmdb/adom"
-            datagram = {}
-            data = self._tools.format_request(FMGRMethods.GET, url, **datagram)
-            resp_obj = self.send_request(FMGRMethods.GET, data)
-            code = resp_obj[0]
-            if code != 0:
-                self._module.fail_json(
-                    msg=(
-                        "An error occurred trying to get the ADOM Info. "
-                        "Error: " + to_text(resp_obj)
-                    )
-                )
-            elif code == 0:
-                num_of_adoms = len(resp_obj[1]["data"])
+            rc, resp_obj = self.send_request("get", self._tools.format_request("get", url))
+            if rc != 0:
+                err_msg = "An error occurred trying to get the ADOM Info. Error %s: %s" % (rc, to_text(resp_obj))
+                raise FMGBaseException(msg=err_msg)
+            else:
                 append_list = ["root", "global"]
-                for adom in resp_obj[1]["data"]:
+                for adom in resp_obj["data"]:
                     if adom["tab_status"] != "":
                         append_list.append(to_text(adom["name"]))
                 self._adom_list = append_list
             self.log("adom list: %s" % (str(self._adom_list)))
-            return resp_obj
+            return rc, resp_obj
 
     def get_locked_adom_list(self):
         """
@@ -625,18 +489,18 @@ class HttpApi(HttpApiBase):
             locked_list = list()
             locked_by_user_list = dict()
             for adom in self._adom_list:
-                adom_lock_info = self.get_lock_info(adom=adom)
                 self.log("lockinfo for adom:%s" % (adom))
-                self.log(json.dumps(adom_lock_info, indent=4))
-                if adom_lock_info[1]["status"]["code"] != 0:
+                rc, adom_lock_info = self.get_lock_info(adom=adom)
+                if adom_lock_info["status"]["code"] != 0:
                     continue
                 # if 'data' is not in the response, the adom is locked by no one
-                if "data" not in adom_lock_info[1]:
+                if "data" not in adom_lock_info:
                     continue
-                locked_list.append(to_text(adom))
-                locked_by_user_list[to_text(adom)] = to_text(
-                    adom_lock_info[1]["data"][0]["lock_user"]
-                )
+                lock_data = adom_lock_info["data"]
+                if isinstance(lock_data, list):
+                    lock_data = lock_data[0]
+                locked_list.append(adom)
+                locked_by_user_list[adom] = lock_data["lock_user"]
 
             self._locked_adom_list = locked_list
             self._locked_adoms_by_user = locked_by_user_list
