@@ -73,6 +73,9 @@ options:
         choices:
           - present
           - absent
+    revision_note:
+        description: The change note that can be specified when an object is created or updated.
+        type: str
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
         type: str
@@ -113,6 +116,7 @@ options:
 EXAMPLES = '''
 - name: Example playbook
   hosts: fortimanagers
+  gather_facts: false
   connection: httpapi
   vars:
     ansible_httpapi_use_ssl: true
@@ -122,7 +126,7 @@ EXAMPLES = '''
     - name: Modify this MMS content checksum list
       fortinet.fortimanager.fmgr_antivirus_mmschecksum_entries:
         adom: FortiCarrier
-        mms-checksum: "1" # id
+        mms_checksum: "1" # id
         state: present
         antivirus_mmschecksum_entries:
           checksum: "test_checksum"
@@ -145,7 +149,7 @@ EXAMPLES = '''
           params:
             adom: "FortiCarrier" # This is FOC-only object, data will only be returned under FortiCarrier adom
             entries: ""
-            mms-checksum: "1" # id
+            mms_checksum: "1" # id
 '''
 
 RETURN = '''
@@ -204,13 +208,14 @@ def main():
         'adom': {'required': True, 'type': 'str'},
         'mms-checksum': {'type': 'str', 'api_name': 'mms_checksum'},
         'mms_checksum': {'type': 'str'},
+        'revision_note': {'type': 'str'},
         'antivirus_mmschecksum_entries': {
             'type': 'dict',
-            'v_range': [['6.0.0', '']],
+            'v_range': [['6.0.0', '7.6.2']],
             'options': {
-                'checksum': {'type': 'str'},
-                'name': {'required': True, 'type': 'str'},
-                'status': {'choices': ['disable', 'enable'], 'type': 'str'}
+                'checksum': {'v_range': [['6.0.0', '7.6.2']], 'type': 'str'},
+                'name': {'v_range': [['6.0.0', '7.6.2']], 'required': True, 'type': 'str'},
+                'status': {'v_range': [['6.0.0', '7.6.2']], 'choices': ['disable', 'enable'], 'type': 'str'}
             }
         }
     }
