@@ -73,6 +73,9 @@ options:
         choices:
           - present
           - absent
+    revision_note:
+        description: The change note that can be specified when an object is created or updated.
+        type: str
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
         type: str
@@ -114,6 +117,7 @@ options:
 EXAMPLES = '''
 - name: Example playbook
   hosts: fortimanagers
+  gather_facts: false
   connection: httpapi
   vars:
     ansible_httpapi_use_ssl: true
@@ -204,13 +208,14 @@ def main():
     module_arg_spec = {
         'adom': {'required': True, 'type': 'str'},
         'notification': {'required': True, 'type': 'str'},
+        'revision_note': {'type': 'str'},
         'antivirus_notification_entries': {
             'type': 'dict',
-            'v_range': [['6.0.0', '']],
+            'v_range': [['6.0.0', '7.6.2']],
             'options': {
-                'name': {'required': True, 'type': 'str'},
-                'prefix': {'choices': ['disable', 'enable'], 'type': 'str'},
-                'status': {'choices': ['disable', 'enable'], 'type': 'str'}
+                'name': {'v_range': [['6.0.0', '7.6.2']], 'required': True, 'type': 'str'},
+                'prefix': {'v_range': [['6.0.0', '7.6.2']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                'status': {'v_range': [['6.0.0', '7.6.2']], 'choices': ['disable', 'enable'], 'type': 'str'}
             }
         }
     }
