@@ -64,6 +64,9 @@ options:
         description: The rc codes list with which the conditions to fail will be overriden.
         type: list
         elements: int
+    revision_note:
+        description: The change note that can be specified when an object is created or updated.
+        type: str
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
         type: str
@@ -182,12 +185,21 @@ options:
                     - 'disable'
                     - 'monitor'
                     - 'block'
+            malware_stream:
+                aliases: ['malware-stream']
+                type: str
+                description: Enable 0-day malware-stream scanning.
+                choices:
+                    - 'disable'
+                    - 'monitor'
+                    - 'block'
 '''
 
 EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -196,45 +208,46 @@ EXAMPLES = '''
     - name: Configure SFTP and SCP AntiVirus options.
       fortinet.fortimanager.fmgr_antivirus_profile_ssh:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         adom: <your own value>
         profile: <your own value>
         antivirus_profile_ssh:
-          archive_block:
-            - "encrypted"
-            - "corrupted"
-            - "multipart"
-            - "nested"
-            - "mailbomb"
-            - "unhandled"
-            - "partiallycorrupted"
-            - "fileslimit"
-            - "timeout"
-          archive_log:
-            - "encrypted"
-            - "corrupted"
-            - "multipart"
-            - "nested"
-            - "mailbomb"
-            - "unhandled"
-            - "partiallycorrupted"
-            - "fileslimit"
-            - "timeout"
-          emulator: <value in [disable, enable]>
-          options:
-            - "avmonitor"
-            - "quarantine"
-            - "scan"
-          outbreak_prevention: <value in [disabled, files, full-archive, ...]>
-          av_scan: <value in [disable, monitor, block]>
-          external_blocklist: <value in [disable, monitor, block]>
-          quarantine: <value in [disable, enable]>
-          fortindr: <value in [disable, block, monitor]>
-          fortisandbox: <value in [disable, block, monitor]>
-          fortiai: <value in [disable, monitor, block]>
+          # archive_block:
+          #   - "encrypted"
+          #   - "corrupted"
+          #   - "multipart"
+          #   - "nested"
+          #   - "mailbomb"
+          #   - "unhandled"
+          #   - "partiallycorrupted"
+          #   - "fileslimit"
+          #   - "timeout"
+          # archive_log:
+          #   - "encrypted"
+          #   - "corrupted"
+          #   - "multipart"
+          #   - "nested"
+          #   - "mailbomb"
+          #   - "unhandled"
+          #   - "partiallycorrupted"
+          #   - "fileslimit"
+          #   - "timeout"
+          # emulator: <value in [disable, enable]>
+          # options:
+          #   - "avmonitor"
+          #   - "quarantine"
+          #   - "scan"
+          # outbreak_prevention: <value in [disabled, files, full-archive, ...]>
+          # av_scan: <value in [disable, monitor, block]>
+          # external_blocklist: <value in [disable, monitor, block]>
+          # quarantine: <value in [disable, enable]>
+          # fortindr: <value in [disable, block, monitor]>
+          # fortisandbox: <value in [disable, block, monitor]>
+          # fortiai: <value in [disable, monitor, block]>
+          # malware_stream: <value in [disable, monitor, block]>
 '''
 
 RETURN = '''
@@ -292,6 +305,7 @@ def main():
     module_arg_spec = {
         'adom': {'required': True, 'type': 'str'},
         'profile': {'required': True, 'type': 'str'},
+        'revision_note': {'type': 'str'},
         'antivirus_profile_ssh': {
             'type': 'dict',
             'v_range': [['6.2.2', '']],
@@ -320,7 +334,8 @@ def main():
                 'quarantine': {'v_range': [['7.0.0', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
                 'fortindr': {'v_range': [['7.0.5', '']], 'choices': ['disable', 'block', 'monitor'], 'type': 'str'},
                 'fortisandbox': {'v_range': [['7.2.0', '']], 'choices': ['disable', 'block', 'monitor'], 'type': 'str'},
-                'fortiai': {'v_range': [['7.0.1', '']], 'choices': ['disable', 'monitor', 'block'], 'type': 'str'}
+                'fortiai': {'v_range': [['7.0.1', '']], 'choices': ['disable', 'monitor', 'block'], 'type': 'str'},
+                'malware-stream': {'v_range': [['7.6.3', '']], 'choices': ['disable', 'monitor', 'block'], 'type': 'str'}
             }
         }
     }
