@@ -73,6 +73,9 @@ options:
         choices:
           - present
           - absent
+    revision_note:
+        description: The change note that can be specified when an object is created or updated.
+        type: str
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
         type: str
@@ -120,6 +123,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -128,8 +132,8 @@ EXAMPLES = '''
     - name: CASB custom control option.
       fortinet.fortimanager.fmgr_casb_profile_saasapplication_customcontrol_option:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         adom: <your own value>
@@ -138,8 +142,8 @@ EXAMPLES = '''
         custom_control: <your own value>
         state: present # <value in [present, absent]>
         casb_profile_saasapplication_customcontrol_option:
-          name: <string>
-          user_input: <list or string>
+          name: "your value" # Required variable, string
+          # user_input: <list or string>
 '''
 
 RETURN = '''
@@ -201,6 +205,7 @@ def main():
         'saas_application': {'type': 'str'},
         'custom-control': {'type': 'str', 'api_name': 'custom_control'},
         'custom_control': {'type': 'str'},
+        'revision_note': {'type': 'str'},
         'casb_profile_saasapplication_customcontrol_option': {
             'type': 'dict',
             'v_range': [['7.4.1', '']],
