@@ -73,6 +73,9 @@ options:
         choices:
           - present
           - absent
+    revision_note:
+        description: The change note that can be specified when an object is created or updated.
+        type: str
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
         type: str
@@ -352,8 +355,8 @@ EXAMPLES = '''
     - name: Cloud orchest awstemplate autoscale existing vpc
       fortinet.fortimanager.fmgr_cloud_orchestawstemplate_autoscaleexistingvpc:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         adom: <your own value>
@@ -468,6 +471,7 @@ def main():
     module_primary_key = 'name'
     module_arg_spec = {
         'adom': {'required': True, 'type': 'str'},
+        'revision_note': {'type': 'str'},
         'cloud_orchestawstemplate_autoscaleexistingvpc': {
             'type': 'dict',
             'v_range': [['7.4.0', '']],
