@@ -73,6 +73,9 @@ options:
         choices:
           - present
           - absent
+    revision_note:
+        description: The change note that can be specified when an object is created or updated.
+        type: str
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
         type: str
@@ -310,6 +313,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -318,59 +322,59 @@ EXAMPLES = '''
     - name: Cloud orchest awstemplate autoscale tgw new vpc
       fortinet.fortimanager.fmgr_cloud_orchestawstemplate_autoscaletgwnewvpc:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         adom: <your own value>
         state: present # <value in [present, absent]>
         cloud_orchestawstemplate_autoscaletgwnewvpc:
-          availability_zones: <string>
-          bgp_asn: <integer>
-          custom_asset_container: <string>
-          custom_asset_directory: <string>
-          custom_identifier: <string>
-          faz_autoscale_admin_password: <list or string>
-          faz_autoscale_admin_username: <string>
-          faz_custom_private_ipaddress: <string>
-          faz_instance_type: <value in [h1.2xlarge, h1.4xlarge, h1.8xlarge, ...]>
-          faz_integration_options: <value in [no, yes]>
-          faz_version: <string>
-          fgt_admin_cidr: <string>
-          fgt_admin_port: <integer>
-          fgt_instance_type: <value in [t2.small, c5.large, c5.xlarge, ...]>
-          fgt_psk_secret: <string>
-          fgtasg_cool_down: <integer>
-          fgtasg_desired_capacity_byol: <integer>
-          fgtasg_desired_capacity_payg: <integer>
-          fgtasg_health_check_grace_period: <integer>
-          fgtasg_max_size_byol: <integer>
-          fgtasg_max_size_payg: <integer>
-          fgtasg_min_size_byol: <integer>
-          fgtasg_min_size_payg: <integer>
-          fgtasg_scale_in_threshold: <integer>
-          fgtasg_scale_out_threshold: <integer>
-          fos_version: <string>
-          get_license_grace_period: <integer>
-          heartbeat_delay_allowance: <integer>
-          heartbeat_interval: <integer>
-          heartbeat_loss_count: <integer>
-          key_pair_name: <string>
-          lifecycle_hook_timeout: <integer>
-          name: <string>
-          notification_email: <string>
-          primary_election_timeout: <integer>
-          public_subnet1_cidr: <string>
-          public_subnet2_cidr: <string>
-          resource_tag_prefix: <string>
-          s3_bucket_name: <string>
-          s3_key_prefix: <string>
-          sync_recovery_count: <integer>
-          terminate_unhealthy_vm: <value in [no, yes]>
-          transit_gateway_id: <string>
-          transit_gateway_support_options: <value in [create one, use an existing one]>
-          use_custom_asset_location: <value in [no, yes]>
-          vpc_cidr: <string>
+          name: "your value" # Required variable, string
+          # availability_zones: <string>
+          # bgp_asn: <integer>
+          # custom_asset_container: <string>
+          # custom_asset_directory: <string>
+          # custom_identifier: <string>
+          # faz_autoscale_admin_password: <list or string>
+          # faz_autoscale_admin_username: <string>
+          # faz_custom_private_ipaddress: <string>
+          # faz_instance_type: <value in [h1.2xlarge, h1.4xlarge, h1.8xlarge, ...]>
+          # faz_integration_options: <value in [no, yes]>
+          # faz_version: <string>
+          # fgt_admin_cidr: <string>
+          # fgt_admin_port: <integer>
+          # fgt_instance_type: <value in [t2.small, c5.large, c5.xlarge, ...]>
+          # fgt_psk_secret: <string>
+          # fgtasg_cool_down: <integer>
+          # fgtasg_desired_capacity_byol: <integer>
+          # fgtasg_desired_capacity_payg: <integer>
+          # fgtasg_health_check_grace_period: <integer>
+          # fgtasg_max_size_byol: <integer>
+          # fgtasg_max_size_payg: <integer>
+          # fgtasg_min_size_byol: <integer>
+          # fgtasg_min_size_payg: <integer>
+          # fgtasg_scale_in_threshold: <integer>
+          # fgtasg_scale_out_threshold: <integer>
+          # fos_version: <string>
+          # get_license_grace_period: <integer>
+          # heartbeat_delay_allowance: <integer>
+          # heartbeat_interval: <integer>
+          # heartbeat_loss_count: <integer>
+          # key_pair_name: <string>
+          # lifecycle_hook_timeout: <integer>
+          # notification_email: <string>
+          # primary_election_timeout: <integer>
+          # public_subnet1_cidr: <string>
+          # public_subnet2_cidr: <string>
+          # resource_tag_prefix: <string>
+          # s3_bucket_name: <string>
+          # s3_key_prefix: <string>
+          # sync_recovery_count: <integer>
+          # terminate_unhealthy_vm: <value in [no, yes]>
+          # transit_gateway_id: <string>
+          # transit_gateway_support_options: <value in [create one, use an existing one]>
+          # use_custom_asset_location: <value in [no, yes]>
+          # vpc_cidr: <string>
 '''
 
 RETURN = '''
@@ -427,6 +431,7 @@ def main():
     module_primary_key = 'name'
     module_arg_spec = {
         'adom': {'required': True, 'type': 'str'},
+        'revision_note': {'type': 'str'},
         'cloud_orchestawstemplate_autoscaletgwnewvpc': {
             'type': 'dict',
             'v_range': [['7.4.0', '']],
