@@ -180,6 +180,7 @@ options:
                             - 'icap'
                             - 'ztna'
                             - 'virtual-patch'
+                            - 'debug'
                     filter:
                         type: str
                         description: Free style filter string.
@@ -295,12 +296,19 @@ options:
                 choices:
                     - 'disable'
                     - 'enable'
+            debug:
+                type: str
+                description: Enable/disable debug logging.
+                choices:
+                    - 'disable'
+                    - 'enable'
 '''
 
 EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -309,47 +317,45 @@ EXAMPLES = '''
     - name: Filters for remote system server.
       fortinet.fortimanager.fmgr_devprof_log_syslogd_filter:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         adom: <your own value>
         devprof: <your own value>
         devprof_log_syslogd_filter:
-          severity: <value in [emergency, alert, critical, ...]>
-          anomaly: <value in [disable, enable]>
-          exclude_list:
-            -
-              category: <value in [app-ctrl, attack, dlp, ...]>
-              fields:
-                -
-                  args: <list or string>
-                  field: <string>
-                  negate: <value in [disable, enable]>
-              id: <integer>
-          forward_traffic: <value in [disable, enable]>
-          free_style:
-            -
-              category: <value in [traffic, event, virus, ...]>
-              filter: <string>
-              filter_type: <value in [include, exclude]>
-              id: <integer>
-          gtp: <value in [disable, enable]>
-          local_traffic: <value in [disable, enable]>
-          multicast_traffic: <value in [disable, enable]>
-          sniffer_traffic: <value in [disable, enable]>
-          voip: <value in [disable, enable]>
-          ztna_traffic: <value in [disable, enable]>
-          filter_type: <value in [include, exclude]>
-          filter: <string>
-          cifs: <value in [disable, enable]>
-          ssl: <value in [disable, enable]>
-          dns: <value in [disable, enable]>
-          ssh: <value in [disable, enable]>
-          netscan_discovery: <value in [disable, enable]>
-          netscan_vulnerability: <value in [disable, enable]>
-          forti_switch: <value in [disable, enable]>
-          http_transaction: <value in [disable, enable]>
+          # severity: <value in [emergency, alert, critical, ...]>
+          # anomaly: <value in [disable, enable]>
+          # exclude_list:
+          #   - category: <value in [app-ctrl, attack, dlp, ...]>
+          #     fields:
+          #       - args: <list or string>
+          #         field: <string>
+          #         negate: <value in [disable, enable]>
+          #     id: <integer>
+          # forward_traffic: <value in [disable, enable]>
+          # free_style:
+          #   - category: <value in [traffic, event, virus, ...]>
+          #     filter: <string>
+          #     filter_type: <value in [include, exclude]>
+          #     id: <integer>
+          # gtp: <value in [disable, enable]>
+          # local_traffic: <value in [disable, enable]>
+          # multicast_traffic: <value in [disable, enable]>
+          # sniffer_traffic: <value in [disable, enable]>
+          # voip: <value in [disable, enable]>
+          # ztna_traffic: <value in [disable, enable]>
+          # filter_type: <value in [include, exclude]>
+          # filter: <string>
+          # cifs: <value in [disable, enable]>
+          # ssl: <value in [disable, enable]>
+          # dns: <value in [disable, enable]>
+          # ssh: <value in [disable, enable]>
+          # netscan_discovery: <value in [disable, enable]>
+          # netscan_vulnerability: <value in [disable, enable]>
+          # forti_switch: <value in [disable, enable]>
+          # http_transaction: <value in [disable, enable]>
+          # debug: <value in [disable, enable]>
 '''
 
 RETURN = '''
@@ -415,67 +421,68 @@ def main():
                     'choices': ['emergency', 'alert', 'critical', 'error', 'warning', 'notification', 'information', 'debug'],
                     'type': 'str'
                 },
-                'anomaly': {'v_range': [['7.0.4', '7.0.13'], ['7.2.1', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                'anomaly': {'v_range': [['7.0.4', '7.0.14'], ['7.2.1', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
                 'exclude-list': {
-                    'v_range': [['7.0.4', '7.0.13']],
+                    'v_range': [['7.0.4', '7.0.14']],
                     'type': 'list',
                     'options': {
                         'category': {
-                            'v_range': [['7.0.4', '7.0.13']],
+                            'v_range': [['7.0.4', '7.0.14']],
                             'choices': [
                                 'app-ctrl', 'attack', 'dlp', 'event', 'traffic', 'virus', 'voip', 'webfilter', 'netscan', 'spam', 'anomaly', 'waf'
                             ],
                             'type': 'str'
                         },
                         'fields': {
-                            'v_range': [['7.0.4', '7.0.13']],
+                            'v_range': [['7.0.4', '7.0.14']],
                             'type': 'list',
                             'options': {
-                                'args': {'v_range': [['7.0.4', '7.0.13']], 'type': 'raw'},
-                                'field': {'v_range': [['7.0.4', '7.0.13']], 'type': 'str'},
-                                'negate': {'v_range': [['7.0.4', '7.0.13']], 'choices': ['disable', 'enable'], 'type': 'str'}
+                                'args': {'v_range': [['7.0.4', '7.0.14']], 'type': 'raw'},
+                                'field': {'v_range': [['7.0.4', '7.0.14']], 'type': 'str'},
+                                'negate': {'v_range': [['7.0.4', '7.0.14']], 'choices': ['disable', 'enable'], 'type': 'str'}
                             },
                             'elements': 'dict'
                         },
-                        'id': {'v_range': [['7.0.4', '7.0.13']], 'type': 'int'}
+                        'id': {'v_range': [['7.0.4', '7.0.14']], 'type': 'int'}
                     },
                     'elements': 'dict'
                 },
-                'forward-traffic': {'v_range': [['7.0.4', '7.0.13'], ['7.2.1', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                'forward-traffic': {'v_range': [['7.0.4', '7.0.14'], ['7.2.1', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
                 'free-style': {
-                    'v_range': [['7.0.4', '7.0.13'], ['7.2.1', '']],
+                    'v_range': [['7.0.4', '7.0.14'], ['7.2.1', '']],
                     'type': 'list',
                     'options': {
                         'category': {
-                            'v_range': [['7.0.4', '7.0.13'], ['7.2.1', '']],
+                            'v_range': [['7.0.4', '7.0.14'], ['7.2.1', '']],
                             'choices': [
                                 'traffic', 'event', 'virus', 'webfilter', 'attack', 'spam', 'voip', 'dlp', 'app-ctrl', 'anomaly', 'waf', 'gtp', 'dns',
-                                'ssh', 'ssl', 'file-filter', 'icap', 'ztna', 'virtual-patch'
+                                'ssh', 'ssl', 'file-filter', 'icap', 'ztna', 'virtual-patch', 'debug'
                             ],
                             'type': 'str'
                         },
-                        'filter': {'v_range': [['7.0.4', '7.0.13'], ['7.2.1', '']], 'type': 'str'},
-                        'filter-type': {'v_range': [['7.0.4', '7.0.13'], ['7.2.1', '']], 'choices': ['include', 'exclude'], 'type': 'str'},
-                        'id': {'v_range': [['7.0.4', '7.0.13'], ['7.2.1', '']], 'type': 'int'}
+                        'filter': {'v_range': [['7.0.4', '7.0.14'], ['7.2.1', '']], 'type': 'str'},
+                        'filter-type': {'v_range': [['7.0.4', '7.0.14'], ['7.2.1', '']], 'choices': ['include', 'exclude'], 'type': 'str'},
+                        'id': {'v_range': [['7.0.4', '7.0.14'], ['7.2.1', '']], 'type': 'int'}
                     },
                     'elements': 'dict'
                 },
-                'gtp': {'v_range': [['7.0.4', '7.0.13'], ['7.2.1', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
-                'local-traffic': {'v_range': [['7.0.4', '7.0.13'], ['7.2.1', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
-                'multicast-traffic': {'v_range': [['7.0.4', '7.0.13'], ['7.2.1', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
-                'sniffer-traffic': {'v_range': [['7.0.4', '7.0.13'], ['7.2.1', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
-                'voip': {'v_range': [['7.0.4', '7.0.13'], ['7.2.1', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
-                'ztna-traffic': {'v_range': [['7.0.4', '7.0.13'], ['7.2.1', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
-                'filter-type': {'v_range': [['7.0.4', '7.0.13'], ['7.2.1', '']], 'choices': ['include', 'exclude'], 'type': 'str'},
-                'filter': {'v_range': [['7.0.4', '7.0.13'], ['7.2.1', '']], 'type': 'str'},
-                'cifs': {'v_range': [['7.0.4', '7.0.13']], 'choices': ['disable', 'enable'], 'type': 'str'},
-                'ssl': {'v_range': [['7.0.4', '7.0.13']], 'choices': ['disable', 'enable'], 'type': 'str'},
-                'dns': {'v_range': [['7.0.4', '7.0.13'], ['7.2.1', '7.2.1']], 'choices': ['disable', 'enable'], 'type': 'str'},
-                'ssh': {'v_range': [['7.0.4', '7.0.13'], ['7.2.1', '7.2.1']], 'choices': ['disable', 'enable'], 'type': 'str'},
-                'netscan-discovery': {'v_range': [['7.0.4', '7.0.13']], 'choices': ['disable', 'enable'], 'type': 'str'},
-                'netscan-vulnerability': {'v_range': [['7.0.4', '7.0.13']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                'gtp': {'v_range': [['7.0.4', '7.0.14'], ['7.2.1', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                'local-traffic': {'v_range': [['7.0.4', '7.0.14'], ['7.2.1', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                'multicast-traffic': {'v_range': [['7.0.4', '7.0.14'], ['7.2.1', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                'sniffer-traffic': {'v_range': [['7.0.4', '7.0.14'], ['7.2.1', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                'voip': {'v_range': [['7.0.4', '7.0.14'], ['7.2.1', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                'ztna-traffic': {'v_range': [['7.0.4', '7.0.14'], ['7.2.1', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                'filter-type': {'v_range': [['7.0.4', '7.0.14'], ['7.2.1', '']], 'choices': ['include', 'exclude'], 'type': 'str'},
+                'filter': {'v_range': [['7.0.4', '7.0.14'], ['7.2.1', '']], 'type': 'str'},
+                'cifs': {'v_range': [['7.0.4', '7.0.14']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                'ssl': {'v_range': [['7.0.4', '7.0.14']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                'dns': {'v_range': [['7.0.4', '7.0.14'], ['7.2.1', '7.2.1']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                'ssh': {'v_range': [['7.0.4', '7.0.14'], ['7.2.1', '7.2.1']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                'netscan-discovery': {'v_range': [['7.0.4', '7.0.14']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                'netscan-vulnerability': {'v_range': [['7.0.4', '7.0.14']], 'choices': ['disable', 'enable'], 'type': 'str'},
                 'forti-switch': {'v_range': [['7.4.2', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
-                'http-transaction': {'v_range': [['7.6.0', '']], 'choices': ['disable', 'enable'], 'type': 'str'}
+                'http-transaction': {'v_range': [['7.6.0', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                'debug': {'v_range': [['7.6.3', '']], 'choices': ['disable', 'enable'], 'type': 'str'}
             }
         }
     }
