@@ -117,6 +117,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -125,8 +126,8 @@ EXAMPLES = '''
     - name: System template log syslogd filter exclude list fields
       fortinet.fortimanager.fmgr_devprof_log_syslogd_filter_excludelist_fields:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         adom: <your own value>
@@ -134,9 +135,9 @@ EXAMPLES = '''
         exclude_list: <your own value>
         state: present # <value in [present, absent]>
         devprof_log_syslogd_filter_excludelist_fields:
-          args: <list or string>
-          field: <string>
-          negate: <value in [disable, enable]>
+          # args: <list or string>
+          # field: <string>
+          # negate: <value in [disable, enable]>
 '''
 
 RETURN = '''
@@ -197,11 +198,11 @@ def main():
         'exclude_list': {'type': 'str'},
         'devprof_log_syslogd_filter_excludelist_fields': {
             'type': 'dict',
-            'v_range': [['7.0.4', '7.0.13']],
+            'v_range': [['7.0.4', '7.0.14']],
             'options': {
-                'args': {'v_range': [['7.0.4', '7.0.13']], 'type': 'raw'},
-                'field': {'v_range': [['7.0.4', '7.0.13']], 'type': 'str'},
-                'negate': {'v_range': [['7.0.4', '7.0.13']], 'choices': ['disable', 'enable'], 'type': 'str'}
+                'args': {'v_range': [['7.0.4', '7.0.14']], 'type': 'raw'},
+                'field': {'v_range': [['7.0.4', '7.0.14']], 'type': 'str'},
+                'negate': {'v_range': [['7.0.4', '7.0.14']], 'choices': ['disable', 'enable'], 'type': 'str'}
             }
         }
     }
