@@ -134,11 +134,16 @@ options:
                     - 'auto'
                     - 'sdwan'
                     - 'specify'
+            vrf_select:
+                aliases: ['vrf-select']
+                type: int
+                description: VRF ID used for connection to server.
 '''
 
 EXAMPLES = '''
 - name: Example playbook
   hosts: fortimanagers
+  gather_facts: false
   connection: httpapi
   vars:
     ansible_httpapi_use_ssl: true
@@ -153,8 +158,8 @@ EXAMPLES = '''
         community: "1" # id
         state: present
         devprof_system_snmp_community_hosts6:
-          ha-direct: enable
-          host-type: any
+          ha_direct: enable
+          host_type: any
           id: 1
 
 - name: Gathering fortimanager facts
@@ -242,7 +247,8 @@ def main():
                 'ipv6': {'v_range': [['6.0.0', '6.2.5'], ['6.2.7', '6.4.1'], ['6.4.3', '']], 'type': 'str'},
                 'source-ipv6': {'v_range': [['6.0.0', '6.2.5'], ['6.2.7', '6.4.1'], ['6.4.3', '']], 'type': 'str'},
                 'interface': {'v_range': [['7.6.0', '']], 'type': 'raw'},
-                'interface-select-method': {'v_range': [['7.6.0', '']], 'choices': ['auto', 'sdwan', 'specify'], 'type': 'str'}
+                'interface-select-method': {'v_range': [['7.6.0', '']], 'choices': ['auto', 'sdwan', 'specify'], 'type': 'str'},
+                'vrf-select': {'v_range': [['7.6.2', '']], 'type': 'int'}
             }
         }
     }
