@@ -73,6 +73,9 @@ options:
         choices:
           - present
           - absent
+    revision_note:
+        description: The change note that can be specified when an object is created or updated.
+        type: str
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
         type: str
@@ -172,7 +175,7 @@ EXAMPLES = '''
           selector: "dnsfilter_domainfilter"
           params:
             adom: "ansible"
-            domain-filter: "your_value"
+            domain_filter: "your_value"
 '''
 
 RETURN = '''
@@ -229,6 +232,7 @@ def main():
     module_primary_key = 'id'
     module_arg_spec = {
         'adom': {'required': True, 'type': 'str'},
+        'revision_note': {'type': 'str'},
         'dnsfilter_domainfilter': {
             'type': 'dict',
             'v_range': [['6.0.0', '']],
