@@ -102,7 +102,7 @@ options:
                     meta_fields:
                         aliases: ['meta fields']
                         type: raw
-                        description: (dict or str) Meta fields.
+                        description: (dict or str) Add real and model device.
                     mgmt_mode:
                         type: str
                         description: Add real and model device.
@@ -231,7 +231,7 @@ EXAMPLES = '''
             name: "{{ probed_device.meta.response_data.device.name }}"
             sn: "{{ probed_device.meta.response_data.device.sn }}"
       register: installing_task
-    - name: Poll the task
+    - name: Poll the task of adding device
       fortinet.fortimanager.fmgr_fact:
         facts:
           selector: "task_task"
@@ -245,6 +245,7 @@ EXAMPLES = '''
 
 - name: Example playbook
   hosts: fortimanagers
+  gather_facts: false
   connection: httpapi
   vars:
     ansible_httpapi_use_ssl: true
