@@ -114,8 +114,8 @@ EXAMPLES = '''
     - name: Device group table.
       fortinet.fortimanager.fmgr_dvmdb_group_objectmember:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         adom: <your own value>
