@@ -141,6 +141,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -149,20 +150,20 @@ EXAMPLES = '''
     - name: Script schedule table.
       fortinet.fortimanager.fmgr_dvmdb_script_scriptschedule:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         adom: <your own value>
         script: <your own value>
         state: present # <value in [present, absent]>
         dvmdb_script_scriptschedule:
-          datetime: <string>
-          day_of_week: <value in [unknown, sun, mon, ...]>
-          device: <integer>
-          name: <string>
-          run_on_db: <value in [disable, enable]>
-          type: <value in [auto, onetime, daily, ...]>
+          name: "your value" # Required variable, string
+          # datetime: <string>
+          # day_of_week: <value in [unknown, sun, mon, ...]>
+          # device: <integer>
+          # run_on_db: <value in [disable, enable]>
+          # type: <value in [auto, onetime, daily, ...]>
 '''
 
 RETURN = '''
