@@ -73,6 +73,9 @@ options:
         choices:
           - present
           - absent
+    revision_note:
+        description: The change note that can be specified when an object is created or updated.
+        type: str
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
         type: str
@@ -147,6 +150,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -155,22 +159,22 @@ EXAMPLES = '''
     - name: Spam filter banned word.
       fortinet.fortimanager.fmgr_emailfilter_bword_entries:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         adom: <your own value>
         bword: <your own value>
         state: present # <value in [present, absent]>
         emailfilter_bword_entries:
-          action: <value in [spam, clear]>
-          id: <integer>
-          language: <value in [western, simch, trach, ...]>
-          pattern: <string>
-          pattern_type: <value in [wildcard, regexp]>
-          score: <integer>
-          status: <value in [disable, enable]>
-          where: <value in [all, subject, body]>
+          id: 0 # Required variable, integer
+          # action: <value in [spam, clear]>
+          # language: <value in [western, simch, trach, ...]>
+          # pattern: <string>
+          # pattern_type: <value in [wildcard, regexp]>
+          # score: <integer>
+          # status: <value in [disable, enable]>
+          # where: <value in [all, subject, body]>
 '''
 
 RETURN = '''
@@ -228,6 +232,7 @@ def main():
     module_arg_spec = {
         'adom': {'required': True, 'type': 'str'},
         'bword': {'required': True, 'type': 'str'},
+        'revision_note': {'type': 'str'},
         'emailfilter_bword_entries': {
             'type': 'dict',
             'v_range': [['6.2.0', '']],
