@@ -73,6 +73,9 @@ options:
         choices:
           - present
           - absent
+    revision_note:
+        description: The change note that can be specified when an object is created or updated.
+        type: str
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
         type: str
@@ -128,6 +131,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -136,22 +140,21 @@ EXAMPLES = '''
     - name: Configure AntiSpam DNSBL/ORBL.
       fortinet.fortimanager.fmgr_emailfilter_dnsbl:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         adom: <your own value>
         state: present # <value in [present, absent]>
         emailfilter_dnsbl:
-          comment: <string>
-          entries:
-            -
-              action: <value in [spam, reject]>
-              id: <integer>
-              server: <string>
-              status: <value in [disable, enable]>
-          id: <integer>
-          name: <string>
+          id: 0 # Required variable, integer
+          # comment: <string>
+          # entries:
+          #   - action: <value in [spam, reject]>
+          #     id: <integer>
+          #     server: <string>
+          #     status: <value in [disable, enable]>
+          # name: <string>
 '''
 
 RETURN = '''
@@ -208,6 +211,7 @@ def main():
     module_primary_key = 'id'
     module_arg_spec = {
         'adom': {'required': True, 'type': 'str'},
+        'revision_note': {'type': 'str'},
         'emailfilter_dnsbl': {
             'type': 'dict',
             'v_range': [['6.2.0', '']],
