@@ -73,6 +73,9 @@ options:
         choices:
           - present
           - absent
+    revision_note:
+        description: The change note that can be specified when an object is created or updated.
+        type: str
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
         type: str
@@ -448,6 +451,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -456,103 +460,102 @@ EXAMPLES = '''
     - name: Configure Email Filter profiles.
       fortinet.fortimanager.fmgr_emailfilter_profile:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         adom: <your own value>
         state: present # <value in [present, absent]>
         emailfilter_profile:
-          comment: <string>
-          external: <value in [disable, enable]>
-          name: <string>
-          options:
-            - "bannedword"
-            - "spambwl"
-            - "spamfsip"
-            - "spamfssubmit"
-            - "spamfschksum"
-            - "spamfsurl"
-            - "spamhelodns"
-            - "spamraddrdns"
-            - "spamrbl"
-            - "spamhdrcheck"
-            - "spamfsphish"
-            - "spambal"
-            - "spamfgip"
-            - "spamfgsubmit"
-            - "spamfgchksum"
-            - "spamfgurl"
-            - "spamfgphish"
-          replacemsg_group: <string>
-          spam_bwl_table: <string>
-          spam_bword_table: <string>
-          spam_bword_threshold: <integer>
-          spam_filtering: <value in [disable, enable]>
-          spam_iptrust_table: <string>
-          spam_log: <value in [disable, enable]>
-          spam_log_fortiguard_response: <value in [disable, enable]>
-          spam_mheader_table: <string>
-          spam_rbl_table: <string>
-          feature_set: <value in [proxy, flow]>
-          gmail:
-            log: <value in [disable, enable]>
-            log_all: <value in [disable, enable]>
-          imap:
-            action: <value in [pass, tag]>
-            log: <value in [disable, enable]>
-            log_all: <value in [disable, enable]>
-            tag_msg: <string>
-            tag_type:
-              - "subject"
-              - "header"
-              - "spaminfo"
-          mapi:
-            action: <value in [pass, discard]>
-            log: <value in [disable, enable]>
-            log_all: <value in [disable, enable]>
-          msn_hotmail:
-            log: <value in [disable, enable]>
-            log_all: <value in [disable, enable]>
-          other_webmails:
-            log_all: <value in [disable, enable]>
-          pop3:
-            action: <value in [pass, tag]>
-            log: <value in [disable, enable]>
-            log_all: <value in [disable, enable]>
-            tag_msg: <string>
-            tag_type:
-              - "subject"
-              - "header"
-              - "spaminfo"
-          smtp:
-            action: <value in [pass, tag, discard]>
-            hdrip: <value in [disable, enable]>
-            local_override: <value in [disable, enable]>
-            log: <value in [disable, enable]>
-            log_all: <value in [disable, enable]>
-            tag_msg: <string>
-            tag_type:
-              - "subject"
-              - "header"
-              - "spaminfo"
-          file_filter:
-            entries:
-              -
-                action: <value in [log, block]>
-                comment: <string>
-                encryption: <value in [any, yes]>
-                file_type: <list or string>
-                filter: <string>
-                password_protected: <value in [any, yes]>
-                protocol:
-                  - "smtp"
-                  - "imap"
-                  - "pop3"
-            log: <value in [disable, enable]>
-            scan_archive_contents: <value in [disable, enable]>
-            status: <value in [disable, enable]>
-          spam_bal_table: <string>
+          name: "your value" # Required variable, string
+          # comment: <string>
+          # external: <value in [disable, enable]>
+          # options:
+          #   - "bannedword"
+          #   - "spambwl"
+          #   - "spamfsip"
+          #   - "spamfssubmit"
+          #   - "spamfschksum"
+          #   - "spamfsurl"
+          #   - "spamhelodns"
+          #   - "spamraddrdns"
+          #   - "spamrbl"
+          #   - "spamhdrcheck"
+          #   - "spamfsphish"
+          #   - "spambal"
+          #   - "spamfgip"
+          #   - "spamfgsubmit"
+          #   - "spamfgchksum"
+          #   - "spamfgurl"
+          #   - "spamfgphish"
+          # replacemsg_group: <string>
+          # spam_bwl_table: <string>
+          # spam_bword_table: <string>
+          # spam_bword_threshold: <integer>
+          # spam_filtering: <value in [disable, enable]>
+          # spam_iptrust_table: <string>
+          # spam_log: <value in [disable, enable]>
+          # spam_log_fortiguard_response: <value in [disable, enable]>
+          # spam_mheader_table: <string>
+          # spam_rbl_table: <string>
+          # feature_set: <value in [proxy, flow]>
+          # gmail:
+          #   log: <value in [disable, enable]>
+          #   log_all: <value in [disable, enable]>
+          # imap:
+          #   action: <value in [pass, tag]>
+          #   log: <value in [disable, enable]>
+          #   log_all: <value in [disable, enable]>
+          #   tag_msg: <string>
+          #   tag_type:
+          #     - "subject"
+          #     - "header"
+          #     - "spaminfo"
+          # mapi:
+          #   action: <value in [pass, discard]>
+          #   log: <value in [disable, enable]>
+          #   log_all: <value in [disable, enable]>
+          # msn_hotmail:
+          #   log: <value in [disable, enable]>
+          #   log_all: <value in [disable, enable]>
+          # other_webmails:
+          #   log_all: <value in [disable, enable]>
+          # pop3:
+          #   action: <value in [pass, tag]>
+          #   log: <value in [disable, enable]>
+          #   log_all: <value in [disable, enable]>
+          #   tag_msg: <string>
+          #   tag_type:
+          #     - "subject"
+          #     - "header"
+          #     - "spaminfo"
+          # smtp:
+          #   action: <value in [pass, tag, discard]>
+          #   hdrip: <value in [disable, enable]>
+          #   local_override: <value in [disable, enable]>
+          #   log: <value in [disable, enable]>
+          #   log_all: <value in [disable, enable]>
+          #   tag_msg: <string>
+          #   tag_type:
+          #     - "subject"
+          #     - "header"
+          #     - "spaminfo"
+          # file_filter:
+          #   entries:
+          #     - action: <value in [log, block]>
+          #       comment: <string>
+          #       encryption: <value in [any, yes]>
+          #       file_type: <list or string>
+          #       filter: <string>
+          #       password_protected: <value in [any, yes]>
+          #       protocol:
+          #         - "smtp"
+          #         - "imap"
+          #         - "pop3"
+          #   log: <value in [disable, enable]>
+          #   scan_archive_contents: <value in [disable, enable]>
+          #   status: <value in [disable, enable]>
+          # spam_bal_table: <string>
 '''
 
 RETURN = '''
@@ -609,6 +612,7 @@ def main():
     module_primary_key = 'name'
     module_arg_spec = {
         'adom': {'required': True, 'type': 'str'},
+        'revision_note': {'type': 'str'},
         'emailfilter_profile': {
             'type': 'dict',
             'v_range': [['6.2.0', '']],
@@ -717,21 +721,21 @@ def main():
                     }
                 },
                 'file-filter': {
-                    'v_range': [['6.2.8', '6.2.13'], ['6.4.5', '']],
+                    'v_range': [['6.2.8', '6.2.13'], ['6.4.5', '7.6.2']],
                     'type': 'dict',
                     'options': {
                         'entries': {
-                            'v_range': [['6.2.8', '6.2.13'], ['6.4.5', '']],
+                            'v_range': [['6.2.8', '6.2.13'], ['6.4.5', '7.6.2']],
                             'type': 'list',
                             'options': {
-                                'action': {'v_range': [['6.2.8', '6.2.13'], ['6.4.5', '']], 'choices': ['log', 'block'], 'type': 'str'},
-                                'comment': {'v_range': [['6.2.8', '6.2.13'], ['6.4.5', '']], 'type': 'str'},
+                                'action': {'v_range': [['6.2.8', '6.2.13'], ['6.4.5', '7.6.2']], 'choices': ['log', 'block'], 'type': 'str'},
+                                'comment': {'v_range': [['6.2.8', '6.2.13'], ['6.4.5', '7.6.2']], 'type': 'str'},
                                 'encryption': {'v_range': [['6.2.8', '6.2.13'], ['6.4.5', '7.2.0']], 'choices': ['any', 'yes'], 'type': 'str'},
-                                'file-type': {'v_range': [['6.2.8', '6.2.13'], ['6.4.5', '']], 'type': 'raw'},
-                                'filter': {'v_range': [['6.2.8', '6.2.13'], ['6.4.5', '']], 'type': 'str'},
-                                'password-protected': {'v_range': [['6.2.8', '6.2.13'], ['6.4.5', '']], 'choices': ['any', 'yes'], 'type': 'str'},
+                                'file-type': {'v_range': [['6.2.8', '6.2.13'], ['6.4.5', '7.6.2']], 'type': 'raw'},
+                                'filter': {'v_range': [['6.2.8', '6.2.13'], ['6.4.5', '7.6.2']], 'type': 'str'},
+                                'password-protected': {'v_range': [['6.2.8', '6.2.13'], ['6.4.5', '7.6.2']], 'choices': ['any', 'yes'], 'type': 'str'},
                                 'protocol': {
-                                    'v_range': [['6.2.8', '6.2.13'], ['6.4.5', '']],
+                                    'v_range': [['6.2.8', '6.2.13'], ['6.4.5', '7.6.2']],
                                     'type': 'list',
                                     'choices': ['smtp', 'imap', 'pop3'],
                                     'elements': 'str'
@@ -739,9 +743,9 @@ def main():
                             },
                             'elements': 'dict'
                         },
-                        'log': {'v_range': [['6.2.8', '6.2.13'], ['6.4.5', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
-                        'scan-archive-contents': {'v_range': [['6.2.8', '6.2.13'], ['6.4.5', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
-                        'status': {'v_range': [['6.2.8', '6.2.13'], ['6.4.5', '']], 'choices': ['disable', 'enable'], 'type': 'str'}
+                        'log': {'v_range': [['6.2.8', '6.2.13'], ['6.4.5', '7.6.2']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                        'scan-archive-contents': {'v_range': [['6.2.8', '6.2.13'], ['6.4.5', '7.6.2']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                        'status': {'v_range': [['6.2.8', '6.2.13'], ['6.4.5', '7.6.2']], 'choices': ['disable', 'enable'], 'type': 'str'}
                     }
                 },
                 'spam-bal-table': {'v_range': [['7.0.0', '']], 'type': 'str'}
