@@ -64,6 +64,9 @@ options:
         description: The rc codes list with which the conditions to fail will be overriden.
         type: list
         elements: int
+    revision_note:
+        description: The change note that can be specified when an object is created or updated.
+        type: str
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
         type: str
@@ -147,8 +150,8 @@ EXAMPLES = '''
     - name: Extender controller sim profile auto switch profile
       fortinet.fortimanager.fmgr_extendercontroller_simprofile_autoswitchprofile:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         adom: <your own value>
@@ -222,6 +225,7 @@ def main():
     module_arg_spec = {
         'adom': {'required': True, 'type': 'str'},
         'sim_profile': {'required': True, 'type': 'str'},
+        'revision_note': {'type': 'str'},
         'extendercontroller_simprofile_autoswitchprofile': {
             'type': 'dict',
             'v_range': [['6.4.4', '']],
