@@ -64,6 +64,9 @@ options:
         description: The rc codes list with which the conditions to fail will be overriden.
         type: list
         elements: int
+    revision_note:
+        description: The change note that can be specified when an object is created or updated.
+        type: str
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
         type: str
@@ -463,8 +466,8 @@ EXAMPLES = '''
     - name: FortiExtender cellular configuration.
       fortinet.fortimanager.fmgr_extensioncontroller_extenderprofile_cellular:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         adom: <your own value>
@@ -611,6 +614,7 @@ def main():
         'adom': {'required': True, 'type': 'str'},
         'extender-profile': {'type': 'str', 'api_name': 'extender_profile'},
         'extender_profile': {'type': 'str'},
+        'revision_note': {'type': 'str'},
         'extensioncontroller_extenderprofile_cellular': {
             'type': 'dict',
             'v_range': [['7.2.1', '']],
