@@ -64,6 +64,9 @@ options:
         description: The rc codes list with which the conditions to fail will be overriden.
         type: list
         elements: int
+    revision_note:
+        description: The change note that can be specified when an object is created or updated.
+        type: str
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
         type: str
@@ -166,12 +169,34 @@ options:
                     vap:
                         type: raw
                         description: (list) FortiExtender LAN extension downlink vap.
+            traffic_split_services:
+                aliases: ['traffic-split-services']
+                type: list
+                elements: dict
+                description: Traffic split services.
+                suboptions:
+                    address:
+                        type: raw
+                        description: (list) Address selection.
+                    name:
+                        type: str
+                        description: FortiExtender LAN extension tunnel split entry name.
+                    service:
+                        type: raw
+                        description: (list) Service selection.
+                    vsdb:
+                        type: str
+                        description: Select vsdb [enable/disable].
+                        choices:
+                            - 'disable'
+                            - 'enable'
 '''
 
 EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -180,30 +205,33 @@ EXAMPLES = '''
     - name: FortiExtender lan extension configuration.
       fortinet.fortimanager.fmgr_extensioncontroller_extenderprofile_lanextension:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         adom: <your own value>
         extender_profile: <your own value>
         extensioncontroller_extenderprofile_lanextension:
-          backhaul:
-            -
-              name: <string>
-              port: <value in [wan, lte1, lte2, ...]>
-              role: <value in [primary, secondary]>
-              weight: <integer>
-          backhaul_interface: <string>
-          backhaul_ip: <string>
-          ipsec_tunnel: <string>
-          link_loadbalance: <value in [activebackup, loadbalance]>
-          downlinks:
-            -
-              name: <string>
-              port: <value in [port1, port2, port3, ...]>
-              pvid: <integer>
-              type: <value in [port, vap]>
-              vap: <list or string>
+          # backhaul:
+          #   - name: <string>
+          #     port: <value in [wan, lte1, lte2, ...]>
+          #     role: <value in [primary, secondary]>
+          #     weight: <integer>
+          # backhaul_interface: <string>
+          # backhaul_ip: <string>
+          # ipsec_tunnel: <string>
+          # link_loadbalance: <value in [activebackup, loadbalance]>
+          # downlinks:
+          #   - name: <string>
+          #     port: <value in [port1, port2, port3, ...]>
+          #     pvid: <integer>
+          #     type: <value in [port, vap]>
+          #     vap: <list or string>
+          # traffic_split_services:
+          #   - address: <list or string>
+          #     name: <string>
+          #     service: <list or string>
+          #     vsdb: <value in [disable, enable]>
 '''
 
 RETURN = '''
@@ -262,6 +290,7 @@ def main():
         'adom': {'required': True, 'type': 'str'},
         'extender-profile': {'type': 'str', 'api_name': 'extender_profile'},
         'extender_profile': {'type': 'str'},
+        'revision_note': {'type': 'str'},
         'extensioncontroller_extenderprofile_lanextension': {
             'type': 'dict',
             'v_range': [['7.2.1', '']],
@@ -296,6 +325,17 @@ def main():
                         'vap': {'v_range': [['7.6.0', '']], 'type': 'raw'}
                     },
                     'elements': 'dict'
+                },
+                'traffic-split-services': {
+                    'v_range': [['7.6.2', '']],
+                    'type': 'list',
+                    'options': {
+                        'address': {'v_range': [['7.6.2', '']], 'type': 'raw'},
+                        'name': {'v_range': [['7.6.2', '']], 'type': 'str'},
+                        'service': {'v_range': [['7.6.2', '']], 'type': 'raw'},
+                        'vsdb': {'v_range': [['7.6.2', '']], 'choices': ['disable', 'enable'], 'type': 'str'}
+                    },
+                    'elements': 'dict'
                 }
             }
         }
