@@ -64,6 +64,9 @@ options:
         description: The rc codes list with which the conditions to fail will be overriden.
         type: list
         elements: int
+    revision_note:
+        description: The change note that can be specified when an object is created or updated.
+        type: str
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
         type: str
@@ -310,12 +313,20 @@ options:
                     - 'block'
                     - 'monitor'
                     - 'allow'
+            http_0_9:
+                aliases: ['http-0.9']
+                type: str
+                description: Configure action to take upon receipt of HTTP 0.
+                choices:
+                    - 'block'
+                    - 'allow'
 '''
 
 EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -324,73 +335,74 @@ EXAMPLES = '''
     - name: Configure HTTP protocol options.
       fortinet.fortimanager.fmgr_firewall_profileprotocoloptions_http:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         adom: <your own value>
         profile_protocol_options: <your own value>
         firewall_profileprotocoloptions_http:
-          block_page_status_code: <integer>
-          comfort_amount: <integer>
-          comfort_interval: <integer>
-          fortinet_bar: <value in [disable, enable]>
-          fortinet_bar_port: <integer>
-          http_policy: <value in [disable, enable]>
-          inspect_all: <value in [disable, enable]>
-          options:
-            - "oversize"
-            - "chunkedbypass"
-            - "clientcomfort"
-            - "no-content-summary"
-            - "servercomfort"
-          oversize_limit: <integer>
-          ports: <list or integer>
-          post_lang:
-            - "jisx0201"
-            - "jisx0208"
-            - "jisx0212"
-            - "gb2312"
-            - "ksc5601-ex"
-            - "euc-jp"
-            - "sjis"
-            - "iso2022-jp"
-            - "iso2022-jp-1"
-            - "iso2022-jp-2"
-            - "euc-cn"
-            - "ces-gbk"
-            - "hz"
-            - "ces-big5"
-            - "euc-kr"
-            - "iso2022-jp-3"
-            - "iso8859-1"
-            - "tis620"
-            - "cp874"
-            - "cp1252"
-            - "cp1251"
-          range_block: <value in [disable, enable]>
-          retry_count: <integer>
-          scan_bzip2: <value in [disable, enable]>
-          status: <value in [disable, enable]>
-          streaming_content_bypass: <value in [disable, enable]>
-          strip_x_forwarded_for: <value in [disable, enable]>
-          switching_protocols: <value in [bypass, block]>
-          uncompressed_nest_limit: <integer>
-          uncompressed_oversize_limit: <integer>
-          tcp_window_maximum: <integer>
-          tcp_window_minimum: <integer>
-          tcp_window_size: <integer>
-          tcp_window_type: <value in [system, static, dynamic, ...]>
-          ssl_offloaded: <value in [no, yes]>
-          stream_based_uncompressed_limit: <integer>
-          proxy_after_tcp_handshake: <value in [disable, enable]>
-          tunnel_non_http: <value in [disable, enable]>
-          unknown_http_version: <value in [best-effort, reject, tunnel]>
-          address_ip_rating: <value in [disable, enable]>
-          h2c: <value in [disable, enable]>
-          verify_dns_for_policy_matching: <value in [disable, enable]>
-          unknown_content_encoding: <value in [block, inspect, bypass]>
-          domain_fronting: <value in [block, monitor, allow]>
+          # block_page_status_code: <integer>
+          # comfort_amount: <integer>
+          # comfort_interval: <integer>
+          # fortinet_bar: <value in [disable, enable]>
+          # fortinet_bar_port: <integer>
+          # http_policy: <value in [disable, enable]>
+          # inspect_all: <value in [disable, enable]>
+          # options:
+          #   - "oversize"
+          #   - "chunkedbypass"
+          #   - "clientcomfort"
+          #   - "no-content-summary"
+          #   - "servercomfort"
+          # oversize_limit: <integer>
+          # ports: <list or integer>
+          # post_lang:
+          #   - "jisx0201"
+          #   - "jisx0208"
+          #   - "jisx0212"
+          #   - "gb2312"
+          #   - "ksc5601-ex"
+          #   - "euc-jp"
+          #   - "sjis"
+          #   - "iso2022-jp"
+          #   - "iso2022-jp-1"
+          #   - "iso2022-jp-2"
+          #   - "euc-cn"
+          #   - "ces-gbk"
+          #   - "hz"
+          #   - "ces-big5"
+          #   - "euc-kr"
+          #   - "iso2022-jp-3"
+          #   - "iso8859-1"
+          #   - "tis620"
+          #   - "cp874"
+          #   - "cp1252"
+          #   - "cp1251"
+          # range_block: <value in [disable, enable]>
+          # retry_count: <integer>
+          # scan_bzip2: <value in [disable, enable]>
+          # status: <value in [disable, enable]>
+          # streaming_content_bypass: <value in [disable, enable]>
+          # strip_x_forwarded_for: <value in [disable, enable]>
+          # switching_protocols: <value in [bypass, block]>
+          # uncompressed_nest_limit: <integer>
+          # uncompressed_oversize_limit: <integer>
+          # tcp_window_maximum: <integer>
+          # tcp_window_minimum: <integer>
+          # tcp_window_size: <integer>
+          # tcp_window_type: <value in [system, static, dynamic, ...]>
+          # ssl_offloaded: <value in [no, yes]>
+          # stream_based_uncompressed_limit: <integer>
+          # proxy_after_tcp_handshake: <value in [disable, enable]>
+          # tunnel_non_http: <value in [disable, enable]>
+          # unknown_http_version: <value in [best-effort, reject, tunnel]>
+          # address_ip_rating: <value in [disable, enable]>
+          # h2c: <value in [disable, enable]>
+          # verify_dns_for_policy_matching: <value in [disable, enable]>
+          # unknown_content_encoding: <value in [block, inspect, bypass]>
+          # domain_fronting: <value in [block, monitor, allow]>
+          # http_0_9: <value in [block, allow]>
 '''
 
 RETURN = '''
@@ -449,6 +461,7 @@ def main():
         'adom': {'required': True, 'type': 'str'},
         'profile-protocol-options': {'type': 'str', 'api_name': 'profile_protocol_options'},
         'profile_protocol_options': {'type': 'str'},
+        'revision_note': {'type': 'str'},
         'firewall_profileprotocoloptions_http': {
             'type': 'dict',
             'v_range': [['6.0.0', '']],
@@ -497,7 +510,8 @@ def main():
                 'h2c': {'v_range': [['7.2.0', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
                 'verify-dns-for-policy-matching': {'v_range': [['7.2.1', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
                 'unknown-content-encoding': {'v_range': [['7.2.2', '']], 'choices': ['block', 'inspect', 'bypass'], 'type': 'str'},
-                'domain-fronting': {'v_range': [['7.6.0', '']], 'choices': ['block', 'monitor', 'allow'], 'type': 'str'}
+                'domain-fronting': {'v_range': [['7.6.0', '']], 'choices': ['block', 'monitor', 'allow'], 'type': 'str'},
+                'http-0.9': {'v_range': [['7.6.2', '']], 'choices': ['block', 'allow'], 'type': 'str'}
             }
         }
     }
