@@ -73,6 +73,9 @@ options:
         choices:
           - present
           - absent
+    revision_note:
+        description: The change note that can be specified when an object is created or updated.
+        type: str
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
         type: str
@@ -142,7 +145,7 @@ EXAMPLES = '''
       fortinet.fortimanager.fmgr_firewall_sslsshprofile_sslexempt:
         bypass_validation: false
         adom: ansible
-        ssl-ssh-profile: "ansible-test" # name
+        ssl_ssh_profile: "ansible-test" # name
         state: present
         firewall_sslsshprofile_sslexempt:
           id: 1
@@ -163,8 +166,8 @@ EXAMPLES = '''
           selector: "firewall_sslsshprofile_sslexempt"
           params:
             adom: "ansible"
-            ssl-ssh-profile: "ansible-test" # name
-            ssl-exempt: "your_value"
+            ssl_ssh_profile: "ansible-test" # name
+            ssl_exempt: "your_value"
 '''
 
 RETURN = '''
@@ -223,6 +226,7 @@ def main():
         'adom': {'required': True, 'type': 'str'},
         'ssl-ssh-profile': {'type': 'str', 'api_name': 'ssl_ssh_profile'},
         'ssl_ssh_profile': {'type': 'str'},
+        'revision_note': {'type': 'str'},
         'firewall_sslsshprofile_sslexempt': {
             'type': 'dict',
             'v_range': [['6.0.0', '']],
