@@ -73,6 +73,9 @@ options:
         choices:
           - present
           - absent
+    revision_note:
+        description: The change note that can be specified when an object is created or updated.
+        type: str
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
         type: str
@@ -342,6 +345,13 @@ options:
                         choices:
                             - 'ping'
                             - 'http'
+                    verify_cert:
+                        aliases: ['verify-cert']
+                        type: str
+                        description: Verify cert.
+                        choices:
+                            - 'disable'
+                            - 'enable'
             server_type:
                 aliases: ['server-type']
                 type: str
@@ -815,11 +825,34 @@ options:
                 choices:
                     - 'disable'
                     - 'enable'
+            client_cert:
+                aliases: ['client-cert']
+                type: str
+                description: Enable/disable requesting client certificate.
+                choices:
+                    - 'disable'
+                    - 'enable'
+            empty_cert_action:
+                aliases: ['empty-cert-action']
+                type: str
+                description: Action for an empty client certificate.
+                choices:
+                    - 'accept'
+                    - 'block'
+                    - 'accept-unmanageable'
+            user_agent_detect:
+                aliases: ['user-agent-detect']
+                type: str
+                description: Enable/disable detecting device type by HTTP user-agent if no client certificate is provided.
+                choices:
+                    - 'disable'
+                    - 'enable'
 '''
 
 EXAMPLES = '''
 - name: Example playbook
   hosts: fortimanagers
+  gather_facts: false
   connection: httpapi
   vars:
     ansible_httpapi_use_ssl: true
@@ -836,7 +869,7 @@ EXAMPLES = '''
           _scope: # Required
             - name: FGT_AWS # need a valid device name
               vdom: root # need a valid vdom name under the device
-          arp-reply: enable
+          arp_reply: enable
           color: 2
           comment: "ansible-comment"
           id: 1
@@ -915,6 +948,7 @@ def main():
     module_arg_spec = {
         'adom': {'required': True, 'type': 'str'},
         'vip': {'required': True, 'type': 'str'},
+        'revision_note': {'type': 'str'},
         'firewall_vip_dynamicmapping': {
             'type': 'dict',
             'v_range': [['6.0.0', '']],
@@ -970,7 +1004,8 @@ def main():
                         'id': {'v_range': [['6.4.0', '']], 'type': 'int'},
                         'type': {'v_range': [['6.4.0', '']], 'choices': ['ip', 'address'], 'type': 'str'},
                         'translate-host': {'v_range': [['7.2.2', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
-                        'health-check-proto': {'v_range': [['7.2.3', '']], 'choices': ['ping', 'http'], 'type': 'str'}
+                        'health-check-proto': {'v_range': [['7.2.3', '']], 'choices': ['ping', 'http'], 'type': 'str'},
+                        'verify-cert': {'v_range': [['7.4.7', '7.4.7'], ['7.6.3', '']], 'choices': ['disable', 'enable'], 'type': 'str'}
                     },
                     'elements': 'dict'
                 },
@@ -1071,7 +1106,10 @@ def main():
                 'gslb-domain-name': {'v_range': [['7.4.2', '']], 'type': 'str'},
                 'gslb-hostname': {'v_range': [['7.4.2', '']], 'type': 'str'},
                 'one-click-gslb-server': {'v_range': [['7.4.2', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
-                'src-vip-filter': {'v_range': [['7.4.3', '']], 'choices': ['disable', 'enable'], 'type': 'str'}
+                'src-vip-filter': {'v_range': [['7.4.3', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                'client-cert': {'v_range': [['7.6.2', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                'empty-cert-action': {'v_range': [['7.6.2', '']], 'choices': ['accept', 'block', 'accept-unmanageable'], 'type': 'str'},
+                'user-agent-detect': {'v_range': [['7.6.2', '']], 'choices': ['disable', 'enable'], 'type': 'str'}
             }
         }
     }
