@@ -64,6 +64,9 @@ options:
         description: The rc codes list with which the conditions to fail will be overriden.
         type: list
         elements: int
+    revision_note:
+        description: The change note that can be specified when an object is created or updated.
+        type: str
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
         type: str
@@ -106,6 +109,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -114,16 +118,16 @@ EXAMPLES = '''
     - name: Fmg sase manager status
       fortinet.fortimanager.fmgr_fmg_sasemanager_status:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         adom: <your own value>
         fmg_sasemanager_status:
-          forticlient_ver: <string>
-          forticloud_id: <integer>
-          license_type: <value in [standard_license, advanced_license, comprehensive_license]>
-          spa_hubs: <integer>
+          # forticlient_ver: <string>
+          # forticloud_id: <integer>
+          # license_type: <value in [standard_license, advanced_license, comprehensive_license]>
+          # spa_hubs: <integer>
 '''
 
 RETURN = '''
@@ -180,14 +184,19 @@ def main():
     module_primary_key = None
     module_arg_spec = {
         'adom': {'required': True, 'type': 'str'},
+        'revision_note': {'type': 'str'},
         'fmg_sasemanager_status': {
             'type': 'dict',
-            'v_range': [['7.6.0', '']],
+            'v_range': [['7.6.0', '7.6.1']],
             'options': {
-                'forticlient-ver': {'v_range': [['7.6.0', '']], 'type': 'str'},
-                'forticloud-id': {'v_range': [['7.6.0', '']], 'type': 'int'},
-                'license-type': {'v_range': [['7.6.0', '']], 'choices': ['standard_license', 'advanced_license', 'comprehensive_license'], 'type': 'str'},
-                'spa-hubs': {'v_range': [['7.6.0', '']], 'type': 'int'}
+                'forticlient-ver': {'v_range': [['7.6.0', '7.6.1']], 'type': 'str'},
+                'forticloud-id': {'v_range': [['7.6.0', '7.6.1']], 'type': 'int'},
+                'license-type': {
+                    'v_range': [['7.6.0', '7.6.1']],
+                    'choices': ['standard_license', 'advanced_license', 'comprehensive_license'],
+                    'type': 'str'
+                },
+                'spa-hubs': {'v_range': [['7.6.0', '7.6.1']], 'type': 'int'}
             }
         }
     }
