@@ -73,6 +73,9 @@ options:
         choices:
           - present
           - absent
+    revision_note:
+        description: The change note that can be specified when an object is created or updated.
+        type: str
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
         type: str
@@ -146,6 +149,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -154,8 +158,8 @@ EXAMPLES = '''
     - name: DHCP options.
       fortinet.fortimanager.fmgr_fsp_vlan_dynamicmapping_dhcpserver_options:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         adom: <your own value>
@@ -163,15 +167,15 @@ EXAMPLES = '''
         dynamic_mapping: <your own value>
         state: present # <value in [present, absent]>
         fsp_vlan_dynamicmapping_dhcpserver_options:
-          code: <integer>
-          id: <integer>
-          ip: <list or string>
-          type: <value in [hex, string, ip, ...]>
-          value: <string>
-          vci_match: <value in [disable, enable]>
-          vci_string: <list or string>
-          uci_match: <value in [disable, enable]>
-          uci_string: <list or string>
+          id: 0 # Required variable, integer
+          # code: <integer>
+          # ip: <list or string>
+          # type: <value in [hex, string, ip, ...]>
+          # value: <string>
+          # vci_match: <value in [disable, enable]>
+          # vci_string: <list or string>
+          # uci_match: <value in [disable, enable]>
+          # uci_string: <list or string>
 '''
 
 RETURN = '''
@@ -230,6 +234,7 @@ def main():
         'adom': {'required': True, 'type': 'str'},
         'vlan': {'required': True, 'type': 'str'},
         'dynamic_mapping': {'required': True, 'type': 'str'},
+        'revision_note': {'type': 'str'},
         'fsp_vlan_dynamicmapping_dhcpserver_options': {
             'type': 'dict',
             'v_range': [['6.0.0', '7.2.5'], ['7.4.0', '7.4.0']],
