@@ -73,6 +73,9 @@ options:
         choices:
           - present
           - absent
+    revision_note:
+        description: The change note that can be specified when an object is created or updated.
+        type: str
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
         type: str
@@ -162,6 +165,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -170,8 +174,8 @@ EXAMPLES = '''
     - name: Second IP address of interface.
       fortinet.fortimanager.fmgr_fsp_vlan_dynamicmapping_interface_secondaryip:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         adom: <your own value>
@@ -179,34 +183,34 @@ EXAMPLES = '''
         dynamic_mapping: <your own value>
         state: present # <value in [present, absent]>
         fsp_vlan_dynamicmapping_interface_secondaryip:
-          allowaccess:
-            - "https"
-            - "ping"
-            - "ssh"
-            - "snmp"
-            - "http"
-            - "telnet"
-            - "fgfm"
-            - "auto-ipsec"
-            - "radius-acct"
-            - "probe-response"
-            - "capwap"
-            - "dnp"
-            - "ftm"
-            - "fabric"
-            - "speed-test"
-          detectprotocol:
-            - "ping"
-            - "tcp-echo"
-            - "udp-echo"
-          detectserver: <string>
-          gwdetect: <value in [disable, enable]>
-          ha_priority: <integer>
-          id: <integer>
-          ip: <string>
-          ping_serv_status: <integer>
-          seq: <integer>
-          secip_relay_ip: <string>
+          id: 0 # Required variable, integer
+          # allowaccess:
+          #   - "https"
+          #   - "ping"
+          #   - "ssh"
+          #   - "snmp"
+          #   - "http"
+          #   - "telnet"
+          #   - "fgfm"
+          #   - "auto-ipsec"
+          #   - "radius-acct"
+          #   - "probe-response"
+          #   - "capwap"
+          #   - "dnp"
+          #   - "ftm"
+          #   - "fabric"
+          #   - "speed-test"
+          # detectprotocol:
+          #   - "ping"
+          #   - "tcp-echo"
+          #   - "udp-echo"
+          # detectserver: <string>
+          # gwdetect: <value in [disable, enable]>
+          # ha_priority: <integer>
+          # ip: <string>
+          # ping_serv_status: <integer>
+          # seq: <integer>
+          # secip_relay_ip: <string>
 '''
 
 RETURN = '''
@@ -265,6 +269,7 @@ def main():
         'adom': {'required': True, 'type': 'str'},
         'vlan': {'required': True, 'type': 'str'},
         'dynamic_mapping': {'required': True, 'type': 'str'},
+        'revision_note': {'type': 'str'},
         'fsp_vlan_dynamicmapping_interface_secondaryip': {
             'type': 'dict',
             'v_range': [['6.2.3', '7.2.5'], ['7.4.0', '7.4.0']],
