@@ -73,6 +73,9 @@ options:
         choices:
           - present
           - absent
+    revision_note:
+        description: The change note that can be specified when an object is created or updated.
+        type: str
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
         type: str
@@ -130,6 +133,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -138,21 +142,21 @@ EXAMPLES = '''
     - name: Advertised prefix list.
       fortinet.fortimanager.fmgr_fsp_vlan_interface_ipv6_ip6prefixlist:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         adom: <your own value>
         vlan: <your own value>
         state: present # <value in [present, absent]>
         fsp_vlan_interface_ipv6_ip6prefixlist:
-          autonomous_flag: <value in [disable, enable]>
-          dnssl: <list or string>
-          onlink_flag: <value in [disable, enable]>
-          preferred_life_time: <integer>
-          prefix: <string>
-          rdnss: <list or string>
-          valid_life_time: <integer>
+          # autonomous_flag: <value in [disable, enable]>
+          # dnssl: <list or string>
+          # onlink_flag: <value in [disable, enable]>
+          # preferred_life_time: <integer>
+          # prefix: <string>
+          # rdnss: <list or string>
+          # valid_life_time: <integer>
 '''
 
 RETURN = '''
@@ -210,6 +214,7 @@ def main():
     module_arg_spec = {
         'adom': {'required': True, 'type': 'str'},
         'vlan': {'required': True, 'type': 'str'},
+        'revision_note': {'type': 'str'},
         'fsp_vlan_interface_ipv6_ip6prefixlist': {
             'type': 'dict',
             'v_range': [['6.2.2', '']],
