@@ -73,6 +73,9 @@ options:
         choices:
           - present
           - absent
+    revision_note:
+        description: The change note that can be specified when an object is created or updated.
+        type: str
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
         type: str
@@ -143,6 +146,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -151,26 +155,24 @@ EXAMPLES = '''
     - name: Configure advice of charge.
       fortinet.fortimanager.fmgr_hotspot20_h2qpadviceofcharge:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         adom: <your own value>
         state: present # <value in [present, absent]>
         hotspot20_h2qpadviceofcharge:
-          aoc_list:
-            -
-              nai_realm: <string>
-              nai_realm_encoding: <string>
-              name: <string>
-              plan_info:
-                -
-                  currency: <string>
-                  info_file: <string>
-                  lang: <string>
-                  name: <string>
-              type: <value in [time-based, volume-based, time-and-volume-based, ...]>
-          name: <string>
+          name: "your value" # Required variable, string
+          # aoc_list:
+          #   - nai_realm: <string>
+          #     nai_realm_encoding: <string>
+          #     name: <string>
+          #     plan_info:
+          #       - currency: <string>
+          #         info_file: <string>
+          #         lang: <string>
+          #         name: <string>
+          #     type: <value in [time-based, volume-based, time-and-volume-based, ...]>
 '''
 
 RETURN = '''
@@ -227,6 +229,7 @@ def main():
     module_primary_key = 'name'
     module_arg_spec = {
         'adom': {'required': True, 'type': 'str'},
+        'revision_note': {'type': 'str'},
         'hotspot20_h2qpadviceofcharge': {
             'type': 'dict',
             'v_range': [['7.0.3', '']],
