@@ -73,6 +73,9 @@ options:
         choices:
           - present
           - absent
+    revision_note:
+        description: The change note that can be specified when an object is created or updated.
+        type: str
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
         type: str
@@ -114,6 +117,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -122,19 +126,18 @@ EXAMPLES = '''
     - name: Configure operator friendly name.
       fortinet.fortimanager.fmgr_hotspot20_h2qpoperatorname:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         adom: <your own value>
         state: present # <value in [present, absent]>
         hotspot20_h2qpoperatorname:
-          name: <string>
-          value_list:
-            -
-              index: <integer>
-              lang: <string>
-              value: <string>
+          name: "your value" # Required variable, string
+          # value_list:
+          #   - index: <integer>
+          #     lang: <string>
+          #     value: <string>
 '''
 
 RETURN = '''
@@ -191,6 +194,7 @@ def main():
     module_primary_key = 'name'
     module_arg_spec = {
         'adom': {'required': True, 'type': 'str'},
+        'revision_note': {'type': 'str'},
         'hotspot20_h2qpoperatorname': {
             'type': 'dict',
             'v_range': [['6.0.0', '']],
