@@ -73,6 +73,9 @@ options:
         choices:
           - present
           - absent
+    revision_note:
+        description: The change note that can be specified when an object is created or updated.
+        type: str
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
         type: str
@@ -113,6 +116,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -121,17 +125,17 @@ EXAMPLES = '''
     - name: OSU service name.
       fortinet.fortimanager.fmgr_hotspot20_h2qposuprovider_servicedescription:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         adom: <your own value>
         h2qp_osu_provider: <your own value>
         state: present # <value in [present, absent]>
         hotspot20_h2qposuprovider_servicedescription:
-          lang: <string>
-          service_description: <string>
-          service_id: <integer>
+          service_id: 0 # Required variable, integer
+          # lang: <string>
+          # service_description: <string>
 '''
 
 RETURN = '''
@@ -190,6 +194,7 @@ def main():
         'adom': {'required': True, 'type': 'str'},
         'h2qp-osu-provider': {'type': 'str', 'api_name': 'h2qp_osu_provider'},
         'h2qp_osu_provider': {'type': 'str'},
+        'revision_note': {'type': 'str'},
         'hotspot20_h2qposuprovider_servicedescription': {
             'type': 'dict',
             'v_range': [['6.0.0', '']],
