@@ -73,6 +73,9 @@ options:
         choices:
           - present
           - absent
+    revision_note:
+        description: The change note that can be specified when an object is created or updated.
+        type: str
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
         type: str
@@ -114,6 +117,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -122,18 +126,18 @@ EXAMPLES = '''
     - name: Differentiated Services Code Point
       fortinet.fortimanager.fmgr_hotspot20_qosmap_dscprange:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         adom: <your own value>
         qos_map: <your own value>
         state: present # <value in [present, absent]>
         hotspot20_qosmap_dscprange:
-          high: <integer>
-          index: <integer>
-          low: <integer>
-          up: <integer>
+          index: 0 # Required variable, integer
+          # high: <integer>
+          # low: <integer>
+          # up: <integer>
 '''
 
 RETURN = '''
@@ -192,6 +196,7 @@ def main():
         'adom': {'required': True, 'type': 'str'},
         'qos-map': {'type': 'str', 'api_name': 'qos_map'},
         'qos_map': {'type': 'str'},
+        'revision_note': {'type': 'str'},
         'hotspot20_qosmap_dscprange': {
             'type': 'dict',
             'v_range': [['6.0.0', '']],
