@@ -73,6 +73,9 @@ options:
         choices:
           - present
           - absent
+    revision_note:
+        description: The change note that can be specified when an object is created or updated.
+        type: str
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
         type: str
@@ -232,8 +235,8 @@ EXAMPLES = '''
     - name: IPS sensor filter.
       fortinet.fortimanager.fmgr_ips_baseline_sensor_entries:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         adom: <your own value>
@@ -322,6 +325,7 @@ def main():
     module_arg_spec = {
         'adom': {'required': True, 'type': 'str'},
         'sensor': {'required': True, 'type': 'str'},
+        'revision_note': {'type': 'str'},
         'ips_baseline_sensor_entries': {
             'type': 'dict',
             'v_range': [['7.0.1', '7.0.2']],
