@@ -73,6 +73,9 @@ options:
         choices:
           - present
           - absent
+    revision_note:
+        description: The change note that can be specified when an object is created or updated.
+        type: str
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
         type: str
@@ -115,6 +118,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -123,8 +127,8 @@ EXAMPLES = '''
     - name: Ips baseline sensor override exempt ip
       fortinet.fortimanager.fmgr_ips_baseline_sensor_override_exemptip:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         adom: <your own value>
@@ -132,9 +136,9 @@ EXAMPLES = '''
         override: <your own value>
         state: present # <value in [present, absent]>
         ips_baseline_sensor_override_exemptip:
-          dst_ip: <string>
-          id: <integer>
-          src_ip: <string>
+          id: 0 # Required variable, integer
+          # dst_ip: <string>
+          # src_ip: <string>
 '''
 
 RETURN = '''
@@ -193,6 +197,7 @@ def main():
         'adom': {'required': True, 'type': 'str'},
         'sensor': {'required': True, 'type': 'str'},
         'override': {'required': True, 'type': 'str'},
+        'revision_note': {'type': 'str'},
         'ips_baseline_sensor_override_exemptip': {
             'type': 'dict',
             'v_range': [['7.0.1', '7.0.2']],
