@@ -73,6 +73,9 @@ options:
         choices:
           - present
           - absent
+    revision_note:
+        description: The change note that can be specified when an object is created or updated.
+        type: str
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
         type: str
@@ -211,9 +214,9 @@ EXAMPLES = '''
         pkg: ansible # package name
         state: present
         pkg_firewall_centralsnatmap:
-          dst-addr: "ansible-test1"
+          dst_addr: "ansible-test1"
           nat: enable
-          orig-addr: "ansible-test1"
+          orig_addr: "ansible-test1"
           policyid: 2
           status: disable
 
@@ -233,7 +236,7 @@ EXAMPLES = '''
           params:
             adom: "ansible"
             pkg: "ansible" # package name
-            central-snat-map: "your_value"
+            central_snat_map: "your_value"
 '''
 
 RETURN = '''
@@ -290,6 +293,7 @@ def main():
     module_arg_spec = {
         'adom': {'required': True, 'type': 'str'},
         'pkg': {'required': True, 'type': 'str'},
+        'revision_note': {'type': 'str'},
         'pkg_firewall_centralsnatmap': {
             'type': 'dict',
             'v_range': [['6.0.0', '']],
