@@ -73,6 +73,9 @@ options:
         choices:
           - present
           - absent
+    revision_note:
+        description: The change note that can be specified when an object is created or updated.
+        type: str
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
         type: str
@@ -290,6 +293,7 @@ options:
 EXAMPLES = '''
 - name: Example playbook
   hosts: fortimanagers
+  gather_facts: false
   connection: httpapi
   vars:
     ansible_httpapi_use_ssl: true
@@ -306,7 +310,7 @@ EXAMPLES = '''
           dstaddr: all
           dstintf: any
           id: 1
-          ip-version: 4 # <value in [4, 6]>
+          ip_version: 4 # <value in [4, 6]>
           schedule: always
           service: ALL
           srcaddr: all
@@ -328,7 +332,7 @@ EXAMPLES = '''
           params:
             adom: "ansible"
             pkg: "ansible" # package name
-            shaping-policy: "your_value"
+            shaping_policy: "your_value"
 '''
 
 RETURN = '''
@@ -385,6 +389,7 @@ def main():
     module_arg_spec = {
         'adom': {'required': True, 'type': 'str'},
         'pkg': {'required': True, 'type': 'str'},
+        'revision_note': {'type': 'str'},
         'pkg_firewall_shapingpolicy': {
             'type': 'dict',
             'v_range': [['6.0.0', '']],
@@ -418,12 +423,12 @@ def main():
                 'internet-service-custom': {'v_range': [['6.2.0', '']], 'type': 'raw'},
                 'internet-service-custom-group': {'v_range': [['6.2.0', '']], 'type': 'raw'},
                 'internet-service-group': {'v_range': [['6.2.0', '']], 'type': 'raw'},
-                'internet-service-id': {'v_range': [['6.2.0', '']], 'type': 'raw'},
+                'internet-service-id': {'v_range': [['6.2.0', '7.6.2']], 'type': 'raw'},
                 'internet-service-src': {'v_range': [['6.2.0', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
                 'internet-service-src-custom': {'v_range': [['6.2.0', '']], 'type': 'raw'},
                 'internet-service-src-custom-group': {'v_range': [['6.2.0', '']], 'type': 'raw'},
                 'internet-service-src-group': {'v_range': [['6.2.0', '']], 'type': 'raw'},
-                'internet-service-src-id': {'v_range': [['6.2.0', '']], 'type': 'raw'},
+                'internet-service-src-id': {'v_range': [['6.2.0', '7.6.2']], 'type': 'raw'},
                 'name': {'v_range': [['6.2.0', '']], 'type': 'str'},
                 'srcintf': {'v_range': [['6.2.0', '']], 'type': 'raw'},
                 'tos': {'v_range': [['6.2.0', '']], 'type': 'str'},
