@@ -121,8 +121,8 @@ EXAMPLES = '''
     - name: Configure consolidated IPv4/IPv6 policies.
       fortinet.fortimanager.fmgr_pm_config_pblock_firewall_consolidated_policy_sectionvalue:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         adom: <your own value>
