@@ -257,6 +257,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -265,39 +266,38 @@ EXAMPLES = '''
     - name: Policy package or folder.
       fortinet.fortimanager.fmgr_pm_pkg:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         adom: <your own value>
         pkg_path: <your own value>
         state: present # <value in [present, absent]>
         pm_pkg:
-          name: <string>
-          obj_ver: <integer>
-          oid: <integer>
-          package_setting:
-            central_nat: <value in [disable, enable]>
-            consolidated_firewall_mode: <value in [disable, enable]>
-            fwpolicy_implicit_log: <value in [disable, enable]>
-            fwpolicy6_implicit_log: <value in [disable, enable]>
-            inspection_mode: <value in [proxy, flow]>
-            ngfw_mode: <value in [profile-based, policy-based]>
-            ssl_ssh_profile: <string>
-          scope_member:
-            -
-              name: <string>
-              vdom: <string>
-          type: <value in [pkg, folder]>
-          package_settings:
-            central_nat: <value in [disable, enable]>
-            consolidated_firewall_mode: <value in [disable, enable]>
-            fwpolicy_implicit_log: <value in [disable, enable]>
-            fwpolicy6_implicit_log: <value in [disable, enable]>
-            inspection_mode: <value in [proxy, flow]>
-            ngfw_mode: <value in [profile-based, policy-based]>
-            policy_offload_level: <value in [disable, default, dos-offload, ...]>
-            ssl_ssh_profile: <string>
+          name: "your value" # Required variable, string
+          # obj_ver: <integer>
+          # oid: <integer>
+          # package_setting:
+          #   central_nat: <value in [disable, enable]>
+          #   consolidated_firewall_mode: <value in [disable, enable]>
+          #   fwpolicy_implicit_log: <value in [disable, enable]>
+          #   fwpolicy6_implicit_log: <value in [disable, enable]>
+          #   inspection_mode: <value in [proxy, flow]>
+          #   ngfw_mode: <value in [profile-based, policy-based]>
+          #   ssl_ssh_profile: <string>
+          # scope_member:
+          #   - name: <string>
+          #     vdom: <string>
+          # type: <value in [pkg, folder]>
+          # package_settings:
+          #   central_nat: <value in [disable, enable]>
+          #   consolidated_firewall_mode: <value in [disable, enable]>
+          #   fwpolicy_implicit_log: <value in [disable, enable]>
+          #   fwpolicy6_implicit_log: <value in [disable, enable]>
+          #   inspection_mode: <value in [proxy, flow]>
+          #   ngfw_mode: <value in [profile-based, policy-based]>
+          #   policy_offload_level: <value in [disable, default, dos-offload, ...]>
+          #   ssl_ssh_profile: <string>
 '''
 
 RETURN = '''
