@@ -73,6 +73,9 @@ options:
         choices:
           - present
           - absent
+    revision_note:
+        description: The change note that can be specified when an object is created or updated.
+        type: str
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
         type: str
@@ -164,6 +167,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -172,27 +176,27 @@ EXAMPLES = '''
     - name: DSL policy.
       fortinet.fortimanager.fmgr_switchcontroller_dsl_policy:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         adom: <your own value>
         state: present # <value in [present, absent]>
         switchcontroller_dsl_policy:
-          append_padding: <value in [disable, enable]>
-          cpe_aele: <value in [disable, enable]>
-          cpe_aele_mode: <value in [ELE_M0, ELE_DS, ELE_PB, ...]>
-          cs:
-            - "A43"
-            - "B43"
-            - "A43C"
-            - "V43"
-          ds_bitswap: <value in [disable, enable]>
-          name: <string>
-          pause_frame: <value in [disable, enable]>
-          profile: <value in [auto-30a, auto-17a, auto-12ab]>
-          type: <value in [Procend, Proscend]>
-          us_bitswap: <value in [disable, enable]>
+          name: "your value" # Required variable, string
+          # append_padding: <value in [disable, enable]>
+          # cpe_aele: <value in [disable, enable]>
+          # cpe_aele_mode: <value in [ELE_M0, ELE_DS, ELE_PB, ...]>
+          # cs:
+          #   - "A43"
+          #   - "B43"
+          #   - "A43C"
+          #   - "V43"
+          # ds_bitswap: <value in [disable, enable]>
+          # pause_frame: <value in [disable, enable]>
+          # profile: <value in [auto-30a, auto-17a, auto-12ab]>
+          # type: <value in [Procend, Proscend]>
+          # us_bitswap: <value in [disable, enable]>
 '''
 
 RETURN = '''
@@ -249,6 +253,7 @@ def main():
     module_primary_key = 'name'
     module_arg_spec = {
         'adom': {'required': True, 'type': 'str'},
+        'revision_note': {'type': 'str'},
         'switchcontroller_dsl_policy': {
             'type': 'dict',
             'v_range': [['7.0.3', '']],
