@@ -73,6 +73,9 @@ options:
         choices:
           - present
           - absent
+    revision_note:
+        description: The change note that can be specified when an object is created or updated.
+        type: str
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
         type: str
@@ -125,12 +128,24 @@ options:
             fortilink:
                 type: raw
                 description: (list) FortiLink interface for which this MAC policy belongs to.
+            bounce_port_duration:
+                aliases: ['bounce-port-duration']
+                type: int
+                description: Bounce duration in seconds of a switch port where this mac-policy is applied.
+            poe_reset:
+                aliases: ['poe-reset']
+                type: str
+                description: Enable/disable POE reset of a switch port where this mac-policy is applied.
+                choices:
+                    - 'disable'
+                    - 'enable'
 '''
 
 EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -139,21 +154,23 @@ EXAMPLES = '''
     - name: Configure MAC policy to be applied on the managed FortiSwitch devices through NAC device.
       fortinet.fortimanager.fmgr_switchcontroller_macpolicy:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         adom: <your own value>
         state: present # <value in [present, absent]>
         switchcontroller_macpolicy:
-          bounce_port_link: <value in [disable, enable]>
-          count: <value in [disable, enable]>
-          description: <string>
-          name: <string>
-          traffic_policy: <string>
-          vlan: <string>
-          drop: <value in [disable, enable]>
-          fortilink: <list or string>
+          name: "your value" # Required variable, string
+          # bounce_port_link: <value in [disable, enable]>
+          # count: <value in [disable, enable]>
+          # description: <string>
+          # traffic_policy: <string>
+          # vlan: <string>
+          # drop: <value in [disable, enable]>
+          # fortilink: <list or string>
+          # bounce_port_duration: <integer>
+          # poe_reset: <value in [disable, enable]>
 '''
 
 RETURN = '''
@@ -210,6 +227,7 @@ def main():
     module_primary_key = 'name'
     module_arg_spec = {
         'adom': {'required': True, 'type': 'str'},
+        'revision_note': {'type': 'str'},
         'switchcontroller_macpolicy': {
             'type': 'dict',
             'v_range': [['7.2.1', '']],
@@ -221,7 +239,9 @@ def main():
                 'traffic-policy': {'v_range': [['7.2.1', '']], 'type': 'str'},
                 'vlan': {'v_range': [['7.2.1', '']], 'type': 'str'},
                 'drop': {'v_range': [['7.2.1', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
-                'fortilink': {'v_range': [['7.2.6', '7.2.8'], ['7.4.3', '']], 'type': 'raw'}
+                'fortilink': {'v_range': [['7.2.6', '7.2.11'], ['7.4.3', '']], 'type': 'raw'},
+                'bounce-port-duration': {'v_range': [['7.6.2', '']], 'type': 'int'},
+                'poe-reset': {'v_range': [['7.6.2', '']], 'choices': ['disable', 'enable'], 'type': 'str'}
             }
         }
     }
