@@ -64,6 +64,9 @@ options:
         description: The rc codes list with which the conditions to fail will be overriden.
         type: list
         elements: int
+    revision_note:
+        description: The change note that can be specified when an object is created or updated.
+        type: str
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
         type: str
@@ -112,6 +115,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -120,18 +124,18 @@ EXAMPLES = '''
     - name: Configuration method to edit Simple Network Management Protocol
       fortinet.fortimanager.fmgr_switchcontroller_managedswitch_snmpsysinfo:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         adom: <your own value>
         managed_switch: <your own value>
         switchcontroller_managedswitch_snmpsysinfo:
-          contact_info: <string>
-          description: <string>
-          engine_id: <string>
-          location: <string>
-          status: <value in [disable, enable]>
+          # contact_info: <string>
+          # description: <string>
+          # engine_id: <string>
+          # location: <string>
+          # status: <value in [disable, enable]>
 '''
 
 RETURN = '''
@@ -190,6 +194,7 @@ def main():
         'adom': {'required': True, 'type': 'str'},
         'managed-switch': {'type': 'str', 'api_name': 'managed_switch'},
         'managed_switch': {'type': 'str'},
+        'revision_note': {'type': 'str'},
         'switchcontroller_managedswitch_snmpsysinfo': {
             'type': 'dict',
             'v_range': [['6.2.1', '6.2.3']],
