@@ -73,6 +73,9 @@ options:
         choices:
           - present
           - absent
+    revision_note:
+        description: The change note that can be specified when an object is created or updated.
+        type: str
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
         type: str
@@ -109,6 +112,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -117,16 +121,16 @@ EXAMPLES = '''
     - name: Configure VLAN assignment priority.
       fortinet.fortimanager.fmgr_switchcontroller_managedswitch_vlan:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         adom: <your own value>
         managed_switch: <your own value>
         state: present # <value in [present, absent]>
         switchcontroller_managedswitch_vlan:
-          assignment_priority: <integer>
-          vlan_name: <string>
+          # assignment_priority: <integer>
+          # vlan_name: <string>
 '''
 
 RETURN = '''
@@ -185,6 +189,7 @@ def main():
         'adom': {'required': True, 'type': 'str'},
         'managed-switch': {'type': 'str', 'api_name': 'managed_switch'},
         'managed_switch': {'type': 'str'},
+        'revision_note': {'type': 'str'},
         'switchcontroller_managedswitch_vlan': {
             'type': 'dict',
             'v_range': [['7.4.2', '']],
