@@ -73,6 +73,9 @@ options:
         choices:
           - present
           - absent
+    revision_note:
+        description: The change note that can be specified when an object is created or updated.
+        type: str
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
         type: str
@@ -157,6 +160,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -165,27 +169,26 @@ EXAMPLES = '''
     - name: Configure FortiSwitch QoS egress queue policy.
       fortinet.fortimanager.fmgr_switchcontroller_qos_queuepolicy:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         adom: <your own value>
         state: present # <value in [present, absent]>
         switchcontroller_qos_queuepolicy:
-          cos_queue:
-            -
-              description: <string>
-              drop_policy: <value in [taildrop, weighted-random-early-detection]>
-              max_rate: <integer>
-              min_rate: <integer>
-              name: <string>
-              weight: <integer>
-              max_rate_percent: <integer>
-              min_rate_percent: <integer>
-              ecn: <value in [disable, enable]>
-          name: <string>
-          schedule: <value in [strict, round-robin, weighted]>
-          rate_by: <value in [kbps, percent]>
+          name: "your value" # Required variable, string
+          # cos_queue:
+          #   - description: <string>
+          #     drop_policy: <value in [taildrop, weighted-random-early-detection]>
+          #     max_rate: <integer>
+          #     min_rate: <integer>
+          #     name: <string>
+          #     weight: <integer>
+          #     max_rate_percent: <integer>
+          #     min_rate_percent: <integer>
+          #     ecn: <value in [disable, enable]>
+          # schedule: <value in [strict, round-robin, weighted]>
+          # rate_by: <value in [kbps, percent]>
 '''
 
 RETURN = '''
@@ -242,6 +245,7 @@ def main():
     module_primary_key = 'name'
     module_arg_spec = {
         'adom': {'required': True, 'type': 'str'},
+        'revision_note': {'type': 'str'},
         'switchcontroller_qos_queuepolicy': {
             'type': 'dict',
             'v_range': [['6.0.0', '']],
