@@ -99,6 +99,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -107,14 +108,14 @@ EXAMPLES = '''
     - name: Group members.
       fortinet.fortimanager.fmgr_system_admin_group_member:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         group: <your own value>
         state: present # <value in [present, absent]>
         system_admin_group_member:
-          name: <string>
+          name: "your value" # Required variable, string
 '''
 
 RETURN = '''
