@@ -122,6 +122,7 @@ options:
 EXAMPLES = '''
 - name: Example playbook
   hosts: fortimanagers
+  gather_facts: false
   connection: httpapi
   vars:
     ansible_httpapi_use_ssl: true
@@ -155,7 +156,7 @@ EXAMPLES = '''
           selector: "system_admin_user_metadata"
           params:
             user: "ansible-test" # userid
-            meta-data: "your_value"
+            meta_data: "your_value"
 '''
 
 RETURN = '''
