@@ -118,6 +118,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -126,18 +127,18 @@ EXAMPLES = '''
     - name: OFTP certificates and keys.
       fortinet.fortimanager.fmgr_system_certificate_oftp:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         system_certificate_oftp:
-          certificate: <list or string>
-          comment: <string>
-          custom: <value in [disable, enable]>
-          password: <list or string>
-          private_key: <list or string>
-          local: <string>
-          mode: <value in [default, custom, local]>
+          # certificate: <list or string>
+          # comment: <string>
+          # custom: <value in [disable, enable]>
+          # password: <list or string>
+          # private_key: <list or string>
+          # local: <string>
+          # mode: <value in [default, custom, local]>
 '''
 
 RETURN = '''
