@@ -215,8 +215,8 @@ EXAMPLES = '''
     - name: HA configuration.
       fortinet.fortimanager.fmgr_system_ha:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         system_ha:
@@ -344,7 +344,7 @@ def main():
                 'vip': {'v_range': [['7.2.0', '']], 'type': 'str'},
                 'vrrp-adv-interval': {'v_range': [['7.2.0', '']], 'type': 'int'},
                 'vrrp-interface': {'v_range': [['7.2.0', '']], 'type': 'str'},
-                'vip-interface': {'v_range': [['7.2.4', '7.2.9'], ['7.4.1', '']], 'type': 'str'}
+                'vip-interface': {'v_range': [['7.2.4', '7.2.11'], ['7.4.1', '']], 'type': 'str'}
             }
         }
     }
