@@ -95,6 +95,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -103,13 +104,13 @@ EXAMPLES = '''
     - name: Monitored interfaces.
       fortinet.fortimanager.fmgr_system_ha_monitoredinterfaces:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         state: present # <value in [present, absent]>
         system_ha_monitoredinterfaces:
-          interface_name: <string>
+          # interface_name: <string>
 '''
 
 RETURN = '''
