@@ -154,8 +154,8 @@ EXAMPLES = '''
     - name: Logging rate limit.
       fortinet.fortimanager.fmgr_system_log_ratelimit:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         system_log_ratelimit:
