@@ -109,6 +109,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -117,16 +118,16 @@ EXAMPLES = '''
     - name: Device log rate limit.
       fortinet.fortimanager.fmgr_system_log_ratelimit_device:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         state: present # <value in [present, absent]>
         system_log_ratelimit_device:
-          device: <string>
-          filter_type: <value in [devid]>
-          id: <integer>
-          ratelimit: <integer>
+          id: 0 # Required variable, integer
+          # device: <string>
+          # filter_type: <value in [devid]>
+          # ratelimit: <integer>
 '''
 
 RETURN = '''
