@@ -64,6 +64,9 @@ options:
         description: The rc codes list with which the conditions to fail will be overriden.
         type: list
         elements: int
+    revision_note:
+        description: The change note that can be specified when an object is created or updated.
+        type: str
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
         type: str
@@ -355,8 +358,8 @@ EXAMPLES = '''
     - name: Mask fields of TCAM.
       fortinet.fortimanager.fmgr_system_npu_nputcam_mask:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         adom: <your own value>
@@ -474,6 +477,7 @@ def main():
         'adom': {'required': True, 'type': 'str'},
         'npu-tcam': {'type': 'str', 'api_name': 'npu_tcam'},
         'npu_tcam': {'type': 'str'},
+        'revision_note': {'type': 'str'},
         'system_npu_nputcam_mask': {
             'type': 'dict',
             'v_range': [['7.4.2', '']],
