@@ -136,6 +136,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -144,23 +145,22 @@ EXAMPLES = '''
     - name: NTP settings.
       fortinet.fortimanager.fmgr_system_ntp:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         system_ntp:
-          ntpserver:
-            -
-              authentication: <value in [disable, enable]>
-              id: <integer>
-              key: <list or string>
-              key_id: <integer>
-              ntpv3: <value in [disable, enable]>
-              server: <string>
-              maxpoll: <integer>
-              minpoll: <integer>
-          status: <value in [disable, enable]>
-          sync_interval: <integer>
+          # ntpserver:
+          #   - authentication: <value in [disable, enable]>
+          #     id: <integer>
+          #     key: <list or string>
+          #     key_id: <integer>
+          #     ntpv3: <value in [disable, enable]>
+          #     server: <string>
+          #     maxpoll: <integer>
+          #     minpoll: <integer>
+          # status: <value in [disable, enable]>
+          # sync_interval: <integer>
 '''
 
 RETURN = '''
