@@ -73,6 +73,9 @@ options:
         choices:
           - present
           - absent
+    revision_note:
+        description: The change note that can be specified when an object is created or updated.
+        type: str
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
         type: str
@@ -104,6 +107,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -112,15 +116,15 @@ EXAMPLES = '''
     - name: Configure OCI region list.
       fortinet.fortimanager.fmgr_system_sdnconnector_ociregionlist:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         adom: <your own value>
         sdn_connector: <your own value>
         state: present # <value in [present, absent]>
         system_sdnconnector_ociregionlist:
-          region: <string>
+          # region: <string>
 '''
 
 RETURN = '''
@@ -179,6 +183,7 @@ def main():
         'adom': {'required': True, 'type': 'str'},
         'sdn-connector': {'type': 'str', 'api_name': 'sdn_connector'},
         'sdn_connector': {'type': 'str'},
+        'revision_note': {'type': 'str'},
         'system_sdnconnector_ociregionlist': {
             'type': 'dict',
             'v_range': [['7.4.0', '']],
