@@ -116,6 +116,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -124,19 +125,19 @@ EXAMPLES = '''
     - name: SNMP configuration.
       fortinet.fortimanager.fmgr_system_snmp_sysinfo:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         system_snmp_sysinfo:
-          contact_info: <string>
-          description: <string>
-          engine_id: <string>
-          location: <string>
-          status: <value in [disable, enable]>
-          trap_cpu_high_exclude_nice_threshold: <integer>
-          trap_high_cpu_threshold: <integer>
-          trap_low_memory_threshold: <integer>
+          # contact_info: <string>
+          # description: <string>
+          # engine_id: <string>
+          # location: <string>
+          # status: <value in [disable, enable]>
+          # trap_cpu_high_exclude_nice_threshold: <integer>
+          # trap_high_cpu_threshold: <integer>
+          # trap_low_memory_threshold: <integer>
 '''
 
 RETURN = '''
