@@ -96,6 +96,7 @@ options:
 EXAMPLES = '''
 - name: Example playbook
   hosts: fortimanagers
+  gather_facts: false
   connection: httpapi
   vars:
     ansible_httpapi_use_ssl: true
@@ -124,7 +125,7 @@ EXAMPLES = '''
         facts:
           selector: "system_sql_tsindexfield"
           params:
-            ts-index-field: "your_value"
+            ts_index_field: "your_value"
 '''
 
 RETURN = '''
