@@ -73,6 +73,9 @@ options:
         choices:
           - present
           - absent
+    revision_note:
+        description: The change note that can be specified when an object is created or updated.
+        type: str
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
         type: str
@@ -114,6 +117,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -122,17 +126,17 @@ EXAMPLES = '''
     - name: Device list.
       fortinet.fortimanager.fmgr_user_deviceaccesslist_devicelist:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         adom: <your own value>
         device_access_list: <your own value>
         state: present # <value in [present, absent]>
         user_deviceaccesslist_devicelist:
-          action: <value in [deny, accept]>
-          device: <string>
-          id: <integer>
+          id: 0 # Required variable, integer
+          # action: <value in [deny, accept]>
+          # device: <string>
 '''
 
 RETURN = '''
@@ -191,6 +195,7 @@ def main():
         'adom': {'required': True, 'type': 'str'},
         'device-access-list': {'type': 'str', 'api_name': 'device_access_list'},
         'device_access_list': {'type': 'str'},
+        'revision_note': {'type': 'str'},
         'user_deviceaccesslist_devicelist': {
             'type': 'dict',
             'v_range': [['6.2.2', '7.2.1']],
