@@ -73,6 +73,9 @@ options:
         choices:
           - present
           - absent
+    revision_note:
+        description: The change note that can be specified when an object is created or updated.
+        type: str
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
         type: str
@@ -146,6 +149,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -154,29 +158,28 @@ EXAMPLES = '''
     - name: Configure virtual-patch profile.
       fortinet.fortimanager.fmgr_virtualpatch_profile:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         adom: <your own value>
         state: present # <value in [present, absent]>
         virtualpatch_profile:
-          action: <value in [pass, block]>
-          comment: <string>
-          exemption:
-            -
-              device: <list or string>
-              id: <integer>
-              rule: <list or integer>
-              status: <value in [disable, enable]>
-          log: <value in [disable, enable]>
-          name: <string>
-          severity:
-            - "low"
-            - "medium"
-            - "high"
-            - "critical"
-            - "info"
+          name: "your value" # Required variable, string
+          # action: <value in [pass, block]>
+          # comment: <string>
+          # exemption:
+          #   - device: <list or string>
+          #     id: <integer>
+          #     rule: <list or integer>
+          #     status: <value in [disable, enable]>
+          # log: <value in [disable, enable]>
+          # severity:
+          #   - "low"
+          #   - "medium"
+          #   - "high"
+          #   - "critical"
+          #   - "info"
 '''
 
 RETURN = '''
@@ -233,6 +236,7 @@ def main():
     module_primary_key = 'name'
     module_arg_spec = {
         'adom': {'required': True, 'type': 'str'},
+        'revision_note': {'type': 'str'},
         'virtualpatch_profile': {
             'type': 'dict',
             'v_range': [['7.4.1', '']],
