@@ -73,6 +73,9 @@ options:
         choices:
           - present
           - absent
+    revision_note:
+        description: The change note that can be specified when an object is created or updated.
+        type: str
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
         type: str
@@ -1034,6 +1037,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -1042,177 +1046,171 @@ EXAMPLES = '''
     - name: Portal.
       fortinet.fortimanager.fmgr_vpnsslweb_portal:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         adom: <your own value>
         state: present # <value in [present, absent]>
         vpnsslweb_portal:
-          allow_user_access:
-            - "web"
-            - "ftp"
-            - "telnet"
-            - "smb"
-            - "vnc"
-            - "rdp"
-            - "ssh"
-            - "ping"
-            - "citrix"
-            - "portforward"
-            - "sftp"
-          auto_connect: <value in [disable, enable]>
-          bookmark_group:
-            -
-              bookmarks:
-                -
-                  additional_params: <string>
-                  apptype: <value in [web, telnet, ssh, ...]>
-                  description: <string>
-                  folder: <string>
-                  form_data:
-                    -
-                      name: <string>
-                      value: <string>
-                  host: <string>
-                  listening_port: <integer>
-                  load_balancing_info: <string>
-                  logon_password: <list or string>
-                  logon_user: <string>
-                  name: <string>
-                  port: <integer>
-                  preconnection_blob: <string>
-                  preconnection_id: <integer>
-                  remote_port: <integer>
-                  security: <value in [rdp, nla, tls, ...]>
-                  server_layout: <value in [en-us-qwerty, de-de-qwertz, fr-fr-azerty, ...]>
-                  show_status_window: <value in [disable, enable]>
-                  sso: <value in [disable, static, auto]>
-                  sso_credential: <value in [sslvpn-login, alternative]>
-                  sso_credential_sent_once: <value in [disable, enable]>
-                  sso_password: <list or string>
-                  sso_username: <string>
-                  url: <string>
-                  domain: <string>
-                  color_depth: <value in [8, 16, 32]>
-                  height: <integer>
-                  keyboard_layout: <value in [ar, da, de, ...]>
-                  restricted_admin: <value in [disable, enable]>
-                  send_preconnection_id: <value in [disable, enable]>
-                  width: <integer>
-                  vnc_keyboard_layout: <value in [da, de, de-ch, ...]>
-              name: <string>
-          custom_lang: <string>
-          customize_forticlient_download_url: <value in [disable, enable]>
-          display_bookmark: <value in [disable, enable]>
-          display_connection_tools: <value in [disable, enable]>
-          display_history: <value in [disable, enable]>
-          display_status: <value in [disable, enable]>
-          dns_server1: <string>
-          dns_server2: <string>
-          dns_suffix: <string>
-          exclusive_routing: <value in [disable, enable]>
-          forticlient_download: <value in [disable, enable]>
-          forticlient_download_method: <value in [direct, ssl-vpn]>
-          heading: <string>
-          hide_sso_credential: <value in [disable, enable]>
-          host_check: <value in [none, av, fw, ...]>
-          host_check_interval: <integer>
-          host_check_policy: <list or string>
-          ip_mode: <value in [range, user-group, dhcp, ...]>
-          ip_pools: <list or string>
-          ipv6_dns_server1: <string>
-          ipv6_dns_server2: <string>
-          ipv6_exclusive_routing: <value in [disable, enable]>
-          ipv6_pools: <list or string>
-          ipv6_service_restriction: <value in [disable, enable]>
-          ipv6_split_tunneling: <value in [disable, enable]>
-          ipv6_split_tunneling_routing_address: <list or string>
-          ipv6_tunnel_mode: <value in [disable, enable]>
-          ipv6_wins_server1: <string>
-          ipv6_wins_server2: <string>
-          keep_alive: <value in [disable, enable]>
-          limit_user_logins: <value in [disable, enable]>
-          mac_addr_action: <value in [deny, allow]>
-          mac_addr_check: <value in [disable, enable]>
-          mac_addr_check_rule:
-            -
-              mac_addr_list: <list or string>
-              mac_addr_mask: <integer>
-              name: <string>
-          macos_forticlient_download_url: <string>
-          name: <string>
-          os_check: <value in [disable, enable]>
-          redir_url: <string>
-          save_password: <value in [disable, enable]>
-          service_restriction: <value in [disable, enable]>
-          skip_check_for_unsupported_browser: <value in [disable, enable]>
-          skip_check_for_unsupported_os: <value in [disable, enable]>
-          smb_ntlmv1_auth: <value in [disable, enable]>
-          smbv1: <value in [disable, enable]>
-          split_dns:
-            -
-              dns_server1: <string>
-              dns_server2: <string>
-              domains: <string>
-              id: <integer>
-              ipv6_dns_server1: <string>
-              ipv6_dns_server2: <string>
-          split_tunneling: <value in [disable, enable]>
-          split_tunneling_routing_address: <list or string>
-          theme: <value in [gray, blue, orange, ...]>
-          tunnel_mode: <value in [disable, enable]>
-          user_bookmark: <value in [disable, enable]>
-          user_group_bookmark: <value in [disable, enable]>
-          web_mode: <value in [disable, enable]>
-          windows_forticlient_download_url: <string>
-          wins_server1: <string>
-          wins_server2: <string>
-          skip_check_for_browser: <value in [disable, enable]>
-          smb_max_version: <value in [smbv1, smbv2, smbv3]>
-          smb_min_version: <value in [smbv1, smbv2, smbv3]>
-          virtual_desktop_logout_when_browser_close: <value in [disable, enable]>
-          virtual_desktop_clipboard_share: <value in [disable, enable]>
-          virtual_desktop_desktop_switch: <value in [disable, enable]>
-          virtual_desktop: <value in [disable, enable]>
-          virtual_desktop_network_share_access: <value in [disable, enable]>
-          virtual_desktop_printing: <value in [disable, enable]>
-          virtual_desktop_app_list: <string>
-          virtual_desktop_removable_media_access: <value in [disable, enable]>
-          transform_backward_slashes: <value in [disable, enable]>
-          ipv6_split_tunneling_routing_negate: <value in [disable, enable]>
-          split_tunneling_routing_negate: <value in [disable, enable]>
-          os_check_list:
-            action: <value in [allow, check-up-to-date, deny]>
-            latest_patch_level: <string>
-            name: <string>
-            tolerance: <integer>
-            minor_version: <integer>
-          use_sdwan: <value in [disable, enable]>
-          prefer_ipv6_dns: <value in [disable, enable]>
-          rewrite_ip_uri_ui: <value in [disable, enable]>
-          clipboard: <value in [disable, enable]>
-          default_window_height: <integer>
-          default_window_width: <integer>
-          dhcp_ip_overlap: <value in [use-old, use-new]>
-          client_src_range: <value in [disable, enable]>
-          dhcp_ra_giaddr: <string>
-          dhcp6_ra_linkaddr: <string>
-          landing_page:
-            form_data:
-              -
-                name: <string>
-                value: <string>
-            logout_url: <string>
-            sso: <value in [disable, static, auto]>
-            sso_credential: <value in [sslvpn-login, alternative]>
-            sso_password: <list or string>
-            sso_username: <string>
-            url: <string>
-          landing_page_mode: <value in [disable, enable]>
-          default_protocol: <value in [web, ftp, telnet, ...]>
-          focus_bookmark: <value in [disable, enable]>
-          dhcp_reservation: <value in [disable, enable]>
+          name: "your value" # Required variable, string
+          # allow_user_access:
+          #   - "web"
+          #   - "ftp"
+          #   - "telnet"
+          #   - "smb"
+          #   - "vnc"
+          #   - "rdp"
+          #   - "ssh"
+          #   - "ping"
+          #   - "citrix"
+          #   - "portforward"
+          #   - "sftp"
+          # auto_connect: <value in [disable, enable]>
+          # bookmark_group:
+          #   - bookmarks:
+          #       - additional_params: <string>
+          #         apptype: <value in [web, telnet, ssh, ...]>
+          #         description: <string>
+          #         folder: <string>
+          #         form_data:
+          #           - name: <string>
+          #             value: <string>
+          #         host: <string>
+          #         listening_port: <integer>
+          #         load_balancing_info: <string>
+          #         logon_password: <list or string>
+          #         logon_user: <string>
+          #         name: <string>
+          #         port: <integer>
+          #         preconnection_blob: <string>
+          #         preconnection_id: <integer>
+          #         remote_port: <integer>
+          #         security: <value in [rdp, nla, tls, ...]>
+          #         server_layout: <value in [en-us-qwerty, de-de-qwertz, fr-fr-azerty, ...]>
+          #         show_status_window: <value in [disable, enable]>
+          #         sso: <value in [disable, static, auto]>
+          #         sso_credential: <value in [sslvpn-login, alternative]>
+          #         sso_credential_sent_once: <value in [disable, enable]>
+          #         sso_password: <list or string>
+          #         sso_username: <string>
+          #         url: <string>
+          #         domain: <string>
+          #         color_depth: <value in [8, 16, 32]>
+          #         height: <integer>
+          #         keyboard_layout: <value in [ar, da, de, ...]>
+          #         restricted_admin: <value in [disable, enable]>
+          #         send_preconnection_id: <value in [disable, enable]>
+          #         width: <integer>
+          #         vnc_keyboard_layout: <value in [da, de, de-ch, ...]>
+          #     name: <string>
+          # custom_lang: <string>
+          # customize_forticlient_download_url: <value in [disable, enable]>
+          # display_bookmark: <value in [disable, enable]>
+          # display_connection_tools: <value in [disable, enable]>
+          # display_history: <value in [disable, enable]>
+          # display_status: <value in [disable, enable]>
+          # dns_server1: <string>
+          # dns_server2: <string>
+          # dns_suffix: <string>
+          # exclusive_routing: <value in [disable, enable]>
+          # forticlient_download: <value in [disable, enable]>
+          # forticlient_download_method: <value in [direct, ssl-vpn]>
+          # heading: <string>
+          # hide_sso_credential: <value in [disable, enable]>
+          # host_check: <value in [none, av, fw, ...]>
+          # host_check_interval: <integer>
+          # host_check_policy: <list or string>
+          # ip_mode: <value in [range, user-group, dhcp, ...]>
+          # ip_pools: <list or string>
+          # ipv6_dns_server1: <string>
+          # ipv6_dns_server2: <string>
+          # ipv6_exclusive_routing: <value in [disable, enable]>
+          # ipv6_pools: <list or string>
+          # ipv6_service_restriction: <value in [disable, enable]>
+          # ipv6_split_tunneling: <value in [disable, enable]>
+          # ipv6_split_tunneling_routing_address: <list or string>
+          # ipv6_tunnel_mode: <value in [disable, enable]>
+          # ipv6_wins_server1: <string>
+          # ipv6_wins_server2: <string>
+          # keep_alive: <value in [disable, enable]>
+          # limit_user_logins: <value in [disable, enable]>
+          # mac_addr_action: <value in [deny, allow]>
+          # mac_addr_check: <value in [disable, enable]>
+          # mac_addr_check_rule:
+          #   - mac_addr_list: <list or string>
+          #     mac_addr_mask: <integer>
+          #     name: <string>
+          # macos_forticlient_download_url: <string>
+          # os_check: <value in [disable, enable]>
+          # redir_url: <string>
+          # save_password: <value in [disable, enable]>
+          # service_restriction: <value in [disable, enable]>
+          # skip_check_for_unsupported_browser: <value in [disable, enable]>
+          # skip_check_for_unsupported_os: <value in [disable, enable]>
+          # smb_ntlmv1_auth: <value in [disable, enable]>
+          # smbv1: <value in [disable, enable]>
+          # split_dns:
+          #   - dns_server1: <string>
+          #     dns_server2: <string>
+          #     domains: <string>
+          #     id: <integer>
+          #     ipv6_dns_server1: <string>
+          #     ipv6_dns_server2: <string>
+          # split_tunneling: <value in [disable, enable]>
+          # split_tunneling_routing_address: <list or string>
+          # theme: <value in [gray, blue, orange, ...]>
+          # tunnel_mode: <value in [disable, enable]>
+          # user_bookmark: <value in [disable, enable]>
+          # user_group_bookmark: <value in [disable, enable]>
+          # web_mode: <value in [disable, enable]>
+          # windows_forticlient_download_url: <string>
+          # wins_server1: <string>
+          # wins_server2: <string>
+          # skip_check_for_browser: <value in [disable, enable]>
+          # smb_max_version: <value in [smbv1, smbv2, smbv3]>
+          # smb_min_version: <value in [smbv1, smbv2, smbv3]>
+          # virtual_desktop_logout_when_browser_close: <value in [disable, enable]>
+          # virtual_desktop_clipboard_share: <value in [disable, enable]>
+          # virtual_desktop_desktop_switch: <value in [disable, enable]>
+          # virtual_desktop: <value in [disable, enable]>
+          # virtual_desktop_network_share_access: <value in [disable, enable]>
+          # virtual_desktop_printing: <value in [disable, enable]>
+          # virtual_desktop_app_list: <string>
+          # virtual_desktop_removable_media_access: <value in [disable, enable]>
+          # transform_backward_slashes: <value in [disable, enable]>
+          # ipv6_split_tunneling_routing_negate: <value in [disable, enable]>
+          # split_tunneling_routing_negate: <value in [disable, enable]>
+          # os_check_list:
+          #   action: <value in [allow, check-up-to-date, deny]>
+          #   latest_patch_level: <string>
+          #   name: <string>
+          #   tolerance: <integer>
+          #   minor_version: <integer>
+          # use_sdwan: <value in [disable, enable]>
+          # prefer_ipv6_dns: <value in [disable, enable]>
+          # rewrite_ip_uri_ui: <value in [disable, enable]>
+          # clipboard: <value in [disable, enable]>
+          # default_window_height: <integer>
+          # default_window_width: <integer>
+          # dhcp_ip_overlap: <value in [use-old, use-new]>
+          # client_src_range: <value in [disable, enable]>
+          # dhcp_ra_giaddr: <string>
+          # dhcp6_ra_linkaddr: <string>
+          # landing_page:
+          #   form_data:
+          #     - name: <string>
+          #       value: <string>
+          #   logout_url: <string>
+          #   sso: <value in [disable, static, auto]>
+          #   sso_credential: <value in [sslvpn-login, alternative]>
+          #   sso_password: <list or string>
+          #   sso_username: <string>
+          #   url: <string>
+          # landing_page_mode: <value in [disable, enable]>
+          # default_protocol: <value in [web, ftp, telnet, ...]>
+          # focus_bookmark: <value in [disable, enable]>
+          # dhcp_reservation: <value in [disable, enable]>
 '''
 
 RETURN = '''
@@ -1269,6 +1267,7 @@ def main():
     module_primary_key = 'name'
     module_arg_spec = {
         'adom': {'required': True, 'type': 'str'},
+        'revision_note': {'type': 'str'},
         'vpnsslweb_portal': {
             'type': 'dict',
             'v_range': [['6.0.0', '']],
@@ -1442,7 +1441,7 @@ def main():
                 'virtual-desktop-printing': {'v_range': [['6.2.0', '6.2.13']], 'choices': ['disable', 'enable'], 'type': 'str'},
                 'virtual-desktop-app-list': {'v_range': [['6.2.0', '6.2.13']], 'type': 'str'},
                 'virtual-desktop-removable-media-access': {'v_range': [['6.2.0', '6.2.13']], 'choices': ['disable', 'enable'], 'type': 'str'},
-                'transform-backward-slashes': {'v_range': [['6.2.2', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                'transform-backward-slashes': {'v_range': [['6.2.2', '7.6.2']], 'choices': ['disable', 'enable'], 'type': 'str'},
                 'ipv6-split-tunneling-routing-negate': {'v_range': [['6.4.0', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
                 'split-tunneling-routing-negate': {'v_range': [['6.4.0', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
                 'os-check-list': {
@@ -1453,7 +1452,7 @@ def main():
                         'latest-patch-level': {'v_range': [['6.2.8', '6.2.13'], ['6.4.5', '']], 'type': 'str'},
                         'name': {'v_range': [['6.2.8', '6.2.13'], ['6.4.5', '']], 'type': 'str'},
                         'tolerance': {'v_range': [['6.2.8', '6.2.13'], ['6.4.5', '']], 'type': 'int'},
-                        'minor-version': {'v_range': [['7.6.0', '']], 'type': 'int'}
+                        'minor-version': {'v_range': [['7.2.10', '7.2.11'], ['7.4.7', '']], 'type': 'int'}
                     }
                 },
                 'use-sdwan': {'v_range': [['6.2.7', '6.2.13'], ['6.4.3', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
@@ -1462,7 +1461,7 @@ def main():
                 'clipboard': {'v_range': [['6.4.7', '6.4.15'], ['7.0.1', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
                 'default-window-height': {'v_range': [['7.0.4', '']], 'type': 'int'},
                 'default-window-width': {'v_range': [['7.0.4', '']], 'type': 'int'},
-                'dhcp-ip-overlap': {'v_range': [['7.0.4', '7.0.13'], ['7.2.1', '']], 'choices': ['use-old', 'use-new'], 'type': 'str'},
+                'dhcp-ip-overlap': {'v_range': [['7.0.4', '7.0.14'], ['7.2.1', '']], 'choices': ['use-old', 'use-new'], 'type': 'str'},
                 'client-src-range': {'v_range': [['7.2.2', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
                 'dhcp-ra-giaddr': {'v_range': [['7.2.2', '']], 'type': 'str'},
                 'dhcp6-ra-linkaddr': {'v_range': [['7.2.2', '']], 'type': 'str'},
