@@ -73,6 +73,9 @@ options:
         choices:
           - present
           - absent
+    revision_note:
+        description: The change note that can be specified when an object is created or updated.
+        type: str
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
         type: str
@@ -928,6 +931,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -936,195 +940,190 @@ EXAMPLES = '''
     - name: Web application firewall configuration.
       fortinet.fortimanager.fmgr_waf_profile:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         adom: <your own value>
         state: present # <value in [present, absent]>
         waf_profile:
-          comment: <string>
-          extended_log: <value in [disable, enable]>
-          external: <value in [disable, enable]>
-          name: <string>
-          url_access:
-            -
-              access_pattern:
-                -
-                  id: <integer>
-                  negate: <value in [disable, enable]>
-                  pattern: <string>
-                  regex: <value in [disable, enable]>
-                  srcaddr: <string>
-              action: <value in [bypass, permit, block]>
-              address: <string>
-              id: <integer>
-              log: <value in [disable, enable]>
-              severity: <value in [low, medium, high]>
-          address_list:
-            blocked_address: <list or string>
-            blocked_log: <value in [disable, enable]>
-            severity: <value in [low, medium, high]>
-            status: <value in [disable, enable]>
-            trusted_address: <list or string>
-          constraint:
-            content_length:
-              action: <value in [allow, block]>
-              length: <integer>
-              log: <value in [disable, enable]>
-              severity: <value in [low, medium, high]>
-              status: <value in [disable, enable]>
-            exception:
-              -
-                address: <string>
-                content_length: <value in [disable, enable]>
-                header_length: <value in [disable, enable]>
-                hostname: <value in [disable, enable]>
-                id: <integer>
-                line_length: <value in [disable, enable]>
-                malformed: <value in [disable, enable]>
-                max_cookie: <value in [disable, enable]>
-                max_header_line: <value in [disable, enable]>
-                max_range_segment: <value in [disable, enable]>
-                max_url_param: <value in [disable, enable]>
-                method: <value in [disable, enable]>
-                param_length: <value in [disable, enable]>
-                pattern: <string>
-                regex: <value in [disable, enable]>
-                url_param_length: <value in [disable, enable]>
-                version: <value in [disable, enable]>
-            header_length:
-              action: <value in [allow, block]>
-              length: <integer>
-              log: <value in [disable, enable]>
-              severity: <value in [low, medium, high]>
-              status: <value in [disable, enable]>
-            hostname:
-              action: <value in [allow, block]>
-              log: <value in [disable, enable]>
-              severity: <value in [low, medium, high]>
-              status: <value in [disable, enable]>
-            line_length:
-              action: <value in [allow, block]>
-              length: <integer>
-              log: <value in [disable, enable]>
-              severity: <value in [low, medium, high]>
-              status: <value in [disable, enable]>
-            malformed:
-              action: <value in [allow, block]>
-              log: <value in [disable, enable]>
-              severity: <value in [low, medium, high]>
-              status: <value in [disable, enable]>
-            max_cookie:
-              action: <value in [allow, block]>
-              log: <value in [disable, enable]>
-              max_cookie: <integer>
-              severity: <value in [low, medium, high]>
-              status: <value in [disable, enable]>
-            max_header_line:
-              action: <value in [allow, block]>
-              log: <value in [disable, enable]>
-              max_header_line: <integer>
-              severity: <value in [low, medium, high]>
-              status: <value in [disable, enable]>
-            max_range_segment:
-              action: <value in [allow, block]>
-              log: <value in [disable, enable]>
-              max_range_segment: <integer>
-              severity: <value in [low, medium, high]>
-              status: <value in [disable, enable]>
-            max_url_param:
-              action: <value in [allow, block]>
-              log: <value in [disable, enable]>
-              max_url_param: <integer>
-              severity: <value in [low, medium, high]>
-              status: <value in [disable, enable]>
-            method:
-              action: <value in [allow, block]>
-              log: <value in [disable, enable]>
-              severity: <value in [low, medium, high]>
-              status: <value in [disable, enable]>
-            param_length:
-              action: <value in [allow, block]>
-              length: <integer>
-              log: <value in [disable, enable]>
-              severity: <value in [low, medium, high]>
-              status: <value in [disable, enable]>
-            url_param_length:
-              action: <value in [allow, block]>
-              length: <integer>
-              log: <value in [disable, enable]>
-              severity: <value in [low, medium, high]>
-              status: <value in [disable, enable]>
-            version:
-              action: <value in [allow, block]>
-              log: <value in [disable, enable]>
-              severity: <value in [low, medium, high]>
-              status: <value in [disable, enable]>
-          method:
-            default_allowed_methods:
-              - "delete"
-              - "get"
-              - "head"
-              - "options"
-              - "post"
-              - "put"
-              - "trace"
-              - "others"
-              - "connect"
-            log: <value in [disable, enable]>
-            method_policy:
-              -
-                address: <string>
-                allowed_methods:
-                  - "delete"
-                  - "get"
-                  - "head"
-                  - "options"
-                  - "post"
-                  - "put"
-                  - "trace"
-                  - "others"
-                  - "connect"
-                id: <integer>
-                pattern: <string>
-                regex: <value in [disable, enable]>
-            severity: <value in [low, medium, high]>
-            status: <value in [disable, enable]>
-          signature:
-            credit_card_detection_threshold: <integer>
-            custom_signature:
-              -
-                action: <value in [allow, block, erase]>
-                case_sensitivity: <value in [disable, enable]>
-                direction: <value in [request, response]>
-                log: <value in [disable, enable]>
-                name: <string>
-                pattern: <string>
-                severity: <value in [low, medium, high]>
-                status: <value in [disable, enable]>
-                target:
-                  - "arg"
-                  - "arg-name"
-                  - "req-body"
-                  - "req-cookie"
-                  - "req-cookie-name"
-                  - "req-filename"
-                  - "req-header"
-                  - "req-header-name"
-                  - "req-raw-uri"
-                  - "req-uri"
-                  - "resp-body"
-                  - "resp-hdr"
-                  - "resp-status"
-            disabled_signature: <list or string>
-            disabled_sub_class: <list or string>
-            main_class:
-              action: <value in [allow, block, erase]>
-              id: <integer>
-              log: <value in [disable, enable]>
-              severity: <value in [low, medium, high]>
-              status: <value in [disable, enable]>
+          name: "your value" # Required variable, string
+          # comment: <string>
+          # extended_log: <value in [disable, enable]>
+          # external: <value in [disable, enable]>
+          # url_access:
+          #   - access_pattern:
+          #       - id: <integer>
+          #         negate: <value in [disable, enable]>
+          #         pattern: <string>
+          #         regex: <value in [disable, enable]>
+          #         srcaddr: <string>
+          #     action: <value in [bypass, permit, block]>
+          #     address: <string>
+          #     id: <integer>
+          #     log: <value in [disable, enable]>
+          #     severity: <value in [low, medium, high]>
+          # address_list:
+          #   blocked_address: <list or string>
+          #   blocked_log: <value in [disable, enable]>
+          #   severity: <value in [low, medium, high]>
+          #   status: <value in [disable, enable]>
+          #   trusted_address: <list or string>
+          # constraint:
+          #   content_length:
+          #     action: <value in [allow, block]>
+          #     length: <integer>
+          #     log: <value in [disable, enable]>
+          #     severity: <value in [low, medium, high]>
+          #     status: <value in [disable, enable]>
+          #   exception:
+          #     - address: <string>
+          #       content_length: <value in [disable, enable]>
+          #       header_length: <value in [disable, enable]>
+          #       hostname: <value in [disable, enable]>
+          #       id: <integer>
+          #       line_length: <value in [disable, enable]>
+          #       malformed: <value in [disable, enable]>
+          #       max_cookie: <value in [disable, enable]>
+          #       max_header_line: <value in [disable, enable]>
+          #       max_range_segment: <value in [disable, enable]>
+          #       max_url_param: <value in [disable, enable]>
+          #       method: <value in [disable, enable]>
+          #       param_length: <value in [disable, enable]>
+          #       pattern: <string>
+          #       regex: <value in [disable, enable]>
+          #       url_param_length: <value in [disable, enable]>
+          #       version: <value in [disable, enable]>
+          #   header_length:
+          #     action: <value in [allow, block]>
+          #     length: <integer>
+          #     log: <value in [disable, enable]>
+          #     severity: <value in [low, medium, high]>
+          #     status: <value in [disable, enable]>
+          #   hostname:
+          #     action: <value in [allow, block]>
+          #     log: <value in [disable, enable]>
+          #     severity: <value in [low, medium, high]>
+          #     status: <value in [disable, enable]>
+          #   line_length:
+          #     action: <value in [allow, block]>
+          #     length: <integer>
+          #     log: <value in [disable, enable]>
+          #     severity: <value in [low, medium, high]>
+          #     status: <value in [disable, enable]>
+          #   malformed:
+          #     action: <value in [allow, block]>
+          #     log: <value in [disable, enable]>
+          #     severity: <value in [low, medium, high]>
+          #     status: <value in [disable, enable]>
+          #   max_cookie:
+          #     action: <value in [allow, block]>
+          #     log: <value in [disable, enable]>
+          #     max_cookie: <integer>
+          #     severity: <value in [low, medium, high]>
+          #     status: <value in [disable, enable]>
+          #   max_header_line:
+          #     action: <value in [allow, block]>
+          #     log: <value in [disable, enable]>
+          #     max_header_line: <integer>
+          #     severity: <value in [low, medium, high]>
+          #     status: <value in [disable, enable]>
+          #   max_range_segment:
+          #     action: <value in [allow, block]>
+          #     log: <value in [disable, enable]>
+          #     max_range_segment: <integer>
+          #     severity: <value in [low, medium, high]>
+          #     status: <value in [disable, enable]>
+          #   max_url_param:
+          #     action: <value in [allow, block]>
+          #     log: <value in [disable, enable]>
+          #     max_url_param: <integer>
+          #     severity: <value in [low, medium, high]>
+          #     status: <value in [disable, enable]>
+          #   method:
+          #     action: <value in [allow, block]>
+          #     log: <value in [disable, enable]>
+          #     severity: <value in [low, medium, high]>
+          #     status: <value in [disable, enable]>
+          #   param_length:
+          #     action: <value in [allow, block]>
+          #     length: <integer>
+          #     log: <value in [disable, enable]>
+          #     severity: <value in [low, medium, high]>
+          #     status: <value in [disable, enable]>
+          #   url_param_length:
+          #     action: <value in [allow, block]>
+          #     length: <integer>
+          #     log: <value in [disable, enable]>
+          #     severity: <value in [low, medium, high]>
+          #     status: <value in [disable, enable]>
+          #   version:
+          #     action: <value in [allow, block]>
+          #     log: <value in [disable, enable]>
+          #     severity: <value in [low, medium, high]>
+          #     status: <value in [disable, enable]>
+          # method:
+          #   default_allowed_methods:
+          #     - "delete"
+          #     - "get"
+          #     - "head"
+          #     - "options"
+          #     - "post"
+          #     - "put"
+          #     - "trace"
+          #     - "others"
+          #     - "connect"
+          #   log: <value in [disable, enable]>
+          #   method_policy:
+          #     - address: <string>
+          #       allowed_methods:
+          #         - "delete"
+          #         - "get"
+          #         - "head"
+          #         - "options"
+          #         - "post"
+          #         - "put"
+          #         - "trace"
+          #         - "others"
+          #         - "connect"
+          #       id: <integer>
+          #       pattern: <string>
+          #       regex: <value in [disable, enable]>
+          #   severity: <value in [low, medium, high]>
+          #   status: <value in [disable, enable]>
+          # signature:
+          #   credit_card_detection_threshold: <integer>
+          #   custom_signature:
+          #     - action: <value in [allow, block, erase]>
+          #       case_sensitivity: <value in [disable, enable]>
+          #       direction: <value in [request, response]>
+          #       log: <value in [disable, enable]>
+          #       name: <string>
+          #       pattern: <string>
+          #       severity: <value in [low, medium, high]>
+          #       status: <value in [disable, enable]>
+          #       target:
+          #         - "arg"
+          #         - "arg-name"
+          #         - "req-body"
+          #         - "req-cookie"
+          #         - "req-cookie-name"
+          #         - "req-filename"
+          #         - "req-header"
+          #         - "req-header-name"
+          #         - "req-raw-uri"
+          #         - "req-uri"
+          #         - "resp-body"
+          #         - "resp-hdr"
+          #         - "resp-status"
+          #   disabled_signature: <list or string>
+          #   disabled_sub_class: <list or string>
+          #   main_class:
+          #     action: <value in [allow, block, erase]>
+          #     id: <integer>
+          #     log: <value in [disable, enable]>
+          #     severity: <value in [low, medium, high]>
+          #     status: <value in [disable, enable]>
 '''
 
 RETURN = '''
@@ -1181,6 +1180,7 @@ def main():
     module_primary_key = 'name'
     module_arg_spec = {
         'adom': {'required': True, 'type': 'str'},
+        'revision_note': {'type': 'str'},
         'waf_profile': {
             'type': 'dict',
             'v_range': [['6.0.0', '']],
