@@ -64,6 +64,9 @@ options:
         description: The rc codes list with which the conditions to fail will be overriden.
         type: list
         elements: int
+    revision_note:
+        description: The change note that can be specified when an object is created or updated.
+        type: str
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
         type: str
@@ -614,6 +617,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -622,106 +626,105 @@ EXAMPLES = '''
     - name: WAF HTTP protocol restrictions.
       fortinet.fortimanager.fmgr_waf_profile_constraint:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         adom: <your own value>
         profile: <your own value>
         waf_profile_constraint:
-          content_length:
-            action: <value in [allow, block]>
-            length: <integer>
-            log: <value in [disable, enable]>
-            severity: <value in [low, medium, high]>
-            status: <value in [disable, enable]>
-          exception:
-            -
-              address: <string>
-              content_length: <value in [disable, enable]>
-              header_length: <value in [disable, enable]>
-              hostname: <value in [disable, enable]>
-              id: <integer>
-              line_length: <value in [disable, enable]>
-              malformed: <value in [disable, enable]>
-              max_cookie: <value in [disable, enable]>
-              max_header_line: <value in [disable, enable]>
-              max_range_segment: <value in [disable, enable]>
-              max_url_param: <value in [disable, enable]>
-              method: <value in [disable, enable]>
-              param_length: <value in [disable, enable]>
-              pattern: <string>
-              regex: <value in [disable, enable]>
-              url_param_length: <value in [disable, enable]>
-              version: <value in [disable, enable]>
-          header_length:
-            action: <value in [allow, block]>
-            length: <integer>
-            log: <value in [disable, enable]>
-            severity: <value in [low, medium, high]>
-            status: <value in [disable, enable]>
-          hostname:
-            action: <value in [allow, block]>
-            log: <value in [disable, enable]>
-            severity: <value in [low, medium, high]>
-            status: <value in [disable, enable]>
-          line_length:
-            action: <value in [allow, block]>
-            length: <integer>
-            log: <value in [disable, enable]>
-            severity: <value in [low, medium, high]>
-            status: <value in [disable, enable]>
-          malformed:
-            action: <value in [allow, block]>
-            log: <value in [disable, enable]>
-            severity: <value in [low, medium, high]>
-            status: <value in [disable, enable]>
-          max_cookie:
-            action: <value in [allow, block]>
-            log: <value in [disable, enable]>
-            max_cookie: <integer>
-            severity: <value in [low, medium, high]>
-            status: <value in [disable, enable]>
-          max_header_line:
-            action: <value in [allow, block]>
-            log: <value in [disable, enable]>
-            max_header_line: <integer>
-            severity: <value in [low, medium, high]>
-            status: <value in [disable, enable]>
-          max_range_segment:
-            action: <value in [allow, block]>
-            log: <value in [disable, enable]>
-            max_range_segment: <integer>
-            severity: <value in [low, medium, high]>
-            status: <value in [disable, enable]>
-          max_url_param:
-            action: <value in [allow, block]>
-            log: <value in [disable, enable]>
-            max_url_param: <integer>
-            severity: <value in [low, medium, high]>
-            status: <value in [disable, enable]>
-          method:
-            action: <value in [allow, block]>
-            log: <value in [disable, enable]>
-            severity: <value in [low, medium, high]>
-            status: <value in [disable, enable]>
-          param_length:
-            action: <value in [allow, block]>
-            length: <integer>
-            log: <value in [disable, enable]>
-            severity: <value in [low, medium, high]>
-            status: <value in [disable, enable]>
-          url_param_length:
-            action: <value in [allow, block]>
-            length: <integer>
-            log: <value in [disable, enable]>
-            severity: <value in [low, medium, high]>
-            status: <value in [disable, enable]>
-          version:
-            action: <value in [allow, block]>
-            log: <value in [disable, enable]>
-            severity: <value in [low, medium, high]>
-            status: <value in [disable, enable]>
+          # content_length:
+          #   action: <value in [allow, block]>
+          #   length: <integer>
+          #   log: <value in [disable, enable]>
+          #   severity: <value in [low, medium, high]>
+          #   status: <value in [disable, enable]>
+          # exception:
+          #   - address: <string>
+          #     content_length: <value in [disable, enable]>
+          #     header_length: <value in [disable, enable]>
+          #     hostname: <value in [disable, enable]>
+          #     id: <integer>
+          #     line_length: <value in [disable, enable]>
+          #     malformed: <value in [disable, enable]>
+          #     max_cookie: <value in [disable, enable]>
+          #     max_header_line: <value in [disable, enable]>
+          #     max_range_segment: <value in [disable, enable]>
+          #     max_url_param: <value in [disable, enable]>
+          #     method: <value in [disable, enable]>
+          #     param_length: <value in [disable, enable]>
+          #     pattern: <string>
+          #     regex: <value in [disable, enable]>
+          #     url_param_length: <value in [disable, enable]>
+          #     version: <value in [disable, enable]>
+          # header_length:
+          #   action: <value in [allow, block]>
+          #   length: <integer>
+          #   log: <value in [disable, enable]>
+          #   severity: <value in [low, medium, high]>
+          #   status: <value in [disable, enable]>
+          # hostname:
+          #   action: <value in [allow, block]>
+          #   log: <value in [disable, enable]>
+          #   severity: <value in [low, medium, high]>
+          #   status: <value in [disable, enable]>
+          # line_length:
+          #   action: <value in [allow, block]>
+          #   length: <integer>
+          #   log: <value in [disable, enable]>
+          #   severity: <value in [low, medium, high]>
+          #   status: <value in [disable, enable]>
+          # malformed:
+          #   action: <value in [allow, block]>
+          #   log: <value in [disable, enable]>
+          #   severity: <value in [low, medium, high]>
+          #   status: <value in [disable, enable]>
+          # max_cookie:
+          #   action: <value in [allow, block]>
+          #   log: <value in [disable, enable]>
+          #   max_cookie: <integer>
+          #   severity: <value in [low, medium, high]>
+          #   status: <value in [disable, enable]>
+          # max_header_line:
+          #   action: <value in [allow, block]>
+          #   log: <value in [disable, enable]>
+          #   max_header_line: <integer>
+          #   severity: <value in [low, medium, high]>
+          #   status: <value in [disable, enable]>
+          # max_range_segment:
+          #   action: <value in [allow, block]>
+          #   log: <value in [disable, enable]>
+          #   max_range_segment: <integer>
+          #   severity: <value in [low, medium, high]>
+          #   status: <value in [disable, enable]>
+          # max_url_param:
+          #   action: <value in [allow, block]>
+          #   log: <value in [disable, enable]>
+          #   max_url_param: <integer>
+          #   severity: <value in [low, medium, high]>
+          #   status: <value in [disable, enable]>
+          # method:
+          #   action: <value in [allow, block]>
+          #   log: <value in [disable, enable]>
+          #   severity: <value in [low, medium, high]>
+          #   status: <value in [disable, enable]>
+          # param_length:
+          #   action: <value in [allow, block]>
+          #   length: <integer>
+          #   log: <value in [disable, enable]>
+          #   severity: <value in [low, medium, high]>
+          #   status: <value in [disable, enable]>
+          # url_param_length:
+          #   action: <value in [allow, block]>
+          #   length: <integer>
+          #   log: <value in [disable, enable]>
+          #   severity: <value in [low, medium, high]>
+          #   status: <value in [disable, enable]>
+          # version:
+          #   action: <value in [allow, block]>
+          #   log: <value in [disable, enable]>
+          #   severity: <value in [low, medium, high]>
+          #   status: <value in [disable, enable]>
 '''
 
 RETURN = '''
@@ -779,6 +782,7 @@ def main():
     module_arg_spec = {
         'adom': {'required': True, 'type': 'str'},
         'profile': {'required': True, 'type': 'str'},
+        'revision_note': {'type': 'str'},
         'waf_profile_constraint': {
             'type': 'dict',
             'v_range': [['6.0.0', '']],
