@@ -73,6 +73,9 @@ options:
         choices:
           - present
           - absent
+    revision_note:
+        description: The change note that can be specified when an object is created or updated.
+        type: str
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
         type: str
@@ -114,6 +117,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -122,17 +126,17 @@ EXAMPLES = '''
     - name: Custom username and password regex patterns.
       fortinet.fortimanager.fmgr_webfilter_profile_antiphish_custompatterns:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         adom: <your own value>
         profile: <your own value>
         state: present # <value in [present, absent]>
         webfilter_profile_antiphish_custompatterns:
-          category: <value in [username, password]>
-          pattern: <string>
-          type: <value in [regex, literal]>
+          # category: <value in [username, password]>
+          # pattern: <string>
+          # type: <value in [regex, literal]>
 '''
 
 RETURN = '''
@@ -190,6 +194,7 @@ def main():
     module_arg_spec = {
         'adom': {'required': True, 'type': 'str'},
         'profile': {'required': True, 'type': 'str'},
+        'revision_note': {'type': 'str'},
         'webfilter_profile_antiphish_custompatterns': {
             'type': 'dict',
             'v_range': [['6.4.0', '']],
