@@ -64,6 +64,9 @@ options:
         description: The rc codes list with which the conditions to fail will be overriden.
         type: list
         elements: int
+    revision_note:
+        description: The change note that can be specified when an object is created or updated.
+        type: str
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
         type: str
@@ -227,12 +230,37 @@ options:
                 aliases: ['category-override']
                 type: str
                 description: Local categories take precedence over FortiGuard categories.
+            risk:
+                type: list
+                elements: dict
+                description: Risk.
+                suboptions:
+                    action:
+                        type: str
+                        description: Action to take for matches.
+                        choices:
+                            - 'block'
+                            - 'monitor'
+                    id:
+                        type: int
+                        description: ID number.
+                    log:
+                        type: str
+                        description: Enable/disable logging.
+                        choices:
+                            - 'disable'
+                            - 'enable'
+                    risk_level:
+                        aliases: ['risk-level']
+                        type: raw
+                        description: (list) Risk level to be examined.
 '''
 
 EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -241,51 +269,54 @@ EXAMPLES = '''
     - name: FortiGuard Web Filter settings.
       fortinet.fortimanager.fmgr_webfilter_profile_ftgdwf:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         adom: <your own value>
         profile: <your own value>
         webfilter_profile_ftgdwf:
-          exempt_quota: <list or string>
-          filters:
-            -
-              action: <value in [block, monitor, warning, ...]>
-              auth_usr_grp: <list or string>
-              category: <string>
-              id: <integer>
-              log: <value in [disable, enable]>
-              override_replacemsg: <string>
-              warn_duration: <string>
-              warning_duration_type: <value in [session, timeout]>
-              warning_prompt: <value in [per-domain, per-category]>
-          max_quota_timeout: <integer>
-          options:
-            - "error-allow"
-            - "http-err-detail"
-            - "rate-image-urls"
-            - "strict-blocking"
-            - "rate-server-ip"
-            - "redir-block"
-            - "connect-request-bypass"
-            - "log-all-url"
-            - "ftgd-disable"
-          ovrd: <list or string>
-          quota:
-            -
-              category: <list or string>
-              duration: <string>
-              id: <integer>
-              override_replacemsg: <string>
-              type: <value in [time, traffic]>
-              unit: <value in [B, KB, MB, ...]>
-              value: <integer>
-          rate_crl_urls: <value in [disable, enable]>
-          rate_css_urls: <value in [disable, enable]>
-          rate_image_urls: <value in [disable, enable]>
-          rate_javascript_urls: <value in [disable, enable]>
-          category_override: <string>
+          # exempt_quota: <list or string>
+          # filters:
+          #   - action: <value in [block, monitor, warning, ...]>
+          #     auth_usr_grp: <list or string>
+          #     category: <string>
+          #     id: <integer>
+          #     log: <value in [disable, enable]>
+          #     override_replacemsg: <string>
+          #     warn_duration: <string>
+          #     warning_duration_type: <value in [session, timeout]>
+          #     warning_prompt: <value in [per-domain, per-category]>
+          # max_quota_timeout: <integer>
+          # options:
+          #   - "error-allow"
+          #   - "http-err-detail"
+          #   - "rate-image-urls"
+          #   - "strict-blocking"
+          #   - "rate-server-ip"
+          #   - "redir-block"
+          #   - "connect-request-bypass"
+          #   - "log-all-url"
+          #   - "ftgd-disable"
+          # ovrd: <list or string>
+          # quota:
+          #   - category: <list or string>
+          #     duration: <string>
+          #     id: <integer>
+          #     override_replacemsg: <string>
+          #     type: <value in [time, traffic]>
+          #     unit: <value in [B, KB, MB, ...]>
+          #     value: <integer>
+          # rate_crl_urls: <value in [disable, enable]>
+          # rate_css_urls: <value in [disable, enable]>
+          # rate_image_urls: <value in [disable, enable]>
+          # rate_javascript_urls: <value in [disable, enable]>
+          # category_override: <string>
+          # risk:
+          #   - action: <value in [block, monitor]>
+          #     id: <integer>
+          #     log: <value in [disable, enable]>
+          #     risk_level: <list or string>
 '''
 
 RETURN = '''
@@ -343,6 +374,7 @@ def main():
     module_arg_spec = {
         'adom': {'required': True, 'type': 'str'},
         'profile': {'required': True, 'type': 'str'},
+        'revision_note': {'type': 'str'},
         'webfilter_profile_ftgdwf': {
             'type': 'dict',
             'v_range': [['6.0.0', '']],
@@ -390,7 +422,18 @@ def main():
                 'rate-css-urls': {'choices': ['disable', 'enable'], 'type': 'str'},
                 'rate-image-urls': {'choices': ['disable', 'enable'], 'type': 'str'},
                 'rate-javascript-urls': {'choices': ['disable', 'enable'], 'type': 'str'},
-                'category-override': {'v_range': [['6.2.0', '6.4.15']], 'type': 'str'}
+                'category-override': {'v_range': [['6.2.0', '6.4.15']], 'type': 'str'},
+                'risk': {
+                    'v_range': [['7.6.2', '']],
+                    'type': 'list',
+                    'options': {
+                        'action': {'v_range': [['7.6.2', '']], 'choices': ['block', 'monitor'], 'type': 'str'},
+                        'id': {'v_range': [['7.6.2', '']], 'type': 'int'},
+                        'log': {'v_range': [['7.6.2', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                        'risk-level': {'v_range': [['7.6.2', '']], 'type': 'raw'}
+                    },
+                    'elements': 'dict'
+                }
             }
         }
     }
