@@ -7,7 +7,6 @@ __metaclass__ = type
 
 DOCUMENTATION = """
     name: gcp_compute
-    plugin_type: inventory
     short_description: Google Cloud Compute Engine inventory source
     requirements:
         - requests >= 2.18.4
@@ -19,35 +18,36 @@ DOCUMENTATION = """
         - Get inventory hosts from Google Cloud Platform GCE.
         - Uses a YAML configuration file that ends with gcp_compute.(yml|yaml) or gcp.(yml|yaml).
     options:
-        plugin:
-            description: token that ensures this is a source file for the 'gcp_compute' plugin.
-            required: True
-            choices: ['google.cloud.gcp_compute', 'gcp_compute']
         zones:
-          description: A list of regions in which to describe GCE instances.
+          description: A list of zones in which to describe GCE instances.
                        If none provided, it defaults to all zones available to a given project.
           type: list
+          elements: string
         folders:
           description: A folder that contains many projects
           type: list
           required: False
+          elements: string
         projects:
           description: A list of projects in which to describe GCE instances.
           type: list
           required: False
+          elements: string
         filters:
           description: >
             A list of filter value pairs. Available filters are listed here
             U(https://cloud.google.com/compute/docs/reference/rest/v1/instances/aggregatedList).
-            Each additional filter in the list will act be added as an AND condition
+            Each additional filter in the list will be added as an AND condition
             (filter1 and filter2)
           type: list
+          elements: string
         hostnames:
           description: A list of options that describe the ordering for which
               hostnames should be assigned. Currently supported hostnames are
-              'public_ip', 'private_ip', 'name' or 'labels.vm_name'.
+              'public_ip', 'private_ip', 'name', 'hostname' or 'labels.vm_name'.
           default: ['public_ip', 'private_ip', 'name']
           type: list
+          elements: string
         name_suffix:
           description: Custom domain suffix. If set, this string will be appended to all hosts.
           default: ""
@@ -57,12 +57,13 @@ DOCUMENTATION = """
             description:
                 - The type of credential used.
             required: True
-            choices: ['application', 'serviceaccount', 'machineaccount']
+            choices: ['application', 'serviceaccount', 'machineaccount', 'accesstoken']
             env:
                 - name: GCP_AUTH_KIND
         scopes:
             description: list of authentication scopes
             type: list
+            elements: string
             default: ['https://www.googleapis.com/auth/compute']
             env:
                 - name: GCP_SCOPES
@@ -86,6 +87,11 @@ DOCUMENTATION = """
                   and the user does not wish to use the default email.
             env:
                 - name: GCP_SERVICE_ACCOUNT_EMAIL
+        access_token:
+            description:
+                - An OAuth2 access token if credential type is accesstoken.
+            env:
+                - name: GCP_ACCESS_TOKEN
         vars_prefix:
             description: prefix to apply to host variables, does not include facts nor params
             default: ''
@@ -111,7 +117,7 @@ DOCUMENTATION = """
 
 EXAMPLES = """
 plugin: google.cloud.gcp_compute
-zones: # populate inventory with instances in these regions
+zones: # populate inventory with instances in these zones
   - us-east1-a
 projects:
   - gcp-prod-gke-100
@@ -232,11 +238,14 @@ class GcpInstance(object):
         for order in self.hostname_ordering:
             name = None
             if order.startswith("labels."):
-                name = self.json["labels"].get(order[7:])
+                if "labels" in self.json:
+                    name = self.json["labels"].get(order[7:])
             elif order == "public_ip":
                 name = self._get_publicip()
             elif order == "private_ip":
                 name = self._get_privateip()
+            elif order == "hostname":
+                name = self.json.get("hostname", self.json["name"] + self.name_suffix)
             elif order == "name":
                 name = self.json["name"] + self.name_suffix
             else:
@@ -476,38 +485,38 @@ class InventoryModule(BaseInventoryPlugin, Constructable, Cacheable):
                         session_responses.append(response_json)
                     page_token = "pageToken" in request_params
 
-            for response in session_responses:
-                if "items" in response:
-                    # example k would be a zone or region name
-                    # example v would be { "disks" : [], "otherkey" : "..." }
-                    for zone_or_region, aggregate in response["items"].items():
-                        if "zones" in zone_or_region:
-                            if "disks" in aggregate:
-                                zone = zone_or_region.replace("zones/", "")
-                                for disk in aggregate["disks"]:
-                                    if (
-                                        "zones" in config_data
-                                        and zone in config_data["zones"]
-                                    ):
-                                        # If zones specified, only store those zones' data
-                                        if "sourceImage" in disk:
-                                            self._project_disks[
-                                                disk["selfLink"]
-                                            ] = disk["sourceImage"].split("/")[-1]
-                                        else:
-                                            self._project_disks[
-                                                disk["selfLink"]
-                                            ] = disk["selfLink"].split("/")[-1]
+                for response in session_responses:
+                    if "items" in response:
+                        # example k would be a zone or region name
+                        # example v would be { "disks" : [], "otherkey" : "..." }
+                        for zone_or_region, aggregate in response["items"].items():
+                            if "zones" in zone_or_region:
+                                if "disks" in aggregate:
+                                    zone = zone_or_region.replace("zones/", "")
+                                    for disk in aggregate["disks"]:
+                                        if (
+                                            "zones" in config_data
+                                            and zone in config_data["zones"]
+                                        ):
+                                            # If zones specified, only store those zones' data
+                                            if "sourceImage" in disk:
+                                                self._project_disks[
+                                                    disk["selfLink"]
+                                                ] = disk["sourceImage"].split("/")[-1]
+                                            else:
+                                                self._project_disks[
+                                                    disk["selfLink"]
+                                                ] = disk["selfLink"].split("/")[-1]
 
-                                    else:
-                                        if "sourceImage" in disk:
-                                            self._project_disks[
-                                                disk["selfLink"]
-                                            ] = disk["sourceImage"].split("/")[-1]
                                         else:
-                                            self._project_disks[
-                                                disk["selfLink"]
-                                            ] = disk["selfLink"].split("/")[-1]
+                                            if "sourceImage" in disk:
+                                                self._project_disks[
+                                                    disk["selfLink"]
+                                                ] = disk["sourceImage"].split("/")[-1]
+                                            else:
+                                                self._project_disks[
+                                                    disk["selfLink"]
+                                                ] = disk["selfLink"].split("/")[-1]
 
         return self._project_disks
 
@@ -558,6 +567,7 @@ class InventoryModule(BaseInventoryPlugin, Constructable, Cacheable):
             "service_account_file": self.get_option("service_account_file"),
             "service_account_contents": self.get_option("service_account_contents"),
             "service_account_email": self.get_option("service_account_email"),
+            "access_token": self.get_option("access_token"),
         }
 
         self.fake_module = GcpMockModule(params)
