@@ -3,7 +3,7 @@
 
 from __future__ import annotations
 
-DOCUMENTATION = r"""
+DOCUMENTATION = """
 name: hcloud
 short_description: Ansible dynamic inventory plugin for the Hetzner Cloud.
 
@@ -24,34 +24,21 @@ extends_documentation_fragment:
 
 options:
   plugin:
-    description: Mark this as an C(hetzner.hcloud.hcloud) inventory instance.
+    description: Mark this as an P(hetzner.hcloud.hcloud#inventory) inventory instance.
     required: true
     choices: [hcloud, hetzner.hcloud.hcloud]
 
   api_token:
     description:
       - The API Token for the Hetzner Cloud.
-      - You can also set this option by using the C(HCLOUD_TOKEN) environment variable.
     type: str
-    required: false # TODO: Mark as required once I(api_token_env) is removed.
+    required: true
     aliases: [token]
     env:
       - name: HCLOUD_TOKEN
-  api_token_env:
-    description:
-      - Environment variable name to load the Hetzner Cloud API Token from.
-    type: str
-    default: HCLOUD_TOKEN
-    aliases: [token_env]
-    deprecated:
-      why: The option is adding too much complexity, while the alternatives are preferred.
-      collection_name: hetzner.hcloud
-      version: 3.0.0
-      alternatives: Use the ``{{ lookup('ansible.builtin.env', 'YOUR_ENV_VAR') }}`` lookup instead.
   api_endpoint:
     description:
       - The API Endpoint for the Hetzner Cloud.
-      - You can also set this option by using the C(HCLOUD_ENDPOINT) environment variable.
     type: str
     default: https://api.hetzner.cloud/v1
     env:
@@ -64,10 +51,10 @@ options:
     required: false
   connect_with:
     description: |
-      Connect to the server using the value from this field. This sets the `ansible_host`
+      Connect to the server using the value from this field. This sets the C(ansible_host)
       variable to the value indicated, if that value is available. If you need further
       customization, like falling back to private ipv4 if the server has no public ipv4,
-      you can use `compose` top-level key.
+      you can use O(compose) top-level key.
     default: public_ipv4
     type: str
     choices:
@@ -111,30 +98,96 @@ options:
     type: list
     elements: str
     required: false
+
+  hostvars_prefix:
+    description:
+      - The prefix for host variables names coming from Hetzner Cloud.
+    default: hcloud_
+    type: str
+    version_added: 2.5.0
+  hostvars_suffix:
+    description:
+      - The suffix for host variables names coming from Hetzner Cloud.
+    type: str
+    version_added: 2.5.0
+
+  hostname:
+    description:
+      - A template for the instances hostname, if not provided the Hetzner Cloud server name will be used.
+      - Available variables are the Hetzner Cloud host variables.
+      - The available variables names are provide with the O(hostvars_prefix) or O(hostvars_suffix) modifications.
+    type: str
+    version_added: 3.0.0
 """
 
-EXAMPLES = r"""
-plugin: hcloud
+EXAMPLES = """
+# Minimal example. 'HCLOUD_TOKEN' is exposed in environment.
+plugin: hetzner.hcloud.hcloud
+
+---
+# Example with templated token, e.g. provided through extra vars.
+plugin: hetzner.hcloud.hcloud
+api_token: "{{ _vault_hetzner_cloud_token }}"
+
+---
+# Example with locations, types, status
+plugin: hetzner.hcloud.hcloud
 locations:
   - nbg1
 types:
-  - cx11
+  - cpx22
 status:
   - running
 
+---
 # Group by a location with prefix e.g. "hcloud_location_nbg1"
 # and image_os_flavor without prefix and separator e.g. "ubuntu"
 # and status with prefix e.g. "server_status_running"
+plugin: hetzner.hcloud.hcloud
 keyed_groups:
-  - key: location
+  - key: hcloud_location
     prefix: hcloud_location
   - key: image_os_flavor
     separator: ""
-  - key: status
+  - key: hcloud_status
     prefix: server_status
+
+---
+# Use a custom hostname template.
+plugin: hetzner.hcloud.hcloud
+
+# Available variables are for example:
+## Server
+#   hcloud_id: 42984895
+#   hcloud_name: "my-server"
+#   hcloud_labels:
+#     foo: "bar"
+#   hcloud_status: "running"
+## Server Type
+#   hcloud_type: "cpx22"
+#   hcloud_server_type: "cpx22"
+#   hcloud_architecture: "x86"
+## Image
+#   hcloud_image_id: 114690387
+#   hcloud_image_name: "debian-12"
+#   hcloud_image_os_flavor: "debian"
+## Datacenter
+#   hcloud_datacenter: "hel1-dc2"
+#   hcloud_location: "hel1"
+## Network
+#   hcloud_ipv4: "65.109.140.95" # Value is optional!
+#   hcloud_ipv6: "2a01:4f9:c011:b83f::1" # Value is optional!
+#   hcloud_ipv6_network: 2a01:4f9:c011:b83f::" # Value is optional!
+#   hcloud_ipv6_network_mask: "64" # Value is optional!
+#   hcloud_private_ipv4: "10.0.0.3" # Value is optional!
+#   hcloud_private_networks:
+#     - id: 114690387
+#       name: "my-private-network"
+#       ip: "10.0.0.3"
+#
+hostname: "my-prefix-{{ hcloud_datacenter }}-{{ hcloud_name }}-{{ hcloud_server_type }}"
 """
 
-import os
 import sys
 from ipaddress import IPv6Network
 
@@ -143,6 +196,7 @@ from ansible.inventory.manager import InventoryData
 from ansible.module_utils.common.text.converters import to_native
 from ansible.plugins.inventory import BaseInventoryPlugin, Cacheable, Constructable
 from ansible.utils.display import Display
+from ansible.utils.vars import combine_vars
 
 from ..module_utils.client import (
     Client,
@@ -169,16 +223,16 @@ if sys.version_info >= (3, 11):
         id: int
         name: str
         status: str
+
+        # Server Type
         type: str
+        server_type: str
         architecture: str
 
         # Datacenter
         datacenter: str
         location: str
 
-        # Server Type
-        server_type: NotRequired[str]
-
         # Labels
         labels: dict[str, str]
 
@@ -208,7 +262,7 @@ def first_ipv6_address(network: str) -> str:
 
     :param network: IPv6 Network.
     """
-    return next(IPv6Network(network).hosts())
+    return str(next(IPv6Network(network).hosts()))
 
 
 class InventoryModule(BaseInventoryPlugin, Constructable, Cacheable):
@@ -222,30 +276,9 @@ class InventoryModule(BaseInventoryPlugin, Constructable, Cacheable):
     network: Network | None
 
     def _configure_hcloud_client(self):
-        # If api_token_env is not the default, print a deprecation warning and load the
-        # environment variable.
-        api_token_env = self.get_option("api_token_env")
-        if api_token_env != "HCLOUD_TOKEN":
-            self.display.deprecated(
-                "The 'api_token_env' option is deprecated, please use the `HCLOUD_TOKEN` "
-                "environment variable or use the 'ansible.builtin.env' lookup instead.",
-                version="3.0.0",
-                collection_name="hetzner.hcloud",
-            )
-            if api_token_env in os.environ:
-                self.set_option("api_token", os.environ.get(api_token_env))
-
         api_token = self.get_option("api_token")
         api_endpoint = self.get_option("api_endpoint")
 
-        if api_token is None:  # TODO: Remove once I(api_token_env) is removed.
-            raise AnsibleError(
-                "No setting was provided for required configuration setting: "
-                "plugin_type: inventory "
-                "plugin: hetzner.hcloud.hcloud "
-                "setting: api_token"
-            )
-
         # Resolve template string
         api_token = self.templar.template(api_token)
 
@@ -304,44 +337,43 @@ class InventoryModule(BaseInventoryPlugin, Constructable, Cacheable):
     def _build_inventory_server(self, server: Server) -> InventoryServer:
         server_dict: InventoryServer = {}
         server_dict["id"] = server.id
-        server_dict["name"] = to_native(server.name)
-        server_dict["status"] = to_native(server.status)
-        server_dict["type"] = to_native(server.server_type.name)
-        server_dict["architecture"] = to_native(server.server_type.architecture)
+        server_dict["name"] = server.name
+        server_dict["status"] = server.status
+
+        # Server Type
+        server_dict["type"] = server.server_type.name
+        server_dict["server_type"] = server.server_type.name
+        server_dict["architecture"] = server.server_type.architecture
 
         # Network
         if server.public_net.ipv4:
-            server_dict["ipv4"] = to_native(server.public_net.ipv4.ip)
+            server_dict["ipv4"] = server.public_net.ipv4.ip
 
         if server.public_net.ipv6:
-            server_dict["ipv6"] = to_native(first_ipv6_address(server.public_net.ipv6.ip))
-            server_dict["ipv6_network"] = to_native(server.public_net.ipv6.network)
-            server_dict["ipv6_network_mask"] = to_native(server.public_net.ipv6.network_mask)
+            server_dict["ipv6"] = first_ipv6_address(server.public_net.ipv6.ip)
+            server_dict["ipv6_network"] = server.public_net.ipv6.network
+            server_dict["ipv6_network_mask"] = server.public_net.ipv6.network_mask
 
         server_dict["private_networks"] = [
-            {"id": v.network.id, "name": to_native(v.network.name), "ip": to_native(v.ip)} for v in server.private_net
+            {"id": v.network.id, "name": v.network.name, "ip": v.ip} for v in server.private_net
         ]
 
         if self.get_option("network"):
             for private_net in server.private_net:
                 # Set private_ipv4 if user filtered for one network
                 if private_net.network.id == self.network.id:
-                    server_dict["private_ipv4"] = to_native(private_net.ip)
+                    server_dict["private_ipv4"] = private_net.ip
                     break
 
-        # Server Type
-        if server.server_type is not None:
-            server_dict["server_type"] = to_native(server.server_type.name)
-
         # Datacenter
-        server_dict["datacenter"] = to_native(server.datacenter.name)
-        server_dict["location"] = to_native(server.datacenter.location.name)
+        server_dict["datacenter"] = server.datacenter.name
+        server_dict["location"] = server.datacenter.location.name
 
         # Image
         if server.image is not None:
             server_dict["image_id"] = server.image.id
-            server_dict["image_os_flavor"] = to_native(server.image.os_flavor)
-            server_dict["image_name"] = to_native(server.image.name or server.image.description)
+            server_dict["image_os_flavor"] = server.image.os_flavor
+            server_dict["image_name"] = server.image.name or server.image.description
 
         # Labels
         server_dict["labels"] = dict(server.labels)
@@ -350,7 +382,7 @@ class InventoryModule(BaseInventoryPlugin, Constructable, Cacheable):
             server_dict["ansible_host"] = self._get_server_ansible_host(server)
         except AnsibleError as exception:
             # Log warning that for this host can not be connected to, using the
-            # method specified in `connect_with`. Users might use `compose` to
+            # method specified in 'connect_with'. Users might use 'compose' to
             # override the connection method, or implement custom logic, so we
             # do not need to abort if nothing matched.
             self.display.v(f"[hcloud] {exception}", server.name)
@@ -360,28 +392,28 @@ class InventoryModule(BaseInventoryPlugin, Constructable, Cacheable):
     def _get_server_ansible_host(self, server: Server):
         if self.get_option("connect_with") == "public_ipv4":
             if server.public_net.ipv4:
-                return to_native(server.public_net.ipv4.ip)
+                return server.public_net.ipv4.ip
             raise AnsibleError("Server has no public ipv4, but connect_with=public_ipv4 was specified")
 
         if self.get_option("connect_with") == "public_ipv6":
             if server.public_net.ipv6:
-                return to_native(first_ipv6_address(server.public_net.ipv6.ip))
+                return first_ipv6_address(server.public_net.ipv6.ip)
             raise AnsibleError("Server has no public ipv6, but connect_with=public_ipv6 was specified")
 
         if self.get_option("connect_with") == "hostname":
             # every server has a name, no need to guard this
-            return to_native(server.name)
+            return server.name
 
         if self.get_option("connect_with") == "ipv4_dns_ptr":
             if server.public_net.ipv4:
-                return to_native(server.public_net.ipv4.dns_ptr)
+                return server.public_net.ipv4.dns_ptr
             raise AnsibleError("Server has no public ipv4, but connect_with=ipv4_dns_ptr was specified")
 
         if self.get_option("connect_with") == "private_ipv4":
             if self.get_option("network"):
                 for private_net in server.private_net:
                     if private_net.network.id == self.network.id:
-                        return to_native(private_net.ip)
+                        return private_net.ip
 
             else:
                 raise AnsibleError("You can only connect via private IPv4 if you specify a network")
@@ -444,10 +476,33 @@ class InventoryModule(BaseInventoryPlugin, Constructable, Cacheable):
         # Add a top group
         self.inventory.add_group(group=self.get_option("group"))
 
+        hostvars_prefix = self.get_option("hostvars_prefix")
+        hostvars_suffix = self.get_option("hostvars_suffix")
+        hostname_template = self.get_option("hostname")
+
         for server in servers:
-            self.inventory.add_host(server["name"], group=self.get_option("group"))
+            hostvars = {}
             for key, value in server.items():
-                self.inventory.set_variable(server["name"], key, value)
+                # Add hostvars prefix and suffix for variables coming from the Hetzner Cloud.
+                if hostvars_prefix or hostvars_suffix:
+                    if key not in ("ansible_host",):
+                        if hostvars_prefix:
+                            key = hostvars_prefix + key
+                        if hostvars_suffix:
+                            key = key + hostvars_suffix
+
+                hostvars[key] = value
+
+            if hostname_template:
+                templar = self.templar
+                templar.available_variables = combine_vars(hostvars, self._vars)
+                hostname = templar.template(hostname_template)
+            else:
+                hostname = server["name"]
+
+            self.inventory.add_host(hostname, group=self.get_option("group"))
+            for key, value in hostvars.items():
+                self.inventory.set_variable(hostname, key, value)
 
             # Use constructed if applicable
             strict = self.get_option("strict")
@@ -455,8 +510,8 @@ class InventoryModule(BaseInventoryPlugin, Constructable, Cacheable):
             # Composed variables
             self._set_composite_vars(
                 self.get_option("compose"),
-                self.inventory.get_host(server["name"]).get_vars(),
-                server["name"],
+                self.inventory.get_host(hostname).get_vars(),
+                hostname,
                 strict=strict,
             )
 
@@ -464,7 +519,7 @@ class InventoryModule(BaseInventoryPlugin, Constructable, Cacheable):
             self._add_host_to_composed_groups(
                 self.get_option("groups"),
                 {},
-                server["name"],
+                hostname,
                 strict=strict,
             )
 
@@ -472,7 +527,7 @@ class InventoryModule(BaseInventoryPlugin, Constructable, Cacheable):
             self._add_host_to_keyed_groups(
                 self.get_option("keyed_groups"),
                 {},
-                server["name"],
+                hostname,
                 strict=strict,
             )
 
