@@ -9,10 +9,8 @@ from __future__ import annotations
 DOCUMENTATION = """
 ---
 module: firewall
-
 short_description: Create and manage firewalls on the Hetzner Cloud.
 
-
 description:
     - Create, update and manage firewalls on the Hetzner Cloud.
 
@@ -22,62 +20,74 @@ author:
 options:
     id:
         description:
-            - The ID of the Hetzner Cloud firewall to manage.
-            - Only required if no firewall I(name) is given
+            - The ID of the Hetzner Cloud Firewall to manage.
+            - Only required if no firewall O(name) is given.
         type: int
     name:
         description:
-            - The Name of the Hetzner Cloud firewall to manage.
-            - Only required if no firewall I(id) is given, or a firewall does not exist.
+            - The Name of the Hetzner Cloud Firewall to manage.
+            - Only required if no firewall O(id) is given, or the firewall does not exist.
         type: str
     labels:
         description:
-            - User-defined labels (key-value pairs)
+            - User-defined labels (key-value pairs).
         type: dict
     rules:
         description:
-            - List of rules the firewall should contain.
+            - List of rules the firewall contain.
         type: list
         elements: dict
         suboptions:
-            direction:
-                description:
-                    - The direction of the firewall rule.
-                type: str
-                choices: [ in, out ]
-            port:
-                description:
-                    - The port of the firewall rule.
-                type: str
-            protocol:
-                description:
-                    - The protocol of the firewall rule.
-                type: str
-                choices: [ icmp, tcp, udp, esp, gre ]
-            source_ips:
-                description:
-                    - List of CIDRs that are allowed within this rule
-                type: list
-                elements: str
-                default: [ ]
-            destination_ips:
-                description:
-                    - List of CIDRs that are allowed within this rule
-                type: list
-                elements: str
-                default: [ ]
             description:
                 description:
                     - User defined description of this rule.
                 type: str
+            direction:
+                description:
+                    - The direction of the firewall rule.
+                type: str
+                choices: [in, out]
+            protocol:
+                description:
+                    - The protocol of the firewall rule.
+                type: str
+                choices: [icmp, tcp, udp, esp, gre]
+            port:
+                description:
+                    - The port or port range allowed by this rule.
+                    - A port range can be specified by separating two ports with a dash, e.g 1024-5000.
+                    - Only used if O(rules[].protocol=tcp) or O(rules[].protocol=udp).
+                type: str
+            source_ips:
+                description:
+                    - List of CIDRs that are allowed within this rule.
+                    - Use 0.0.0.0/0 to allow all IPv4 addresses and ::/0 to allow all IPv6 addresses.
+                    - Only used if O(rules[].direction=in).
+                type: list
+                elements: str
+                default: []
+            destination_ips:
+                description:
+                    - List of CIDRs that are allowed within this rule.
+                    - Use 0.0.0.0/0 to allow all IPv4 addresses and ::/0 to allow all IPv6 addresses.
+                    - Only used if O(rules[].direction=out).
+                type: list
+                elements: str
+                default: []
+    force:
+        description:
+            - Force the deletion of the Firewall when still in use.
+        type: bool
+        default: false
     state:
         description:
             - State of the firewall.
         default: present
-        choices: [ absent, present ]
+        choices: [absent, present]
         type: str
+
 extends_documentation_fragment:
-- hetzner.hcloud.hcloud
+    - hetzner.hcloud.hcloud
 """
 
 EXAMPLES = """
@@ -90,12 +100,12 @@ EXAMPLES = """
   hetzner.hcloud.firewall:
     name: my-firewall
     rules:
-      - direction: in
+      - description: allow icmp from everywhere
+        direction: in
         protocol: icmp
         source_ips:
           - 0.0.0.0/0
           - ::/0
-        description: allow icmp in
     state: present
 
 - name: Create a firewall with labels
@@ -114,68 +124,118 @@ EXAMPLES = """
 
 RETURN = """
 hcloud_firewall:
-    description: The firewall instance
-    returned: Always
-    type: complex
+    description: The firewall instance.
+    returned: always
+    type: dict
     contains:
         id:
-            description: Numeric identifier of the firewall
+            description: Numeric identifier of the firewall.
             returned: always
             type: int
             sample: 1937415
         name:
-            description: Name of the firewall
+            description: Name of the firewall.
             returned: always
             type: str
-            sample: my firewall
-        rules:
-            description: List of Rules within this Firewall
+            sample: my-firewall
+        labels:
+            description: User-defined labels (key-value pairs).
             returned: always
-            type: complex
+            type: dict
+        rules:
+            description: List of rules the firewall contain.
+            returned: always
+            type: list
+            elements: dict
             contains:
+                description:
+                    description: User defined description of this rule.
+                    type: str
+                    returned: always
+                    sample: allow http from anywhere
                 direction:
-                    description: Direction of the Firewall Rule
+                    description: The direction of the firewall rule.
                     type: str
                     returned: always
                     sample: in
                 protocol:
-                    description: Protocol of the Firewall Rule
+                    description: The protocol of the firewall rule.
                     type: str
                     returned: always
-                    sample: icmp
+                    sample: tcp
                 port:
-                    description: Port of the Firewall Rule, None/Null if protocol is icmp
+                    description: The port or port range allowed by this rule.
                     type: str
-                    returned: always
-                    sample: in
+                    returned: if RV(hcloud_firewall.rules[].protocol=tcp) or RV(hcloud_firewall.rules[].protocol=udp)
+                    sample: "80"
                 source_ips:
-                    description: Source IPs of the Firewall
+                    description: List of source CIDRs that are allowed within this rule.
                     type: list
                     elements: str
                     returned: always
+                    sample: ["0.0.0.0/0", "::/0"]
                 destination_ips:
-                    description: Source IPs of the Firewall
+                    description: List of destination CIDRs that are allowed within this rule.
                     type: list
                     elements: str
                     returned: always
-                description:
-                    description: User defined description of the Firewall Rule
-                    type: str
-                    returned: always
-        labels:
-            description: User-defined labels (key-value pairs)
+                    sample: []
+        applied_to:
+            description: List of Resources the Firewall is applied to.
             returned: always
-            type: dict
+            type: list
+            elements: dict
+            contains:
+                type:
+                    description: Type of the resource.
+                    type: str
+                    choices: [server, label_selector]
+                    sample: label_selector
+                server:
+                    description: ID of the server.
+                    type: int
+                    sample: 12345
+                label_selector:
+                    description: Label selector value.
+                    type: str
+                    sample: env=prod
+                applied_to_resources:
+                    description: List of Resources the Firewall label selector is applied to.
+                    returned: if RV(hcloud_firewall.applied_to[].type=label_selector)
+                    type: list
+                    elements: dict
+                    contains:
+                        type:
+                            description: Type of resource referenced.
+                            type: str
+                            choices: [server]
+                            sample: server
+                        server:
+                            description: ID of the Server.
+                            type: int
+                            sample: 12345
 """
 
 import time
 
 from ansible.module_utils.basic import AnsibleModule
-from ansible.module_utils.common.text.converters import to_native
 
 from ..module_utils.hcloud import AnsibleHCloud
+from ..module_utils.ipaddress import normalize_ip
 from ..module_utils.vendor.hcloud import APIException, HCloudException
-from ..module_utils.vendor.hcloud.firewalls import BoundFirewall, FirewallRule
+from ..module_utils.vendor.hcloud.firewalls import (
+    BoundFirewall,
+    FirewallResource,
+    FirewallRule,
+)
+
+
+def normalize_rules(rules: list[dict]) -> list[dict]:
+    for rule in rules:
+        # Ensure ip addresses canonical representation
+        rule["source_ips"] = [normalize_ip(o) for o in rule["source_ips"]]
+        rule["destination_ips"] = [normalize_ip(o) for o in rule["destination_ips"]]
+    return rules
 
 
 class AnsibleHCloudFirewall(AnsibleHCloud):
@@ -185,22 +245,39 @@ class AnsibleHCloudFirewall(AnsibleHCloud):
 
     def _prepare_result(self):
         return {
-            "id": to_native(self.hcloud_firewall.id),
-            "name": to_native(self.hcloud_firewall.name),
+            "id": self.hcloud_firewall.id,
+            "name": self.hcloud_firewall.name,
             "rules": [self._prepare_result_rule(rule) for rule in self.hcloud_firewall.rules],
             "labels": self.hcloud_firewall.labels,
+            "applied_to": [self._prepare_result_applied_to(resource) for resource in self.hcloud_firewall.applied_to],
         }
 
-    def _prepare_result_rule(self, rule):
+    def _prepare_result_rule(self, rule: FirewallRule):
         return {
             "direction": rule.direction,
-            "protocol": to_native(rule.protocol),
-            "port": to_native(rule.port) if rule.port is not None else None,
-            "source_ips": [to_native(cidr) for cidr in rule.source_ips],
-            "destination_ips": [to_native(cidr) for cidr in rule.destination_ips],
-            "description": to_native(rule.description) if rule.description is not None else None,
+            "protocol": rule.protocol,
+            "port": rule.port,
+            "source_ips": rule.source_ips,
+            "destination_ips": rule.destination_ips,
+            "description": rule.description,
         }
 
+    def _prepare_result_applied_to(self, resource: FirewallResource):
+        result = {
+            "type": resource.type,
+            "server": resource.server.id if resource.server is not None else None,
+            "label_selector": resource.label_selector.selector if resource.label_selector is not None else None,
+        }
+        if resource.applied_to_resources is not None:
+            result["applied_to_resources"] = [
+                {
+                    "type": item.type,
+                    "server": item.server.id if item.server is not None else None,
+                }
+                for item in resource.applied_to_resources
+            ]
+        return result
+
     def _get_firewall(self):
         try:
             if self.module.params.get("id") is not None:
@@ -219,6 +296,7 @@ class AnsibleHCloudFirewall(AnsibleHCloud):
         }
         rules = self.module.params.get("rules")
         if rules is not None:
+            rules = normalize_rules(rules)
             params["rules"] = [
                 FirewallRule(
                     direction=rule["direction"],
@@ -230,11 +308,13 @@ class AnsibleHCloudFirewall(AnsibleHCloud):
                 )
                 for rule in rules
             ]
+
         if not self.module.check_mode:
             try:
                 self.client.firewalls.create(**params)
             except HCloudException as exception:
                 self.fail_json_hcloud(exception, params=params)
+
         self._mark_as_changed()
         self._get_firewall()
 
@@ -253,21 +333,25 @@ class AnsibleHCloudFirewall(AnsibleHCloud):
             self._mark_as_changed()
 
         rules = self.module.params.get("rules")
-        if rules is not None and rules != [self._prepare_result_rule(rule) for rule in self.hcloud_firewall.rules]:
-            if not self.module.check_mode:
-                new_rules = [
-                    FirewallRule(
-                        direction=rule["direction"],
-                        protocol=rule["protocol"],
-                        source_ips=rule["source_ips"] if rule["source_ips"] is not None else [],
-                        destination_ips=rule["destination_ips"] if rule["destination_ips"] is not None else [],
-                        port=rule["port"],
-                        description=rule["description"],
-                    )
-                    for rule in rules
-                ]
-                self.hcloud_firewall.set_rules(new_rules)
-            self._mark_as_changed()
+        if rules is not None:
+            rules = normalize_rules(rules)
+
+            if rules != [self._prepare_result_rule(rule) for rule in self.hcloud_firewall.rules]:
+                if not self.module.check_mode:
+                    new_rules = [
+                        FirewallRule(
+                            direction=rule["direction"],
+                            protocol=rule["protocol"],
+                            source_ips=rule["source_ips"] if rule["source_ips"] is not None else [],
+                            destination_ips=rule["destination_ips"] if rule["destination_ips"] is not None else [],
+                            port=rule["port"],
+                            description=rule["description"],
+                        )
+                        for rule in rules
+                    ]
+                    self.hcloud_firewall.set_rules(new_rules)
+                self._mark_as_changed()
+
         self._get_firewall()
 
     def present_firewall(self):
@@ -281,19 +365,32 @@ class AnsibleHCloudFirewall(AnsibleHCloud):
         self._get_firewall()
         if self.hcloud_firewall is not None:
             if not self.module.check_mode:
+                if self.hcloud_firewall.applied_to:
+                    if self.module.params.get("force"):
+                        actions = self.hcloud_firewall.remove_from_resources(self.hcloud_firewall.applied_to)
+                        for action in actions:
+                            action.wait_until_finished()
+                    else:
+                        self.module.warn(
+                            f"Firewall {self.hcloud_firewall.name} is currently used by "
+                            "other resources. You need to unassign the resources before "
+                            "deleting the Firewall or use force=true."
+                        )
+
                 retry_count = 0
-                while retry_count < 10:
+                while True:
                     try:
-                        self.client.firewalls.delete(self.hcloud_firewall)
+                        self.hcloud_firewall.delete()
                         break
                     except APIException as exception:
-                        if "is still in use" in exception.message:
-                            retry_count = retry_count + 1
+                        if "is still in use" in exception.message and retry_count < 10:
+                            retry_count += 1
                             time.sleep(0.5 * retry_count)
-                        else:
-                            self.fail_json_hcloud(exception)
+                            continue
+                        self.fail_json_hcloud(exception)
                     except HCloudException as exception:
                         self.fail_json_hcloud(exception)
+
             self._mark_as_changed()
         self.hcloud_firewall = None
 
@@ -303,16 +400,17 @@ class AnsibleHCloudFirewall(AnsibleHCloud):
             argument_spec=dict(
                 id={"type": "int"},
                 name={"type": "str"},
+                labels={"type": "dict"},
                 rules=dict(
                     type="list",
                     elements="dict",
                     options=dict(
+                        description={"type": "str"},
                         direction={"type": "str", "choices": ["in", "out"]},
                         protocol={"type": "str", "choices": ["icmp", "udp", "tcp", "esp", "gre"]},
                         port={"type": "str"},
                         source_ips={"type": "list", "elements": "str", "default": []},
                         destination_ips={"type": "list", "elements": "str", "default": []},
-                        description={"type": "str"},
                     ),
                     required_together=[["direction", "protocol"]],
                     required_if=[
@@ -320,7 +418,7 @@ class AnsibleHCloudFirewall(AnsibleHCloud):
                         ["protocol", "tcp", ["port"]],
                     ],
                 ),
-                labels={"type": "dict"},
+                force={"type": "bool", "default": False},
                 state={
                     "choices": ["absent", "present"],
                     "default": "present",
