@@ -124,90 +124,86 @@ EXAMPLES = """
 """
 
 RETURN = """
-data:
+external_path_group:
   description: The External Path Group managed by the module.
   returned: success
   type: list
   elements: dict
   contains:
-    external_path_group:
-      description: The list of external path groups.
-      type: dict
+    external_path_group_id:
+      description: External path group number.
+      type: int
+      sample: 1
+    external_serial_number:
+      description: Serial number of the external storage system.
+      type: str
+      sample: "410109"
+    storage_serial_number:
+      description: Serial number of the storage system.
+      type: str
+      sample: "410109"
+    external_parity_groups:
+      description: The list of external parity groups.
+      type: list
+      elements: dict
       contains:
-        external_path_group_id:
-          description: External path group number.
+        cache_mode:
+          description: Cache mode.
+          type: str
+          sample: "E"
+        external_parity_group_id:
+          description: External parity group ID.
+          type: str
+          sample: "1-3"
+        external_parity_group_status:
+          description: Status of the external parity group.
+          type: str
+          sample: "NML"
+        is_data_direct_mapping:
+          description: Whether the data direct mapping attribute is enabled.
+          type: bool
+          sample: false
+        is_inflow_control_enabled:
+          description: Inflow cache control.
+          type: bool
+          sample: false
+        load_balance_mode:
+          description: The load balancing method for I/O operations for the external storage system.
+          type: str
+          sample: "N"
+        mp_blade_id:
+          description: Inflow cache control.
           type: int
-          sample: 1
-        external_serial_number:
-          description: Serial number of the external storage system.
+          sample: 0
+        path_mode:
+          description: Path mode of the external storage system.
           type: str
-          sample: "410109"
-        storage_serial_number:
-          description: Serial number of the storage system.
-          type: str
-          sample: "410109"
-        external_parity_groups:
-          description: The list of external parity groups.
+          sample: "M"
+        external_luns:
+          description: List of LUNs of the external storage system.
           type: list
           elements: dict
           contains:
-            cache_mode:
-              description: Cache mode.
+            external_lun:
+              description: LUN within the ports of the external storage system.
+              type: int
+              sample: 2
+            external_wwn:
+              description: WWN of the external storage system.
               type: str
-              sample: "E"
-            external_parity_group_id:
-              description: External parity group ID.
-              type: str
-              sample: "1-3"
-            external_parity_group_status:
-              description: Status of the external parity group.
+              sample: "50060e8012277d71"
+            path_status:
+              description: Status of the external path.
               type: str
               sample: "NML"
-            is_data_direct_mapping:
-              description: Whether the data direct mapping attribute is enabled.
-              type: bool
-              sample: false
-            is_inflow_control_enabled:
-              description: Inflow cache control.
-              type: bool
-              sample: false
-            load_balance_mode:
-              description: The load balancing method for I/O operations for the external storage system.
+            port_id:
+              description: Port number.
               type: str
-              sample: "N"
-            mp_blade_id:
-              description: Inflow cache control.
+              sample: "CL6-B"
+            priority:
+              description: Priority within the external path group.
               type: int
-              sample: 0
-            path_mode:
-              description: Path mode of the external storage system.
-              type: str
-              sample: "M"
-            external_luns:
-              description: List of LUNs of the external storage system.
-              type: list
-              elements: dict
-              contains:
-                external_lun:
-                  description: LUN within the ports of the external storage system.
-                  type: int
-                  sample: 2
-                external_wwn:
-                  description: WWN of the external storage system.
-                  type: str
-                  sample: "50060e8012277d71"
-                path_status:
-                  description: Status of the external path.
-                  type: str
-                  sample: "NML"
-                port_id:
-                  description: Port number.
-                  type: str
-                  sample: "CL6-B"
-                priority:
-                  description: Priority within the external path group.
-                  type: int
-                  sample: 1
+              sample: 1
 """
 from ansible.module_utils.basic import AnsibleModule
 from ansible_collections.hitachivantara.vspone_block.plugins.module_utils.reconciler.vsp_external_path_group import (
