@@ -72,33 +72,43 @@ options:
       name:
         description: Name of the host group. If not given,
           it will create the name with prefix "smrha-" and add 10 digit random number at the end, for example "smrha-0806262996".
+          Optional for the Create a host group task. Required for the Update host mode and host mode options/Add WWNs to a host group
+          /Remove WWNs from a host group/Present LDEVS/Unpresent LDEVS/Delete/Change or unset nick name of a WWN tasks.
         type: str
         required: false
       port:
-        description: FC Port.
+        description: FC Port. Required for the Create a host group/Update host mode and host mode options/Add WWNs to a host group
+          /Remove WWNs from a host group/Present LDEVS/Unpresent LDEVS/Delete/Change or unset nick name of a WWN
+          /Asymmetric access priority level for ALUA host group/Release the host reservation status by specifying a host group
+          /Release the host reservation status by specifying the LU path tasks.
         type: str
         required: true
       wwns:
-        description: List of host WWN to add or remove.
+        description: List of host WWN to add or remove. Required for the Create a host group/Add WWNs to a host group
+          /Remove WWNs from a host group tasks.
         type: list
         elements: dict
         suboptions:
           wwn:
-            description: WWN of the host.
+            description: WWN of the host. Required for the Create a host group/Add WWNs to a host group
+              /Remove WWNs from a host group/Change or unset nick name of a WWN tasks.
             type: str
             required: true
           nick_name:
-            description: Nickname of the host.
+            description: Nickname of the host. Optional for the Create a host group/Add WWNs to a host group
+              /Remove WWNs from a host group tasks. Required for the Change or unset nick name of a WWN task.
             type: str
             required: false
         required: false
       ldevs:
         description: LDEVs to be mapped/unmapped with the host group. Supported format can be decimal or HEX.
+           Optional for the Create a host group task. Required for the Present LDEVS/Unpresent LDEVS tasks.
         type: list
         elements: str
         required: false
       host_mode:
-        description: Host mode of host group.
+        description: Host mode of host group. Optional for the Create a host group task.
+          Required for the Update host mode and host mode options task.
         type: str
         required: false
         choices: ['LINUX', 'VMWARE', 'HP', 'OPEN_VMS', 'TRU64', 'SOLARIS',
@@ -106,7 +116,8 @@ options:
           'WINDOWS_EXTENSION', 'UVM', 'HP_XP', 'DYNIX']
       host_mode_options:
         description:
-          - List of host group host mode option numbers.
+          - List of host group host mode option numbers. Optional for the Create a host group task.
+            Required for the Update host mode and host mode options task.
           - '0 # RESERVED'
           - '2 # VERITAS_DB_EDITION_ADV_CLUSTER'
           - '6 # TPRLO'
@@ -163,26 +174,32 @@ options:
         required: false
         type: bool
       host_group_number:
-        description: The host group number.
+        description: The host group number. Required for the Asymmetric access priority level for ALUA host group
+          /Release the host reservation status by specifying a host group
+          /Release the host reservation status by specifying the LU path tasks.
         type: int
         required: false
       should_release_host_reserve:
         description: If the value is true, release the host reserve.
+          Required for the Release the host reservation status by specifying a host group
+          /Release the host reservation status by specifying the LU path tasks.
         type: bool
         required: false
       lun:
         description: LUN ID to be releases the host reservation status of the LU mapped to a specified LU path.
+          Required for the Release the host reservation status by specifying the LU path task.
         type: int
         required: false
       asymmetric_access_priority:
         description: Asymmetric access priority level for ALUA host group.
+          Required for the Asymmetric access priority level for ALUA host group task.
         type: str
         required: false
         choices: ['low', 'high']
 """
 
 EXAMPLES = """
-- name: Create host group with LUN in decimal
+- name: Create host group with LDEVs and WWNs
   hitachivantara.vspone_block.vsp.hv_hg:
     state: present
     connection_info:
@@ -201,25 +218,6 @@ EXAMPLES = """
           nick_name: 'test2'
       ldevs: [393, 851]
 
-- name: Create host group with LUN in HEX
-  hitachivantara.vspone_block.vsp.hv_hg:
-    state: present
-    connection_info:
-      address: storage1.company.com
-      username: "dummy_user"
-      password: "dummy_password"
-    host_group_info:
-      name: 'testhg26dec'
-      port: 'CL1-A'
-      host_mode: 'VMWARE_EXTENSION'
-      host_mode_options: [54, 63]
-      wwns:
-        - wwn: '200000109B3C0FD3'
-          nick_name: 'test1'
-        - wwn: '200000109B3C0FD4'
-          nick_name: 'test2'
-      ldevs: ['00:23:A4']
-
 - name: Delete host group
   hitachivantara.vspone_block.vsp.hv_hg:
     state: absent
@@ -231,7 +229,7 @@ EXAMPLES = """
       name: 'testhg26dec'
       port: 'CL1-A'
 
-- name: Present LUN
+- name: Present LDEVs to hostgroup
   hitachivantara.vspone_block.vsp.hv_hg:
     state: present
     connection_info:
@@ -242,9 +240,9 @@ EXAMPLES = """
       state: present_ldev
       name: 'testhg26dec'
       port: 'CL1-A'
-      ldevs: ['00:05:77', '00:05:7D']
+      ldevs: [300, 400]
 
-- name: Unpresent LUN
+- name: Unpresent LDEVs from hostgroup
   hitachivantara.vspone_block.vsp.hv_hg:
     state: present
     connection_info:
@@ -257,7 +255,7 @@ EXAMPLES = """
       port: 'CL1-A'
       ldevs: [800, 801]
 
-- name: Add WWN
+- name: Add WWNs to hostgroup
   hitachivantara.vspone_block.vsp.hv_hg:
     state: present
     connection_info:
@@ -274,7 +272,7 @@ EXAMPLES = """
         - wwn: '200000109B3C0FD4'
         - wwn: '200000109B3C0FD5'
 
-- name: Remove WWN
+- name: Remove WWNs from hostgroup
   hitachivantara.vspone_block.vsp.hv_hg:
     state: present
     connection_info:
@@ -314,7 +312,7 @@ EXAMPLES = """
       port: 'CL1-A'
       asymmetric_access_priority: 'high'
 
-- name: Release host reserve status of the LU mapped to a specified LU path.
+- name: Release the host reservation status by specifying the LU path.
   hitachivantara.vspone_block.vsp.hv_hg:
     state: present
     connection_info:
@@ -329,74 +327,124 @@ EXAMPLES = """
 """
 
 RETURN = """
-hostGroups:
-  description: Information of host group.
+host_group:
+  description: Detailed information about the host group on the storage system.
   returned: always
   type: dict
   contains:
     host_group_id:
-      description: ID of the host group.
+      description: ID of the host group (internal identifier used by the storage system).
       type: int
-      sample: 93
+      sample: 33
     host_group_name:
-      description: Name of the host group.
+      description: Human readable name of the host group.
       type: str
-      sample: "ansible-test-hg"
+      sample: "AutoAnsibleHurPri01"
     host_mode:
-      description: Host mode of the host group.
+      description: Configured host mode for the host group (OS type or special mode).
       type: str
-      sample: "STANDARD"
+      sample: "LINUX"
     host_mode_options:
-      description: List of host mode options for the host group.
+      description: List of host mode option identifiers currently set for the host group.
       type: list
-      elements: dict
-      contains:
-        host_mode_option:
-          description: Name of the host mode option.
-          type: str
-          sample: "EXTENDED_COPY"
-        host_mode_option_number:
-          description: Number of the host mode option.
-          type: int
-          sample: 54
+      elements: int
+      sample: []
     lun_paths:
-      description: List of LUN paths for the host group.
+      description: List of LUN path entries associated with this host group. Each entry describes an LDEV mapping and path metadata.
       type: list
       elements: dict
       contains:
-        ldevId:
-          description: ID of the logical device.
+        asymmetric_access_state:
+          description: Asymmetric access state for the path (for ALUA-capable devices).
+          type: str
+          sample: "Active/Optimized"
+        host_group_number:
+          description: Numeric host group identifier as exposed via the path.
           type: int
-          sample: 166
-        lunId:
-          description: ID of the LUN.
+          sample: 33
+        host_mode:
+          description: Host mode string reported for the path (may include extra qualifiers).
+          type: str
+          sample: "LINUX/IRIX"
+        host_mode_options:
+          description: Host mode option identifiers reported for the path.
+          type: list
+          elements: int
+          sample: []
+        is_alua_enabled:
+          description: Whether ALUA is enabled for the path.
+          type: bool
+          sample: false
+        is_command_device:
+          description: Whether the LDEV is marked as a command device.
+          type: bool
+          sample: false
+        ldev_id:
+          description: Logical device ID (decimal).
           type: int
-          sample: 0
-    port:
-      description: Port associated with the host group.
+          sample: 3694
+        ldev_id_hex:
+          description: Logical device ID formatted in hex (colon separated).
+          type: str
+          sample: "00:0E:6E"
+        lu_host_reserve:
+          description: Host reservation information for the LU path, presented as booleans for reservation types and keys.
+          type: dict
+          contains:
+            aca_reserve:
+              description: Whether ACA (Auto Contingent Allegiance) reserve is set.
+              type: bool
+              sample: false
+            mainframe:
+              description: Whether mainframe-style reserve is set.
+              type: bool
+              sample: false
+            open_system:
+              description: Whether open system (standard SCSI-based) reserve is set.
+              type: bool
+              sample: false
+            persistent:
+              description: Whether persistent reservation is active.
+              type: bool
+              sample: false
+            pgr_key:
+              description: Presence of a persistent group reservation key.
+              type: bool
+              sample: false
+        lun:
+          description: LUN number assigned to this path.
+          type: int
+          sample: 17
+        lun_id:
+          description: Identifier string for the LU path, typically combining port, hostgroup number and LUN.
+          type: str
+          sample: "CL4-B,33,17"
+        port_id:
+          description: Port identifier associated with this path entry.
+          type: str
+          sample: "CL4-B"
+    port_id:
+      description: Default or requested port associated with the host group operations (e.g., CLx-A).
       type: str
-      sample: "CL1-A"
+      sample: "CL4-B"
     resource_group_id:
-      description: Resource group ID associated with the host group.
+      description: Resource group ID associated with the host group (if applicable).
       type: int
       sample: 0
-    storage_id:
-      description: Storage ID associated with the host group.
-      type: str
-      sample: "storage-39f4eef0175c754bb90417358b0133c3"
     wwns:
-      description: List of WWNs associated with the host group.
+      description: List of WWN entries (host HBA identifiers) that belong to the host group.
       type: list
       elements: dict
       contains:
-        id:
-          description: ID of the WWN.
+        wwn:
+          description: World Wide Name string for the host HBA.
           type: str
-          sample: "1212121212121212"
-        name:
-          description: Name of the WWN.
+          sample: "100000109B583B2D"
+        nick_name:
+          description: Optional human readable nickname assigned to the WWN.
           type: str
-          sample: ""
+          sample: "app-server-1"
+      sample: []
 """
 
 from ansible.module_utils.basic import AnsibleModule
