@@ -14,6 +14,11 @@ short_description: Manages logical devices (LDEVs) on Hitachi VSP storage system
 description:
   - This module allows for the creation, modification, or deletion of logical devices (LDEVs) on Hitachi VSP storage systems.
   - It supports operations such as creating a new LDEV, updating an existing LDEV, or deleting a LDEV.
+  - To create multiple volumes/LDEVs in a single task on VSP One Block or VSP E
+      Series storage systems, use `hv_vsp_one_volume` module for faster execution.
+      See `hv_vsp_one_volume` module documentation for more information. For other
+      volume/LDEV configurations not available in `hv_vsp_one_volume` module, use
+      `hv_ldev` module.
   - For examples, go to URL
     U(https://github.com/hitachi-vantara/vspone-block-ansible/blob/main/playbooks/vsp_direct/ldev.yml)
 version_added: '3.0.0'
@@ -36,7 +41,7 @@ options:
     description: The desired state of the LDEV.
     type: str
     required: false
-    choices: ['present', 'absent']
+    choices: ['present', 'absent', 'assign_virtual_ldev']
     default: 'present'
   storage_system_info:
     description: Information about the storage system. This field is an optional field.
@@ -54,22 +59,60 @@ options:
     suboptions:
       pool_id:
         description: ID of the pool where the LDEV will be created. Options pool_id and parity_group_id are mutually exclusive.
+          Required for the Create LDEV with a specific LDEV ID
+          /Create ldev with free ID and present to NVM System
+          /Create LDEV within a range of LDEV IDs using parallel execution
+          /Create LDEV with capacity saving and data_reduction_share
+          /Configuring QoS settings for a new volume
+          /Create new volume with tiering policy
+          /Create new volume with virtual ldev tasks.
         type: int
         required: false
       parity_group:
         description: ID of the parity_group where the LDEV will be created. Options pool_id and parity_group_id are mutually exclusive.
+          Required for the Create LDEV using a parity group and auto-free LDEV ID selection task.
         type: str
         required: false
       size:
         description: Size of the LDEV. Can be specified in units such as GB, TB, or MB (e.g., '10GB', '5TB', '100MB', 200).
+          Required for the Create LDEV with a specific LDEV ID
+          /Create ldev with free ID and present to NVM System
+          /Create LDEV within a range of LDEV IDs using parallel execution
+          /Expand the size of LDEV
+          /Create LDEV using a parity group and auto-free LDEV ID selection
+          /Create LDEV using external parity group and auto free LDEV ID selection
+          /Create LDEV with capacity saving and data_reduction_share
+          /Configuring QoS settings for a new volume
+          /Create new volume with tiering policy
+          /Create new volume with virtual ldev tasks.
         type: str
         required: false
       ldev_id:
         description: ID of the LDEV (required for delete and update operations), for new it will assigned to this ldev if it's free.
-        type: int
+          Required for the Create LDEV with a specific LDEV ID
+          /Present existing volume to NVM System
+          /Expand the size of LDEV
+          /Remove host NQNs from existing volume of NVM System
+          /Delete LDEV
+          /Force delete LDEV removes the LDEV from hostgroups, iSCSI targets or NVM subsystem namespace
+          /Shredding an existing volume
+          /Shredding an existing volume before deleting
+          /Configuring QoS settings for an existing volume
+          /Assign virtual LDEV Id for a volume
+          /Unassign virtual LDEV Id for a volume
+          /Set MP blade ID of a volume
+          /Set CLPR id of a volume
+          /Reclaiming zero pages of a DP volume
+          /Format a volume
+          /Change volume settings tasks.
+        type: str
         required: false
       name:
         description: Name of the LDEV (optional). If not given, it assigns the name of the LDEV to "smrha-<ldev_id>".
+          Optional for the Create ldev with free ID and present to NVM System
+          /Create LDEV within a range of LDEV IDs using parallel execution
+          /Create LDEV using a parity group and auto-free LDEV ID selection
+          /Create LDEV using external parity group and auto free LDEV ID selection tasks.
         type: str
         required: false
       capacity_saving:
@@ -79,15 +122,23 @@ options:
           - 2. compression_deduplication - Enable the capacity saving function (compression and deduplication).
           - 3 disabled - Disable the capacity saving function (compression and deduplication)
           Default value is disabled.
+          Optional for the Create ldev with free ID and present to NVM System
+          /Create LDEV within a range of LDEV IDs using parallel execution tasks.
+          Required for the Create LDEV with capacity saving and data_reduction_share task.
         type: str
         required: false
       data_reduction_share:
         description: Specify whether to create a data reduction shared volume.
           This value is set to true for Thin Image Advance.
+          Optional for the Create ldev with free ID and present to NVM System task.
+          Required for the Create LDEV with capacity saving and data_reduction_share task.
         type: bool
         required: false
       nvm_subsystem_name:
         description: Specify whether the LDEV created will be part of an NVM subsystem.
+          Required for the Create ldev with free ID and present to NVM System
+          /Present existing volume to NVM System
+          /Remove host NQNs from existing volume of NVM System tasks.
         type: str
         required: false
       state:
@@ -95,99 +146,139 @@ options:
           - State of the NVM subsystems task. This is valid only when nvm_subsystem_name is specified.
           - C(add_host_nqn) - Add the host NQNs to the LDEV.
           - C(remove_host_nqn) - Remove the host NQNs from the LDEV.
+          - Optional for the Create ldev with free ID and present to NVM System task.
         type: str
         required: false
         choices: ['add_host_nqn', 'remove_host_nqn']
         default: 'add_host_nqn'
       host_nqns:
         description: List of host nqns to add to or remove from the LDEV depending on the state value.
+          Required for the Create ldev with free ID and present to NVM System
+          /Remove host NQNs from existing volume of NVM System tasks.
+          Optional for the Present existing volume to NVM System task.
         type: list
         required: false
         elements: str
       is_relocation_enabled:
         description: Specify whether to enable the tier relocation setting for the HDT volume.
+          Required for the Create new volume with tiering policy task.
+          Optional for the Change volume settings task.
         type: bool
         required: false
       tier_level_for_new_page_allocation:
         description: Specify which tier of the HDT pool will be prioritized when a new page is allocated.
+          Required for the Create new volume with tiering policy task.
         type: str
         required: false
       tiering_policy:
         description: Tiering policy for the LDEV.
+          Required for the Create new volume with tiering policy task.
         type: dict
         required: false
         suboptions:
           tier_level:
             description: Tier level, a value from 0 to 31.
+              Optional for the Create new volume with tiering policy task.
             type: int
             required: false
           tier1_allocation_rate_min:
             description: Tier1 min, a value from 1 to 100.
+              Optional for the Create new volume with tiering policy task.
             type: int
             required: false
           tier1_allocation_rate_max:
             description: Tier1 max, a value from 1 to 100.
+              Optional for the Create new volume with tiering policy task.
             type: int
             required: false
           tier3_allocation_rate_min:
             description: Tier3 min, a value from 1 to 100.
+              Optional for the Create new volume with tiering policy task.
             type: int
             required: false
           tier3_allocation_rate_max:
             description: Tier3 max, a value from 1 to 100.
+              Optional for the Create new volume with tiering policy task.
             type: int
             required: false
       vldev_id:
-        description: Specify the virtual LDEV id.
-        type: int
+        description: Specify the virtual LDEV id. Specify -1 if you want to unassign the vldev_id.
+          Required for the Create new volume with virtual ldev
+          /Assign virtual LDEV Id for a volume
+          /Unassign virtual LDEV Id for a volume tasks.
+        type: str
         required: false
       force:
         description: Force delete. Delete the LDEV and removes the LDEV from hostgroups, iscsi targets or NVM subsystem namespace.
+          Required for the Force delete LDEV removes the LDEV from hostgroups,
+          iSCSI targets or NVM subsystem namespace task.
         type: bool
         required: false
       should_shred_volume_enable:
         description: It shreds an LDEV (basic volume) or DP volume. Overwrites the volume three times with dummy data.
+          Required for the Shredding an existing volume
+          /Shredding an existing volume before deleting task.
         type: bool
         required: false
       qos_settings:
         description: QoS settings for the LDEV.
+          Required for the Configuring QoS settings for an existing volume
+          /Configuring QoS settings for a new volume tasks.
         type: dict
         required: false
         suboptions:
           upper_iops:
             description: Upper IOPS limit.
+              Optional for the Configuring QoS settings for an existing volume
+              /Configuring QoS settings for a new volume tasks.
             type: int
             required: false
           lower_iops:
             description: Lower IOPS limit.
+              Optional for the Configuring QoS settings for an existing volume
+              /Configuring QoS settings for a new volume tasks.
             type: int
             required: false
           upper_transfer_rate:
             description: Upper transfer rate limit.
+              Optional for the Configuring QoS settings for an existing volume
+              /Configuring QoS settings for a new volume tasks.
             type: int
             required: false
           lower_transfer_rate:
             description: Lower transfer rate limit.
+              Optional for the Configuring QoS settings for an existing volume
+              /Configuring QoS settings for a new volume tasks.
             type: int
             required: false
           upper_alert_allowable_time:
             description: Upper alert allowable time.
+              Optional for the Configuring QoS settings for an existing volume
+              /Configuring QoS settings for a new volume tasks.
             type: int
             required: false
           lower_alert_allowable_time:
             description: Lower alert allowable time.
+              Optional for the Configuring QoS settings for an existing volume
+              /Configuring QoS settings for a new volume tasks.
             type: int
             required: false
           response_priority:
             description: Response priority.
+              Optional for the Configuring QoS settings for an existing volume
+              /Configuring QoS settings for a new volume tasks.
             type: int
             required: false
           response_alert_allowable_time:
             description: Response alert allowable time.
+              Optional for the Configuring QoS settings for an existing volume
+              /Configuring QoS settings for a new volume tassk.
             type: int
             required: false
       is_compression_acceleration_enabled:
         description: Whether the compression accelerator of the capacity saving function is enabled.
+          Optional for the Create LDEV within a range of LDEV IDs using parallel execution
+          /Change volume settings tasks.
         type: bool
         required: false
       data_reduction_process_mode:
@@ -196,18 +287,22 @@ options:
           Valid values are:
           - "post_process" -  Post-process mode.
           - "inline" - Inline mode.
+          Optional for the Change volume settings task.
         choices: ["post_process", "inline"]
         type: str
       is_alua_enabled:
         description: Whether the ALUA (Asymmetric Logical Unit Access) is enabled for the LDEV.
+          Optional for the Change volume settings task.
         type: bool
         required: false
       is_full_allocation_enabled:
         description: Whether the LDEV is a full allocation volume.
+          Optional for the Change volume settings task.
         type: bool
         required: false
       should_format_volume:
         description: Whether to format the volume after creation or existing volume.
+          Required for the Format a volume task.
         type: bool
         required: false
       format_type:
@@ -215,6 +310,7 @@ options:
           The format type of the volume. Valid values are:
           - "quick" - Quick formatting.
           - "normal" - Normal formatting, It may take time to finish the formatting process.
+          Optional for the Format a volume task.
         type: str
         required: false
         choices: ["quick", "normal"]
@@ -223,42 +319,49 @@ options:
         description: >
           The starting LDEV ID for the range of LDEVs to be created. This is used when creating multiple LDEVs.
           If not specified, a free LDEV ID will be assigned.
-        type: int
+          Required for the Create LDEV within a range of LDEV IDs using parallel execution task.
+        type: str
         required: false
       end_ldev_id:
         description: >
           The ending LDEV ID for the range of LDEVs to be created. This is used when creating multiple LDEVs.
           If not specified, only one LDEV will be created.
-        type: int
+          Required for the Create LDEV within a range of LDEV IDs using parallel execution task.
+        type: str
         required: false
       mp_blade_id:
         description: >
           The MP blade ID to which the LDEV will be assigned. This is used for specifying the MP blade for the LDEV.
           If not specified, the LDEV will be assigned to the default MP blade.
+          Optional for the Set MP blade ID of a volume task.
         type: int
         required: false
       clpr_id:
         description: >
           The CLPR (Control Logical Partition) ID to which the LDEV will be assigned. This is used for specifying the CLPR for the LDEV.
           If not specified, the LDEV will be assigned to the default CLPR.
+          Required for the Set CLPR id of a volume task.
         type: int
         required: false
       should_reclaim_zero_pages:
         description: >
           Whether to reclaim zero pages of a DP volume. This is used to reclaim space in a DP volume.
           If set to true, it will reclaim the zero pages of the DP volume.
+          Required for the Reclaiming zero pages of a DP volume task.
         type: bool
         required: false
       external_parity_group:
         description: >
           The external parity group ID to which the LDEV will be assigned. This is used for specifying the external parity group for the LDEV.
           If not specified, the LDEV will be assigned to the default parity group.
+          Optional for the Create LDEV using external parity group and auto free LDEV ID selection task.
         type: str
         required: false
       is_parallel_execution_enabled:
         description: >
           Whether to enable parallel execution for the LDEV operations. This is used to speed up the LDEV operations.
           If set to true, it will enable parallel execution for the LDEV operations.
+          Required for the Create LDEV within a range of LDEV IDs using parallel execution task.
         type: bool
 """
 
@@ -385,14 +488,26 @@ EXAMPLES = """
 
 RETURN = r"""
 volume:
-  description: Storage volumes with their attributes.
+  description: Storage volume with its attributes.
   returned: success
   type: dict
   contains:
     canonical_name:
       description: Unique identifier for the volume.
       type: str
-      sample: "naa.60060e8028274200508027420000000a"
+      sample: "naa.60060e8028273d005080273d00000102"
+    clpr_id:
+      description: CLPR (Control Logical Partition) ID.
+      type: int
+      sample: 0
+    compression_acceleration_status:
+      description: Status of compression accelerator.
+      type: str
+      sample: "ENABLED"
+    data_reduction_process_mode:
+      description: Data reduction process mode.
+      type: str
+      sample: "inline"
     dedup_compression_progress:
       description: Progress percentage of deduplication and compression.
       type: int
@@ -400,19 +515,19 @@ volume:
     dedup_compression_status:
       description: Status of deduplication and compression.
       type: str
-      sample: "DISABLED"
+      sample: "ENABLED"
     deduplication_compression_mode:
       description: Mode of deduplication and compression.
       type: str
-      sample: "disabled"
+      sample: "compression_deduplication"
     emulation_type:
       description: Emulation type of the volume.
       type: str
-      sample: "OPEN-V-CVS-CM"
+      sample: "OPEN-V-CVS"
     hostgroups:
       description: List of host groups associated with the volume.
       type: list
-      elements: str
+      elements: dict
       sample: []
     is_alua:
       description: Indicates if ALUA is enabled.
@@ -421,81 +536,97 @@ volume:
     is_command_device:
       description: Indicates if the volume is a command device.
       type: bool
-      sample: false
+      sample: null
+    is_compression_acceleration_enabled:
+      description: Whether compression accelerator is enabled.
+      type: bool
+      sample: true
     is_data_reduction_share_enabled:
       description: Indicates if data reduction share is enabled.
       type: bool
-      sample: false
+      sample: true
     is_device_group_definition_enabled:
       description: Indicates if device group definition is enabled.
       type: bool
-      sample: false
+      sample: null
     is_encryption_enabled:
       description: Indicates if encryption is enabled.
       type: bool
       sample: false
+    is_full_allocation_enabled:
+      description: Indicates if full allocation is enabled.
+      type: bool
+      sample: false
+    is_relocation_enabled:
+      description: Indicates if tier relocation is enabled.
+      type: bool
+      sample: null
     is_security_enabled:
       description: Indicates if security is enabled.
       type: bool
-      sample: false
+      sample: null
     is_user_authentication_enabled:
       description: Indicates if user authentication is enabled.
       type: bool
-      sample: false
+      sample: null
     is_write_protected:
-      description: Indicates if the volume is write-protected.
+      description: Indicates if write protection is enabled.
       type: bool
-      sample: false
+      sample: null
     is_write_protected_by_key:
-      description: Indicates if the volume is write-protected by key.
+      description: Indicates if write protection by key is enabled.
       type: bool
-      sample: false
+      sample: null
     iscsi_targets:
-      description: List of associated iSCSI targets.
+      description: List of iSCSI targets associated with the volume.
       type: list
-      elements: str
+      elements: dict
       sample: []
     ldev_id:
       description: Logical Device ID.
       type: int
-      sample: 10
-    logical_unit_id_hex_format:
-      description: Logical Unit ID in hexadecimal format.
+      sample: 258
+    ldev_id_hex:
+      description: Logical Device ID in hexadecimal.
       type: str
-      sample: "00:00:0A"
+      sample: "00:01:02"
+    mp_blade_id:
+      description: MP blade ID.
+      type: int
+      sample: 0
     name:
       description: Name of the volume.
       type: str
-      sample: "snewar-cmd"
+      sample: "smrha-258"
     num_of_ports:
       description: Number of ports associated with the volume.
       type: int
-      sample: 1
+      sample: -1
     nvm_subsystems:
-      description: List of associated NVM subsystems.
+      description: List of NVMe subsystems associated with the volume.
       type: list
-      elements: str
+      elements: dict
       sample: []
     parity_group_id:
-      description: Parity group ID of the volume.
+      description: Parity group ID.
       type: str
       sample: ""
     path_count:
-      description: Number of paths to the volume.
+      description: Path count to the volume.
       type: int
-      sample: 1
+      sample: -1
     pool_id:
       description: Pool ID where the volume resides.
       type: int
-      sample: 0
+      sample: 13
     provision_type:
       description: Provisioning type of the volume.
       type: str
-      sample: "CMD,CVS,HDP"
+      sample: "CVS,HDP,DRS"
     qos_settings:
-      description: Quality of Service settings for the volume.
+      description: QoS settings for the volume.
       type: dict
-      sample: {}
+      sample: null
     resource_group_id:
       description: Resource group ID of the volume.
       type: int
@@ -503,7 +634,7 @@ volume:
     snapshots:
       description: List of snapshots associated with the volume.
       type: list
-      elements: str
+      elements: dict
       sample: []
     status:
       description: Current status of the volume.
@@ -512,31 +643,35 @@ volume:
     storage_serial_number:
       description: Serial number of the storage system.
       type: str
-      sample: "810050"
+      sample: "810045"
     tiering_policy:
-      description: Tiering policy applied to the volume.
+      description: Tiering policy details.
       type: dict
       sample: {}
     total_capacity:
       description: Total capacity of the volume.
       type: str
-      sample: "50.00MB"
+      sample: "1.00GB"
     total_capacity_in_mb:
       description: Total capacity of the volume in megabytes.
-      type: str
-      sample: "50.0 MB"
+      type: float
+      sample: 1024.0
     used_capacity:
       description: Used capacity of the volume.
       type: str
       sample: "0.00B"
     used_capacity_in_mb:
       description: Used capacity of the volume in megabytes.
-      type: str
-      sample: "0.0 MB"
+      type: float
+      sample: 0
     virtual_ldev_id:
       description: Virtual Logical Device ID.
       type: int
       sample: -1
+    virtual_ldev_id_hex:
+      description: Virtual Logical Device ID in hexadecimal.
+      type: str
+      sample: ""
 """
 
 from ansible.module_utils.basic import AnsibleModule
