@@ -1,5 +1,6 @@
-# Copyright (C) 2020 IBM CORPORATION
+# Copyright (C) 2024 IBM CORPORATION
 # Author(s): Shilpi Jain <shilpi.jain1@ibm.com>
+#            Sandip G. Rajbanshi <sandip.rajbanshi@ibm.com>
 #
 # GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
 
@@ -9,20 +10,26 @@ from __future__ import absolute_import, division, print_function
 
 __metaclass__ = type
 
+import inspect
+import uuid
 from ansible.module_utils.compat.paramiko import paramiko
 from ansible_collections.ibm.storage_virtualize.plugins.module_utils.ibm_svc_utils import get_logger
 
+COLLECTION_VERSION = "3.1.0"
+
 
 class IBMSVCssh(object):
     """ Communicate with SVC through SSH
-        The module use paramiko to connect SVC
+        The module uses paramiko to connect SVC
     """
 
-    def __init__(self, module, clustername, username, password,
+    def __init__(self, module, clustername, domain, username, password,
                  look_for_keys, key_filename, log_path):
         """ Initialize module with what we need for initial connection
         :param clustername: name of the SVC cluster
         :type clustername: string
+        :param domain: domain to create FQDN of SVC system
+        :type domain: string
         :param username: SVC username
         :type username: string
         :param password: Password for user
@@ -36,6 +43,7 @@ class IBMSVCssh(object):
         """
         self.module = module
         self.clustername = clustername
+        self.domain = domain
         self.username = username
         self.password = password
         self.look_for_keys = look_for_keys
@@ -65,13 +73,19 @@ class IBMSVCssh(object):
         """
         self.client.load_system_host_keys()
         self.client.set_missing_host_key_policy(paramiko.AutoAddPolicy())
+        self.hostname = self.clustername
+        self.log(self.domain)
+        if self.domain:
+            self.hostname = f"{self.clustername}.{self.domain}"
+        self.log(self.hostname)
         try:
             self.client.connect(
-                hostname=self.clustername,
+                hostname=self.hostname,
                 username=self.username,
                 password=self.password,
                 look_for_keys=self.look_for_keys,
                 key_filename=self.key_filename)
+            self.register_plugin()
             return True
         except paramiko.BadHostKeyException as e:
             self.log("BadHostKeyException %s", e)
@@ -98,3 +112,26 @@ class IBMSVCssh(object):
         except Exception as e:
             self.log("SSH Disconnection failed %s", e)
             return False
+
+    def register_plugin(self):
+        try:
+            cmd = 'svctask registerplugin'
+            cmdopts = {}
+            name = "Ansible"
+            unique_key = self.username + "_" + str(uuid.getnode())
+            caller_class = inspect.stack()[2].frame.f_locals.get('self', None)
+            caller_class_name = caller_class.__class__.__name__
+            module_name = str(inspect.stack()[3].filename).rsplit('/', maxsplit=1)[-1]
+            metadata = module_name[:-3] + " module with class " + str(caller_class_name) + " has been executed by " + self.username
+
+            cmdopts['name'] = name
+            cmdopts['uniquekey'] = unique_key
+            cmdopts['version'] = COLLECTION_VERSION
+            cmdopts['metadata'] = metadata
+
+            for cmdoptions in cmdopts:
+                cmd = cmd + " -" + cmdoptions + " '" + cmdopts[cmdoptions] + "'"
+            self.client.exec_command(cmd)
+            return True
+        except Exception as e:
+            return False
