@@ -15,13 +15,28 @@ from ansible.module_utils import basic
 from ansible.module_utils._text import to_bytes
 from ansible_collections.ibm.storage_virtualize.plugins.module_utils.ibm_svc_utils import IBMSVCRestApi
 from ansible_collections.ibm.storage_virtualize.plugins.modules.ibm_sv_manage_cloud_backups import IBMSVCloudBackup
+import contextlib
 
 
+@contextlib.contextmanager
 def set_module_args(args):
-    """prepare arguments so that they will be picked up during module
-    creation """
-    args = json.dumps({'ANSIBLE_MODULE_ARGS': args})
-    basic._ANSIBLE_ARGS = to_bytes(args)  # pylint: disable=protected-access
+    """
+    Context manager that sets module arguments for AnsibleModule
+    """
+    if '_ansible_remote_tmp' not in args:
+        args['_ansible_remote_tmp'] = '/tmp'
+    if '_ansible_keep_remote_files' not in args:
+        args['_ansible_keep_remote_files'] = False
+
+    try:
+        from ansible.module_utils.testing import patch_module_args
+        with patch_module_args(args):
+            yield
+    except ImportError:
+        from ansible.module_utils import basic
+        serialized_args = to_bytes(json.dumps({'ANSIBLE_MODULE_ARGS': args}))
+        with patch.object(basic, '_ANSIBLE_ARGS', serialized_args):
+            yield
 
 
 class AnsibleExitJson(Exception):
@@ -69,20 +84,19 @@ class TestIBMSVCloudBackup(unittest.TestCase):
                                      False, 'test.log', '')
 
     def test_missing_state_parameter(self):
-        set_module_args({
+        with set_module_args({
             'clustername': 'clustername',
             'domain': 'domain',
             'username': 'username',
             'password': 'password',
             'volume_name': 'vol1'
-        })
-
-        with pytest.raises(AnsibleFailJson) as exc:
-            IBMSVCloudBackup()
-        self.assertTrue(exc.value.args[0]['failed'])
+        }):
+            with pytest.raises(AnsibleFailJson) as exc:
+                IBMSVCloudBackup()
+            self.assertTrue(exc.value.args[0]['failed'])
 
     def test_mutually_exclusive_parameters_1(self):
-        set_module_args({
+        with set_module_args({
             'clustername': 'clustername',
             'domain': 'domain',
             'username': 'username',
@@ -90,14 +104,13 @@ class TestIBMSVCloudBackup(unittest.TestCase):
             'volume_name': 'vol1',
             'volumegroup_name': 'VG1',
             'state': 'present'
-        })
-
-        with pytest.raises(AnsibleFailJson) as exc:
-            IBMSVCloudBackup()
-        self.assertTrue(exc.value.args[0]['failed'])
+        }):
+            with pytest.raises(AnsibleFailJson) as exc:
+                IBMSVCloudBackup()
+            self.assertTrue(exc.value.args[0]['failed'])
 
     def test_mutually_exclusive_parameters_2(self):
-        set_module_args({
+        with set_module_args({
             'clustername': 'clustername',
             'domain': 'domain',
             'username': 'username',
@@ -105,14 +118,13 @@ class TestIBMSVCloudBackup(unittest.TestCase):
             'volume_name': 'vol1',
             'volume_UID': '8320948320948',
             'state': 'absent'
-        })
-
-        with pytest.raises(AnsibleFailJson) as exc:
-            IBMSVCloudBackup()
-        self.assertTrue(exc.value.args[0]['failed'])
+        }):
+            with pytest.raises(AnsibleFailJson) as exc:
+                IBMSVCloudBackup()
+            self.assertTrue(exc.value.args[0]['failed'])
 
     def test_mutually_exclusive_parameters_3(self):
-        set_module_args({
+        with set_module_args({
             'clustername': 'clustername',
             'domain': 'domain',
             'username': 'username',
@@ -121,28 +133,26 @@ class TestIBMSVCloudBackup(unittest.TestCase):
             'all': True,
             'generation': 1,
             'state': 'absent'
-        })
-
-        with pytest.raises(AnsibleFailJson) as exc:
-            IBMSVCloudBackup()
-        self.assertTrue(exc.value.args[0]['failed'])
+        }):
+            with pytest.raises(AnsibleFailJson) as exc:
+                IBMSVCloudBackup()
+            self.assertTrue(exc.value.args[0]['failed'])
 
     def test_invalid_parameters_delete_1(self):
-        set_module_args({
+        with set_module_args({
             'clustername': 'clustername',
             'domain': 'domain',
             'username': 'username',
             'password': 'password',
             'volumegroup_name': 'VG1',
             'state': 'absent'
-        })
-
-        with pytest.raises(AnsibleFailJson) as exc:
-            IBMSVCloudBackup()
-        self.assertTrue(exc.value.args[0]['failed'])
+        }):
+            with pytest.raises(AnsibleFailJson) as exc:
+                IBMSVCloudBackup()
+            self.assertTrue(exc.value.args[0]['failed'])
 
     def test_invalid_parameters_delete_2(self):
-        set_module_args({
+        with set_module_args({
             'clustername': 'clustername',
             'domain': 'domain',
             'username': 'username',
@@ -150,11 +160,10 @@ class TestIBMSVCloudBackup(unittest.TestCase):
             'volume_name': 'vol1',
             'full': True,
             'state': 'absent'
-        })
-
-        with pytest.raises(AnsibleFailJson) as exc:
-            IBMSVCloudBackup()
-        self.assertTrue(exc.value.args[0]['failed'])
+        }):
+            with pytest.raises(AnsibleFailJson) as exc:
+                IBMSVCloudBackup()
+            self.assertTrue(exc.value.args[0]['failed'])
 
     @patch('ansible_collections.ibm.storage_virtualize.plugins.module_utils.'
            'ibm_svc_utils.IBMSVCRestApi.svc_run_command')
@@ -165,7 +174,7 @@ class TestIBMSVCloudBackup(unittest.TestCase):
     def test_with_invalid_create_parameters(self, svc_authorize_mock,
                                             svc_obj_info_mock,
                                             svc_run_command_mock):
-        set_module_args({
+        with set_module_args({
             'clustername': 'clustername',
             'domain': 'domain',
             'username': 'username',
@@ -174,13 +183,12 @@ class TestIBMSVCloudBackup(unittest.TestCase):
             'volume_UID': '230984093284032984',
             'generation': 1,
             'state': 'present'
-        })
-
-        svc_obj_info_mock.return_value = {'id': 1, 'name': 'vol1'}
-        with pytest.raises(AnsibleFailJson) as exc:
-            aws = IBMSVCloudBackup()
-            aws.apply()
-        self.assertTrue(exc.value.args[0]['failed'])
+        }):
+            svc_obj_info_mock.return_value = {'id': 1, 'name': 'vol1'}
+            with pytest.raises(AnsibleFailJson) as exc:
+                aws = IBMSVCloudBackup()
+                aws.apply()
+            self.assertTrue(exc.value.args[0]['failed'])
 
     @patch('ansible_collections.ibm.storage_virtualize.plugins.module_utils.'
            'ibm_svc_utils.IBMSVCRestApi._svc_token_wrap')
@@ -191,22 +199,21 @@ class TestIBMSVCloudBackup(unittest.TestCase):
     def test_create_cloud_backup_volume(self, svc_authorize_mock,
                                         svc_obj_info_mock,
                                         svc_token_wrap_mock):
-        set_module_args({
+        with set_module_args({
             'clustername': 'clustername',
             'domain': 'domain',
             'username': 'username',
             'password': 'password',
             'volume_name': 'vol1',
             'state': 'present'
-        })
+        }):
+            aws = IBMSVCloudBackup()
+            svc_obj_info_mock.return_value = {'id': 1, 'name': 'vol1'}
+            svc_token_wrap_mock.return_value = {'out': None}
 
-        aws = IBMSVCloudBackup()
-        svc_obj_info_mock.return_value = {'id': 1, 'name': 'vol1'}
-        svc_token_wrap_mock.return_value = {'out': None}
-
-        with pytest.raises(AnsibleExitJson) as exc:
-            aws.apply()
-        self.assertTrue(exc.value.args[0]['changed'])
+            with pytest.raises(AnsibleExitJson) as exc:
+                aws.apply()
+            self.assertTrue(exc.value.args[0]['changed'])
 
     @patch('ansible_collections.ibm.storage_virtualize.plugins.module_utils.'
            'ibm_svc_utils.IBMSVCRestApi._svc_token_wrap')
@@ -217,22 +224,21 @@ class TestIBMSVCloudBackup(unittest.TestCase):
     def test_create_cloud_backup_volume_idempotency(self, svc_authorize_mock,
                                                     svc_obj_info_mock,
                                                     svc_token_wrap_mock):
-        set_module_args({
+        with set_module_args({
             'clustername': 'clustername',
             'domain': 'domain',
             'username': 'username',
             'password': 'password',
             'volume_name': 'vol1',
             'state': 'present'
-        })
+        }):
+            aws = IBMSVCloudBackup()
+            svc_obj_info_mock.return_value = {'id': 1, 'name': 'vol1'}
+            svc_token_wrap_mock.return_value = {'out': b'CMMVC9083E'}
 
-        aws = IBMSVCloudBackup()
-        svc_obj_info_mock.return_value = {'id': 1, 'name': 'vol1'}
-        svc_token_wrap_mock.return_value = {'out': b'CMMVC9083E'}
-
-        with pytest.raises(AnsibleExitJson) as exc:
-            aws.apply()
-        self.assertFalse(exc.value.args[0]['changed'])
+            with pytest.raises(AnsibleExitJson) as exc:
+                aws.apply()
+            self.assertFalse(exc.value.args[0]['changed'])
 
     @patch('ansible_collections.ibm.storage_virtualize.plugins.module_utils.'
            'ibm_svc_utils.IBMSVCRestApi._svc_token_wrap')
@@ -243,21 +249,20 @@ class TestIBMSVCloudBackup(unittest.TestCase):
     def test_create_cloud_backup_with_invalid_volume(self, svc_authorize_mock,
                                                      svc_obj_info_mock,
                                                      svc_token_wrap_mock):
-        set_module_args({
+        with set_module_args({
             'clustername': 'clustername',
             'domain': 'domain',
             'username': 'username',
             'password': 'password',
             'volume_name': 'vol1',
             'state': 'present'
-        })
+        }):
+            aws = IBMSVCloudBackup()
+            svc_obj_info_mock.return_value = {}
 
-        aws = IBMSVCloudBackup()
-        svc_obj_info_mock.return_value = {}
-
-        with pytest.raises(AnsibleFailJson) as exc:
-            aws.apply()
-        self.assertTrue(exc.value.args[0]['failed'])
+            with pytest.raises(AnsibleFailJson) as exc:
+                aws.apply()
+            self.assertTrue(exc.value.args[0]['failed'])
 
     @patch('ansible_collections.ibm.storage_virtualize.plugins.module_utils.'
            'ibm_svc_utils.IBMSVCRestApi._svc_token_wrap')
@@ -268,22 +273,21 @@ class TestIBMSVCloudBackup(unittest.TestCase):
     def test_create_cloud_backup_volumegroup(self, svc_authorize_mock,
                                              svc_obj_info_mock,
                                              svc_token_wrap_mock):
-        set_module_args({
+        with set_module_args({
             'clustername': 'clustername',
             'domain': 'domain',
             'username': 'username',
             'password': 'password',
             'volumegroup_name': 'VG1',
             'state': 'present'
-        })
+        }):
+            aws = IBMSVCloudBackup()
+            svc_obj_info_mock.return_value = {'id': 1, 'name': 'VG1'}
+            svc_token_wrap_mock.return_value = {'out': None}
 
-        aws = IBMSVCloudBackup()
-        svc_obj_info_mock.return_value = {'id': 1, 'name': 'VG1'}
-        svc_token_wrap_mock.return_value = {'out': None}
-
-        with pytest.raises(AnsibleExitJson) as exc:
-            aws.apply()
-        self.assertTrue(exc.value.args[0]['changed'])
+            with pytest.raises(AnsibleExitJson) as exc:
+                aws.apply()
+            self.assertTrue(exc.value.args[0]['changed'])
 
     @patch('ansible_collections.ibm.storage_virtualize.plugins.module_utils.'
            'ibm_svc_utils.IBMSVCRestApi._svc_token_wrap')
@@ -294,22 +298,21 @@ class TestIBMSVCloudBackup(unittest.TestCase):
     def test_create_cloud_backup_volumegroup_idempotency(self, svc_authorize_mock,
                                                          svc_obj_info_mock,
                                                          svc_token_wrap_mock):
-        set_module_args({
+        with set_module_args({
             'clustername': 'clustername',
             'domain': 'domain',
             'username': 'username',
             'password': 'password',
             'volumegroup_name': 'VG1',
             'state': 'present'
-        })
+        }):
+            aws = IBMSVCloudBackup()
+            svc_obj_info_mock.return_value = {'id': 1, 'name': 'VG1'}
+            svc_token_wrap_mock.return_value = {'out': b'CMMVC9083E'}
 
-        aws = IBMSVCloudBackup()
-        svc_obj_info_mock.return_value = {'id': 1, 'name': 'VG1'}
-        svc_token_wrap_mock.return_value = {'out': b'CMMVC9083E'}
-
-        with pytest.raises(AnsibleExitJson) as exc:
-            aws.apply()
-        self.assertFalse(exc.value.args[0]['changed'])
+            with pytest.raises(AnsibleExitJson) as exc:
+                aws.apply()
+            self.assertFalse(exc.value.args[0]['changed'])
 
     @patch('ansible_collections.ibm.storage_virtualize.plugins.module_utils.'
            'ibm_svc_utils.IBMSVCRestApi._svc_token_wrap')
@@ -320,21 +323,20 @@ class TestIBMSVCloudBackup(unittest.TestCase):
     def test_create_cloud_backup_with_invalid_volumegroup(self, svc_authorize_mock,
                                                           svc_obj_info_mock,
                                                           svc_token_wrap_mock):
-        set_module_args({
+        with set_module_args({
             'clustername': 'clustername',
             'domain': 'domain',
             'username': 'username',
             'password': 'password',
             'volumegroup_name': 'VG1',
             'state': 'present'
-        })
+        }):
+            aws = IBMSVCloudBackup()
+            svc_obj_info_mock.return_value = {}
 
-        aws = IBMSVCloudBackup()
-        svc_obj_info_mock.return_value = {}
-
-        with pytest.raises(AnsibleFailJson) as exc:
-            aws.apply()
-        self.assertTrue(exc.value.args[0]['failed'])
+            with pytest.raises(AnsibleFailJson) as exc:
+                aws.apply()
+            self.assertTrue(exc.value.args[0]['failed'])
 
     @patch('ansible_collections.ibm.storage_virtualize.plugins.module_utils.'
            'ibm_svc_utils.IBMSVCRestApi.svc_run_command')
@@ -345,7 +347,7 @@ class TestIBMSVCloudBackup(unittest.TestCase):
     def test_delete_cloud_backup_with_volume_name(self, svc_authorize_mock,
                                                   svc_obj_info_mock,
                                                   svc_run_command_mock):
-        set_module_args({
+        with set_module_args({
             'clustername': 'clustername',
             'domain': 'domain',
             'username': 'username',
@@ -353,14 +355,13 @@ class TestIBMSVCloudBackup(unittest.TestCase):
             'volume_name': 'vol1',
             'generation': 1,
             'state': 'absent'
-        })
+        }):
+            aws = IBMSVCloudBackup()
+            svc_obj_info_mock.return_value = {'id': 1, 'name': 'vol1'}
 
-        aws = IBMSVCloudBackup()
-        svc_obj_info_mock.return_value = {'id': 1, 'name': 'vol1'}
-
-        with pytest.raises(AnsibleExitJson) as exc:
-            aws.apply()
-        self.assertTrue(exc.value.args[0]['changed'])
+            with pytest.raises(AnsibleExitJson) as exc:
+                aws.apply()
+            self.assertTrue(exc.value.args[0]['changed'])
 
     @patch('ansible_collections.ibm.storage_virtualize.plugins.module_utils.'
            'ibm_svc_utils.IBMSVCRestApi.svc_run_command')
@@ -371,7 +372,7 @@ class TestIBMSVCloudBackup(unittest.TestCase):
     def test_delete_cloud_backup_with_volume_name_idempotency(self, svc_authorize_mock,
                                                               svc_obj_info_mock,
                                                               svc_run_command_mock):
-        set_module_args({
+        with set_module_args({
             'clustername': 'clustername',
             'domain': 'domain',
             'username': 'username',
@@ -379,14 +380,13 @@ class TestIBMSVCloudBackup(unittest.TestCase):
             'volume_name': 'vol1',
             'generation': 1,
             'state': 'absent'
-        })
+        }):
+            aws = IBMSVCloudBackup()
+            svc_obj_info_mock.return_value = {}
 
-        aws = IBMSVCloudBackup()
-        svc_obj_info_mock.return_value = {}
-
-        with pytest.raises(AnsibleExitJson) as exc:
-            aws.apply()
-        self.assertFalse(exc.value.args[0]['changed'])
+            with pytest.raises(AnsibleExitJson) as exc:
+                aws.apply()
+            self.assertFalse(exc.value.args[0]['changed'])
 
     @patch('ansible_collections.ibm.storage_virtualize.plugins.module_utils.'
            'ibm_svc_utils.IBMSVCRestApi.svc_run_command')
@@ -397,7 +397,7 @@ class TestIBMSVCloudBackup(unittest.TestCase):
     def test_delete_cloud_backup_with_uid(self, svc_authorize_mock,
                                           svc_obj_info_mock,
                                           svc_run_command_mock):
-        set_module_args({
+        with set_module_args({
             'clustername': 'clustername',
             'domain': 'domain',
             'username': 'username',
@@ -405,14 +405,13 @@ class TestIBMSVCloudBackup(unittest.TestCase):
             'volume_UID': '3280948320948',
             'all': True,
             'state': 'absent'
-        })
+        }):
+            aws = IBMSVCloudBackup()
+            svc_obj_info_mock.return_value = {'id': 1, 'name': 'vol1'}
 
-        aws = IBMSVCloudBackup()
-        svc_obj_info_mock.return_value = {'id': 1, 'name': 'vol1'}
-
-        with pytest.raises(AnsibleExitJson) as exc:
-            aws.apply()
-        self.assertTrue(exc.value.args[0]['changed'])
+            with pytest.raises(AnsibleExitJson) as exc:
+                aws.apply()
+            self.assertTrue(exc.value.args[0]['changed'])
 
     @patch('ansible_collections.ibm.storage_virtualize.plugins.module_utils.'
            'ibm_svc_utils.IBMSVCRestApi.svc_run_command')
@@ -423,7 +422,7 @@ class TestIBMSVCloudBackup(unittest.TestCase):
     def test_delete_cloud_backup_with_uid_idempotency(self, svc_authorize_mock,
                                                       svc_obj_info_mock,
                                                       svc_run_command_mock):
-        set_module_args({
+        with set_module_args({
             'clustername': 'clustername',
             'domain': 'domain',
             'username': 'username',
@@ -431,14 +430,13 @@ class TestIBMSVCloudBackup(unittest.TestCase):
             'volume_UID': '3280948320948',
             'all': True,
             'state': 'absent'
-        })
+        }):
+            aws = IBMSVCloudBackup()
+            svc_obj_info_mock.return_value = {}
 
-        aws = IBMSVCloudBackup()
-        svc_obj_info_mock.return_value = {}
-
-        with pytest.raises(AnsibleExitJson) as exc:
-            aws.apply()
-        self.assertFalse(exc.value.args[0]['changed'])
+            with pytest.raises(AnsibleExitJson) as exc:
+                aws.apply()
+            self.assertFalse(exc.value.args[0]['changed'])
 
 
 if __name__ == '__main__':
