@@ -16,13 +16,28 @@ from ansible.module_utils import basic
 from ansible.module_utils._text import to_bytes
 from ansible_collections.ibm.storage_virtualize.plugins.module_utils.ibm_svc_utils import IBMSVCRestApi
 from ansible_collections.ibm.storage_virtualize.plugins.modules.ibm_svc_manage_user import IBMSVCUser
+import contextlib
 
 
+@contextlib.contextmanager
 def set_module_args(args):
-    """prepare arguments so that they will be picked up during module
-    creation """
-    args = json.dumps({'ANSIBLE_MODULE_ARGS': args})
-    basic._ANSIBLE_ARGS = to_bytes(args)  # pylint: disable=protected-access
+    """
+    Context manager that sets module arguments for AnsibleModule
+    """
+    if '_ansible_remote_tmp' not in args:
+        args['_ansible_remote_tmp'] = '/tmp'
+    if '_ansible_keep_remote_files' not in args:
+        args['_ansible_keep_remote_files'] = False
+
+    try:
+        from ansible.module_utils.testing import patch_module_args
+        with patch_module_args(args):
+            yield
+    except ImportError:
+        from ansible.module_utils import basic
+        serialized_args = to_bytes(json.dumps({'ANSIBLE_MODULE_ARGS': args}))
+        with patch.object(basic, '_ANSIBLE_ARGS', serialized_args):
+            yield
 
 
 class AnsibleExitJson(Exception):
@@ -75,17 +90,17 @@ class TestIBMSVCUser(unittest.TestCase):
 
     def test_module_fail_when_required_args_missing(self):
         """ required arguments are reported as errors """
-        with pytest.raises(AnsibleFailJson) as exc:
-            set_module_args({})
-            IBMSVCUser()
-        print('Info: %s' % exc.value.args[0]['msg'])
+        with set_module_args({}):
+            with pytest.raises(AnsibleFailJson) as exc:
+                IBMSVCUser()
+            print('Info: %s' % exc.value.args[0]['msg'])
 
     @patch('ansible_collections.ibm.storage_virtualize.plugins.module_utils.'
            'ibm_svc_utils.IBMSVCRestApi.svc_obj_info')
     @patch('ansible_collections.ibm.storage_virtualize.plugins.module_utils.'
            'ibm_svc_utils.IBMSVCRestApi._svc_authorize')
     def test_get_existing_user(self, mock_svc_authorize, svc_obj_info_mock):
-        set_module_args({
+        with set_module_args({
             'clustername': 'clustername',
             'domain': 'domain',
             'username': 'username',
@@ -95,30 +110,30 @@ class TestIBMSVCUser(unittest.TestCase):
             'user_password': 'Test@123',
             'auth_type': 'usergrp',
             'usergroup': 'Service',
-        })
-        svc_obj_info_mock.return_value = {
-            "id": "3",
-            "name": "userx",
-            "password": "yes",
-            "ssh_key": "no",
-            "remote": "no",
-            "usergrp_id": "3",
-            "usergrp_name": "Service",
-            "owner_id": "",
-            "owner_name": "",
-            "locked": "no",
-            "locked_until": "",
-            "password_expiry_time": "",
-            "password_change_required": "no"
-        }
-        ug = IBMSVCUser()
-        data = ug.get_existing_user()
-        self.assertEqual(data["name"], "userx")
+        }):
+            svc_obj_info_mock.return_value = {
+                "id": "3",
+                "name": "userx",
+                "password": "yes",
+                "ssh_key": "no",
+                "remote": "no",
+                "usergrp_id": "3",
+                "usergrp_name": "Service",
+                "owner_id": "",
+                "owner_name": "",
+                "locked": "no",
+                "locked_until": "",
+                "password_expiry_time": "",
+                "password_change_required": "no"
+            }
+            ug = IBMSVCUser()
+            data = ug.get_existing_user()
+            self.assertEqual(data["name"], "userx")
 
     @patch('ansible_collections.ibm.storage_virtualize.plugins.module_utils.'
            'ibm_svc_utils.IBMSVCRestApi._svc_authorize')
     def test_basic_checks(self, mock_svc_authorize):
-        set_module_args({
+        with set_module_args({
             'clustername': 'clustername',
             'domain': 'domain',
             'username': 'username',
@@ -128,17 +143,17 @@ class TestIBMSVCUser(unittest.TestCase):
             'user_password': 'Test@123',
             'auth_type': 'usergrp',
             'usergroup': 'Service',
-        })
-        ug = IBMSVCUser()
-        data = ug.basic_checks()
-        self.assertEqual(data, None)
+        }):
+            ug = IBMSVCUser()
+            data = ug.basic_checks()
+            self.assertEqual(data, None)
 
     @patch('ansible_collections.ibm.storage_virtualize.plugins.module_utils.'
            'ibm_svc_utils.IBMSVCRestApi.svc_obj_info')
     @patch('ansible_collections.ibm.storage_virtualize.plugins.module_utils.'
            'ibm_svc_utils.IBMSVCRestApi._svc_authorize')
     def test_get_existing_user(self, mock_svc_authorize, svc_obj_info_mock):
-        set_module_args({
+        with set_module_args({
             'clustername': 'clustername',
             'domain': 'domain',
             'username': 'username',
@@ -148,32 +163,32 @@ class TestIBMSVCUser(unittest.TestCase):
             'user_password': 'Test@123',
             'auth_type': 'usergrp',
             'usergroup': 'Service',
-        })
-        svc_obj_info_mock.return_value = {
-            "id": "3",
-            "name": "userx",
-            "password": "yes",
-            "ssh_key": "no",
-            "remote": "no",
-            "usergrp_id": "3",
-            "usergrp_name": "Service",
-            "owner_id": "",
-            "owner_name": "",
-            "locked": "no",
-            "locked_until": "",
-            "password_expiry_time": "",
-            "password_change_required": "no"
-        }
-        ug = IBMSVCUser()
-        data = ug.get_existing_user()
-        self.assertEqual(data["name"], "userx")
+        }):
+            svc_obj_info_mock.return_value = {
+                "id": "3",
+                "name": "userx",
+                "password": "yes",
+                "ssh_key": "no",
+                "remote": "no",
+                "usergrp_id": "3",
+                "usergrp_name": "Service",
+                "owner_id": "",
+                "owner_name": "",
+                "locked": "no",
+                "locked_until": "",
+                "password_expiry_time": "",
+                "password_change_required": "no"
+            }
+            ug = IBMSVCUser()
+            data = ug.get_existing_user()
+            self.assertEqual(data["name"], "userx")
 
     @patch('ansible_collections.ibm.storage_virtualize.plugins.module_utils.'
            'ibm_svc_utils.IBMSVCRestApi.svc_run_command')
     @patch('ansible_collections.ibm.storage_virtualize.plugins.module_utils.'
            'ibm_svc_utils.IBMSVCRestApi._svc_authorize')
     def test_create_user(self, mock_svc_authorize, svc_run_command_mock):
-        set_module_args({
+        with set_module_args({
             'clustername': 'clustername',
             'domain': 'domain',
             'username': 'username',
@@ -183,19 +198,19 @@ class TestIBMSVCUser(unittest.TestCase):
             'user_password': 'Test@123',
             'auth_type': 'usergrp',
             'usergroup': 'Service',
-        })
-        svc_run_command_mock.return_value = {
-            'id': '3',
-            'message': 'User, id [3], successfully created'
-        }
-        ug = IBMSVCUser()
-        data = ug.create_user()
-        self.assertEqual(data, None)
+        }):
+            svc_run_command_mock.return_value = {
+                'id': '3',
+                'message': 'User, id [3], successfully created'
+            }
+            ug = IBMSVCUser()
+            data = ug.create_user()
+            self.assertEqual(data, None)
 
     @patch('ansible_collections.ibm.storage_virtualize.plugins.module_utils.'
            'ibm_svc_utils.IBMSVCRestApi._svc_authorize')
     def test_probe_user(self, mock_svc_authorize):
-        set_module_args({
+        with set_module_args({
             'clustername': 'clustername',
             'domain': 'domain',
             'username': 'username',
@@ -205,32 +220,32 @@ class TestIBMSVCUser(unittest.TestCase):
             'user_password': 'Test@123',
             'auth_type': 'usergrp',
             'usergroup': 'Monitor',
-        })
-        data = {
-            "id": "3",
-            "name": "userx",
-            "password": "yes",
-            "ssh_key": "no",
-            "remote": "no",
-            "usergrp_id": "3",
-            "usergrp_name": "Service",
-            "owner_id": "",
-            "owner_name": "",
-            "locked": "no",
-            "locked_until": "",
-            "password_expiry_time": "",
-            "password_change_required": "no"
-        }
-        ug = IBMSVCUser()
-        result = ug.probe_user(data)
-        self.assertEqual(result['usergrp'], 'Monitor')
+        }):
+            data = {
+                "id": "3",
+                "name": "userx",
+                "password": "yes",
+                "ssh_key": "no",
+                "remote": "no",
+                "usergrp_id": "3",
+                "usergrp_name": "Service",
+                "owner_id": "",
+                "owner_name": "",
+                "locked": "no",
+                "locked_until": "",
+                "password_expiry_time": "",
+                "password_change_required": "no"
+            }
+            ug = IBMSVCUser()
+            result = ug.probe_user(data)
+            self.assertEqual(result['usergrp'], 'Monitor')
 
     @patch('ansible_collections.ibm.storage_virtualize.plugins.module_utils.'
            'ibm_svc_utils.IBMSVCRestApi.svc_run_command')
     @patch('ansible_collections.ibm.storage_virtualize.plugins.module_utils.'
            'ibm_svc_utils.IBMSVCRestApi._svc_authorize')
     def test_update_user(self, mock_svc_authorize, svc_run_command_mock):
-        set_module_args({
+        with set_module_args({
             'clustername': 'clustername',
             'domain': 'domain',
             'username': 'username',
@@ -240,33 +255,33 @@ class TestIBMSVCUser(unittest.TestCase):
             'user_password': 'Test@123',
             'auth_type': 'usergrp',
             'usergroup': 'Monitor',
-        })
-        data = {
-            'usergrp': 'Monitor',
-            'password': 'Test@123'
-        }
-        svc_run_command_mock.return_value = None
-        ug = IBMSVCUser()
-        result = ug.update_user(data)
-        self.assertEqual(result, None)
+        }):
+            data = {
+                'usergrp': 'Monitor',
+                'password': 'Test@123'
+            }
+            svc_run_command_mock.return_value = None
+            ug = IBMSVCUser()
+            result = ug.update_user(data)
+            self.assertEqual(result, None)
 
     @patch('ansible_collections.ibm.storage_virtualize.plugins.module_utils.'
            'ibm_svc_utils.IBMSVCRestApi.svc_run_command')
     @patch('ansible_collections.ibm.storage_virtualize.plugins.module_utils.'
            'ibm_svc_utils.IBMSVCRestApi._svc_authorize')
     def test_remove_user(self, mock_svc_authorize, svc_run_command_mock):
-        set_module_args({
+        with set_module_args({
             'clustername': 'clustername',
             'domain': 'domain',
             'username': 'username',
             'password': 'password',
             'state': 'absent',
             'name': 'userx',
-        })
-        svc_run_command_mock.return_value = None
-        ug = IBMSVCUser()
-        result = ug.remove_user()
-        self.assertEqual(result, None)
+        }):
+            svc_run_command_mock.return_value = None
+            ug = IBMSVCUser()
+            result = ug.remove_user()
+            self.assertEqual(result, None)
 
     @patch('ansible_collections.ibm.storage_virtualize.plugins.module_utils.'
            'ibm_svc_utils.IBMSVCRestApi.svc_run_command')
@@ -275,7 +290,7 @@ class TestIBMSVCUser(unittest.TestCase):
     @patch('ansible_collections.ibm.storage_virtualize.plugins.module_utils.'
            'ibm_svc_utils.IBMSVCRestApi._svc_authorize')
     def test_creating_new_user(self, mock_svc_authorize, mock_soi, mock_src):
-        set_module_args({
+        with set_module_args({
             'clustername': 'clustername',
             'domain': 'domain',
             'username': 'username',
@@ -284,23 +299,23 @@ class TestIBMSVCUser(unittest.TestCase):
             'name': 'userx',
             'user_password': 'userx@123',
             'usergroup': 'Monitor'
-        })
-        mock_soi.return_value = {}
-        mock_src.return_value = {
-            'id': '3',
-            'message': 'User, id [3], successfully created'
-        }
-        with pytest.raises(AnsibleExitJson) as exc:
-            ug = IBMSVCUser()
-            ug.apply()
-            self.assertTrue(exc.value.args[0]['changed'])
+        }):
+            mock_soi.return_value = {}
+            mock_src.return_value = {
+                'id': '3',
+                'message': 'User, id [3], successfully created'
+            }
+            with pytest.raises(AnsibleExitJson) as exc:
+                ug = IBMSVCUser()
+                ug.apply()
+                self.assertTrue(exc.value.args[0]['changed'])
 
     @patch('ansible_collections.ibm.storage_virtualize.plugins.module_utils.'
            'ibm_svc_utils.IBMSVCRestApi.svc_obj_info')
     @patch('ansible_collections.ibm.storage_virtualize.plugins.module_utils.'
            'ibm_svc_utils.IBMSVCRestApi._svc_authorize')
     def test_creating_existing_user(self, mock_svc_authorize, mock_soi):
-        set_module_args({
+        with set_module_args({
             'clustername': 'clustername',
             'domain': 'domain',
             'username': 'username',
@@ -308,26 +323,26 @@ class TestIBMSVCUser(unittest.TestCase):
             'state': 'present',
             'name': 'userx',
             'usergroup': 'Service'
-        })
-        mock_soi.return_value = {
-            "id": "3",
-            "name": "userx",
-            "password": "yes",
-            "ssh_key": "no",
-            "remote": "no",
-            "usergrp_id": "3",
-            "usergrp_name": "Service",
-            "owner_id": "",
-            "owner_name": "",
-            "locked": "no",
-            "locked_until": "",
-            "password_expiry_time": "",
-            "password_change_required": "no"
-        }
-        with pytest.raises(AnsibleExitJson) as exc:
-            ug = IBMSVCUser()
-            ug.apply()
-            self.assertFalse(exc.value.args[0]['changed'])
+        }):
+            mock_soi.return_value = {
+                "id": "3",
+                "name": "userx",
+                "password": "yes",
+                "ssh_key": "no",
+                "remote": "no",
+                "usergrp_id": "3",
+                "usergrp_name": "Service",
+                "owner_id": "",
+                "owner_name": "",
+                "locked": "no",
+                "locked_until": "",
+                "password_expiry_time": "",
+                "password_change_required": "no"
+            }
+            with pytest.raises(AnsibleExitJson) as exc:
+                ug = IBMSVCUser()
+                ug.apply()
+                self.assertFalse(exc.value.args[0]['changed'])
 
     @patch('ansible_collections.ibm.storage_virtualize.plugins.module_utils.'
            'ibm_svc_utils.IBMSVCRestApi.svc_run_command')
@@ -336,7 +351,7 @@ class TestIBMSVCUser(unittest.TestCase):
     @patch('ansible_collections.ibm.storage_virtualize.plugins.module_utils.'
            'ibm_svc_utils.IBMSVCRestApi._svc_authorize')
     def test_updating_user(self, mock_svc_authorize, mock_soi, mock_src):
-        set_module_args({
+        with set_module_args({
             'clustername': 'clustername',
             'domain': 'domain',
             'username': 'username',
@@ -346,27 +361,27 @@ class TestIBMSVCUser(unittest.TestCase):
             'usergroup': 'Monitor',
             'lock': True,
             'forcepasswordchange': True
-        })
-        mock_soi.return_value = {
-            "id": "3",
-            "name": "userx",
-            "password": "yes",
-            "ssh_key": "no",
-            "remote": "no",
-            "usergrp_id": "3",
-            "usergrp_name": "Service",
-            "owner_id": "",
-            "owner_name": "",
-            "locked": "no",
-            "locked_until": "",
-            "password_expiry_time": "",
-            "password_change_required": "no"
-        }
-        mock_src.return_value = None
-        with pytest.raises(AnsibleExitJson) as exc:
-            ug = IBMSVCUser()
-            ug.apply()
-            self.assertTrue(exc.value.args[0]['changed'])
+        }):
+            mock_soi.return_value = {
+                "id": "3",
+                "name": "userx",
+                "password": "yes",
+                "ssh_key": "no",
+                "remote": "no",
+                "usergrp_id": "3",
+                "usergrp_name": "Service",
+                "owner_id": "",
+                "owner_name": "",
+                "locked": "no",
+                "locked_until": "",
+                "password_expiry_time": "",
+                "password_change_required": "no"
+            }
+            mock_src.return_value = None
+            with pytest.raises(AnsibleExitJson) as exc:
+                ug = IBMSVCUser()
+                ug.apply()
+                self.assertTrue(exc.value.args[0]['changed'])
 
     @patch('ansible_collections.ibm.storage_virtualize.plugins.module_utils.'
            'ibm_svc_utils.IBMSVCRestApi.svc_run_command')
@@ -375,88 +390,88 @@ class TestIBMSVCUser(unittest.TestCase):
     @patch('ansible_collections.ibm.storage_virtualize.plugins.module_utils.'
            'ibm_svc_utils.IBMSVCRestApi._svc_authorize')
     def test_removing_existing_user(self, mock_svc_authorize, mock_soi, mock_src):
-        set_module_args({
+        with set_module_args({
             'clustername': 'clustername',
             'domain': 'domain',
             'username': 'username',
             'password': 'password',
             'state': 'absent',
             'name': 'userx',
-        })
-        mock_soi.return_value = {
-            "id": "3",
-            "name": "userx",
-            "password": "yes",
-            "ssh_key": "no",
-            "remote": "no",
-            "usergrp_id": "3",
-            "usergrp_name": "Service",
-            "owner_id": "",
-            "owner_name": "",
-            "locked": "no",
-            "locked_until": "",
-            "password_expiry_time": "",
-            "password_change_required": "no"
-        }
-        mock_src.return_value = None
-        with pytest.raises(AnsibleExitJson) as exc:
-            ug = IBMSVCUser()
-            ug.apply()
-            self.assertTrue(exc.value.args[0]['changed'])
+        }):
+            mock_soi.return_value = {
+                "id": "3",
+                "name": "userx",
+                "password": "yes",
+                "ssh_key": "no",
+                "remote": "no",
+                "usergrp_id": "3",
+                "usergrp_name": "Service",
+                "owner_id": "",
+                "owner_name": "",
+                "locked": "no",
+                "locked_until": "",
+                "password_expiry_time": "",
+                "password_change_required": "no"
+            }
+            mock_src.return_value = None
+            with pytest.raises(AnsibleExitJson) as exc:
+                ug = IBMSVCUser()
+                ug.apply()
+                self.assertTrue(exc.value.args[0]['changed'])
 
     @patch('ansible_collections.ibm.storage_virtualize.plugins.module_utils.'
            'ibm_svc_utils.IBMSVCRestApi.svc_obj_info')
     @patch('ansible_collections.ibm.storage_virtualize.plugins.module_utils.'
            'ibm_svc_utils.IBMSVCRestApi._svc_authorize')
     def test_removing_non_existing_user(self, mock_svc_authorize, mock_soi):
-        set_module_args({
+        with set_module_args({
             'clustername': 'clustername',
             'domain': 'domain',
             'username': 'username',
             'password': 'password',
             'state': 'absent',
             'name': 'userx',
-        })
-        mock_soi.return_value = {}
-        with pytest.raises(AnsibleExitJson) as exc:
-            ug = IBMSVCUser()
-            ug.apply()
-            self.assertFalse(exc.value.args[0]['changed'])
+        }):
+            mock_soi.return_value = {}
+            with pytest.raises(AnsibleExitJson) as exc:
+                ug = IBMSVCUser()
+                ug.apply()
+                self.assertFalse(exc.value.args[0]['changed'])
 
     @patch('ansible_collections.ibm.storage_virtualize.plugins.module_utils.'
            'ibm_svc_utils.IBMSVCRestApi._svc_authorize')
     def test_missing_mandatory_parameters(self, mock_svc_authorize):
-        set_module_args({
+        with set_module_args({
             'clustername': 'clustername',
             'domain': 'domain',
             'username': 'username',
             'password': 'password',
-        })
-        with pytest.raises(AnsibleFailJson) as exc:
-            ug = IBMSVCUser()
-            ug.apply()
-            self.assertTrue(exc.value.args[0]['failed'])
+        }):
+            with pytest.raises(AnsibleFailJson) as exc:
+                ug = IBMSVCUser()
+                ug.apply()
+                self.assertTrue(exc.value.args[0]['failed'])
 
     @patch('ansible_collections.ibm.storage_virtualize.plugins.module_utils.'
            'ibm_svc_utils.IBMSVCRestApi._svc_authorize')
     def test_missing_parameter_during_creation(self, mock_svc_authorize):
-        set_module_args({
+        with set_module_args({
             'clustername': 'clustername',
             'domain': 'domain',
             'username': 'username',
             'password': 'password',
             'name': 'userx',
             'state': 'present',
-        })
-        with pytest.raises(AnsibleFailJson) as exc:
-            ug = IBMSVCUser()
-            ug.apply()
-            self.assertTrue(exc.value.args[0]['failed'])
+        }):
+            with pytest.raises(AnsibleFailJson) as exc:
+                ug = IBMSVCUser()
+                ug.apply()
+                self.assertTrue(exc.value.args[0]['failed'])
 
     @patch('ansible_collections.ibm.storage_virtualize.plugins.module_utils.'
            'ibm_svc_utils.IBMSVCRestApi._svc_authorize')
     def test_mutually_exclusive_nopassword(self, mock_svc_authorize):
-        set_module_args({
+        with set_module_args({
             'clustername': 'clustername',
             'domain': 'domain',
             'username': 'username',
@@ -467,16 +482,16 @@ class TestIBMSVCUser(unittest.TestCase):
             'nopassword': True,
             'auth_type': 'usergrp',
             'usergroup': 'Service',
-        })
-        with pytest.raises(AnsibleFailJson) as exc:
-            ug = IBMSVCUser()
-            ug.apply()
-            self.assertTrue(exc.value.args[0]['failed'])
+        }):
+            with pytest.raises(AnsibleFailJson) as exc:
+                ug = IBMSVCUser()
+                ug.apply()
+                self.assertTrue(exc.value.args[0]['failed'])
 
     @patch('ansible_collections.ibm.storage_virtualize.plugins.module_utils.'
            'ibm_svc_utils.IBMSVCRestApi._svc_authorize')
     def test_mutually_exclusive_nokey(self, mock_svc_authorize):
-        set_module_args({
+        with set_module_args({
             'clustername': 'clustername',
             'domain': 'domain',
             'username': 'username',
@@ -488,16 +503,16 @@ class TestIBMSVCUser(unittest.TestCase):
             'nokey': True,
             'auth_type': 'usergrp',
             'usergroup': 'Service',
-        })
-        with pytest.raises(AnsibleFailJson) as exc:
-            ug = IBMSVCUser()
-            ug.apply()
-            self.assertTrue(exc.value.args[0]['failed'])
+        }):
+            with pytest.raises(AnsibleFailJson) as exc:
+                ug = IBMSVCUser()
+                ug.apply()
+                self.assertTrue(exc.value.args[0]['failed'])
 
     @patch('ansible_collections.ibm.storage_virtualize.plugins.module_utils.'
            'ibm_svc_utils.IBMSVCRestApi._svc_authorize')
     def test_mutually_exclusive_nokey(self, mock_svc_authorize):
-        set_module_args({
+        with set_module_args({
             'clustername': 'clustername',
             'domain': 'domain',
             'username': 'username',
@@ -510,11 +525,11 @@ class TestIBMSVCUser(unittest.TestCase):
             'usergroup': 'Service',
             'lock': True,
             'unlock': True
-        })
-        with pytest.raises(AnsibleFailJson) as exc:
-            ug = IBMSVCUser()
-            ug.apply()
-            self.assertTrue(exc.value.args[0]['failed'])
+        }):
+            with pytest.raises(AnsibleFailJson) as exc:
+                ug = IBMSVCUser()
+                ug.apply()
+                self.assertTrue(exc.value.args[0]['failed'])
 
 
 if __name__ == '__main__':
