@@ -16,13 +16,28 @@ from ansible.module_utils import basic
 from ansible.module_utils._text import to_bytes
 from ansible_collections.ibm.storage_virtualize.plugins.module_utils.ibm_svc_utils import IBMSVCRestApi
 from ansible_collections.ibm.storage_virtualize.plugins.modules.ibm_svc_vol_map import IBMSVCvdiskhostmap
+import contextlib
 
 
+@contextlib.contextmanager
 def set_module_args(args):
-    """prepare arguments so that they will be picked up during module
-    creation """
-    args = json.dumps({'ANSIBLE_MODULE_ARGS': args})
-    basic._ANSIBLE_ARGS = to_bytes(args)  # pylint: disable=protected-access
+    """
+    Context manager that sets module arguments for AnsibleModule
+    """
+    if '_ansible_remote_tmp' not in args:
+        args['_ansible_remote_tmp'] = '/tmp'
+    if '_ansible_keep_remote_files' not in args:
+        args['_ansible_keep_remote_files'] = False
+
+    try:
+        from ansible.module_utils.testing import patch_module_args
+        with patch_module_args(args):
+            yield
+    except ImportError:
+        from ansible.module_utils import basic
+        serialized_args = to_bytes(json.dumps({'ANSIBLE_MODULE_ARGS': args}))
+        with patch.object(basic, '_ANSIBLE_ARGS', serialized_args):
+            yield
 
 
 class AnsibleExitJson(Exception):
@@ -75,10 +90,10 @@ class TestIBMSVCvdiskhostmap(unittest.TestCase):
 
     def test_module_fail_when_required_args_missing(self):
         """ required arguments are reported as errors """
-        with pytest.raises(AnsibleFailJson) as exc:
-            set_module_args({})
-            IBMSVCvdiskhostmap()
-        print('Info: %s' % exc.value.args[0]['msg'])
+        with set_module_args({}):
+            with pytest.raises(AnsibleFailJson) as exc:
+                IBMSVCvdiskhostmap()
+            print('Info: %s' % exc.value.args[0]['msg'])
 
     @patch('ansible_collections.ibm.storage_virtualize.plugins.module_utils.'
            'ibm_svc_utils.IBMSVCRestApi.svc_obj_info')
@@ -86,7 +101,7 @@ class TestIBMSVCvdiskhostmap(unittest.TestCase):
            'ibm_svc_utils.IBMSVCRestApi._svc_authorize')
     def test_get_existing_vdiskhostmap(self, svc_authorize_mock,
                                        svc_obj_info_mock):
-        set_module_args({
+        with set_module_args({
             'clustername': 'clustername',
             'domain': 'domain',
             'state': 'present',
@@ -94,19 +109,19 @@ class TestIBMSVCvdiskhostmap(unittest.TestCase):
             'password': 'password',
             'volname': 'volume0',
             'host': 'host4test',
-        })
-        mapping_ret = [{"id": "0", "name": "volume_Ansible_collections",
-                        "SCSI_id": "0", "host_id": "14",
-                        "host_name": "host_ansible_collects",
-                        "vdisk_UID": "6005076810CA0166C00000000000019F",
-                        "IO_group_id": "0", "IO_group_name": "io_grp0",
-                        "mapping_type": "private", "host_cluster_id": "",
-                        "host_cluster_name": "", "protocol": "scsi"}]
-        svc_obj_info_mock.return_value = mapping_ret
-        host_mapping_data = IBMSVCvdiskhostmap().get_existing_vdiskhostmap()
-        for host_mapping in host_mapping_data:
-            self.assertEqual('volume_Ansible_collections', host_mapping['name'])
-            self.assertEqual('0', host_mapping['id'])
+        }):
+            mapping_ret = [{"id": "0", "name": "volume_Ansible_collections",
+                            "SCSI_id": "0", "host_id": "14",
+                            "host_name": "host_ansible_collects",
+                            "vdisk_UID": "6005076810CA0166C00000000000019F",
+                            "IO_group_id": "0", "IO_group_name": "io_grp0",
+                            "mapping_type": "private", "host_cluster_id": "",
+                            "host_cluster_name": "", "protocol": "scsi"}]
+            svc_obj_info_mock.return_value = mapping_ret
+            host_mapping_data = IBMSVCvdiskhostmap().get_existing_vdiskhostmap()
+            for host_mapping in host_mapping_data:
+                self.assertEqual('volume_Ansible_collections', host_mapping['name'])
+                self.assertEqual('0', host_mapping['id'])
 
     @patch('ansible_collections.ibm.storage_virtualize.plugins.modules.'
            'ibm_svc_vol_map.IBMSVCvdiskhostmap.get_existing_vdiskhostmap')
@@ -117,7 +132,7 @@ class TestIBMSVCvdiskhostmap(unittest.TestCase):
     def test_host_mapping_create_get_existing_vdiskhostmap_called(
             self, svc_authorize_mock, vdiskhostmap_probe_mock,
             get_existing_vdiskhostmap_mock):
-        set_module_args({
+        with set_module_args({
             'clustername': 'clustername',
             'domain': 'domain',
             'state': 'present',
@@ -125,13 +140,13 @@ class TestIBMSVCvdiskhostmap(unittest.TestCase):
             'password': 'password',
             'volname': 'volume0',
             'host': 'host4test',
-        })
-        host_mapping_created = IBMSVCvdiskhostmap()
-        vdiskhostmap_probe_mock.return_value = []
-        with pytest.raises(AnsibleExitJson) as exc:
-            host_mapping_created.apply()
-        self.assertFalse(exc.value.args[0]['changed'])
-        get_existing_vdiskhostmap_mock.assert_called_with()
+        }):
+            host_mapping_created = IBMSVCvdiskhostmap()
+            vdiskhostmap_probe_mock.return_value = []
+            with pytest.raises(AnsibleExitJson) as exc:
+                host_mapping_created.apply()
+            self.assertFalse(exc.value.args[0]['changed'])
+            get_existing_vdiskhostmap_mock.assert_called_with()
 
     @patch('ansible_collections.ibm.storage_virtualize.plugins.modules.'
            'ibm_svc_vol_map.IBMSVCvdiskhostmap.get_existing_vdiskhostmap')
@@ -143,7 +158,7 @@ class TestIBMSVCvdiskhostmap(unittest.TestCase):
             self, svc_authorize_mock,
             vdiskhostmap_create_mock,
             get_existing_vdiskhostmap_mock):
-        set_module_args({
+        with set_module_args({
             'clustername': 'clustername',
             'domain': 'domain',
             'state': 'present',
@@ -151,16 +166,16 @@ class TestIBMSVCvdiskhostmap(unittest.TestCase):
             'password': 'password',
             'volname': 'volume0',
             'host': 'host4test',
-        })
-        host_mapping = {u'message': u'Virtual Disk to Host map, id [0], '
-                                    u'successfully created', u'id': u'0'}
-        vdiskhostmap_create_mock.return_value = host_mapping
-        get_existing_vdiskhostmap_mock.return_value = []
-        host_mapping_created = IBMSVCvdiskhostmap()
-        with pytest.raises(AnsibleExitJson) as exc:
-            host_mapping_created.apply()
-        self.assertTrue(exc.value.args[0]['changed'])
-        get_existing_vdiskhostmap_mock.assert_called_with()
+        }):
+            host_mapping = {u'message': u'Virtual Disk to Host map, id [0], '
+                                        u'successfully created', u'id': u'0'}
+            vdiskhostmap_create_mock.return_value = host_mapping
+            get_existing_vdiskhostmap_mock.return_value = []
+            host_mapping_created = IBMSVCvdiskhostmap()
+            with pytest.raises(AnsibleExitJson) as exc:
+                host_mapping_created.apply()
+            self.assertTrue(exc.value.args[0]['changed'])
+            get_existing_vdiskhostmap_mock.assert_called_with()
 
     @patch('ansible_collections.ibm.storage_virtualize.plugins.modules.'
            'ibm_svc_vol_map.IBMSVCvdiskhostmap.get_existing_vdiskhostmap')
@@ -171,7 +186,7 @@ class TestIBMSVCvdiskhostmap(unittest.TestCase):
     def test_create_host_mapping_successfully(self, svc_authorize_mock,
                                               vdiskhostmap_create_mock,
                                               get_existing_vdiskhostmap_mock):
-        set_module_args({
+        with set_module_args({
             'clustername': 'clustername',
             'domain': 'domain',
             'state': 'present',
@@ -179,16 +194,16 @@ class TestIBMSVCvdiskhostmap(unittest.TestCase):
             'password': 'password',
             'volname': 'volume0',
             'host': 'host4test',
-        })
-        host_mapping = {u'message': u'Virtual Disk to Host map, id [0], '
-                                    u'successfully created', u'id': u'0'}
-        vdiskhostmap_create_mock.return_value = host_mapping
-        get_existing_vdiskhostmap_mock.return_value = []
-        host_mapping_created = IBMSVCvdiskhostmap()
-        with pytest.raises(AnsibleExitJson) as exc:
-            host_mapping_created.apply()
-        self.assertTrue(exc.value.args[0]['changed'])
-        get_existing_vdiskhostmap_mock.assert_called_with()
+        }):
+            host_mapping = {u'message': u'Virtual Disk to Host map, id [0], '
+                                        u'successfully created', u'id': u'0'}
+            vdiskhostmap_create_mock.return_value = host_mapping
+            get_existing_vdiskhostmap_mock.return_value = []
+            host_mapping_created = IBMSVCvdiskhostmap()
+            with pytest.raises(AnsibleExitJson) as exc:
+                host_mapping_created.apply()
+            self.assertTrue(exc.value.args[0]['changed'])
+            get_existing_vdiskhostmap_mock.assert_called_with()
 
     @patch('ansible_collections.ibm.storage_virtualize.plugins.modules.'
            'ibm_svc_vol_map.IBMSVCvdiskhostmap.get_existing_vdiskhostmap')
@@ -196,7 +211,7 @@ class TestIBMSVCvdiskhostmap(unittest.TestCase):
            'ibm_svc_utils.IBMSVCRestApi._svc_authorize')
     def test_delete_host_but_host_not_existed(self, svc_authorize_mock,
                                               get_existing_vdiskhostmap_mock):
-        set_module_args({
+        with set_module_args({
             'clustername': 'clustername',
             'domain': 'domain',
             'state': 'absent',
@@ -204,13 +219,13 @@ class TestIBMSVCvdiskhostmap(unittest.TestCase):
             'password': 'password',
             'volname': 'volume0',
             'host': 'host4test',
-        })
-        get_existing_vdiskhostmap_mock.return_value = []
-        host_mapping_deleted = IBMSVCvdiskhostmap()
-        with pytest.raises(AnsibleExitJson) as exc:
-            host_mapping_deleted.apply()
-        self.assertFalse(exc.value.args[0]['changed'])
-        get_existing_vdiskhostmap_mock.assert_called_with()
+        }):
+            get_existing_vdiskhostmap_mock.return_value = []
+            host_mapping_deleted = IBMSVCvdiskhostmap()
+            with pytest.raises(AnsibleExitJson) as exc:
+                host_mapping_deleted.apply()
+            self.assertFalse(exc.value.args[0]['changed'])
+            get_existing_vdiskhostmap_mock.assert_called_with()
 
     @patch('ansible_collections.ibm.storage_virtualize.plugins.modules.'
            'ibm_svc_vol_map.IBMSVCvdiskhostmap.get_existing_vdiskhostmap')
@@ -221,7 +236,7 @@ class TestIBMSVCvdiskhostmap(unittest.TestCase):
     def test_delete_host_successfully(self, svc_authorize_mock,
                                       host_delete_mock,
                                       get_existing_vdiskhostmap_mock):
-        set_module_args({
+        with set_module_args({
             'clustername': 'clustername',
             'domain': 'domain',
             'state': 'absent',
@@ -229,20 +244,20 @@ class TestIBMSVCvdiskhostmap(unittest.TestCase):
             'password': 'password',
             'volname': 'volume0',
             'host': 'host4test',
-        })
-        mapping_ret = [{"id": "0", "name": "volume_Ansible_collections",
-                        "SCSI_id": "0", "host_id": "14",
-                        "host_name": "host_ansible_collects",
-                        "vdisk_UID": "6005076810CA0166C00000000000019F",
-                        "IO_group_id": "0", "IO_group_name": "io_grp0",
-                        "mapping_type": "private", "host_cluster_id": "",
-                        "host_cluster_name": "", "protocol": "scsi"}]
-        get_existing_vdiskhostmap_mock.return_value = mapping_ret
-        host_mapping_deleted = IBMSVCvdiskhostmap()
-        with pytest.raises(AnsibleExitJson) as exc:
-            host_mapping_deleted.apply()
-        self.assertTrue(exc.value.args[0]['changed'])
-        get_existing_vdiskhostmap_mock.assert_called_with()
+        }):
+            mapping_ret = [{"id": "0", "name": "volume_Ansible_collections",
+                            "SCSI_id": "0", "host_id": "14",
+                            "host_name": "host_ansible_collects",
+                            "vdisk_UID": "6005076810CA0166C00000000000019F",
+                            "IO_group_id": "0", "IO_group_name": "io_grp0",
+                            "mapping_type": "private", "host_cluster_id": "",
+                            "host_cluster_name": "", "protocol": "scsi"}]
+            get_existing_vdiskhostmap_mock.return_value = mapping_ret
+            host_mapping_deleted = IBMSVCvdiskhostmap()
+            with pytest.raises(AnsibleExitJson) as exc:
+                host_mapping_deleted.apply()
+            self.assertTrue(exc.value.args[0]['changed'])
+            get_existing_vdiskhostmap_mock.assert_called_with()
 
     @patch('ansible_collections.ibm.storage_virtualize.plugins.modules.'
            'ibm_svc_vol_map.IBMSVCvdiskhostmap.get_existing_vdiskhostmap')
@@ -253,7 +268,7 @@ class TestIBMSVCvdiskhostmap(unittest.TestCase):
     def test_create_hostcluster_mapping_successfully(self, svc_authorize_mock,
                                                      vdiskhostclustermap_create_mock,
                                                      get_existing_vdiskhostmap_mock):
-        set_module_args({
+        with set_module_args({
             'clustername': 'clustername',
             'domain': 'domain',
             'state': 'present',
@@ -261,16 +276,16 @@ class TestIBMSVCvdiskhostmap(unittest.TestCase):
             'password': 'password',
             'volname': 'volume0',
             'hostcluster': 'hostcluster4test',
-        })
-        host_mapping = {u'message': u'Volume to Host Cluster map, id [0], '
-                                    u'successfully created', u'id': u'0'}
-        vdiskhostclustermap_create_mock.return_value = host_mapping
-        get_existing_vdiskhostmap_mock.return_value = []
-        host_mapping_created = IBMSVCvdiskhostmap()
-        with pytest.raises(AnsibleExitJson) as exc:
-            host_mapping_created.apply()
-        self.assertTrue(exc.value.args[0]['changed'])
-        get_existing_vdiskhostmap_mock.assert_called_with()
+        }):
+            host_mapping = {u'message': u'Volume to Host Cluster map, id [0], '
+                                        u'successfully created', u'id': u'0'}
+            vdiskhostclustermap_create_mock.return_value = host_mapping
+            get_existing_vdiskhostmap_mock.return_value = []
+            host_mapping_created = IBMSVCvdiskhostmap()
+            with pytest.raises(AnsibleExitJson) as exc:
+                host_mapping_created.apply()
+            self.assertTrue(exc.value.args[0]['changed'])
+            get_existing_vdiskhostmap_mock.assert_called_with()
 
     @patch('ansible_collections.ibm.storage_virtualize.plugins.modules.'
            'ibm_svc_vol_map.IBMSVCvdiskhostmap.get_existing_vdiskhostmap')
@@ -282,7 +297,7 @@ class TestIBMSVCvdiskhostmap(unittest.TestCase):
             self, svc_authorize_mock,
             vdiskhostclustermap_create_mock,
             get_existing_vdiskhostmap_mock):
-        set_module_args({
+        with set_module_args({
             'clustername': 'clustername',
             'domain': 'domain',
             'state': 'present',
@@ -290,16 +305,16 @@ class TestIBMSVCvdiskhostmap(unittest.TestCase):
             'password': 'password',
             'volname': 'volume0',
             'hostcluster': 'hostcluster4test',
-        })
-        host_mapping = {u'message': u'Volume to Host Cluster map, id [0], '
-                                    u'successfully created', u'id': u'0'}
-        vdiskhostclustermap_create_mock.return_value = host_mapping
-        get_existing_vdiskhostmap_mock.return_value = []
-        host_mapping_created = IBMSVCvdiskhostmap()
-        with pytest.raises(AnsibleExitJson) as exc:
-            host_mapping_created.apply()
-        self.assertTrue(exc.value.args[0]['changed'])
-        get_existing_vdiskhostmap_mock.assert_called_with()
+        }):
+            host_mapping = {u'message': u'Volume to Host Cluster map, id [0], '
+                                        u'successfully created', u'id': u'0'}
+            vdiskhostclustermap_create_mock.return_value = host_mapping
+            get_existing_vdiskhostmap_mock.return_value = []
+            host_mapping_created = IBMSVCvdiskhostmap()
+            with pytest.raises(AnsibleExitJson) as exc:
+                host_mapping_created.apply()
+            self.assertTrue(exc.value.args[0]['changed'])
+            get_existing_vdiskhostmap_mock.assert_called_with()
 
     @patch('ansible_collections.ibm.storage_virtualize.plugins.modules.'
            'ibm_svc_vol_map.IBMSVCvdiskhostmap.get_existing_vdiskhostmap')
@@ -307,7 +322,7 @@ class TestIBMSVCvdiskhostmap(unittest.TestCase):
            'ibm_svc_utils.IBMSVCRestApi._svc_authorize')
     def test_delete_hostcluster_mapping_not_exist(self, svc_authorize_mock,
                                                   get_existing_vdiskhostmap_mock):
-        set_module_args({
+        with set_module_args({
             'clustername': 'clustername',
             'domain': 'domain',
             'state': 'absent',
@@ -315,13 +330,13 @@ class TestIBMSVCvdiskhostmap(unittest.TestCase):
             'password': 'password',
             'volname': 'volume0',
             'hostcluster': 'hostcluster4test',
-        })
-        get_existing_vdiskhostmap_mock.return_value = []
-        host_mapping_deleted = IBMSVCvdiskhostmap()
-        with pytest.raises(AnsibleExitJson) as exc:
-            host_mapping_deleted.apply()
-        self.assertFalse(exc.value.args[0]['changed'])
-        get_existing_vdiskhostmap_mock.assert_called_with()
+        }):
+            get_existing_vdiskhostmap_mock.return_value = []
+            host_mapping_deleted = IBMSVCvdiskhostmap()
+            with pytest.raises(AnsibleExitJson) as exc:
+                host_mapping_deleted.apply()
+            self.assertFalse(exc.value.args[0]['changed'])
+            get_existing_vdiskhostmap_mock.assert_called_with()
 
     @patch('ansible_collections.ibm.storage_virtualize.plugins.modules.'
            'ibm_svc_vol_map.IBMSVCvdiskhostmap.get_existing_vdiskhostmap')
@@ -332,7 +347,7 @@ class TestIBMSVCvdiskhostmap(unittest.TestCase):
     def test_delete_hostcluster_mapping_successfully(self, svc_authorize_mock,
                                                      host_delete_mock,
                                                      get_existing_vdiskhostmap_mock):
-        set_module_args({
+        with set_module_args({
             'clustername': 'clustername',
             'domain': 'domain',
             'state': 'absent',
@@ -340,20 +355,20 @@ class TestIBMSVCvdiskhostmap(unittest.TestCase):
             'password': 'password',
             'volname': 'volume0',
             'hostcluster': 'hostcluster4test',
-        })
-        mapping_ret = [{"id": "0", "name": "volume_Ansible_collections",
-                        "SCSI_id": "0", "host_id": "",
-                        "host_name": "",
-                        "vdisk_UID": "6005076810CA0166C00000000000019F",
-                        "IO_group_id": "0", "IO_group_name": "io_grp0",
-                        "mapping_type": "private", "host_cluster_id": "1",
-                        "host_cluster_name": "hostcluster4test", "protocol": "scsi"}]
-        get_existing_vdiskhostmap_mock.return_value = mapping_ret
-        host_mapping_deleted = IBMSVCvdiskhostmap()
-        with pytest.raises(AnsibleExitJson) as exc:
-            host_mapping_deleted.apply()
-        self.assertTrue(exc.value.args[0]['changed'])
-        get_existing_vdiskhostmap_mock.assert_called_with()
+        }):
+            mapping_ret = [{"id": "0", "name": "volume_Ansible_collections",
+                            "SCSI_id": "0", "host_id": "",
+                            "host_name": "",
+                            "vdisk_UID": "6005076810CA0166C00000000000019F",
+                            "IO_group_id": "0", "IO_group_name": "io_grp0",
+                            "mapping_type": "private", "host_cluster_id": "1",
+                            "host_cluster_name": "hostcluster4test", "protocol": "scsi"}]
+            get_existing_vdiskhostmap_mock.return_value = mapping_ret
+            host_mapping_deleted = IBMSVCvdiskhostmap()
+            with pytest.raises(AnsibleExitJson) as exc:
+                host_mapping_deleted.apply()
+            self.assertTrue(exc.value.args[0]['changed'])
+            get_existing_vdiskhostmap_mock.assert_called_with()
 
 
 if __name__ == '__main__':
