@@ -38,7 +38,6 @@ class TestNiosNAPTRRecordModule(TestNiosModule):
         self.mock_wapi = patch('ansible_collections.infoblox.nios_modules.plugins.modules.nios_naptr_record.WapiModule')
         self.exec_command = self.mock_wapi.start()
         self.mock_wapi_run = patch('ansible_collections.infoblox.nios_modules.plugins.modules.nios_naptr_record.WapiModule.run')
-        self.mock_wapi_run.start()
         self.load_config = self.mock_wapi_run.start()
         self.mock_check_type_dict = patch('ansible.module_utils.common.validation.check_type_dict')
         self.mock_check_type_dict_obj = self.mock_check_type_dict.start()
@@ -91,10 +90,11 @@ class TestNiosNAPTRRecordModule(TestNiosModule):
                               'order': '1000', 'preference': '10', 'replacement': 'replacement1.network.ansiblezone.com',
                               'comment': 'updated comment', 'extattrs': None}
 
+        ref = "naptrrecord/ZG5zLm5ldHdvcmtfdmlldyQw:default/true"
         test_object = [
             {
                 "comment": "test comment",
-                "_ref": "naptrrecord/ZG5zLm5ldHdvcmtfdmlldyQw:default/true",
+                "_ref": ref,
                 "name": "*.subscriber-100.ansiblezone.com",
                 "order": "1000",
                 "preference": "10",
@@ -116,6 +116,8 @@ class TestNiosNAPTRRecordModule(TestNiosModule):
         res = wapi.run('testobject', test_spec)
 
         self.assertTrue(res['changed'])
+        wapi.update_object.assert_called_once_with(ref, {'comment': 'updated comment', 'name': '*.subscriber-100.ansiblezone.com',
+                                                         'order': '1000', 'preference': '10', 'replacement': 'replacement1.network.ansiblezone.com'})
 
     def test_nios_naptr_record_remove(self):
         self.module.params = {'provider': None, 'state': 'absent', 'name': '*.subscriber-100.ansiblezone.com',
