@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 
 # Copyright: (c) 2018-2022, Sumit Kumar <sumit4@netapp.com>, chris Archibald <carchi@netapp.com>
+# Copyright (c) 2018-2025, NetApp, Inc
 # GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
 
 from __future__ import (absolute_import, division, print_function)
@@ -28,9 +29,9 @@ options:
   username:
       description:
         - This can be a Cluster-scoped or SVM-scoped account, depending on whether a Cluster-level or SVM-level API is required.
-        - For more information, please read the documentation U(https://mysupport.netapp.com/NOW/download/software/nmsdk/9.4/).
+        - For more information, please read the documentation U(https://docs.netapp.com/us-en/ontap/authentication/create-svm-user-accounts-task.html).
         - Two authentication methods are supported
-        - 1. basic authentication, using username and password,
+        - 1. Basic authentication, using username and password.
         - 2. SSL certificate authentication, using a ssl client cert file, and optionally a private key file.
         - To use a certificate, the certificate must have been installed in the ONTAP cluster, and cert authentication must have been enabled.
       type: str
@@ -80,7 +81,7 @@ options:
           An error is issued if a module option is not supported in REST.
         - never -- will always use ZAPI if the module supports ZAPI.  An error may be issued if a REST option is not supported in ZAPI.
         - auto -- will try to use the REST API if the module supports REST and modules options are supported.  Reverts to ZAPI otherwise.
-      default: auto
+      default: always
       type: str
   feature_flags:
       description:
@@ -100,11 +101,18 @@ options:
         - Ignored with ZAPI.
       type: str
       version_added: "21.23.0"
+  use_lambda:
+      description:
+        - Specifies if AWS Lambda proxy functionality should be used to connect to the ONTAP system.
+        - Supported only with REST.
+      type: bool
+      default: false
+      version_added: "23.2.0"
 requirements:
   - Ansible 2.9 or later - 2.12 or later is recommended.
   - Python3 - 3.9 or later is recommended.
-  - When using ZAPI, netapp-lib 2018.11.13 or later (install using 'pip install netapp-lib'),
-    netapp-lib 2020.3.12 is strongly recommended as it provides better error reporting for connection issues.
+  - netapp-lib only when using ZAPI (install using 'pip install netapp-lib'),
+    Please note that netapp-lib is deprecated and no longer maintained. Proceed at your own risk.
   - A physical or virtual clustered Data ONTAP system, the modules support Data ONTAP 9.1 and onward,
     REST support requires ONTAP 9.6 or later.
 
@@ -125,9 +133,9 @@ options:
   username:
       description:
         - This can be a Cluster-scoped or SVM-scoped account, depending on whether a Cluster-level or SVM-level API is required.
-        - For more information, please read the documentation U(https://mysupport.netapp.com/NOW/download/software/nmsdk/9.4/).
+        - For more information, please read the documentation U(https://docs.netapp.com/us-en/ontap/authentication/create-svm-user-accounts-task.html).
         - Two authentication methods are supported
-        - 1. basic authentication, using username and password,
+        - 1. Basic authentication, using username and password.
         - 2. SSL certificate authentication, using a ssl client cert file, and optionally a private key file.
         - To use a certificate, the certificate must have been installed in the ONTAP cluster, and cert authentication must have been enabled.
       type: str
@@ -186,8 +194,8 @@ options:
 requirements:
   - Ansible 2.9 or later - 2.12 or later is recommended.
   - Python3 - 3.9 or later is recommended.
-  - When using ZAPI, netapp-lib 2018.11.13 or later (install using 'pip install netapp-lib'),
-    netapp-lib 2020.3.12 is strongly recommended as it provides better error reporting for connection issues.
+  - netapp-lib only when using ZAPI (install using 'pip install netapp-lib'),
+    Please note that netapp-lib is deprecated and no longer maintained. Proceed at your own risk.
   - A physical or virtual clustered Data ONTAP system, the modules support Data ONTAP 9.1 and onward,
     REST support requires ONTAP 9.6 or later.
 
@@ -208,9 +216,9 @@ options:
   username:
       description:
         - This can be a Cluster-scoped or SVM-scoped account, depending on whether a Cluster-level or SVM-level API is required.
-        - For more information, please read the documentation U(https://mysupport.netapp.com/NOW/download/software/nmsdk/9.4/).
+        - For more information, please read the documentation U(https://docs.netapp.com/us-en/ontap/authentication/create-svm-user-accounts-task.html).
         - Two authentication methods are supported
-        - 1. basic authentication, using username and password,
+        - 1. Basic authentication, using username and password.
         - 2. SSL certificate authentication, using a ssl client cert file, and optionally a private key file.
         - To use a certificate, the certificate must have been installed in the ONTAP cluster, and cert authentication must have been enabled.
       type: str
@@ -274,8 +282,8 @@ options:
 requirements:
   - Ansible 2.9 or later - 2.12 or later is recommended.
   - Python3 - 3.9 or later is recommended.
-  - When using ZAPI, netapp-lib 2018.11.13 or later (install using 'pip install netapp-lib'),
-    netapp-lib 2020.3.12 is strongly recommended as it provides better error reporting for connection issues.
+  - netapp-lib only when using ZAPI (install using 'pip install netapp-lib'),
+    Please note that netapp-lib is deprecated and no longer maintained. Proceed at your own risk.
   - A physical or virtual clustered Data ONTAP system, the modules support Data ONTAP 9.1 and onward,
     REST support requires ONTAP 9.6 or later.
 
