@@ -1,12 +1,12 @@
 #!/usr/bin/python
 
-# (c) 2019-2021, NetApp, Inc
+# (c) 2019-2025, NetApp, Inc
 # GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
 from __future__ import absolute_import, division, print_function
 __metaclass__ = type
 
 DOCUMENTATION = '''
-author: NetApp Ansible Team (@carchi8py) <ng-ansibleteam@netapp.com>
+author: NetApp Ansible Team (@carchi8py) <ng-ansible-team@netapp.com>
 description:
   - Update ONTAP service-prosessor firmware
   - The recommend procedure is to
@@ -162,107 +162,103 @@ version_added: 2.9.0
 '''
 
 EXAMPLES = """
+- name: Any firmware upgrade - REST
+  netapp.ontap.na_ontap_firmware_upgrade:
+    state: present
+    package_url: "{{ web_link }}"
+    hostname: "{{ netapp_hostname }}"
+    username: "{{ netapp_username }}"
+    password: "{{ netapp_password }}"
 
-    - name: firmware upgrade
-      netapp.ontap.na_ontap_firmware_upgrade:
-        state: present
-        package_url: "{{ web_link }}"
-        hostname: "{{ netapp_hostname }}"
-        username: "{{ netapp_username }}"
-        password: "{{ netapp_password }}"
-    - name: firmware upgrade, confirm successful download
-      netapp.ontap.na_ontap_firmware_upgrade:
-        state: present
-        package_url: "{{ web_link }}"
-        hostname: "{{ netapp_hostname }}"
-        username: "{{ netapp_username }}"
-        password: "{{ netapp_password }}"
-        fail_on_502_error: true
-    - name: SP firmware upgrade
-      netapp.ontap.na_ontap_firmware_upgrade:
-        state: present
-        node: vsim1
-        package: "{{ file name }}"
-        package_url: "{{ web_link }}"
-        clear_logs: True
-        install_baseline_image: False
-        update_type: serial_full
-        force_disruptive_update: False
-        firmware_type: service-processor
-        hostname: "{{ netapp_hostname }}"
-        username: "{{ netapp_username }}"
-        password: "{{ netapp_password }}"
-    - name: SP firmware download replace package
-      tags:
-      - sp_download
-      netapp.ontap.na_ontap_firmware_upgrade:
-        state: present
-        node: vsim1
-        package_url: "{{ web_link }}"
-        firmware_type: service-processor
-        replace_package: true
-        reboot_sp: true
-        hostname: "{{ netapp_hostname }}"
-        username: "{{ netapp_username }}"
-        password: "{{ netapp_password }}"
-        https: true
-        validate_certs: false
-    - name: SP firmware download rename package
-      tags:
-      - sp_download
-      netapp.ontap.na_ontap_firmware_upgrade:
-        state: present
-        node: vsim1
-        package_url: "{{ web_link }}"
-        firmware_type: service-processor
-        rename_package: SP_FW.zip
-        hostname: "{{ netapp_hostname }}"
-        username: "{{ netapp_username }}"
-        password: "{{ netapp_password }}"
-        https: true
-        validate_certs: false
-    - name: ACP firmware download and upgrade
-      netapp.ontap.na_ontap_firmware_upgrade:
-        state: present
-        node: vsim1
-        firmware_type: acp
-        package_url: "{{ web_link }}"
-        hostname: "{{ netapp_hostname }}"
-        username: "{{ netapp_username }}"
-        password: "{{ netapp_password }}"
-    - name: shelf firmware upgrade
-      netapp.ontap.na_ontap_firmware_upgrade:
-        state: present
-        firmware_type: shelf
-        package_url: "{{ web_link }}"
-        hostname: "{{ netapp_hostname }}"
-        username: "{{ netapp_username }}"
-        password: "{{ netapp_password }}"
-    - name: disk firmware upgrade
-      netapp.ontap.na_ontap_firmware_upgrade:
-        state: present
-        firmware_type: disk
-        package_url: "{{ web_link }}"
-        hostname: "{{ netapp_hostname }}"
-        username: "{{ netapp_username }}"
-        password: "{{ netapp_password }}"
-    - name: any firmware upgrade (REST)
-      netapp.ontap.na_ontap_firmware_upgrade:
-        state: present
-        package_url: "{{ web_link }}"
-        hostname: "{{ netapp_hostname }}"
-        username: "{{ netapp_username }}"
-        password: "{{ netapp_password }}"
-    - name: SP firmware upgrade with reboots (REST)
-      netapp.ontap.na_ontap_firmware_upgrade:
-        state: present
-        package_url: "{{ web_link }}"
-        firmware_type: service-processor
-        reboot_sp_: true
-        reboot_sp_after_download: true
-        hostname: "{{ netapp_hostname }}"
-        username: "{{ netapp_username }}"
-        password: "{{ netapp_password }}"
+- name: Firmware upgrade, confirm successful download
+  netapp.ontap.na_ontap_firmware_upgrade:
+    state: present
+    package_url: "{{ web_link }}"
+    hostname: "{{ netapp_hostname }}"
+    username: "{{ netapp_username }}"
+    password: "{{ netapp_password }}"
+    fail_on_502_error: true
+
+- name: SP firmware upgrade
+  netapp.ontap.na_ontap_firmware_upgrade:
+    state: present
+    node: vsim1
+    package: "{{ file name }}"
+    package_url: "{{ web_link }}"
+    clear_logs: true
+    install_baseline_image: false
+    update_type: serial_full
+    force_disruptive_update: false
+    firmware_type: service-processor
+    hostname: "{{ netapp_hostname }}"
+    username: "{{ netapp_username }}"
+    password: "{{ netapp_password }}"
+
+- name: SP firmware download replace package
+  netapp.ontap.na_ontap_firmware_upgrade:
+    state: present
+    node: vsim1
+    package_url: "{{ web_link }}"
+    firmware_type: service-processor
+    replace_package: true
+    reboot_sp: true
+    hostname: "{{ netapp_hostname }}"
+    username: "{{ netapp_username }}"
+    password: "{{ netapp_password }}"
+    https: true
+    validate_certs: false
+
+- name: SP firmware download rename package
+  netapp.ontap.na_ontap_firmware_upgrade:
+    state: present
+    node: vsim1
+    package_url: "{{ web_link }}"
+    firmware_type: service-processor
+    rename_package: SP_FW.zip
+    hostname: "{{ netapp_hostname }}"
+    username: "{{ netapp_username }}"
+    password: "{{ netapp_password }}"
+    https: true
+    validate_certs: false
+
+- name: ACP firmware download and upgrade
+  netapp.ontap.na_ontap_firmware_upgrade:
+    state: present
+    node: vsim1
+    firmware_type: acp
+    package_url: "{{ web_link }}"
+    hostname: "{{ netapp_hostname }}"
+    username: "{{ netapp_username }}"
+    password: "{{ netapp_password }}"
+
+- name: Shelf firmware upgrade
+  netapp.ontap.na_ontap_firmware_upgrade:
+    state: present
+    firmware_type: shelf
+    package_url: "{{ web_link }}"
+    hostname: "{{ netapp_hostname }}"
+    username: "{{ netapp_username }}"
+    password: "{{ netapp_password }}"
+
+- name: Disk firmware upgrade
+  netapp.ontap.na_ontap_firmware_upgrade:
+    state: present
+    firmware_type: disk
+    package_url: "{{ web_link }}"
+    hostname: "{{ netapp_hostname }}"
+    username: "{{ netapp_username }}"
+    password: "{{ netapp_password }}"
+
+- name: SP firmware upgrade with reboots (REST)
+  netapp.ontap.na_ontap_firmware_upgrade:
+    state: present
+    package_url: "{{ web_link }}"
+    firmware_type: service-processor
+    reboot_sp: true
+    reboot_sp_after_download: true
+    hostname: "{{ netapp_hostname }}"
+    username: "{{ netapp_username }}"
+    password: "{{ netapp_password }}"
 """
 
 RETURN = """
