@@ -1,6 +1,6 @@
 #!/usr/bin/python
 
-# (c) 2018-2022, NetApp, Inc
+# (c) 2018-2025, NetApp, Inc
 # GNU General Public License v3.0+
 # (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
 
@@ -18,10 +18,12 @@ short_description: NetApp ONTAP manage policy group in Quality of Service.
 extends_documentation_fragment:
   - netapp.ontap.netapp.na_ontap
 version_added: 2.8.0
-author: NetApp Ansible Team (@carchi8py) <ng-ansibleteam@netapp.com>
+author: NetApp Ansible Team (@carchi8py) <ng-ansible-team@netapp.com>
 
 description:
   - Create, destroy, modify, or rename QoS policy group on NetApp ONTAP.
+  - With ZAPI, only fixed QoS policy group is supported.
+  - With REST, both fixed and adaptive QoS policy group are supported.
 
 options:
   state:
@@ -135,86 +137,121 @@ options:
             the storage object used size.
         type: int
         required: true
-
+      block_size:
+        description:
+          - Specifies the block size.
+          - Requires ONTAP 9.10.1 or later.
+        type: str
+        required: false
+        choices: ['any', '4k', '8k', '16k', '32k', '64k', '128k']
+        version_added: 22.6.0
+      expected_iops_allocation:
+        description:
+          - Specifies the size to be used to calculate expected IOPS per TB.
+          - Supported only with REST; requires ONTAP 9.10.1 or later.
+        type: str
+        required: false
+        choices: ['used_space', 'allocated_space']
+        version_added: 22.8.0
+      peak_iops_allocation:
+        description:
+          - Specifies the size to be used to calculate peak IOPS per TB.
+          - Supported only with REST; requires ONTAP 9.10.1 or later.
+        type: str
+        required: false
+        choices: ['used_space', 'allocated_space']
+        version_added: 22.8.0
 '''
 
 EXAMPLES = """
-    - name: create qos policy group in ZAPI.
-      netapp.ontap.na_ontap_qos_policy_group:
-        state: present
-        name: policy_1
-        vserver: policy_vserver
-        max_throughput: 800KB/s,800iops
-        min_throughput: 100iops
-        hostname: 10.193.78.30
-        username: admin
-        password: netapp1!
-        use_rest: never
+- name: Create qos policy group in ZAPI.
+  netapp.ontap.na_ontap_qos_policy_group:
+    state: present
+    name: policy_1
+    vserver: policy_vserver
+    max_throughput: 800KB/s,800iops
+    min_throughput: 100iops
+    hostname: "{{ netapp_hostname }}"
+    username: "{{ netapp_username }}"
+    password: "{{ netapp_password }}"
+    use_rest: never
 
-    - name: modify qos policy group max throughput in ZAPI.
-      netapp.ontap.na_ontap_qos_policy_group:
-        state: present
-        name: policy_1
-        vserver: policy_vserver
-        max_throughput: 900KB/s,800iops
-        min_throughput: 100iops
-        hostname: 10.193.78.30
-        username: admin
-        password: netapp1!
-        use_rest: never
+- name: Modify qos policy group max throughput in ZAPI.
+  netapp.ontap.na_ontap_qos_policy_group:
+    state: present
+    name: policy_1
+    vserver: policy_vserver
+    max_throughput: 900KB/s,800iops
+    min_throughput: 100iops
+    hostname: "{{ netapp_hostname }}"
+    username: "{{ netapp_username }}"
+    password: "{{ netapp_password }}"
+    use_rest: never
 
-    - name: delete qos policy group
-      netapp.ontap.na_ontap_qos_policy_group:
-        state: absent
-        name: policy_1
-        vserver: policy_vserver
-        hostname: 10.193.78.30
-        username: admin
-        password: netapp1!
+- name: Delete qos policy group
+  netapp.ontap.na_ontap_qos_policy_group:
+    state: absent
+    name: policy_1
+    vserver: policy_vserver
+    hostname: "{{ netapp_hostname }}"
+    username: "{{ netapp_username }}"
+    password: "{{ netapp_password }}"
 
-    - name: create qos policy group in REST.
-      netapp.ontap.na_ontap_qos_policy_group:
-        state: present
-        name: policy_1
-        vserver: policy_vserver
-        hostname: 10.193.78.30
-        username: admin
-        password: netapp1!
-        use_rest: always
-        fixed_qos_options:
-          max_throughput_iops: 800
-          max_throughput_mbps: 200
-          min_throughput_iops: 500
-          min_throughput_mbps: 100
-          capacity_shared: True
+- name: Create qos policy group in REST.
+  netapp.ontap.na_ontap_qos_policy_group:
+    state: present
+    name: policy_1
+    vserver: policy_vserver
+    hostname: "{{ netapp_hostname }}"
+    username: "{{ netapp_username }}"
+    password: "{{ netapp_password }}"
+    use_rest: always
+    fixed_qos_options:
+      max_throughput_iops: 800
+      max_throughput_mbps: 200
+      min_throughput_iops: 500
+      min_throughput_mbps: 100
+      capacity_shared: true
 
-    - name: modify qos policy max_throughput in REST.
-      netapp.ontap.na_ontap_qos_policy_group:
-        state: present
-        name: policy_1
-        vserver: policy_vserver
-        hostname: 10.193.78.30
-        username: admin
-        password: netapp1!
-        use_rest: always
-        fixed_qos_options:
-          max_throughput_iops: 1000
-          max_throughput_mbps: 300
+- name: Modify qos policy max_throughput in REST.
+  netapp.ontap.na_ontap_qos_policy_group:
+    state: present
+    name: policy_1
+    vserver: policy_vserver
+    hostname: "{{ netapp_hostname }}"
+    username: "{{ netapp_username }}"
+    password: "{{ netapp_password }}"
+    use_rest: always
+    fixed_qos_options:
+      max_throughput_iops: 1000
+      max_throughput_mbps: 300
 
-    - name: create adaptive qos policy group in REST.
-      netapp.ontap.na_ontap_qos_policy_group:
-        state: present
-        name: adaptive_policy
-        vserver: policy_vserver
-        hostname: 10.193.78.30
-        username: admin
-        password: netapp1!
-        use_rest: always
-        adaptive_qos_options:
-          absolute_min_iops: 100
-          expected_iops: 200
-          peak_iops: 500
+- name: Create adaptive qos policy group in REST.
+  netapp.ontap.na_ontap_qos_policy_group:
+    state: present
+    name: adaptive_policy
+    vserver: policy_vserver
+    hostname: "{{ netapp_hostname }}"
+    username: "{{ netapp_username }}"
+    password: "{{ netapp_password }}"
+    use_rest: always
+    adaptive_qos_options:
+      absolute_min_iops: 100
+      expected_iops: 200
+      peak_iops: 500
 
+- name: Modify adaptive qos policy group in REST.
+  netapp.ontap.na_ontap_qos_policy_group:
+    state: present
+    name: adaptive_policy
+    vserver: policy_vserver
+    hostname: "{{ netapp_hostname }}"
+    username: "{{ netapp_username }}"
+    password: "{{ netapp_password }}"
+    use_rest: always
+    adaptive_qos_options:
+      expected_iops_allocation: used_space
+      peak_iops_allocation: allocated_space
 """
 
 RETURN = """
@@ -258,7 +295,10 @@ class NetAppOntapQosPolicyGroup:
             adaptive_qos_options=dict(required=False, type='dict', options=dict(
                 absolute_min_iops=dict(required=True, type='int'),
                 expected_iops=dict(required=True, type='int'),
-                peak_iops=dict(required=True, type='int')
+                peak_iops=dict(required=True, type='int'),
+                block_size=dict(required=False, type='str', choices=['any', '4k', '8k', '16k', '32k', '64k', '128k']),
+                expected_iops_allocation=dict(required=False, type='str', choices=['used_space', 'allocated_space']),
+                peak_iops_allocation=dict(required=False, type='str', choices=['used_space', 'allocated_space'])
             ))
         ))
 
@@ -283,10 +323,15 @@ class NetAppOntapQosPolicyGroup:
         unsupported_rest_properties = ['is_shared', 'max_throughput', 'min_throughput', 'force']
         self.use_rest = self.rest_api.is_rest_supported_properties(self.parameters, unsupported_rest_properties)
 
-        min_ontap_98 = self.rest_api.meets_rest_minimum_version(self.use_rest, 9, 8)
-        if self.use_rest and not min_ontap_98 and \
-                self.na_helper.safe_get(self.parameters, ['fixed_qos_options', 'min_throughput_mbps']) and self.parameters['state'] == 'present':
-            self.module.fail_json("Minimum version of ONTAP for 'fixed_qos_options.min_throughput_mbps' is (9, 8, 0)")
+        if self.use_rest and self.parameters['state'] == 'present':
+            if not self.rest_api.meets_rest_minimum_version(self.use_rest, 9, 8) and \
+                    self.na_helper.safe_get(self.parameters, ['fixed_qos_options', 'min_throughput_mbps']):
+                self.module.fail_json(msg="Minimum version of ONTAP for 'fixed_qos_options.min_throughput_mbps' is (9, 8, 0)")
+
+            ontap_9_10_adaptive_options = ['block_size', 'expected_iops_allocation', 'peak_iops_allocation']
+            if not self.rest_api.meets_rest_minimum_version(self.use_rest, 9, 10, 1) and \
+                    any(self.na_helper.safe_get(self.parameters, ['adaptive_qos_options', option]) for option in ontap_9_10_adaptive_options):
+                self.module.fail_json(msg='Error: %s' % self.rest_api.options_require_ontap_version(ontap_9_10_adaptive_options, version='9.10.1'))
         self.uuid = None
 
         if not self.use_rest:
@@ -370,7 +415,8 @@ class NetAppOntapQosPolicyGroup:
 
             if 'adaptive' in record:
                 current['adaptive_qos_options'] = {}
-                for adaptive_qos_option in ['absolute_min_iops', 'expected_iops', 'peak_iops']:
+                for adaptive_qos_option in ['absolute_min_iops', 'expected_iops', 'peak_iops', 'block_size',
+                                            'expected_iops_allocation', 'peak_iops_allocation']:
                     current['adaptive_qos_options'][adaptive_qos_option] = record['adaptive'].get(adaptive_qos_option)
         return current
 
@@ -466,6 +512,11 @@ class NetAppOntapQosPolicyGroup:
         if 'fixed_qos_options' in modify:
             body['fixed'] = modify['fixed_qos_options']
         else:
+            if 'block_size' not in self.na_helper.safe_get(modify, ['adaptive_qos_options']) and \
+                    self.na_helper.safe_get(self.parameters, ['adaptive_qos_options', 'block_size']) is None:
+                # if block_size is not to be modified then remove it from the params
+                # to avoid error with block_size option during modification of other adaptive qos options
+                del self.parameters['adaptive_qos_options']['block_size']
             body['adaptive'] = self.parameters['adaptive_qos_options']
         dummy, error = rest_generic.patch_async(self.rest_api, api, self.uuid, body)
         if error:
@@ -523,8 +574,6 @@ class NetAppOntapQosPolicyGroup:
         """
         Run module based on playbook
         """
-        if not self.use_rest:
-            netapp_utils.ems_log_event_cserver("na_ontap_qos_policy_group", self.server, self.module)
         current = self.get_policy_group()
         rename, cd_action = None, None
         cd_action = self.na_helper.get_cd_action(current, self.parameters)
@@ -538,7 +587,7 @@ class NetAppOntapQosPolicyGroup:
             if rename is None:
                 self.module.fail_json(msg='Error renaming qos policy group: cannot find %s' %
                                       self.parameters['from_name'])
-        modify = self.na_helper.get_modified_attributes(current, self.parameters)
+        modify = self.na_helper.get_modified_attributes(current, self.parameters) if cd_action is None else {}
         if 'is_shared' in modify or self.na_helper.safe_get(modify, ['fixed_qos_options', 'capacity_shared']) is not None:
             self.module.fail_json(msg="Error cannot modify '%s' attribute." %
                                   ('is_shared' if 'is_shared' in modify else 'fixed_qos_options.capacity_shared'))
