@@ -1,6 +1,6 @@
 #!/usr/bin/python
 
-# (c) 2020-2024, NetApp, Inc
+# (c) 2020-2025, NetApp, Inc
 # GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
 
 """ NetApp ONTAP Info using REST APIs """
@@ -11,7 +11,7 @@ __metaclass__ = type
 
 DOCUMENTATION = '''
 module: na_ontap_rest_info
-author: NetApp Ansible Team (@carchi8py) <ng-ansibleteam@netapp.com>
+author: NetApp Ansible Team (@carchi8py) <ng-ansible-team@netapp.com>
 extends_documentation_fragment:
     - netapp.ontap.netapp.na_ontap_rest
 short_description: NetApp ONTAP information gatherer using REST APIs
@@ -50,6 +50,8 @@ options:
       - Either the REST API or the ZAPI info name can be given. Possible values for this argument include
       - application/applications or application_info
       - application/consistency-groups
+      - application/consistency-groups/metrics B(Requires the owning_resource to be set)
+      - application/consistency-groups/snapshots B(Requires the owning_resource to be set)
       - application/templates or application_template_info
       - cloud/targets or cloud_targets_info
       - cluster
@@ -295,12 +297,14 @@ options:
     description:
       - Some resources cannot be accessed directly.  You need to select them based on the owner or parent.  For instance, volume for a snapshot.
       - The following subsets require an owning resource, and the following suboptions when uuid is not present.
+      - <application/consistency-groups/metrics> B(cg_name) is the consistency group name, B(svm_name) is the owning vserver name for the consistency group.
+      - <application/consistency-groups/snapshots> B(cg_name) is the consistency group name, B(svm_name) is the owning vserver name for the consistency group.
       - <storage/volumes/snapshots>  B(volume_name) is the volume name, B(svm_name) is the owning vserver name for the volume.
       - <protocols/nfs/export-policies/rules> B(policy_name) is the name of the policy, B(svm_name) is the owning vserver name for the policy,
         B(rule_index) is the rule index.
-      - <protocols/vscan/on-access-policies> B(svm_name) is the owning vserver name for the vscan
-      - <protocols/vscan/on-demand-policies> B(svm_name) is the owning vserver name for the vscan
-      - <protocols/vscan/scanner-pools> B(svm_name) is the owning vserver name for the vscan
+      - <protocols/vscan/on-access-policies> B(svm_name) is the owning vserver name for the vscan.
+      - <protocols/vscan/on-demand-policies> B(svm_name) is the owning vserver name for the vscan.
+      - <protocols/vscan/scanner-pools> B(svm_name) is the owning vserver name for the vscan.
     type: dict
     version_added: '21.19.0'
   ignore_api_errors:
@@ -318,96 +322,84 @@ options:
 '''
 
 EXAMPLES = '''
-- name: run ONTAP gather facts for vserver info
+- name: Run ONTAP gather facts for vserver info
   netapp.ontap.na_ontap_rest_info:
-      hostname: "1.2.3.4"
-      username: "testuser"
-      password: "test-password"
-      https: true
-      validate_certs: false
-      use_rest: Always
-      gather_subset:
-        - svm/svms
+    hostname: "{{ netapp_hostname }}"
+    username: "{{ netapp_username }}"
+    password: "{{ netapp_password }}"
+    validate_certs: false
+    gather_subset:
+      - svm/svms
 
-- name: run ONTAP gather facts for aggregate info and volume info
+- name: Run ONTAP gather facts for aggregate info and volume info
   netapp.ontap.na_ontap_rest_info:
-      hostname: "1.2.3.4"
-      username: "testuser"
-      password: "test-password"
-      https: true
-      validate_certs: false
-      use_rest: Always
-      gather_subset:
-        - storage/aggregates
-        - storage/volumes
+    hostname: "{{ netapp_hostname }}"
+    username: "{{ netapp_username }}"
+    password: "{{ netapp_password }}"
+    validate_certs: false
+    gather_subset:
+      - storage/aggregates
+      - storage/volumes
 
-- name: run ONTAP gather facts for aggregate info and volume info with fields section
+- name: Run ONTAP gather facts for aggregate info and volume info with fields section
   netapp.ontap.na_ontap_rest_info:
-      hostname: "1.2.3.4"
-      username: "testuser"
-      password: "test-password"
-      https: true
-      fields:
-        - '*'
-      validate_certs: false
-      use_rest: Always
-      gather_subset:
-        - storage/aggregates
-        - storage/volumes
+    hostname: "{{ netapp_hostname }}"
+    username: "{{ netapp_username }}"
+    password: "{{ netapp_password }}"
+    fields:
+      - '*'
+    validate_certs: false
+    gather_subset:
+      - storage/aggregates
+      - storage/volumes
 
-- name: run ONTAP gather facts for aggregate info with specified fields
+- name: Run ONTAP gather facts for aggregate info with specified fields
   netapp.ontap.na_ontap_rest_info:
-      hostname: "1.2.3.4"
-      username: "testuser"
-      password: "test-password"
-      https: true
-      fields:
-        - 'uuid'
-        - 'name'
-        - 'node'
-      validate_certs: false
-      use_rest: Always
-      gather_subset:
-        - storage/aggregates
-      parameters:
-        recommend:
-          true
+    hostname: "{{ netapp_hostname }}"
+    username: "{{ netapp_username }}"
+    password: "{{ netapp_password }}"
+    fields:
+      - 'uuid'
+      - 'name'
+      - 'node'
+    validate_certs: false
+    gather_subset:
+      - storage/aggregates
+    parameters:
+      recommend:
+        true
 
 - name: Get Snapshot info (owning_resource example)
   netapp.ontap.na_ontap_rest_info:
-      hostname: "1.2.3.4"
-      username: "testuser"
-      password: "test-password"
-      https: true
-      fields:
-        - '*'
-      validate_certs: false
-      use_rest: Always
-      gather_subset:
-        - storage/volumes/snapshots
-      owning_resource:
-        volume_name: volume_name
-        svm_name: svm_name
+    hostname: "{{ netapp_hostname }}"
+    username: "{{ netapp_username }}"
+    password: "{{ netapp_password }}"
+    fields:
+      - '*'
+    validate_certs: false
+    gather_subset:
+      - storage/volumes/snapshots
+    owning_resource:
+      volume_name: volume_name
+      svm_name: svm_name
 
-- name: run ONTAP gather facts for volume info with query on name and state
+- name: Run ONTAP gather facts for volume info with query on name and state
   netapp.ontap.na_ontap_rest_info:
-      hostname: "1.2.3.4"
-      username: "testuser"
-      password: "test-password"
-      https: true
-      validate_certs: false
-      gather_subset:
-        - storage/volumes
-      parameters:
-        name: ansible*
-        state: online
+    hostname: "{{ netapp_hostname }}"
+    username: "{{ netapp_username }}"
+    password: "{{ netapp_password }}"
+    validate_certs: false
+    gather_subset:
+      - storage/volumes
+    parameters:
+      name: ansible*
+      state: online
 
-- name: run ONTAP gather fact to get DACLs
+- name: Run ONTAP gather fact to get DACLs
   netapp.ontap.na_ontap_rest_info:
-    hostname: "1.2.3.4"
-    username: "testuser"
-    password: "test-password"
-    https: true
+    hostname: "{{ netapp_hostname }}"
+    username: "{{ netapp_username }}"
+    password: "{{ netapp_password }}"
     validate_certs: false
     gather_subset:
       - file_directory_security
@@ -416,12 +408,11 @@ EXAMPLES = '''
       path: /vol1/qtree1
     use_python_keys: true
 
-- name: get ip network interface info.
+- name: Get ip network interface info
   netapp.ontap.na_ontap_rest_info:
-    hostname: "1.2.3.4"
-    username: "testuser"
-    password: "test-password"
-    https: true
+    hostname: "{{ netapp_hostname }}"
+    username: "{{ netapp_username }}"
+    password: "{{ netapp_password }}"
     validate_certs: false
     gather_subset:
       - ip_interfaces_info
@@ -430,12 +421,11 @@ EXAMPLES = '''
       location.node.name: ontap_cluster
       service_policy.name: default-data-files
 
-- name: get aggregate info
+- name: Get aggregate info
   netapp.ontap.na_ontap_rest_info:
-    hostname: "1.2.3.4"
-    username: "testuser"
-    password: "test-password"
-    https: true
+    hostname: "{{ netapp_hostname }}"
+    username: "{{ netapp_username }}"
+    password: "{{ netapp_password }}"
     validate_certs: false
     gather_subset:
       - aggregate_info
@@ -444,7 +434,7 @@ EXAMPLES = '''
       block_storage.primary.raid_type: raid_dp
 
 # assuming module_defaults is used to set hostname, username, ...
-- name: run demo subset using custom vsadmin role
+- name: Run demo subset using custom vsadmin role
   netapp.ontap.na_ontap_rest_info:
     gather_subset:
       - demo
@@ -531,6 +521,10 @@ class NetAppONTAPGatherInfo(object):
         headers = self.rest_api.build_headers(accept=accept_header)
         gathered_ontap_info, error = self.rest_api.get(api, data, headers=headers)
 
+        if error and "entry doesn't exist" in error.get('message', ''):
+            # If the API returns no records, return an empty set of records.
+            return {'records': [], 'num_records': 0}
+
         if not error:
             return gathered_ontap_info
 
@@ -1089,9 +1083,23 @@ class NetAppONTAPGatherInfo(object):
 
     def add_uuid_subsets(self, get_ontap_subset_info):
         params = self.parameters.get('owning_resource')
-        owning_resource_supported_subsets = ['storage/volumes/snapshots', 'protocols/nfs/export-policies/rules',
-                                             'protocols/vscan/on-access-policies', 'protocols/vscan/on-demand-policies', 'protocols/vscan/scanner-pools']
+        owning_resource_supported_subsets = ['application/consistency-groups/metrics', 'application/consistency-groups/snapshots',
+                                             'storage/volumes/snapshots', 'protocols/nfs/export-policies/rules',
+                                             'protocols/vscan/on-access-policies', 'protocols/vscan/on-demand-policies',
+                                             'protocols/vscan/scanner-pools']
         if 'gather_subset' in self.parameters:
+            if 'application/consistency-groups/metrics' in self.parameters['gather_subset']:
+                self.check_error_values('application/consistency-groups/metrics', params, ['cg_name', 'svm_name'])
+                cg_uuid = rest_owning_resource.get_consistency_group_uuid(self.rest_api, self.parameters['owning_resource']['cg_name'],
+                                                                          self.parameters['owning_resource']['svm_name'], self.module)
+                if cg_uuid:
+                    get_ontap_subset_info['application/consistency-groups/metrics'] = {'api_call': 'application/consistency-groups/%s/metrics' % cg_uuid}
+            if 'application/consistency-groups/snapshots' in self.parameters['gather_subset']:
+                self.check_error_values('application/consistency-groups/snapshots', params, ['cg_name', 'svm_name'])
+                cg_uuid = rest_owning_resource.get_consistency_group_uuid(self.rest_api, self.parameters['owning_resource']['cg_name'],
+                                                                          self.parameters['owning_resource']['svm_name'], self.module)
+                if cg_uuid:
+                    get_ontap_subset_info['application/consistency-groups/snapshots'] = {'api_call': 'application/consistency-groups/%s/snapshots' % cg_uuid}
             if 'storage/volumes/snapshots' in self.parameters['gather_subset']:
                 self.check_error_values('storage/volumes/snapshots', params, ['volume_name', 'svm_name'])
                 volume_uuid = rest_owning_resource.get_volume_uuid(self.rest_api, self.parameters['owning_resource']['volume_name'],
