@@ -1,4 +1,4 @@
-# (c) 2018-2022, NetApp, Inc
+# (c) 2018-2025, NetApp, Inc
 # GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
 
 ''' unit test for ONTAP debug Ansible module '''
@@ -15,7 +15,8 @@ from ansible_collections.netapp.ontap.plugins.modules.na_ontap_debug \
 import ansible_collections.netapp.ontap.plugins.module_utils.netapp as netapp_utils
 # pylint: disable=unused-import
 from ansible_collections.netapp.ontap.tests.unit.plugins.module_utils.ansible_mocks import \
-    assert_no_warnings, assert_no_warnings_except_zapi, call_main, create_and_apply, create_module, expect_and_capture_ansible_exception, patch_ansible
+    assert_no_warnings, assert_no_warnings_except_zapi, assert_warning_was_raised, call_main, create_and_apply, create_module, \
+    expect_and_capture_ansible_exception, patch_ansible
 from ansible_collections.netapp.ontap.tests.unit.framework.mock_rest_and_zapi_requests import patch_request_and_invoke, register_responses
 from ansible_collections.netapp.ontap.tests.unit.framework.rest_factory import rest_responses
 from ansible_collections.netapp.ontap.tests.unit.framework.zapi_factory import build_zapi_error, zapi_responses
@@ -101,7 +102,7 @@ def test_success_no_vserver():
     args.pop('vserver')
     results = create_and_apply(my_module, args)
     print('Info: %s' % results)
-    assert_no_warnings_except_zapi()
+    assert_warning_was_raised(netapp_utils.ZAPI_DEPRECATION_MESSAGE)
     assert 'notes' in results
     assert 'msg' in results
     assert "NOTE: application console not found for user: user1: ['http', 'ontapi']" in results['notes']
@@ -119,7 +120,7 @@ def test_success_with_vserver():
     results = create_and_apply(my_module, DEFAULT_ARGS)
     print('Info: %s' % results)
     # assert results['changed'] is False
-    assert_no_warnings_except_zapi()
+    assert_warning_was_raised(netapp_utils.ZAPI_DEPRECATION_MESSAGE)
     assert 'notes' not in results
 
 
@@ -135,7 +136,7 @@ def test_fail_with_vserver_locked():
 
     results = create_and_apply(my_module, DEFAULT_ARGS, fail=True)
     print('Info: %s' % results)
-    assert_no_warnings_except_zapi()
+    assert_warning_was_raised(netapp_utils.ZAPI_DEPRECATION_MESSAGE)
     assert 'notes' in results
     assert 'user: user1 is locked on vserver: vserver' in results['notes'][0]
 
@@ -153,7 +154,7 @@ def test_fail_with_vserver_missing_app():
 
     results = create_and_apply(my_module, DEFAULT_ARGS, fail=True)
     print('Info: %s' % results)
-    assert_no_warnings_except_zapi()
+    assert_warning_was_raised(netapp_utils.ZAPI_DEPRECATION_MESSAGE)
     assert 'notes' in results
     assert 'application ontapi not found for user: user1' in results['notes'][0]
     assert 'Error: no unlocked user for ontapi on vserver: vserver' in results['msg']
@@ -169,7 +170,7 @@ def test_fail_with_vserver_list_user_not_found():
 
     results = create_and_apply(my_module, DEFAULT_ARGS, fail=True)
     print('Info: %s' % results)
-    assert_no_warnings_except_zapi()
+    assert_warning_was_raised(netapp_utils.ZAPI_DEPRECATION_MESSAGE)
     assert 'Error getting accounts for: vserver: none found' in results['msg']
 
 
@@ -183,7 +184,7 @@ def test_fail_with_vserver_list_user_error_on_get_users():
 
     results = create_and_apply(my_module, DEFAULT_ARGS, fail=True)
     print('Info: %s' % results)
-    assert_no_warnings_except_zapi()
+    assert_warning_was_raised(netapp_utils.ZAPI_DEPRECATION_MESSAGE)
     assert 'Error getting accounts for: vserver: calling: security/accounts: got Expected error.' in results['msg']
 
 
@@ -197,7 +198,7 @@ def test_success_with_vserver_list_user_not_authorized():
 
     results = create_and_apply(my_module, DEFAULT_ARGS)
     print('Info: %s' % results)
-    assert_no_warnings_except_zapi()
+    assert_warning_was_raised(netapp_utils.ZAPI_DEPRECATION_MESSAGE)
     assert 'Not autorized to get accounts for: vserver: calling: security/accounts: got not authorized for that command.' in results['msg']
 
 
@@ -213,7 +214,7 @@ def test_fail_with_vserver_no_interface():
 
     results = create_and_apply(my_module, DEFAULT_ARGS, fail=True)
     print('Info: %s' % results)
-    assert_no_warnings_except_zapi()
+    assert_warning_was_raised(netapp_utils.ZAPI_DEPRECATION_MESSAGE)
     assert 'notes' in results
     assert "NOTE: application console not found for user: user1: ['http', 'ontapi']" in results['notes']
     assert 'Error vserver is not associated with a network interface: vserver' in results['msg']
@@ -229,7 +230,7 @@ def test_fail_with_vserver_not_found():
 
     results = create_and_apply(my_module, DEFAULT_ARGS, fail=True)
     print('Info: %s' % results)
-    assert_no_warnings_except_zapi()
+    assert_warning_was_raised(netapp_utils.ZAPI_DEPRECATION_MESSAGE)
     assert 'notes' in results
     assert "NOTE: application console not found for user: user1: ['http', 'ontapi']" in results['notes']
     assert 'Error getting vserver in list_interfaces: vserver: not found' in results['msg']
@@ -245,7 +246,7 @@ def test_fail_with_vserver_error_on_get_svms():
 
     results = create_and_apply(my_module, DEFAULT_ARGS, fail=True)
     print('Info: %s' % results)
-    assert_no_warnings_except_zapi()
+    assert_warning_was_raised(netapp_utils.ZAPI_DEPRECATION_MESSAGE)
     assert 'notes' in results
     assert "NOTE: application console not found for user: user1: ['http', 'ontapi']" in results['notes']
     assert 'Error getting vserver in list_interfaces: vserver: calling: svm/svms: got Expected error.' in results['msg']
@@ -263,7 +264,7 @@ def test_note_with_vserver_no_management_service():
 
     results = create_and_apply(my_module, DEFAULT_ARGS)
     print('Info: %s' % results)
-    assert_no_warnings_except_zapi()
+    assert_warning_was_raised(netapp_utils.ZAPI_DEPRECATION_MESSAGE)
     assert 'notes' in results
     assert 'no management policy in services' in results['notes'][2]
 
@@ -289,7 +290,7 @@ def test_fail_zapi_error():
     ])
     results = create_and_apply(my_module, DEFAULT_ARGS, fail=True)
     print('Info: %s' % results)
-    assert_no_warnings_except_zapi()
+    assert_warning_was_raised(netapp_utils.ZAPI_DEPRECATION_MESSAGE)
     assert 'notes' not in results
     assert 'Unclassified, see msg' in results['msg']
     results = create_and_apply(my_module, DEFAULT_ARGS, fail=True)
@@ -310,7 +311,7 @@ def test_fail_rest_error():
     ])
     results = create_and_apply(my_module, DEFAULT_ARGS, fail=True)
     print('Info: %s' % results)
-    assert_no_warnings_except_zapi()
+    assert_warning_was_raised(netapp_utils.ZAPI_DEPRECATION_MESSAGE)
     assert 'notes' not in results
     assert 'Other error for hostname: 10.10.10.10 using REST: Unreachable.' in results['msg']
     results = create_and_apply(my_module, DEFAULT_ARGS, fail=True)
