@@ -1,4 +1,4 @@
-# (c) 2022-2023, NetApp, Inc
+# (c) 2022-2025, NetApp, Inc
 # GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
 
 from __future__ import (absolute_import, division, print_function)
@@ -166,6 +166,7 @@ SRR = rest_responses({
         "audit_event_selector": {"access": "all", "permission": "all"},
         "name": "bucket1",
         "comment": "S3 bucket.",
+        "snapshot_policy": {"name": "none"},
         "svm": {"name": "svm1", "uuid": "02c9e252-41be-11e9-81d5-00a0986138f7"},
         "volume": {"uuid": "1cd8a442-86d1-11e0-abcd-123478563412"}
     }, None),
@@ -409,7 +410,7 @@ def test_low_version():
     ])
     error = create_module(my_module, DEFAULT_ARGS, fail=True)['msg']
     print('Info: %s' % error)
-    msg = 'Error: na_ontap_s3_bucket only supports REST, and requires ONTAP 9.8.0 or later.  Found: 9.7.0.'
+    msg = 'Error: na_ontap_s3_buckets only supports REST, and requires ONTAP 9.8.0 or later.  Found: 9.7.0.'
     assert msg in error
 
 
@@ -574,6 +575,16 @@ def test_create_s3_bucket_error():
     assert 'Error creating S3 bucket bucket1: calling: protocols/s3/buckets: got Expected error.' == error
 
 
+def test_create_s3_bucket_with_versioning_state_9_11():
+    register_responses([
+        ('GET', 'cluster', SRR['is_rest_9_11_1']),
+        ('GET', 'protocols/s3/buckets', SRR['empty_records']),
+        ('POST', 'protocols/s3/buckets', SRR['empty_good'])
+    ])
+    module_args = {'versioning_state': 'enabled'}
+    assert create_and_apply(my_module, DEFAULT_ARGS, module_args)['changed']
+
+
 def test_delete_s3_bucket():
     register_responses([
         ('GET', 'cluster', SRR['is_rest_9_10_1']),
@@ -691,6 +702,17 @@ def test_modify_s3_bucket_policy_statements_conditions():
     assert create_and_apply(my_module, DEFAULT_ARGS, module_args)['changed']
 
 
+def test_modify_s3_bucket_snapshot_policy():
+    register_responses([
+        ('GET', 'cluster', SRR['is_rest_9_16_1']),
+        ('GET', 'protocols/s3/buckets', SRR['s3_bucket_9_10']),
+        ('GET', 'storage/volumes/1cd8a442-86d1-11e0-abcd-123478563412', SRR['volume_info']),
+        ('PATCH', 'protocols/s3/buckets/02c9e252-41be-11e9-81d5-00a0986138f7/414b29a1-3b26-11e9-bd58-0050568ea055', SRR['empty_good']),
+    ])
+    module_args = {'snapshot_policy': 'default-1weekly'}
+    assert create_and_apply(my_module, DEFAULT_ARGS, module_args)['changed']
+
+
 def test_error_when_try_set_empty_dict_to_policy():
     register_responses([
         ('GET', 'cluster', SRR['is_rest_9_10_1'])
