@@ -26,8 +26,8 @@ except ImportError:
 if not HAS_SF_COMMON:
     pytestmark = pytest.mark.skip('skipping as missing required solidfire.common')
 
-if not netapp_utils.has_netapp_lib():
-    pytestmark = pytest.mark.skip('skipping as missing required netapp_lib')
+# if not netapp_utils.has_netapp_lib():
+#     pytestmark = pytest.mark.skip('skipping as missing required netapp_lib')
 
 
 DEFAULT_ARGS = {
@@ -207,7 +207,7 @@ def test_module_fail_when_required_args_missing():
     assert create_module(my_module, {}, fail=True)['msg'] == msg
 
 
-def test_module_fail_unsuuported_rest_options():
+def test_module_fail_unsupported_rest_options():
     ''' required arguments are reported as errors '''
     module_args = {
         "use_rest": "never",
@@ -247,6 +247,7 @@ def test_negative_zapi_unsupported_options():
     assert call_main(my_main, DEFAULT_ARGS, module_args, fail=True)['msg'] == msg
 
 
+@pytest.mark.skipif(not netapp_utils.has_netapp_lib(), reason="skipping as missing required netapp_lib")
 @patch('time.sleep')
 def test_successful_create_with_source(dont_sleep):
     ''' creating snapmirror and testing idempotency '''
@@ -272,6 +273,7 @@ def test_successful_create_with_source(dont_sleep):
     assert not call_main(my_main, DEFAULT_ARGS, module_args)['changed']
 
 
+@pytest.mark.skipif(not netapp_utils.has_netapp_lib(), reason="skipping as missing required netapp_lib")
 @patch('time.sleep')
 def test_successful_create_with_peer(dont_sleep):
     ''' creating snapmirror and testing idempotency '''
@@ -286,6 +288,7 @@ def test_successful_create_with_peer(dont_sleep):
     assert call_main(my_main, DEFAULT_ARGS, module_args)['changed']
 
 
+@pytest.mark.skipif(not netapp_utils.has_netapp_lib(), reason="skipping as missing required netapp_lib")
 @patch('time.sleep')
 def test_negative_break(dont_sleep):
     ''' breaking snapmirror to test quiesce time-delay failure '''
@@ -293,7 +296,8 @@ def test_negative_break(dont_sleep):
         ('ZAPI', 'snapmirror-get-iter', ZRR['sm_info']),
         ('ZAPI', 'vserver-peer-get-iter', ZRR['vserver_peer_info']),    # validate source svm
         ('ZAPI', 'snapmirror-quiesce', ZRR['success']),
-        ('ZAPI', 'snapmirror-get-iter', ZRR['sm_info']),                # 5 retries
+        ('ZAPI', 'snapmirror-get-iter', ZRR['sm_info']),                # 6 retries
+        ('ZAPI', 'snapmirror-get-iter', ZRR['sm_info']),
         ('ZAPI', 'snapmirror-get-iter', ZRR['sm_info']),
         ('ZAPI', 'snapmirror-get-iter', ZRR['sm_info']),
         ('ZAPI', 'snapmirror-get-iter', ZRR['sm_info']),
@@ -303,12 +307,14 @@ def test_negative_break(dont_sleep):
         "use_rest": "never",
         "source_hostname": "10.10.10.10",
         "relationship_state": "broken",
+        "quiesced_time_out": 60,
         "relationship_type": "data_protection",
     }
-    msg = "Taking a long time to quiesce SnapMirror relationship, try again later"
+    msg = "Taking a long time to quiesce SnapMirror relationship after 60 seconds, try again later"
     assert call_main(my_main, DEFAULT_ARGS, module_args, fail=True)['msg'] == msg
 
 
+@pytest.mark.skipif(not netapp_utils.has_netapp_lib(), reason="skipping as missing required netapp_lib")
 @patch('time.sleep')
 def test_successful_break(dont_sleep):
     ''' breaking snapmirror and testing idempotency '''
@@ -334,6 +340,7 @@ def test_successful_break(dont_sleep):
     assert not call_main(my_main, DEFAULT_ARGS, module_args)['changed']
 
 
+@pytest.mark.skipif(not netapp_utils.has_netapp_lib(), reason="skipping as missing required netapp_lib")
 def test_successful_create_without_initialize():
     ''' creating snapmirror and testing idempotency '''
     register_responses([
@@ -390,6 +397,7 @@ def test_set_element_connection(mock_create_sf_cx):
     assert elem is not None
 
 
+@pytest.mark.skipif(not netapp_utils.has_netapp_lib(), reason="skipping as missing required netapp_lib")
 @patch('time.sleep')
 @patch('ansible_collections.netapp.ontap.plugins.modules.na_ontap_snapmirror.NetAppONTAPSnapmirror.set_element_connection')
 def test_successful_element_ontap_create(connection, dont_sleep):
@@ -421,6 +429,7 @@ def test_successful_element_ontap_create(connection, dont_sleep):
     assert not call_main(my_main, DEFAULT_ARGS, module_args)['changed']
 
 
+@pytest.mark.skipif(not netapp_utils.has_netapp_lib(), reason="skipping as missing required netapp_lib")
 @patch('time.sleep')
 @patch('ansible_collections.netapp.ontap.plugins.modules.na_ontap_snapmirror.NetAppONTAPSnapmirror.set_element_connection')
 def test_successful_ontap_element_create(connection, dont_sleep):
@@ -453,6 +462,7 @@ def test_successful_ontap_element_create(connection, dont_sleep):
     assert not call_main(my_main, DEFAULT_ARGS, module_args)['changed']
 
 
+@pytest.mark.skipif(not netapp_utils.has_netapp_lib(), reason="skipping as missing required netapp_lib")
 @patch('time.sleep')
 def test_successful_delete(dont_sleep):
     ''' deleting snapmirror and testing idempotency '''
@@ -479,6 +489,7 @@ def test_successful_delete(dont_sleep):
     assert not call_main(my_main, DEFAULT_ARGS, module_args)['changed']
 
 
+@pytest.mark.skipif(not netapp_utils.has_netapp_lib(), reason="skipping as missing required netapp_lib")
 @patch('time.sleep')
 def test_successful_delete_without_source_hostname_check(dont_sleep):
     ''' source cluster hostname is optional when source is unknown'''
@@ -498,6 +509,7 @@ def test_successful_delete_without_source_hostname_check(dont_sleep):
     assert call_main(my_main, DEFAULT_ARGS, module_args)['changed']
 
 
+@pytest.mark.skipif(not netapp_utils.has_netapp_lib(), reason="skipping as missing required netapp_lib")
 @patch('time.sleep')
 def test_successful_delete_with_error_on_break(dont_sleep):
     ''' source cluster hostname is optional when source is unknown'''
@@ -519,6 +531,7 @@ def test_successful_delete_with_error_on_break(dont_sleep):
     assert_warning_was_raised('Ignored error(s): Error breaking SnapMirror relationship: NetApp API failed. Reason - 12345:synthetic error for UT purpose')
 
 
+@pytest.mark.skipif(not netapp_utils.has_netapp_lib(), reason="skipping as missing required netapp_lib")
 @patch('time.sleep')
 def test_negative_delete_error_with_error_on_break(dont_sleep):
     ''' source cluster hostname is optional when source is unknown'''
@@ -539,6 +552,7 @@ def test_negative_delete_error_with_error_on_break(dont_sleep):
     assert 'Error deleting SnapMirror:' in error
 
 
+@pytest.mark.skipif(not netapp_utils.has_netapp_lib(), reason="skipping as missing required netapp_lib")
 def test_negative_delete_with_destination_path_missing():
     ''' with misisng destination_path'''
     register_responses([
@@ -554,6 +568,7 @@ def test_negative_delete_with_destination_path_missing():
     assert call_main(my_main, args, module_args, fail=True)['msg'] == msg
 
 
+@pytest.mark.skipif(not netapp_utils.has_netapp_lib(), reason="skipping as missing required netapp_lib")
 def test_successful_delete_check_get_destination():
     register_responses([
         ('ZAPI', 'snapmirror-get-destination-iter', ZRR['sm_info']),
@@ -570,6 +585,7 @@ def test_successful_delete_check_get_destination():
     assert my_obj.get_destination() is None
 
 
+@pytest.mark.skipif(not netapp_utils.has_netapp_lib(), reason="skipping as missing required netapp_lib")
 def test_snapmirror_release():
     register_responses([
         ('ZAPI', 'snapmirror-release', ZRR['success']),
@@ -587,6 +603,7 @@ def test_snapmirror_release():
     assert my_obj.snapmirror_release() is None
 
 
+@pytest.mark.skipif(not netapp_utils.has_netapp_lib(), reason="skipping as missing required netapp_lib")
 def test_snapmirror_resume():
     ''' resuming snapmirror '''
     register_responses([
@@ -608,6 +625,7 @@ def test_snapmirror_resume():
     assert not call_main(my_main, DEFAULT_ARGS, module_args)['changed']
 
 
+@pytest.mark.skipif(not netapp_utils.has_netapp_lib(), reason="skipping as missing required netapp_lib")
 def test_snapmirror_restore():
     ''' restore snapmirror '''
     register_responses([
@@ -628,6 +646,7 @@ def test_snapmirror_restore():
     assert call_main(my_main, DEFAULT_ARGS, module_args)['changed']
 
 
+@pytest.mark.skipif(not netapp_utils.has_netapp_lib(), reason="skipping as missing required netapp_lib")
 @patch('time.sleep')
 def test_successful_abort(dont_sleep):
     ''' aborting snapmirror and testing idempotency '''
@@ -651,6 +670,7 @@ def test_successful_abort(dont_sleep):
     assert not call_main(my_main, DEFAULT_ARGS, module_args)['changed']
 
 
+@pytest.mark.skipif(not netapp_utils.has_netapp_lib(), reason="skipping as missing required netapp_lib")
 def test_successful_modify():
     ''' modifying snapmirror and testing idempotency '''
     register_responses([
@@ -680,6 +700,7 @@ def test_successful_modify():
     assert not call_main(my_main, DEFAULT_ARGS, module_args)['changed']
 
 
+@pytest.mark.skipif(not netapp_utils.has_netapp_lib(), reason="skipping as missing required netapp_lib")
 @patch('time.sleep')
 def test_successful_initialize(dont_sleep):
     ''' initialize snapmirror and testing idempotency '''
@@ -710,6 +731,7 @@ def test_successful_initialize(dont_sleep):
     assert call_main(my_main, DEFAULT_ARGS, module_args)['changed']
 
 
+@pytest.mark.skipif(not netapp_utils.has_netapp_lib(), reason="skipping as missing required netapp_lib")
 def test_successful_update():
     ''' update snapmirror and testing idempotency '''
     register_responses([
@@ -737,6 +759,7 @@ def test_successful_update():
     assert call_main(my_main, DEFAULT_ARGS, module_args)['changed']
 
 
+@pytest.mark.skipif(not netapp_utils.has_netapp_lib(), reason="skipping as missing required netapp_lib")
 @patch('ansible_collections.netapp.ontap.plugins.modules.na_ontap_snapmirror.NetAppONTAPSnapmirror.set_element_connection')
 def test_elementsw_no_source_path(connection):
     ''' elementsw_volume_exists '''
@@ -757,6 +780,7 @@ def test_elementsw_no_source_path(connection):
     assert error in call_main(my_main, DEFAULT_ARGS, module_args, fail=True)['msg']
 
 
+@pytest.mark.skipif(not netapp_utils.has_netapp_lib(), reason="skipping as missing required netapp_lib")
 def test_elementsw_volume_exists():
     ''' elementsw_volume_exists '''
     mock_helper = Mock()
@@ -775,6 +799,7 @@ def test_elementsw_volume_exists():
     assert error in expect_and_capture_ansible_exception(my_obj.check_if_elementsw_volume_exists, 'fail', '1234', mock_helper)['msg']
 
 
+@pytest.mark.skipif(not netapp_utils.has_netapp_lib(), reason="skipping as missing required netapp_lib")
 def test_elementsw_svip_exists():
     ''' svip_exists '''
     mock_elem = Mock()
@@ -794,6 +819,7 @@ def test_elementsw_svip_exists():
     assert my_obj.validate_elementsw_svip('10.10.10.10:/lun/1000', mock_elem) is None
 
 
+@pytest.mark.skipif(not netapp_utils.has_netapp_lib(), reason="skipping as missing required netapp_lib")
 def test_elementsw_svip_exists_negative():
     ''' svip_exists negative testing'''
     mock_elem = Mock()
@@ -811,6 +837,7 @@ def test_elementsw_svip_exists_negative():
     assert error in expect_and_capture_ansible_exception(my_obj.validate_elementsw_svip, 'fail', 'svip', mock_elem)['msg']
 
 
+@pytest.mark.skipif(not netapp_utils.has_netapp_lib(), reason="skipping as missing required netapp_lib")
 @patch('ansible_collections.netapp.ontap.plugins.modules.na_ontap_snapmirror.NetAppONTAPSnapmirror.set_element_connection')
 def test_check_elementsw_params_source(connection):
     ''' check elementsw parameters for source '''
@@ -827,6 +854,7 @@ def test_check_elementsw_params_source(connection):
     assert my_obj.check_elementsw_parameters('source') is None
 
 
+@pytest.mark.skipif(not netapp_utils.has_netapp_lib(), reason="skipping as missing required netapp_lib")
 def test_check_elementsw_params_negative():
     ''' check elementsw parameters for source negative testing '''
     args = dict(DEFAULT_ARGS)
@@ -839,6 +867,7 @@ def test_check_elementsw_params_negative():
     assert msg in expect_and_capture_ansible_exception(my_obj.check_elementsw_parameters, 'fail', 'source')['msg']
 
 
+@pytest.mark.skipif(not netapp_utils.has_netapp_lib(), reason="skipping as missing required netapp_lib")
 def test_check_elementsw_params_invalid():
     ''' check elementsw parameters for source invalid testing '''
     module_args = {
@@ -854,6 +883,7 @@ def test_check_elementsw_params_invalid():
     assert msg in expect_and_capture_ansible_exception(my_obj.check_elementsw_parameters, 'fail', 'source')['msg']
 
 
+@pytest.mark.skipif(not netapp_utils.has_netapp_lib(), reason="skipping as missing required netapp_lib")
 def test_elementsw_source_path_format():
     ''' test element_source_path_format_matches '''
     register_responses([
@@ -873,6 +903,7 @@ def test_elementsw_source_path_format():
     assert my_obj.element_source_path_format_matches('10.10.10.10:/lun/10') is not None
 
 
+@pytest.mark.skipif(not netapp_utils.has_netapp_lib(), reason="skipping as missing required netapp_lib")
 def test_remote_volume_exists():
     ''' test check_if_remote_volume_exists '''
     register_responses([
@@ -890,6 +921,7 @@ def test_remote_volume_exists():
     assert my_obj.check_if_remote_volume_exists()
 
 
+@pytest.mark.skipif(not netapp_utils.has_netapp_lib(), reason="skipping as missing required netapp_lib")
 @patch('time.sleep')
 def test_if_all_methods_catch_exception(dont_sleep):
     module_args = {
@@ -934,6 +966,7 @@ def test_if_all_methods_catch_exception(dont_sleep):
             assert error in expect_and_capture_ansible_exception(function, 'fail')['msg']
 
 
+@pytest.mark.skipif(not netapp_utils.has_netapp_lib(), reason="skipping as missing required netapp_lib")
 @patch('time.sleep')
 def test_successful_rest_create(dont_sleep):
     ''' creating snapmirror and testing idempotency '''
@@ -1114,7 +1147,8 @@ def test_rest_sm_break_fails_if_uninit():
     assert call_main(my_main, DEFAULT_ARGS, module_args, fail=True)['msg'] == msg
 
 
-def test_rest_sm_break_fails_if_load_sharing_or_vault():
+@pytest.mark.skipif(not netapp_utils.has_netapp_lib(), reason="skipping as missing required netapp_lib")
+def test_sm_break_fails_if_load_sharing_or_vault():
     ''' testing snapmirror break fails for load_sharing or vault types '''
     register_responses([
         ('ZAPI', 'snapmirror-get-iter', ZRR['sm_info_snapmirrored_load_sharing']),
@@ -1145,13 +1179,15 @@ def test_rest_snapmirror_quiesce_fail_when_state_not_paused(dont_sleep):
         ('GET', 'snapmirror/relationships', SRR['sm_get_mirrored']),   # second fail
         ('GET', 'snapmirror/relationships', SRR['sm_get_mirrored']),   # third fail
         ('GET', 'snapmirror/relationships', SRR['sm_get_mirrored']),   # fourth fail
+        ('GET', 'snapmirror/relationships', SRR['sm_get_mirrored']),   # fifth fail
     ])
     module_args = {
         "use_rest": "always",
         "relationship_state": "broken",
+        "quiesced_time_out": 60,
         "validate_source_path": False
     }
-    msg = "Taking a long time to quiesce SnapMirror relationship, try again later"
+    msg = "Taking a long time to quiesce SnapMirror relationship after 60 seconds, try again later"
     assert call_main(my_main, DEFAULT_ARGS, module_args, fail=True)['msg'] == msg
 
 
@@ -1809,6 +1845,28 @@ def test_wait_for_idle_status(dont_sleep):
     assert_warning_was_raised('SnapMirror relationship is still transferring after 60 seconds.')
 
 
+@patch('time.sleep')
+def test_wait_for_quiesced_status(dont_sleep):
+    # validate wait time and time-out
+    register_responses([
+        ('GET', 'cluster', SRR['is_rest_96']),
+        ('GET', 'snapmirror/relationships', SRR['zero_records']),
+        ('GET', 'snapmirror/relationships', SRR['sm_get_mirrored']),
+        ('GET', 'snapmirror/relationships', SRR['sm_get_mirrored']),
+        ('GET', 'snapmirror/relationships', SRR['sm_get_mirrored']),
+        ('GET', 'snapmirror/relationships', SRR['sm_get_mirrored']),
+        ('GET', 'snapmirror/relationships', SRR['sm_get_mirrored']),
+    ])
+    module_args = {
+        "use_rest": "always",
+        "quiesced_time_out": 60,
+    }
+    my_obj = create_module(my_module, DEFAULT_ARGS, module_args)
+    error = expect_and_capture_ansible_exception(my_obj.wait_for_quiesced_status, 'fail')
+    assert 'Taking a long time to quiesce SnapMirror relationship after 60 seconds, try again later' in error['msg']
+
+
+@pytest.mark.skipif(not netapp_utils.has_netapp_lib(), reason="skipping as missing required netapp_lib")
 def test_dp_to_xdp():
     # with ZAPI, DP is transformed to XDP to match ONTAP behavior
     register_responses([
@@ -1825,6 +1883,7 @@ def test_dp_to_xdp():
     assert my_obj.parameters['relationship_type'] == 'extended_data_protection'
 
 
+@pytest.mark.skipif(not netapp_utils.has_netapp_lib(), reason="skipping as missing required netapp_lib")
 def test_cannot_change_rtype():
     # with ZAPI, can't change relationship_type
     register_responses([
@@ -1847,7 +1906,7 @@ def test_module_fail_when_netapp_lib_missing():
     module_args = {
         'use_rest': 'never',
     }
-    assert 'Error: the python NetApp-Lib module is required.  Import error: None' in call_main(my_main, DEFAULT_ARGS, module_args, fail=True)['msg']
+    assert 'Error: the python NetApp-Lib module is required.  Import error:' in call_main(my_main, DEFAULT_ARGS, module_args, fail=True)['msg']
 
 
 def test_check_health():
@@ -1905,6 +1964,7 @@ def test_snapmirror_release_rest():
     assert my_obj.snapmirror_release() is None
 
 
+@pytest.mark.skipif(not netapp_utils.has_netapp_lib(), reason="skipping as missing required netapp_lib")
 @patch('ansible_collections.netapp.ontap.plugins.module_utils.netapp.has_netapp_lib')
 def test_negative_set_source_cluster_connection(mock_netapp_lib):
     register_responses([
@@ -1929,3 +1989,20 @@ def test_negative_set_source_cluster_connection(mock_netapp_lib):
     my_obj.parameters['peer_options']['use_rest'] = 'auto'
     error = "Error: the python NetApp-Lib module is required.  Import error: None"
     assert error in expect_and_capture_ansible_exception(my_obj.set_source_cluster_connection, 'fail')['msg']
+
+
+@patch('time.sleep')
+def test_rest_synchronous_sm_quick_resync_when_state_is_broken(dont_sleep):
+    ''' resync when snapmirror state is broken and relationship_state active  '''
+    register_responses([
+        ('GET', 'cluster', SRR['is_rest_9_16_1']),
+        ('GET', 'snapmirror/relationships', SRR['sm_sync_get_broken']),  # apply first sm_get with state broken_off
+        ('PATCH', 'snapmirror/relationships/b5ee4571-5429-11ec-9779-005056b39a06', SRR['success']),  # sm resync response
+        ('GET', 'snapmirror/relationships', SRR['sm_sync_get_mirrored']),  # check for idle
+        ('GET', 'snapmirror/relationships', SRR['sm_sync_get_mirrored']),  # check_health calls sm_get
+    ])
+    module_args = {
+        "use_rest": "always",
+        "quick_resync": True
+    }
+    assert call_main(my_main, DEFAULT_ARGS, module_args)['changed']
