@@ -1,4 +1,4 @@
-# (c) 2020, NetApp, Inc
+# (c) 2020-2025, NetApp, Inc
 # GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
 
 """ unit tests NetApp StorageGRID Org Container Ansible module: na_sg_org_container"""
@@ -10,8 +10,6 @@ import json
 import pytest
 import sys
 
-
-import ansible_collections.netapp.storagegrid.plugins.module_utils.netapp as netapp_utils
 from ansible_collections.netapp.storagegrid.tests.unit.compat import unittest
 from ansible_collections.netapp.storagegrid.tests.unit.compat.mock import patch
 from ansible.module_utils import basic
@@ -20,8 +18,8 @@ from ansible_collections.netapp.storagegrid.plugins.modules.na_sg_org_container
     SgOrgContainer as org_container_module,
 )
 
-if not netapp_utils.HAS_REQUESTS and sys.version_info < (2, 7):
-    pytestmark = pytest.mark.skip("Skipping Unit Tests on 2.6 as requests is not available")
+if sys.version_info < (3, 11):
+    pytestmark = pytest.mark.skip("Skipping Unit Tests on 3.11")
 
 # REST API canned responses when mocking send_request
 SRR = {
@@ -36,6 +34,7 @@ SRR = {
     "delete_good": (None, None),
     "version_114": ({"data": {"productVersion": "11.4.0-20200721.1338.d3969b3"}}, None),
     "version_116": ({"data": {"productVersion": "11.6.0-20211120.0301.850531e"}}, None),
+    "version_119": ({"data": {"productVersion": "11.9.0-20241024.4181.246131d"}}, None),
     "global_compliance_disabled": (
         {
             "data": {
@@ -85,6 +84,10 @@ SRR = {
     "org_container_versioning_disabled": ({"data": {"versioningEnabled": False, "versioningSuspended": False}}, None),
     "org_container_versioning_enabled": ({"data": {"versioningEnabled": True, "versioningSuspended": False}}, None),
     "org_container_versioning_suspended": ({"data": {"versioningEnabled": False, "versioningSuspended": True}}, None),
+    "consistency": ({"data": {"consistency": "available"}}, None),
+    "consistency_updated": ({"data": {"consistency": "all"}}, None),
+    "org_container_capacity_limit": ({"data": {"quotaObjectBytes": 100000}}, None),
+    "org_container_capacity_limit_updated": ({"data": {"quotaObjectBytes": 200000}}, None),
 }
 
 
@@ -180,7 +183,7 @@ class TestMyModule(unittest.TestCase):
     def test_module_fail_when_required_args_present(self, mock_request):
         """required arguments are reported as errors"""
         mock_request.side_effect = [
-            SRR["version_114"],
+            SRR["version_116"],
         ]
         with pytest.raises(AnsibleExitJson) as exc:
             set_module_args(self.set_default_args_pass_check())
@@ -193,7 +196,7 @@ class TestMyModule(unittest.TestCase):
     def test_create_na_sg_org_container_pass(self, mock_request):
         set_module_args(self.set_args_create_na_sg_org_container())
         mock_request.side_effect = [
-            SRR["version_114"],
+            SRR["version_116"],
             SRR["empty_good"],  # get
             SRR["org_container_record"],  # post
             SRR["end_of_sequence"],
@@ -208,7 +211,7 @@ class TestMyModule(unittest.TestCase):
     def test_idempotent_create_na_sg_org_container_pass(self, mock_request):
         set_module_args(self.set_args_create_na_sg_org_container())
         mock_request.side_effect = [
-            SRR["version_114"],
+            SRR["version_116"],
             SRR["org_containers"],  # get
             SRR["end_of_sequence"],
         ]
@@ -224,7 +227,7 @@ class TestMyModule(unittest.TestCase):
         args["compliance"] = {"auto_delete": False, "legal_hold": False}
         set_module_args(args)
         mock_request.side_effect = [
-            SRR["version_114"],
+            SRR["version_116"],
             SRR["org_containers"],  # get
             SRR["org_container_record_update"],  # put
             SRR["end_of_sequence"],
@@ -239,7 +242,7 @@ class TestMyModule(unittest.TestCase):
     def test_delete_na_sg_org_container_pass(self, mock_request):
         set_module_args(self.set_args_delete_na_sg_org_container())
         mock_request.side_effect = [
-            SRR["version_114"],
+            SRR["version_116"],
             SRR["org_containers"],  # get
             SRR["delete_good"],  # delete
             SRR["end_of_sequence"],
@@ -340,3 +343,99 @@ class TestMyModule(unittest.TestCase):
             my_obj.apply()
         print("Info: test_update_na_sg_org_container_enable_versioning_pass: %s" % repr(exc.value.args[0]))
         assert exc.value.args[0]["changed"]
+
+    @patch("ansible_collections.netapp.storagegrid.plugins.module_utils.netapp.SGRestAPI.send_request")
+    def test_module_fail_minimum_version_not_met_versioning(self, mock_request):
+        args = self.set_args_create_na_sg_org_container()
+        args["consistency"] = "available"
+        set_module_args(args)
+        mock_request.side_effect = [
+            SRR["version_114"],  # get
+        ]
+        with pytest.raises(AnsibleFailJson) as exc:
+            org_container_module()
+        print("Info: test_module_fail_minimum_version_not_met_consistency: %s" % exc.value.args[0]["msg"])
+
+    @patch("ansible_collections.netapp.storagegrid.plugins.module_utils.netapp.SGRestAPI.send_request")
+    def test_module_fail_minimum_version_not_met_capacity_limit(self, mock_request):
+        args = self.set_args_create_na_sg_org_container()
+        args["capacity_limit"] = 100000
+        set_module_args(args)
+        mock_request.side_effect = [
+            SRR["version_114"],  # get
+        ]
+        with pytest.raises(AnsibleFailJson) as exc:
+            org_container_module()
+        print("Info: test_module_fail_minimum_version_not_met_capacity_limit: %s" % exc.value.args[0]["msg"])
+
+    @patch("ansible_collections.netapp.storagegrid.plugins.module_utils.netapp.SGRestAPI.send_request")
+    def test_create_na_sg_org_container_with_consistency_pass(self, mock_request):
+        args = self.set_args_create_na_sg_org_container()
+        args["consistency"] = "available"
+        set_module_args(args)
+        mock_request.side_effect = [
+            SRR["version_116"],
+            SRR["empty_good"],  # get
+            SRR["org_container_record"],  # post
+            SRR["consistency"],  # post
+            SRR["end_of_sequence"],
+        ]
+        my_obj = org_container_module()
+        with pytest.raises(AnsibleExitJson) as exc:
+            my_obj.apply()
+        print("Info: test_create_na_sg_org_container_with_consistency_pass: %s" % repr(exc.value.args[0]))
+        assert exc.value.args[0]["changed"]
+
+    @patch("ansible_collections.netapp.storagegrid.plugins.module_utils.netapp.SGRestAPI.send_request")
+    def test_create_na_sg_org_container_with_capacity_limit_pass(self, mock_request):
+        args = self.set_args_create_na_sg_org_container()
+        args["capacity_limit"] = 100000
+        set_module_args(args)
+        mock_request.side_effect = [
+            SRR["version_119"],
+            SRR["empty_good"],  # get
+            SRR["org_container_record"],  # post
+            SRR["org_container_capacity_limit"],  # post
+            SRR["end_of_sequence"],
+        ]
+        my_obj = org_container_module()
+        with pytest.raises(AnsibleExitJson) as exc:
+            my_obj.apply()
+        print("Info: test_create_na_sg_org_container_with_capacity_limit_pass: %s" % repr(exc.value.args[0]))
+        assert exc.value.args[0]["changed"]
+
+    @patch("ansible_collections.netapp.storagegrid.plugins.module_utils.netapp.SGRestAPI.send_request")
+    def test_update_na_sg_org_container_consistency_setting_pass(self, mock_request):
+        args = self.set_args_create_na_sg_org_container()
+        args["consistency"] = "all"
+        set_module_args(args)
+        mock_request.side_effect = [
+            SRR["version_116"],
+            SRR["org_containers"],  # get
+            SRR["consistency"],  # put
+            SRR["consistency_updated"],
+            SRR["end_of_sequence"],
+        ]
+        my_obj = org_container_module()
+        with pytest.raises(AnsibleExitJson) as exc:
+            my_obj.apply()
+        print("Info: test_update_na_sg_org_container_consistency_setting_pass: %s" % repr(exc.value.args[0]))
+        assert exc.value.args[0]["changed"]
+
+    @patch("ansible_collections.netapp.storagegrid.plugins.module_utils.netapp.SGRestAPI.send_request")
+    def test_update_na_sg_org_container_capacity_limit_pass(self, mock_request):
+        args = self.set_args_create_na_sg_org_container()
+        args["capacity_limit"] = 200000
+        set_module_args(args)
+        mock_request.side_effect = [
+            SRR["version_119"],
+            SRR["org_containers"],  # get
+            SRR["org_container_capacity_limit"],  # get
+            SRR["org_container_capacity_limit_updated"],  # put
+            SRR["end_of_sequence"],
+        ]
+        my_obj = org_container_module()
+        with pytest.raises(AnsibleExitJson) as exc:
+            my_obj.apply()
+        print("Info: test_update_na_sg_org_container_capacity_limit_pass: %s" % repr(exc.value.args[0]))
+        assert exc.value.args[0]["changed"]
