@@ -39,6 +39,9 @@ API_APPS_ENDPOINTS = dict(
         "providers": {},
         "provider_networks": {},
     },
+    core={
+        "data_sources": {},
+    },
     dcim={
         "cables": {},
         "console_ports": {},
@@ -78,6 +81,7 @@ API_APPS_ENDPOINTS = dict(
         "sites": {},
         "site_groups": {},
         "virtual_chassis": {},
+        "mac_addresses": {},
     },
     extras={
         "config_contexts": {},
@@ -113,6 +117,7 @@ API_APPS_ENDPOINTS = dict(
         "tenants": {},
         "tenant_groups": {},
         "contacts": {},
+        "contact_assignments": {},
         "contact_groups": {},
         "contact_roles": {},
     },
@@ -226,6 +231,7 @@ QUERY_TYPES = dict(
     webhook="name",
     wireless_lan="ssid",
     wireless_lan_group="slug",
+    mac_address="mac_address",
 )
 
 # Specifies keys within data that need to be converted to ID and the endpoint to be used when queried
@@ -275,6 +281,7 @@ CONVERT_TO_ID = {
     "ipsec_profile": "ipsec_profiles",
     "location": "locations",
     "lag": "interfaces",
+    "primary_mac_address": "mac_addresses",
     "manufacturer": "manufacturers",
     "master": "devices",
     "module": "modules",
@@ -363,11 +370,13 @@ ENDPOINT_NAME_MAPPING = {
     "console_server_ports": "console_server_port",
     "console_server_port_templates": "console_server_port_template",
     "contacts": "contact",
+    "contact_assignments": "contact_assignment",
     "contact_groups": "contact_group",
     "contact_roles": "contact_role",
     "custom_fields": "custom_field",
     "custom_field_choice_sets": "choice_set",
     "custom_links": "custom_link",
+    "data_sources": "data_source",
     "device_bays": "device_bay",
     "device_bay_templates": "device_bay_template",
     "devices": "device",
@@ -434,6 +443,7 @@ ENDPOINT_NAME_MAPPING = {
     "wireless_lans": "wireless_lan",
     "wireless_lan_groups": "wireless_lan_group",
     "wireless_links": "wireless_link",
+    "mac_addresses": "mac_address",
 }
 
 ALLOWED_QUERY_PARAMS = {
@@ -472,12 +482,14 @@ ALLOWED_QUERY_PARAMS = {
     "console_server_port": set(["name", "device"]),
     "console_server_port_template": set(["name", "device_type"]),
     "contact": set(["name", "group"]),
+    "contact_assignment": set(["object_type", "object_id", "contact", "role"]),
     "contact_group": set(["name"]),
     "contact_role": set(["name"]),
     "custom_field": set(["name"]),
     "custom_field_choice_set": set(["name"]),
     "choice_set": set(["name"]),
     "custom_link": set(["name"]),
+    "data_source": set(["name"]),
     "dcim.consoleport": set(["name", "device"]),
     "dcim.consoleserverport": set(["name", "device"]),
     "dcim.frontport": set(["name", "device", "rear_port"]),
@@ -516,6 +528,7 @@ ALLOWED_QUERY_PARAMS = {
     ),
     "lag": set(["name"]),
     "location": set(["name", "slug", "site"]),
+    "mac_address": set(["mac_address"]),
     "module": set(["device", "module_bay", "module_type"]),
     "module_bay": set(["device", "name"]),
     "module_type": set(["model"]),
@@ -608,6 +621,7 @@ REQUIRED_ID_FIND = {
     "console_port_templates": set(["type"]),
     "console_server_ports": set(["type"]),
     "console_server_port_templates": set(["type"]),
+    "contact_assignments": set(["priority"]),
     "devices": set(["status", "face"]),
     "device_types": set(["subdevice_role"]),
     "front_ports": set(["type"]),
@@ -718,6 +732,7 @@ NETBOX_ARG_SPEC = dict(
     query_params=dict(required=False, type="list", elements="str"),
     validate_certs=dict(type="raw", default=True),
     cert=dict(type="raw", required=False),
+    headers=dict(type="dict", required=False),
 )
 
 
@@ -746,10 +761,11 @@ class NetboxModule(object):
         token = self.module.params["netbox_token"]
         ssl_verify = self.module.params["validate_certs"]
         cert = self.module.params["cert"]
+        headers = self.module.params["headers"]
 
         # Attempt to initiate connection to NetBox
         if nb_client is None:
-            self.nb = self._connect_netbox_api(url, token, ssl_verify, cert)
+            self.nb = self._connect_netbox_api(url, token, ssl_verify, cert, headers)
         else:
             self.nb = nb_client
             try:
@@ -799,10 +815,14 @@ class NetboxModule(object):
 
         return False
 
-    def _connect_netbox_api(self, url, token, ssl_verify, cert):
+    def _connect_netbox_api(self, url, token, ssl_verify, cert, headers=None):
         try:
             session = requests.Session()
             session.verify = ssl_verify
+            if isinstance(headers, str):
+                headers = json.load(headers)
+            if isinstance(headers, dict):
+                session.headers.update(headers)
             if cert:
                 session.cert = tuple(i for i in cert)
             nb = pynetbox.api(url, token=token)
@@ -1414,7 +1434,7 @@ class NetboxModule(object):
 
         # We need to assign the correct type for the assigned object so the user doesn't have to worry about this.
         # We determine it by whether or not they pass in a device or virtual_machine
-        if data.get("assigned_object"):
+        if data.get("assigned_object") and isinstance(data["assigned_object"], dict):
             if data["assigned_object"].get("device"):
                 data["assigned_object_type"] = "dcim.interface"
             if data["assigned_object"].get("virtual_machine"):
