@@ -62,7 +62,7 @@ def sort_hostvar_arrays(obj):
     if not hostvars:
         return
 
-    for _, host in hostvars.items():
+    for _, host in hostvars.items():  # pylint: disable=disallowed-name
         if interfaces := host.get("interfaces"):
             host["interfaces"] = sorted(interfaces, key=itemgetter("id"))
 
@@ -141,7 +141,7 @@ def main():
 
         if result:
             # Dictionary is not empty - print differences
-            print(json.dumps(result, sort_keys=True, indent=4))
+            print(result.to_json(indent=4))
             sys.exit(1)
         else:
             # Success, no differences
