@@ -62,12 +62,20 @@ options:
     - A virtual network interface (vif)
     type: str
     version_added: 1.14.0
+  context:
+    description:
+    - Name of fleet member on which to perform the operation.
+    - This requires the array receiving the request is a member of a fleet
+      and the context name to be a member of the same fleet.
+    type: str
+    default: ""
+    version_added: 1.40.0
 extends_documentation_fragment:
 - purestorage.flasharray.purestorage.fa
 """
 
 EXAMPLES = r"""
-- name: Delete exisitng DNS settings
+- name: Delete exisitng management DNS settings
   purestorage.flasharray.purefa_dns:
     state: absent
     fa_url: 10.10.10.2
@@ -93,6 +101,12 @@ EXAMPLES = r"""
     fa_url: 10.10.10.2
     api_token: e31060a7-21fc-e277-6240-25983c6c4592
 
+- name: Delete file DNS settings
+  purestorage.flasharray.purefa_dns:
+    state: absent
+    name: ad_dns
+    fa_url: 10.10.10.2
+    api_token: e31060a7-21fc-e277-6240-25983c6c4592
 """
 
 RETURN = r"""
@@ -100,18 +114,21 @@ RETURN = r"""
 
 HAS_PURESTORAGE = True
 try:
-    from pypureclient import flasharray
+    from pypureclient.flasharray import DnsPost, DnsPatch, ReferenceNoId
 except ImportError:
     HAS_PURESTORAGE = False
 
 from ansible.module_utils.basic import AnsibleModule
+from ansible_collections.purestorage.flasharray.plugins.module_utils.version import (
+    LooseVersion,
+)
 from ansible_collections.purestorage.flasharray.plugins.module_utils.purefa import (
-    get_system,
     get_array,
     purefa_argument_spec,
 )
 
 MULTIPLE_DNS = "2.15"
+CONTEXT_API_VERSION = "2.47"
 
 
 def remove(duplicate):
@@ -123,52 +140,84 @@ def remove(duplicate):
 
 
 def _get_source(module, array):
-    res = array.get_network_interfaces(names=[module.params["source"]])
-    if res.status_code == 200:
-        return True
+    api_version = array.get_rest_version()
+    if LooseVersion(CONTEXT_API_VERSION) <= LooseVersion(api_version):
+        res = array.get_network_interfaces(
+            names=[module.params["source"]], context_names=[module.params["context"]]
+        )
     else:
-        return False
+        res = array.get_network_interfaces(names=[module.params["source"]])
+    return bool(res.status_code == 200)
 
 
 def delete_dns(module, array):
     """Delete DNS settings"""
     changed = False
-    current_dns = array.get_dns()
-    if current_dns["domain"] == "" and current_dns["nameservers"] == [""]:
+    api_version = array.get_rest_version()
+    if LooseVersion(CONTEXT_API_VERSION) <= LooseVersion(api_version):
+        current_dns = list(
+            array.get_dns(context_names=[module.params["context"]]).items
+        )[0]
+    else:
+        current_dns = list(array.get_dns().items)[0]
+    if getattr(current_dns, "domain", None) in ["", None] and getattr(
+        current_dns, "nameservers", None
+    ) in [[""], None]:
         module.exit_json(changed=changed)
     else:
-        try:
-            changed = True
-            if not module.check_mode:
-                array.set_dns(domain="", nameservers=[])
-        except Exception:
-            module.fail_json(msg="Delete DNS settigs failed")
+        changed = True
+        if not module.check_mode:
+            if LooseVersion(CONTEXT_API_VERSION) <= LooseVersion(api_version):
+                res = array.delete_dns(
+                    names=["management"], context_names=[module.params["context"]]
+                )
+            else:
+                res = array.delete_dns(names=["management"])
+        if res.status_code != 200:
+            module.fail_json(
+                msg="Delete DNS settigs failed. Error: {0}".format(
+                    res.errors[0].message
+                )
+            )
     module.exit_json(changed=changed)
 
 
 def create_dns(module, array):
     """Set DNS settings"""
     changed = False
-    current_dns = array.get_dns()
+    api_version = array.get_rest_version()
+    current_dns = list(array.get_dns().items)[0]
     if current_dns["domain"] != module.params["domain"] or sorted(
         module.params["nameservers"]
     ) != sorted(current_dns["nameservers"]):
-        try:
-            changed = True
-            if not module.check_mode:
-                array.set_dns(
+        changed = True
+        if not module.check_mode:
+            res = array.patch_dns(
+                names=["management"],
+                dns=DnsPatch(
                     domain=module.params["domain"],
                     nameservers=module.params["nameservers"][0:3],
-                )
-        except Exception:
-            module.fail_json(msg="Set DNS settings failed: Check configuration")
+                ),
+            )
+        if res.status_code != 200:
+            module.fail_json(
+                msg="Set DNS settings failed. Error: {0}".format(res.errors[0].message)
+            )
     module.exit_json(changed=changed)
 
 
 def update_multi_dns(module, array):
     """Update a DNS configuration"""
     changed = False
-    current_dns = list(array.get_dns(names=[module.params["name"]]).items)[0]
+    api_version = array.get_rest_version()
+    if LooseVersion(CONTEXT_API_VERSION) <= LooseVersion(api_version):
+        current_dns = list(
+            array.get_dns(
+                names=[module.params["name"]], context_names=[module.params["context"]]
+            ).items
+        )[0]
+    else:
+        current_dns = list(array.get_dns(names=[module.params["name"]]).items)[0]
     new_dns = current_dns
     if module.params["domain"] and current_dns.domain != module.params["domain"]:
         new_dns.domain = module.params["domain"]
@@ -180,20 +229,31 @@ def update_multi_dns(module, array):
     ):
         new_dns.nameservers = module.params["nameservers"]
         changed = True
-    if (
-        module.params["source"] or module.params["source"] == ""
-    ) and current_dns.source.name != module.params["source"]:
+    if (module.params["source"] or module.params["source"] == "") and getattr(
+        current_dns.source, "name", ""
+    ) != module.params["source"]:
         new_dns.source.name = module.params["source"]
         changed = True
     if changed and not module.check_mode:
-        res = array.patch_dns(
-            names=[module.params["name"]],
-            dns=flasharray.Dns(
-                domain=new_dns.domain,
-                nameservers=new_dns.nameservers,
-                source=flasharray.ReferenceNoId(module.params["source"]),
-            ),
-        )
+        if LooseVersion(CONTEXT_API_VERSION) <= LooseVersion(api_version):
+            res = array.patch_dns(
+                names=[module.params["name"]],
+                dns=DnsPatch(
+                    domain=new_dns.domain,
+                    nameservers=new_dns.nameservers,
+                    source=ReferenceNoId(name=module.params["source"]),
+                ),
+                context_names=[module.params["context"]],
+            )
+        else:
+            res = array.patch_dns(
+                names=[module.params["name"]],
+                dns=DnsPatch(
+                    domain=new_dns.domain,
+                    nameservers=new_dns.nameservers,
+                    source=ReferenceNoId(name=module.params["source"]),
+                ),
+            )
         if res.status_code != 200:
             module.fail_json(
                 msg="Update to DNS service {0} failed. Error: {1}".format(
@@ -206,11 +266,19 @@ def update_multi_dns(module, array):
 def delete_multi_dns(module, array):
     """Delete a DNS configuration"""
     changed = True
+    api_version = array.get_rest_version()
     if module.params["name"] == "management":
-        res = array.patch_dns(
-            names=[module.params["name"]],
-            dns=flasharray.DnsPatch(domain="", nameservers=[]),
-        )
+        if LooseVersion(CONTEXT_API_VERSION) <= LooseVersion(api_version):
+            res = array.patch_dns(
+                names=[module.params["name"]],
+                dns=DnsPatch(domain="", nameservers=[]),
+                context_names=[module.params["context"]],
+            )
+        else:
+            res = array.patch_dns(
+                names=[module.params["name"]],
+                dns=DnsPatch(domain="", nameservers=[]),
+            )
         if res.status_code != 200:
             module.fail_json(
                 msg="Management DNS configuration not deleted. Error: {0}".format(
@@ -219,7 +287,13 @@ def delete_multi_dns(module, array):
             )
     else:
         if not module.check_mode:
-            res = array.delete_dns(names=[module.params["name"]])
+            if LooseVersion(CONTEXT_API_VERSION) <= LooseVersion(api_version):
+                res = array.delete_dns(
+                    names=[module.params["name"]],
+                    context_names=[module.params["context"]],
+                )
+            else:
+                res = array.delete_dns(names=[module.params["name"]])
             if res.status_code != 200:
                 module.fail_json(
                     msg="Failed to delete DNS configuration {0}. Error: {1}".format(
@@ -232,36 +306,71 @@ def delete_multi_dns(module, array):
 def create_multi_dns(module, array):
     """Create a DNS configuration"""
     changed = True
+    api_version = array.get_rest_version()
     if not module.check_mode:
         if module.params["service"] == "file":
             if module.params["source"]:
+                if LooseVersion(CONTEXT_API_VERSION) <= LooseVersion(api_version):
+                    res = array.post_dns(
+                        names=[module.params["name"]],
+                        dns=DnsPost(
+                            services=[module.params["service"]],
+                            domain=module.params["domain"],
+                            nameservers=module.params["nameservers"],
+                            source=ReferenceNoId(name=module.params["source"].lower()),
+                        ),
+                        context_names=[module.params["context"]],
+                    )
+                else:
+                    res = array.post_dns(
+                        names=[module.params["name"]],
+                        dns=DnsPost(
+                            services=[module.params["service"]],
+                            domain=module.params["domain"],
+                            nameservers=module.params["nameservers"],
+                            source=ReferenceNoId(name=module.params["source"].lower()),
+                        ),
+                    )
+            else:
+                if LooseVersion(CONTEXT_API_VERSION) <= LooseVersion(api_version):
+                    res = array.post_dns(
+                        names=[module.params["name"]],
+                        dns=DnsPost(
+                            services=[module.params["service"]],
+                            domain=module.params["domain"],
+                            nameservers=module.params["nameservers"],
+                        ),
+                        context_names=[module.params["context"]],
+                    )
+                else:
+                    res = array.post_dns(
+                        names=[module.params["name"]],
+                        dns=DnsPost(
+                            services=[module.params["service"]],
+                            domain=module.params["domain"],
+                            nameservers=module.params["nameservers"],
+                        ),
+                    )
+        else:
+            if LooseVersion(CONTEXT_API_VERSION) <= LooseVersion(api_version):
                 res = array.post_dns(
                     names=[module.params["name"]],
-                    dns=flasharray.DnsPost(
+                    dns=DnsPost(
                         services=[module.params["service"]],
                         domain=module.params["domain"],
                         nameservers=module.params["nameservers"],
-                        source=flasharray.ReferenceNoId(
-                            module.params["source"].lower()
-                        ),
                     ),
+                    context_names=[module.params["context"]],
                 )
             else:
                 res = array.post_dns(
                     names=[module.params["name"]],
-                    dns=flasharray.DnsPost(
+                    dns=DnsPost(
                         services=[module.params["service"]],
                         domain=module.params["domain"],
                         nameservers=module.params["nameservers"],
                     ),
                 )
-        else:
-            res = array.create_dns(
-                names=[module.params["name"]],
-                services=[module.params["service"]],
-                domain=module.params["domain"],
-                nameservers=module.params["nameservers"],
-            )
         if res.status_code != 200:
             module.fail_json(
                 msg="Failed to create {0} DNS configuration {1}. Error: {2}".format(
@@ -285,21 +394,21 @@ def main():
             domain=dict(type="str"),
             source=dict(type="str"),
             nameservers=dict(type="list", elements="str"),
+            context=dict(type="str", default=""),
         )
     )
 
     module = AnsibleModule(argument_spec, supports_check_mode=True)
 
     state = module.params["state"]
-    array = get_system(module)
-    api_version = array._list_available_rest_versions()
+    array = get_array(module)
+    api_version = array.get_rest_version()
     if module.params["nameservers"]:
         module.params["nameservers"] = remove(module.params["nameservers"])
         if module.params["service"] == "management":
             module.params["nameservers"] = module.params["nameservers"][0:3]
 
-    if MULTIPLE_DNS in api_version:
-        array = get_array(module)
+    if LooseVersion(MULTIPLE_DNS) <= LooseVersion(api_version):
         configs = list(array.get_dns().items)
         exists = False
         for config in range(0, len(configs)):
