@@ -44,13 +44,21 @@ options:
     description:
     - If messages that are necessary in order to audit TLS negotiations
       performed by the array are forwared to the syslog servers.
+  context:
+    description:
+    - Name of fleet member on which to perform the operation.
+    - This requires the array receiving the request is a member of a fleet
+      and the context name to be a member of the same fleet.
+    type: str
+    default: ""
+    version_added: '1.39.0'
 extends_documentation_fragment:
 - purestorage.flasharray.purestorage.fa
 """
 
 EXAMPLES = r"""
 - name: Change syslog servers settings
-  purestorage.flasharray.purefa_syslog_servers:
+  purestorage.flasharray.purefa_syslog_settings:
     tls_audit: false
     severity: debug
     ca_certificate: "{{lookup('file', 'example.crt') }}"
@@ -58,11 +66,10 @@ EXAMPLES = r"""
     api_token: e31060a7-21fc-e277-6240-25983c6c4592
 
 - name: Delete existing CA certifcate for syslog servers settings
-  purestorage.flasharray.purefa_syslog_servers:
+  purestorage.flasharray.purefa_syslog_settings:
     ca_certificate: DELETE
     fa_url: 10.10.10.2
     api_token: e31060a7-21fc-e277-6240-25983c6c4592
-
 """
 
 RETURN = r"""
@@ -84,6 +91,7 @@ from ansible_collections.purestorage.flasharray.plugins.module_utils.version imp
 )
 
 MIN_REQUIRED_API_VERSION = "2.9"
+CONTEXT_VERSION = "2.38"
 
 
 def main():
@@ -97,6 +105,7 @@ def main():
             ),
             tls_audit=dict(type="bool", default=True),
             ca_certificate=dict(type="str", no_log=True),
+            context=dict(type="str", default=""),
         )
     )
 
@@ -119,9 +128,16 @@ def main():
     changed = cert_change = False
     if module.params["ca_certificate"] and len(module.params["ca_certificate"]) > 3000:
         module.fail_json(msg="Certificate exceeds 3000 characters")
-    current = list(array.get_syslog_servers_settings().items)[0]
+    if LooseVersion(CONTEXT_VERSION) <= LooseVersion(api_version):
+        current = list(
+            array.get_syslog_servers_settings(
+                context_names=[module.params["context"]]
+            ).items
+        )[0]
+    else:
+        current = list(array.get_syslog_servers_settings().items)[0]
     try:
-        if current.ca_certificate:
+        if hasattr(current, "ca_certificate"):
             pass
     except AttributeError:
         current.ca_certificate = None
@@ -135,29 +151,51 @@ def main():
         new_sev = module.params["severity"]
     else:
         new_sev = current.logging_severity
+    new_cert = ""  # Initialize for pylint
     if module.params["ca_certificate"]:
         if module.params["ca_certificate"].upper() == "DELETE":
-            if current.ca_certificate:
+            if hasattr(current, "ca_certificate"):
                 cert_change = changed = True
                 new_cert = ""
-        elif current.ca_certificate != module.params["ca_certificate"]:
+        elif (
+            hasattr(current, "ca_certificate")
+            and current.ca_certificate != module.params["ca_certificate"]
+        ):
             cert_change = changed = True
             new_cert = module.params["ca_certificate"]
     if changed and not module.check_mode:
         if cert_change:
-            res = array.patch_syslog_servers_settings(
-                syslog_server_settings=flasharray.SyslogServerSettings(
-                    ca_certificate=new_cert,
-                    tls_audit_enabled=new_tls,
-                    logging_severity=new_sev,
+            if LooseVersion(CONTEXT_VERSION) <= LooseVersion(api_version):
+                res = array.patch_syslog_servers_settings(
+                    syslog_server_settings=flasharray.SyslogServerSettings(
+                        ca_certificate=new_cert,
+                        tls_audit_enabled=new_tls,
+                        logging_severity=new_sev,
+                    ),
+                    context_names=[module.params["context"]],
+                )
+            else:
+                res = array.patch_syslog_servers_settings(
+                    syslog_server_settings=flasharray.SyslogServerSettings(
+                        ca_certificate=new_cert,
+                        tls_audit_enabled=new_tls,
+                        logging_severity=new_sev,
+                    )
                 )
-            )
         else:
-            res = array.patch_syslog_servers_settings(
-                syslog_server_settings=flasharray.SyslogServerSettings(
-                    tls_audit_enabled=new_tls, logging_severity=new_sev
+            if LooseVersion(CONTEXT_VERSION) <= LooseVersion(api_version):
+                res = array.patch_syslog_servers_settings(
+                    context_names=[module.params["context"]],
+                    syslog_server_settings=flasharray.SyslogServerSettings(
+                        tls_audit_enabled=new_tls, logging_severity=new_sev
+                    ),
+                )
+            else:
+                res = array.patch_syslog_servers_settings(
+                    syslog_server_settings=flasharray.SyslogServerSettings(
+                        tls_audit_enabled=new_tls, logging_severity=new_sev
+                    )
                 )
-            )
         if res.status_code != 200:
             module.fail_json(
                 msg="Changing syslog settings failed. Error: {0}".format(
