@@ -31,10 +31,10 @@ author:
 options:
   state:
     description:
-    - Create or delete directory service configuration
+    - Create, delete or test directory service configuration
     default: present
     type: str
-    choices: [ absent, present ]
+    choices: [ absent, present, test ]
   dstype:
     description:
     - The type of directory service to work on
@@ -152,17 +152,18 @@ RETURN = r"""
 """
 
 
-NIS_API_VERSION = "1.7"
+NO_SMB_VERSION = "2.16"
+
 HAS_PURITY_FB = True
 try:
-    from purity_fb import DirectoryService
+    from pypureclient.flashblade import DirectoryService
 except ImportError:
     HAS_PURITY_FB = False
 
 
 from ansible.module_utils.basic import AnsibleModule
 from ansible_collections.purestorage.flashblade.plugins.module_utils.purefb import (
-    get_blade,
+    get_system,
     purefb_argument_spec,
 )
 
@@ -171,16 +172,14 @@ def enable_ds(module, blade):
     """Enable Directory Service"""
     changed = True
     if not module.check_mode:
-        try:
-            blade.directory_services.update_directory_services(
-                names=[module.params["dstype"]],
-                directory_service=DirectoryService(enabled=True),
-            )
-            changed = True
-        except Exception:
+        res = blade.patch_directory_services(
+            names=[module.params["dstype"]],
+            directory_service=DirectoryService(enabled=True),
+        )
+        if res.status_code != 200:
             module.fail_json(
-                msg="Enable {0} Directory Service failed".format(
-                    module.params["dstype"]
+                msg="Enable {0} Directory Service failed. Error: {1}".format(
+                    module.params["dstype"], res.errors[0].message
                 )
             )
     module.exit_json(changed=changed)
@@ -190,15 +189,14 @@ def disable_ds(module, blade):
     """Disable Directory Service"""
     changed = True
     if not module.check_mode:
-        try:
-            blade.directory_services.update_directory_services(
-                names=[module.params["dstype"]],
-                directory_service=DirectoryService(enabled=False),
-            )
-        except Exception:
+        res = blade.patch_directory_services(
+            names=[module.params["dstype"]],
+            directory_service=DirectoryService(enabled=False),
+        )
+        if res.status_code != 200:
             module.fail_json(
-                msg="Disable {0} Directory Service failed".format(
-                    module.params["dstype"]
+                msg="Disable {0} Directory Service failed. Error: {1}".format(
+                    module.params["dstype"], res.errors[0].message
                 )
             )
     module.exit_json(changed=changed)
@@ -208,59 +206,63 @@ def delete_ds(module, blade):
     """Delete Directory Service"""
     changed = True
     if not module.check_mode:
-        dirserv = blade.directory_services.list_directory_services(
-            names=[module.params["dstype"]]
-        )
-        try:
-            dir_service = DirectoryService()  # Initialize for pylint
-            if module.params["dstype"] == "management":
-                if dirserv.items[0].uris:
-                    dir_service = DirectoryService(
-                        uris=[""],
-                        base_dn="",
-                        bind_user="",
-                        bind_password="",
-                        enabled=False,
-                    )
-                else:
-                    changed = False
-            elif module.params["dstype"] == "smb":
-                if dirserv.items[0].uris:
-                    smb_attrs = {"join_ou": ""}
-                    dir_service = DirectoryService(
-                        uris=[""],
-                        base_dn="",
-                        bind_user="",
-                        bind_password="",
-                        smb=smb_attrs,
-                        enabled=False,
-                    )
-                else:
-                    changed = False
-            elif module.params["dstype"] == "nfs":
-                if dirserv.items[0].uris:
-                    dir_service = DirectoryService(
-                        uris=[""],
-                        base_dn="",
-                        bind_user="",
-                        bind_password="",
-                        enabled=False,
-                    )
-                elif dirserv.items[0].nfs.nis_domains:
-                    nfs_attrs = {"nis_domains": [], "nis_servers": []}
-                    dir_service = DirectoryService(nfs=nfs_attrs, enabled=False)
-                else:
-                    changed = False
-            if changed:
-                blade.directory_services.update_directory_services(
-                    names=[module.params["dstype"]], directory_service=dir_service
-                )
-        except Exception:
+        res = blade.get_directory_services(names=[module.params["dstype"]])
+        if res.status_code != 200:
             module.fail_json(
-                msg="Delete {0} Directory Service failed".format(
-                    module.params["dstype"]
+                msg="Fetch {0} Directory Service failed. Error: {1}".format(
+                    module.params["dstype"], res.errors[0].message
                 )
             )
+        dirserv = list(res.items)[0]
+        dir_service = DirectoryService()  # Initialize for pylint
+        if module.params["dstype"] == "management":
+            if dirserv.uris:
+                dir_service = DirectoryService(
+                    uris=[""],
+                    base_dn="",
+                    bind_user="",
+                    bind_password="",
+                    enabled=False,
+                )
+            else:
+                changed = False
+        elif module.params["dstype"] == "smb":
+            if dirserv.uris:
+                smb_attrs = {"join_ou": ""}
+                dir_service = DirectoryService(
+                    uris=[""],
+                    base_dn="",
+                    bind_user="",
+                    bind_password="",
+                    smb=smb_attrs,
+                    enabled=False,
+                )
+            else:
+                changed = False
+        elif module.params["dstype"] == "nfs":
+            if dirserv.uris:
+                dir_service = DirectoryService(
+                    uris=[""],
+                    base_dn="",
+                    bind_user="",
+                    bind_password="",
+                    enabled=False,
+                )
+            elif dirserv.nfs.nis_domains:
+                nfs_attrs = {"nis_domains": [], "nis_servers": []}
+                dir_service = DirectoryService(nfs=nfs_attrs, enabled=False)
+            else:
+                changed = False
+        if changed:
+            res = blade.patch_directory_services(
+                names=[module.params["dstype"]], directory_service=dir_service
+            )
+            if res.status_code != 200:
+                module.fail_json(
+                    msg="Delete {0} Directory Service failed. Error: {1}".format(
+                        module.params["dstype"], res.errors[0].message
+                    )
+                )
     module.exit_json(changed=changed)
 
 
@@ -270,75 +272,68 @@ def update_ds(module, blade):
     changed = False
     password_required = False
     attr = {}
-    try:
-        ds_now = blade.directory_services.list_directory_services(
-            names=[module.params["dstype"]]
-        ).items[0]
-        if module.params["dstype"] == "nfs" and module.params["nis_servers"]:
-            if sorted(module.params["nis_servers"]) != sorted(
-                ds_now.nfs.nis_servers
-            ) or module.params["nis_domain"] != "".join(
-                map(str, ds_now.nfs.nis_domains)
-            ):
-                attr["nfs"] = {
-                    "nis_domains": [module.params["nis_domain"]],
-                    "nis_servers": module.params["nis_servers"][0:30],
-                }
-                mod_ds = True
-        else:
-            if module.params["uri"]:
-                if sorted(module.params["uri"][0:30]) != sorted(ds_now.uris):
-                    attr["uris"] = module.params["uri"][0:30]
-                    mod_ds = True
-                    password_required = True
-            if module.params["base_dn"]:
-                if module.params["base_dn"] != ds_now.base_dn:
-                    attr["base_dn"] = module.params["base_dn"]
-                    mod_ds = True
-            if module.params["bind_user"]:
-                if module.params["bind_user"] != ds_now.bind_user:
-                    password_required = True
-                    attr["bind_user"] = module.params["bind_user"]
-                    mod_ds = True
-                elif module.params["force_bind_password"]:
-                    password_required = True
-                    mod_ds = True
-            if module.params["enable"]:
-                if module.params["enable"] != ds_now.enabled:
-                    attr["enabled"] = module.params["enable"]
-                    mod_ds = True
-            if password_required:
-                if module.params["bind_password"]:
-                    attr["bind_password"] = module.params["bind_password"]
-                    mod_ds = True
-                else:
-                    module.fail_json(
-                        msg="'bind_password' must be provided for this task"
-                    )
-            if module.params["dstype"] == "smb":
-                if module.params["join_ou"] != ds_now.smb.join_ou:
-                    attr["smb"] = {"join_ou": module.params["join_ou"]}
-                    mod_ds = True
-        if mod_ds:
-            changed = True
-            if not module.check_mode:
-                n_attr = DirectoryService(**attr)
-                try:
-                    blade.directory_services.update_directory_services(
-                        names=[module.params["dstype"]], directory_service=n_attr
-                    )
-                except Exception:
-                    module.fail_json(
-                        msg="Failed to change {0} directory service.".format(
-                            module.params["dstype"]
-                        )
-                    )
-    except Exception:
+    res = blade.get_directory_services(names=[module.params["dstype"]])
+    if res.status_code != 200:
         module.fail_json(
-            msg="Failed to get current {0} directory service.".format(
-                module.params["dstype"]
+            msg="Fetch {0} Directory Service failed. Error: {1}".format(
+                module.params["dstype"], res.errors[0].message
             )
         )
+    ds_now = list(res.items)[0]
+    if module.params["dstype"] == "nfs" and module.params["nis_servers"]:
+        if sorted(module.params["nis_servers"]) != sorted(
+            ds_now.nfs.nis_servers
+        ) or module.params["nis_domain"] != "".join(map(str, ds_now.nfs.nis_domains)):
+            attr["nfs"] = {
+                "nis_domains": [module.params["nis_domain"]],
+                "nis_servers": module.params["nis_servers"][0:30],
+            }
+            mod_ds = True
+    else:
+        if module.params["uri"]:
+            if sorted(module.params["uri"][0:30]) != sorted(ds_now.uris):
+                attr["uris"] = module.params["uri"][0:30]
+                mod_ds = True
+                password_required = True
+        if module.params["base_dn"]:
+            if module.params["base_dn"] != ds_now.base_dn:
+                attr["base_dn"] = module.params["base_dn"]
+                mod_ds = True
+        if module.params["bind_user"]:
+            if module.params["bind_user"] != ds_now.bind_user:
+                password_required = True
+                attr["bind_user"] = module.params["bind_user"]
+                mod_ds = True
+            elif module.params["force_bind_password"]:
+                password_required = True
+                mod_ds = True
+        if module.params["enable"]:
+            if module.params["enable"] != ds_now.enabled:
+                attr["enabled"] = module.params["enable"]
+                mod_ds = True
+        if password_required:
+            if module.params["bind_password"]:
+                attr["bind_password"] = module.params["bind_password"]
+                mod_ds = True
+            else:
+                module.fail_json(msg="'bind_password' must be provided for this task")
+        if module.params["dstype"] == "smb":
+            if module.params["join_ou"] != ds_now.smb.join_ou:
+                attr["smb"] = {"join_ou": module.params["join_ou"]}
+                mod_ds = True
+    if mod_ds:
+        changed = True
+        if not module.check_mode:
+            n_attr = DirectoryService(**attr)
+            res = blade.patch_directory_services(
+                names=[module.params["dstype"]], directory_service=n_attr
+            )
+            if res.status_code != 200:
+                module.fail_json(
+                    msg="Failed to change {0} directory service. Error: {1}".format(
+                        module.params["dstype"], res.errors[0].message
+                    )
+                )
     module.exit_json(changed=changed)
 
 
@@ -346,69 +341,99 @@ def create_ds(module, blade):
     """Create Directory Service"""
     changed = True
     if not module.check_mode:
-        try:
-            dir_service = DirectoryService()  # Initialize for pylint
-            if module.params["dstype"] == "management":
-                if module.params["uri"]:
-                    dir_service = DirectoryService(
-                        uris=module.params["uri"][0:30],
-                        base_dn=module.params["base_dn"],
-                        bind_user=module.params["bind_user"],
-                        bind_password=module.params["bind_password"],
-                        enabled=module.params["enable"],
+        dir_service = DirectoryService()  # Initialize for pylint
+        if module.params["dstype"] == "management":
+            if module.params["uri"]:
+                dir_service = DirectoryService(
+                    uris=module.params["uri"][0:30],
+                    base_dn=module.params["base_dn"],
+                    bind_user=module.params["bind_user"],
+                    bind_password=module.params["bind_password"],
+                    enabled=module.params["enable"],
+                )
+            else:
+                module.fail_json(
+                    msg="Incorrect parameters provided for dstype {0}".format(
+                        module.params["dstype"]
                     )
-                else:
-                    module.fail_json(
-                        msg="Incorrect parameters provided for dstype {0}".format(
-                            module.params["dstype"]
-                        )
+                )
+        elif module.params["dstype"] == "smb":
+            if module.params["uri"]:
+                smb_attrs = {"join_ou": module.params["join_ou"]}
+                dir_service = DirectoryService(
+                    uris=module.params["uri"][0:30],
+                    base_dn=module.params["base_dn"],
+                    bind_user=module.params["bind_user"],
+                    bind_password=module.params["bind_password"],
+                    smb=smb_attrs,
+                    enabled=module.params["enable"],
+                )
+            else:
+                module.fail_json(
+                    msg="Incorrect parameters provided for dstype {0}".format(
+                        module.params["dstype"]
                     )
-            elif module.params["dstype"] == "smb":
-                if module.params["uri"]:
-                    smb_attrs = {"join_ou": module.params["join_ou"]}
-                    dir_service = DirectoryService(
-                        uris=module.params["uri"][0:30],
-                        base_dn=module.params["base_dn"],
-                        bind_user=module.params["bind_user"],
-                        bind_password=module.params["bind_password"],
-                        smb=smb_attrs,
-                        enabled=module.params["enable"],
-                    )
-                else:
-                    module.fail_json(
-                        msg="Incorrect parameters provided for dstype {0}".format(
-                            module.params["dstype"]
-                        )
-                    )
-            elif module.params["dstype"] == "nfs":
-                if module.params["nis_domain"]:
-                    nfs_attrs = {
-                        "nis_domains": [module.params["nis_domain"]],
-                        "nis_servers": module.params["nis_servers"][0:30],
-                    }
-                    dir_service = DirectoryService(
-                        nfs=nfs_attrs, enabled=module.params["enable"]
-                    )
-                else:
-                    dir_service = DirectoryService(
-                        uris=module.params["uri"][0:30],
-                        base_dn=module.params["base_dn"],
-                        bind_user=module.params["bind_user"],
-                        bind_password=module.params["bind_password"],
-                        enabled=module.params["enable"],
-                    )
-            blade.directory_services.update_directory_services(
-                names=[module.params["dstype"]], directory_service=dir_service
-            )
-        except Exception:
+                )
+        elif module.params["dstype"] == "nfs":
+            if module.params["nis_domain"]:
+                nfs_attrs = {
+                    "nis_domains": [module.params["nis_domain"]],
+                    "nis_servers": module.params["nis_servers"][0:30],
+                }
+                dir_service = DirectoryService(
+                    nfs=nfs_attrs, enabled=module.params["enable"]
+                )
+            else:
+                dir_service = DirectoryService(
+                    uris=module.params["uri"][0:30],
+                    base_dn=module.params["base_dn"],
+                    bind_user=module.params["bind_user"],
+                    bind_password=module.params["bind_password"],
+                    enabled=module.params["enable"],
+                )
+        res = blade.patch_directory_services(
+            names=[module.params["dstype"]], directory_service=dir_service
+        )
+        if res.status_code != 200:
             module.fail_json(
-                msg="Create {0} Directory Service failed".format(
-                    module.params["dstype"]
+                msg="Create {0} Directory Service failed. Error: {1}".format(
+                    module.params["dstype"], res.errors[0].message
                 )
             )
     module.exit_json(changed=changed)
 
 
+def test_ds(module, blade):
+    """Test directory services configuration"""
+    test_response = []
+    response = list(
+        blade.get_directory_services_test(names=[module.params["dstype"]]).items
+    )
+    for component in range(len(response)):
+        if response[component].enabled:
+            enabled = "true"
+        else:
+            enabled = "false"
+        if response[component].success:
+            success = "true"
+        else:
+            success = "false"
+        test_response.append(
+            {
+                "component_address": response[component].component_address,
+                "component_name": response[component].component_name,
+                "description": response[component].description,
+                "destination": response[component].destination,
+                "enabled": enabled,
+                "result_details": getattr(response[component], "result_details", ""),
+                "success": success,
+                "test_type": response[component].test_type,
+                "resource_name": response[component].resource.name,
+            }
+        )
+    module.exit_json(changed=False, test_response=test_response)
+
+
 def main():
     argument_spec = purefb_argument_spec()
     argument_spec.update(
@@ -417,10 +442,12 @@ def main():
             dstype=dict(
                 required=True, type="str", choices=["management", "nfs", "smb"]
             ),
-            state=dict(type="str", default="present", choices=["absent", "present"]),
+            state=dict(
+                type="str", default="present", choices=["absent", "present", "test"]
+            ),
             enable=dict(type="bool", default=False),
             bind_password=dict(type="str", no_log=True),
-            force_bind_password=dict(type="bool", default=True),
+            force_bind_password=dict(type="bool", default=True, no_log=False),
             bind_user=dict(type="str"),
             base_dn=dict(type="str"),
             join_ou=dict(type="str"),
@@ -442,31 +469,28 @@ def main():
         supports_check_mode=True,
     )
     if not HAS_PURITY_FB:
-        module.fail_json(msg="purity_fb sdk is required for this module")
+        module.fail_json(msg="py-pure-client sdk is required for this module")
 
     state = module.params["state"]
-    blade = get_blade(module)
-    api_version = blade.api_version.list_versions().versions
+    blade = get_system(module)
+    api_version = list(blade.get_versions().items)
+    if NO_SMB_VERSION in api_version and module.params["dstype"] == "smb":
+        module.warn("Directory Service for SMB no longer supported by FlashBlade")
+        module.exit_json(changed=False)
     ds_configured = False
-    dirserv = blade.directory_services.list_directory_services(
-        names=[module.params["dstype"]]
-    )
-    ds_enabled = dirserv.items[0].enabled
-    if dirserv.items[0].base_dn is not None:
+    res = blade.get_directory_services(names=[module.params["dstype"]])
+    ds_configured = False
+    if res.status_code == 200:
         ds_configured = True
-    if (module.params["nis_domain"] or module.params["join_ou"]) and (
-        NIS_API_VERSION not in api_version
-    ):
-        module.fail_json(
-            msg="NFS or SMB directory service attributes not supported by FlashBlade Purity version"
-        )
+    dirserv = list(res.items)[0]
+    ds_enabled = dirserv.enabled
     ldap_uri = False
     set_ldap = False
-    for uri in range(0, len(dirserv.items[0].uris)):
-        if "ldap" in dirserv.items[0].uris[uri].lower():
+    for uri in range(len(dirserv.uris)):
+        if "ldap" in dirserv.uris[uri].lower():
             ldap_uri = True
     if module.params["uri"]:
-        for uri in range(0, len(module.params["uri"])):
+        for uri in range(len(module.params["uri"])):
             if "ldap" in module.params["uri"][uri].lower():
                 set_ldap = True
     if not module.params["uri"] and ldap_uri or module.params["uri"] and set_ldap:
@@ -486,6 +510,8 @@ def main():
         update_ds(module, blade)
     elif not ds_configured and state == "present":
         create_ds(module, blade)
+    elif state == "test":
+        test_ds(module, blade)
     else:
         module.exit_json(changed=False)
 
