@@ -8,14 +8,14 @@ from ansible_collections.vmware.vmware.plugins.modules.cluster_info import (
     ClusterInfo,
     main as module_main
 )
-from ansible_collections.vmware.vmware.plugins.module_utils.clients._pyvmomi import (
+from ansible_collections.vmware.vmware.plugins.module_utils.clients.pyvmomi import (
     PyvmomiClient
 )
 
-from .common.utils import (
-    AnsibleExitJson, ModuleTestCase, set_module_args
+from ...common.utils import (
+    run_module, ModuleTestCase
 )
-from .common.vmware_object_mocks import MockCluster
+from ...common.vmware_object_mocks import MockCluster
 
 pytestmark = pytest.mark.skipif(
     sys.version_info < (2, 7), reason="requires python2.7 or higher"
@@ -36,11 +36,5 @@ class TestClusterInfo(ModuleTestCase):
     def test_gather(self, mocker):
         self.__prepare(mocker)
 
-        set_module_args(
-            add_cluster=True,
-        )
-
-        with pytest.raises(AnsibleExitJson) as c:
-            module_main()
-
-        assert c.value.args[0]["changed"] is False
+        result = run_module(module_entry=module_main, module_args={'cluster': 'foo'})
+        assert result["changed"] is False
