@@ -6,8 +6,8 @@ import pytest
 
 from ansible_collections.vmware.vmware.plugins.modules import guest_info
 
-from .common.utils import (
-    AnsibleExitJson, ModuleTestCase, set_module_args,
+from ...common.utils import (
+    run_module, ModuleTestCase
 )
 
 pytestmark = pytest.mark.skipif(
@@ -27,14 +27,5 @@ class TestGuestInfo(ModuleTestCase):
     def test_gather(self, mocker):
         self.__prepare(mocker)
 
-        set_module_args(
-            hostname="127.0.0.1",
-            username="administrator@local",
-            password="123456",
-            add_cluster=False,
-        )
-
-        with pytest.raises(AnsibleExitJson) as c:
-            guest_info.main()
-
-        assert c.value.args[0]["changed"] is False
+        result = run_module(module_entry=guest_info.main, module_args={})
+        assert result["changed"] is False
